User provided AWS keys
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new AWS Credential
Delete a Credential from your account
Fetch the AWS credentials specified by the provided Credential Sid
Retrieves a collection of AWS Credentials belonging to the account used to make the request
Stream: Retrieves a collection of AWS Credentials belonging to the account used to make the request (lazy auto-pagination).
Modify the properties of a given Account
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Accounts.V1.Credential.AWS.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new AWS Credential
Operation: CreateCredentialAws | Tags: AccountsV1Aws
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Credentials | string | A string that contains the AWS access credentials in the format <AWS_ACCESS_KEY_ID>:<AWS_SECRET_ACCESS_KEY>. For example, AKIAIOSFODNN7EXAMPLE:wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| AccountSid | string | The SID of the Subaccount that this Credential should be associated with. Must be a valid Subaccount of the account issuing the request. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a Credential from your account
Operation: DeleteCredentialAws | Tags: AccountsV1Aws
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Accounts.V1.Credential.AWS.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch the AWS credentials specified by the provided Credential Sid
Operation: FetchCredentialAws | Tags: AccountsV1Aws
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieves a collection of AWS Credentials belonging to the account used to make the request
Operation: ListCredentialAws | Tags: AccountsV1Aws
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieves a collection of AWS Credentials belonging to the account used to make the request (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Accounts.V1.Credential.AWS.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Modify the properties of a given Account
Operation: UpdateCredentialAws | Tags: AccountsV1Aws
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |