Twilio.Accounts.V1.Credential.PublicKeyService (twilio_elixir v0.1.1)

Copy Markdown View Source

User provided public keys

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new Public Key Credential

Delete a Credential from your account

Fetch the public key specified by the provided Credential Sid

Retrieves a collection of Public Key Credentials belonging to the account used to make the request

Stream: Retrieves a collection of Public Key Credentials belonging to the account used to make the request (lazy auto-pagination).

Modify the properties of a given Account

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Accounts.V1.Credential.PublicKey.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Public Key Credential

Operation: CreateCredentialPublicKey | Tags: AccountsV1PublicKey

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| PublicKey | string | A URL encoded representation of the public key. For example, -----BEGIN PUBLIC KEY-----MIIBIjANB.pa9xQIDAQAB-----END PUBLIC KEY----- |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AccountSid | string | The SID of the Subaccount that this Credential should be associated with. Must be a valid Subaccount of the account issuing the request |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a Credential from your account

Operation: DeleteCredentialPublicKey | Tags: AccountsV1PublicKey

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Accounts.V1.Credential.PublicKey.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch the public key specified by the provided Credential Sid

Operation: FetchCredentialPublicKey | Tags: AccountsV1PublicKey

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieves a collection of Public Key Credentials belonging to the account used to make the request

Operation: ListCredentialPublicKey | Tags: AccountsV1PublicKey

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieves a collection of Public Key Credentials belonging to the account used to make the request (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Accounts.V1.Credential.PublicKey.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Modify the properties of a given Account

Operation: UpdateCredentialPublicKey | Tags: AccountsV1PublicKey

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |