Twilio.Accounts.V1.SafeList.NumberService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Number API operations.

Operations: list, create

Summary

Functions

Add a new phone number or phone number 1k prefix to SafeList.

Check if a phone number or phone number 1k prefix exists in SafeList.

Stream: Check if a phone number or phone number 1k prefix exists in SafeList. (lazy auto-pagination).

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Accounts.V1.SafeList.Number.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Add a new phone number or phone number 1k prefix to SafeList.

Operation: CreateSafelist | Tags: AccountsV1Safelist

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| PhoneNumber | string | The phone number or phone number 1k prefix to be added in SafeList. Phone numbers must be in E.164 format. |

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Check if a phone number or phone number 1k prefix exists in SafeList.

Operation: FetchSafelist | Tags: AccountsV1Safelist

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| PhoneNumber | string | The phone number or phone number 1k prefix to be fetched from SafeList. Phone numbers must be in E.164 format. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Check if a phone number or phone number 1k prefix exists in SafeList. (lazy auto-pagination).