Twilio.Api.V2010.AddressService (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

An Address instance resource represents your or your customer's physical location within a country. Around the world, some local authorities require the name and address of the user to be on file with Twilio to purchase and own a phone number.

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateAddress | Tags: Api20100401Address

Operation: DeleteAddress | Tags: Api20100401Address

Operation: FetchAddress | Tags: Api20100401Address

Operation: ListAddress | Tags: Api20100401Address

Stream: (lazy auto-pagination).

Operation: UpdateAddress | Tags: Api20100401Address

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Address.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateAddress | Tags: Api20100401Address

Required Parameters

ParameterTypeDescription
CitystringThe city of the new address.
CustomerNamestringThe name to associate with the new address.
IsoCountrystring (iso-country-code)The ISO country code of the new address.
PostalCodestringThe postal code of the new address.
RegionstringThe state or region of the new address.
StreetstringThe number and street address of the new address.

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AutoCorrectAddressbooleanWhether we should automatically correct the address. Can be: true or false and the default is true. If empty or true, we will correct the address you provide if necessary. If false, we won't alter the address you provide.
EmergencyEnabledbooleanWhether to enable emergency calling on the new address. Can be: true or false.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

FriendlyNamestringA descriptive string that you create to describe the new address. It can be up to 64 characters long for Regulatory Compliance addresses and 32 characters long for Emergency addresses.
StreetSecondarystringThe additional number and street address of the address.

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteAddress | Tags: Api20100401Address

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Address.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchAddress | Tags: Api20100401Address

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListAddress | Tags: Api20100401Address

Query Parameters

ParameterTypeDescription
CustomerNamestringThe customer_name of the Address resources to read.
FriendlyNamestringThe string that identifies the Address resources to read.
EmergencyEnabledbooleanWhether the address can be associated to a number for emergency calling.
IsoCountrystring (iso-country-code)The ISO country code of the Address resources to read.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Address.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateAddress | Tags: Api20100401Address

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AutoCorrectAddressbooleanWhether we should automatically correct the address. Can be: true or false and the default is true. If empty or true, we will correct the address you provide if necessary. If false, we won't alter the address you provide.
CitystringThe city of the address.
CustomerNamestringThe name to associate with the address.
EmergencyEnabledbooleanWhether to enable emergency calling on the address. Can be: true or false.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

FriendlyNamestringA descriptive string that you create to describe the new address. It can be up to 64 characters long for Regulatory Compliance addresses and 32 characters long for Emergency addresses.
PostalCodestringThe postal code of the address.
RegionstringThe state or region of the address.
StreetstringThe number and street address of the address.
StreetSecondarystringThe additional number and street address of the address.