Twilio.Api.V2010.AuthorizedConnectAppService (twilio_elixir v0.1.1)

Copy Markdown View Source

Authorized Twilio Connect apps

Operations: list, fetch

Summary

Functions

Fetch an instance of an authorized-connect-app

Retrieve a list of authorized-connect-apps belonging to the account used to make the request

Stream: Retrieve a list of authorized-connect-apps belonging to the account used to make the request (lazy auto-pagination).

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.AuthorizedConnectApp.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch an instance of an authorized-connect-app

Operation: FetchAuthorizedConnectApp | Tags: Api20100401AuthorizedConnectApp

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of authorized-connect-apps belonging to the account used to make the request

Operation: ListAuthorizedConnectApp | Tags: Api20100401AuthorizedConnectApp

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of authorized-connect-apps belonging to the account used to make the request (lazy auto-pagination).