Twilio.Api.V2010.AvailablePhoneNumber.VoipService (twilio_elixir v0.1.1)

Copy Markdown View Source

Available VoIP phone numbers

Operations: list

Summary

Functions

Operation: ListAvailablePhoneNumberVoip | Tags: Api20100401Voip

Functions

list(client, country_code, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListAvailablePhoneNumberVoip | Tags: Api20100401Voip

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AreaCode | integer | The area code of the phone numbers to read. Applies to only phone numbers in the US and Canada. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ContainsstringMatching pattern to identify phone numbers. This pattern can be between 2 and 16 characters long and allows all digits (0-9) and all non-diacritic latin alphabet letters (a-z, A-Z). It accepts four meta-characters: *, %, +, $. The * and % meta-characters can appear multiple times in the pattern. To match wildcards at the beginning or end of the pattern, use * to match any single character or % to match a sequence of characters. If you use the wildcard patterns, it must include at least two non-meta-characters, and wildcards cannot be used between non-meta-characters. To match the beginning of a pattern, start the pattern with +. To match the end of the pattern, append the pattern with $. These meta-characters can't be adjacent to each other.
SmsEnabledbooleanWhether the phone numbers can receive text messages. Can be: true or false.
MmsEnabledbooleanWhether the phone numbers can receive MMS messages. Can be: true or false.
VoiceEnabledbooleanWhether the phone numbers can receive calls. Can be: true or false.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ExcludeAllAddressRequired | boolean | Whether to exclude phone numbers that require an Address. Can be: true or false and the default is false. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ExcludeLocalAddressRequired | boolean | Whether to exclude phone numbers that require a local Address. Can be: true or false and the default is false. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ExcludeForeignAddressRequired | boolean | Whether to exclude phone numbers that require a foreign Address. Can be: true or false and the default is false. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Beta | boolean | Whether to read phone numbers that are new to the Twilio platform. Can be: true or false and the default is true. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| NearNumber | string (phone-number) | Given a phone number, find a geographically close number within distance miles. Distance defaults to 25 miles. Applies to only phone numbers in the US and Canada. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| NearLatLong | string | Given a latitude/longitude pair lat,long find geographically close numbers within distance miles. Applies to only phone numbers in the US and Canada. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Distance | integer | The search radius, in miles, for a near_ query. Can be up to 500 and the default is 25. Applies to only phone numbers in the US and Canada. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| InPostalCode | string | Limit results to a particular postal code. Given a phone number, search within the same postal code as that number. Applies to only phone numbers in the US and Canada. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| InRegion | string | Limit results to a particular region, state, or province. Given a phone number, search within the same region as that number. Applies to only phone numbers in the US and Canada. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| InRateCenter | string | Limit results to a specific rate center, or given a phone number search within the same rate center as that number. Requires in_lata to be set as well. Applies to only phone numbers in the US and Canada. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| InLata | string | Limit results to a specific local access and transport area (LATA). Given a phone number, search within the same LATA as that number. Applies to only phone numbers in the US and Canada. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

InLocalitystringLimit results to a particular locality or city. Given a phone number, search within the same Locality as that number.
FaxEnabledbooleanWhether the phone numbers can receive faxes. Can be: true or false.

stream(client, country_code, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).