Twilio.Api.V2010.Call.NotificationService (twilio_elixir v0.1.1)

Copy Markdown View Source

Error notifications for calls

Operations: list, fetch

Summary

Functions

Operation: FetchCallNotification | Tags: Api20100401CallNotification

Operation: ListCallNotification | Tags: Api20100401CallNotification

Stream: (lazy auto-pagination).

Functions

fetch(client, call_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Call.Notification.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchCallNotification | Tags: Api20100401CallNotification

list(client, call_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListCallNotification | Tags: Api20100401CallNotification

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Log | integer | Only read notifications of the specified log level. Can be: 0 to read only ERROR notifications or 1 to read only WARNING notifications. By default, all notifications are read. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessageDate | string (date) | Only show notifications for the specified date, formatted as YYYY-MM-DD. You can also specify an inequality, such as <=YYYY-MM-DD for messages logged at or before midnight on a date, or >=YYYY-MM-DD for messages logged at or after midnight on a date. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessageDate< | string (date) | Only show notifications for the specified date, formatted as YYYY-MM-DD. You can also specify an inequality, such as <=YYYY-MM-DD for messages logged at or before midnight on a date, or >=YYYY-MM-DD for messages logged at or after midnight on a date. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessageDate> | string (date) | Only show notifications for the specified date, formatted as YYYY-MM-DD. You can also specify an inequality, such as <=YYYY-MM-DD for messages logged at or before midnight on a date, or >=YYYY-MM-DD for messages logged at or after midnight on a date. |

stream(client, call_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).