Twilio.Api.V2010.Call.TranscriptionService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Transcription API operations.

Operations: create, update

Summary

Functions

Stop a Transcription using either the SID of the Transcription resource or the name used when creating the resource

Functions

create(client, call_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Call.Transcription.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a Transcription

Operation: CreateRealtimeTranscription | Tags: Api20100401CallTranscription

Optional Parameters

ParameterTypeDescription
EnableAutomaticPunctuationbooleanThe provider will add punctuation to recognition result
EnableProviderDatabooleanWhether the callback includes raw provider data.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

HintsstringA Phrase contains words and phrase "hints" so that the speech recognition engine is more likely to recognize them.
InboundTrackLabelstringFriendly name given to the Inbound Track

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| IntelligenceService | string | The SID or unique name of the Intelligence Service for persisting transcripts and running post-call Language Operators |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LanguageCode | string | Language code used by the transcription engine, specified in BCP-47 format |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

NamestringThe user-specified name of this Transcription, if one was given when the Transcription was created. This may be used to stop the Transcription.
OutboundTrackLabelstringFriendly name given to the Outbound Track
PartialResultsbooleanIndicates if partial results are going to be sent to the customer

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ProfanityFilterbooleanindicates if the server will attempt to filter out profanities, replacing all but the initial character in each filtered word with asterisks
SpeechModelstringRecognition model used by the transcription engine, among those supported by the provider

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

StatusCallbackMethodstring (http-method)The http method for the status_callback (one of GET, POST). Values: GET, POST
StatusCallbackUrlstring (uri)Absolute URL of the status callback.
TrackstringValues: inbound_track, outbound_track, both_tracks

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| TranscriptionEngine | string | Definition of the transcription engine to be used, among those supported by Twilio |

update(client, call_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Call.Transcription.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Stop a Transcription using either the SID of the Transcription resource or the name used when creating the resource

Operation: UpdateRealtimeTranscription | Tags: Api20100401CallTranscription

Required Parameters

ParameterTypeDescription
StatusstringValues: stopped