Twilio.Api.V2010.Call.UserDefinedMessageSubscriptionService (twilio_elixir v0.1.1)

Copy Markdown View Source

Subscription for server-side application access to messages sent from the Voice SDK for an active Call.

Operations: create, delete

Summary

Functions

Subscribe to User Defined Messages for a given Call SID.

Delete a specific User Defined Message Subscription.

Functions

create(client, call_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Call.UserDefinedMessageSubscription.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Subscribe to User Defined Messages for a given Call SID.

Operation: CreateUserDefinedMessageSubscription | Tags: Api20100401UserDefinedMessageSubscription

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Callback | string (uri) | The URL we should call using the method to send user defined events to your application. URLs must contain a valid hostname (underscores are not permitted). |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| IdempotencyKey | string | A unique string value to identify API call. This should be a unique string value per API call and can be a randomly generated. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Method | string (http-method) | The HTTP method Twilio will use when requesting the above Url. Either GET or POST. Default is POST. Values: GET, POST |

delete(client, call_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific User Defined Message Subscription.

Operation: DeleteUserDefinedMessageSubscription | Tags: Api20100401UserDefinedMessageSubscription