Twilio.Api.V2010.ConferenceService (twilio_elixir v0.1.1)

Copy Markdown View Source

Voice call conferences

Operations: list, fetch, update

Summary

Functions

Fetch an instance of a conference

Retrieve a list of conferences belonging to the account used to make the request

Stream: Retrieve a list of conferences belonging to the account used to make the request (lazy auto-pagination).

Operation: UpdateConference | Tags: Api20100401Conference

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Conference.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch an instance of a conference

Operation: FetchConference | Tags: Api20100401Conference

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of conferences belonging to the account used to make the request

Operation: ListConference | Tags: Api20100401Conference

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreated | string (date) | Only include conferences that were created on this date. Specify a date as YYYY-MM-DD in UTC, for example: 2009-07-06, to read only conferences that were created on this date. You can also specify an inequality, such as DateCreated<=YYYY-MM-DD, to read conferences that were created on or before midnight of this date, and DateCreated>=YYYY-MM-DD to read conferences that were created on or after midnight of this date. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreated< | string (date) | Only include conferences that were created on this date. Specify a date as YYYY-MM-DD in UTC, for example: 2009-07-06, to read only conferences that were created on this date. You can also specify an inequality, such as DateCreated<=YYYY-MM-DD, to read conferences that were created on or before midnight of this date, and DateCreated>=YYYY-MM-DD to read conferences that were created on or after midnight of this date. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreated> | string (date) | Only include conferences that were created on this date. Specify a date as YYYY-MM-DD in UTC, for example: 2009-07-06, to read only conferences that were created on this date. You can also specify an inequality, such as DateCreated<=YYYY-MM-DD, to read conferences that were created on or before midnight of this date, and DateCreated>=YYYY-MM-DD to read conferences that were created on or after midnight of this date. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateUpdated | string (date) | Only include conferences that were last updated on this date. Specify a date as YYYY-MM-DD in UTC, for example: 2009-07-06, to read only conferences that were last updated on this date. You can also specify an inequality, such as DateUpdated<=YYYY-MM-DD, to read conferences that were last updated on or before midnight of this date, and DateUpdated>=YYYY-MM-DD to read conferences that were last updated on or after midnight of this date. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateUpdated< | string (date) | Only include conferences that were last updated on this date. Specify a date as YYYY-MM-DD in UTC, for example: 2009-07-06, to read only conferences that were last updated on this date. You can also specify an inequality, such as DateUpdated<=YYYY-MM-DD, to read conferences that were last updated on or before midnight of this date, and DateUpdated>=YYYY-MM-DD to read conferences that were last updated on or after midnight of this date. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DateUpdated>string (date)Only include conferences that were last updated on this date. Specify a date as YYYY-MM-DD in UTC, for example: 2009-07-06, to read only conferences that were last updated on this date. You can also specify an inequality, such as DateUpdated<=YYYY-MM-DD, to read conferences that were last updated on or before midnight of this date, and DateUpdated>=YYYY-MM-DD to read conferences that were last updated on or after midnight of this date.
FriendlyNamestringThe string that identifies the Conference resources to read.
StatusstringThe status of the resources to read. Can be: init, in-progress, or completed.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of conferences belonging to the account used to make the request (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Conference.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateConference | Tags: Api20100401Conference

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AnnounceMethod | string (http-method) | The HTTP method used to call announce_url. Can be: GET or POST and the default is POST Values: GET, POST |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AnnounceUrlstring (uri)The URL we should call to announce something into the conference. The URL may return an MP3 file, a WAV file, or a TwiML document that contains <Play>, <Say>, <Pause>, or <Redirect> verbs.
StatusstringValues: completed