Twilio.Api.V2010.Message.FeedbackService (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

The MessageFeedback subresource of a Message resource. MessageFeedback contains the reported outcome of whether the Message recipient performed a tracked user action.

Operations: create

Summary

Functions

Create Message Feedback to confirm a tracked user action was performed by the recipient of the associated Message

Functions

create(client, message_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Message.Feedback.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create Message Feedback to confirm a tracked user action was performed by the recipient of the associated Message

Operation: CreateMessageFeedback | Tags: Api20100401Feedback

Optional Parameters

ParameterTypeDescription
OutcomestringValues: confirmed, unconfirmed