Twilio.Api.V2010.NotificationService (twilio_elixir v0.1.1)

Copy Markdown View Source

[DEPRECATED] Log entries

Operations: list, fetch

Summary

Functions

Fetch a notification belonging to the account used to make the request

Retrieve a list of notifications belonging to the account used to make the request

Stream: Retrieve a list of notifications belonging to the account used to make the request (lazy auto-pagination).

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Notification.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a notification belonging to the account used to make the request

Operation: FetchNotification | Tags: Api20100401Notification

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of notifications belonging to the account used to make the request

Operation: ListNotification | Tags: Api20100401Notification

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Log | integer | Only read notifications of the specified log level. Can be: 0 to read only ERROR notifications or 1 to read only WARNING notifications. By default, all notifications are read. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessageDate | string (date) | Only show notifications for the specified date, formatted as YYYY-MM-DD. You can also specify an inequality, such as <=YYYY-MM-DD for messages logged at or before midnight on a date, or >=YYYY-MM-DD for messages logged at or after midnight on a date. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessageDate< | string (date) | Only show notifications for the specified date, formatted as YYYY-MM-DD. You can also specify an inequality, such as <=YYYY-MM-DD for messages logged at or before midnight on a date, or >=YYYY-MM-DD for messages logged at or after midnight on a date. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessageDate> | string (date) | Only show notifications for the specified date, formatted as YYYY-MM-DD. You can also specify an inequality, such as <=YYYY-MM-DD for messages logged at or before midnight on a date, or >=YYYY-MM-DD for messages logged at or after midnight on a date. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of notifications belonging to the account used to make the request (lazy auto-pagination).