Twilio.Api.V2010.Queue.MemberService (twilio_elixir v0.1.1)

Copy Markdown View Source

Calls in a call queue

Operations: list, fetch, update

Summary

Functions

Fetch a specific member from the queue

Retrieve the members of the queue

Stream: Retrieve the members of the queue (lazy auto-pagination).

Dequeue a member from a queue and have the member's call begin executing the TwiML document at that URL

Functions

fetch(client, queue_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Queue.Member.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific member from the queue

Operation: FetchMember | Tags: Api20100401Member

list(client, queue_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve the members of the queue

Operation: ListMember | Tags: Api20100401Member

stream(client, queue_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve the members of the queue (lazy auto-pagination).

update(client, queue_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Queue.Member.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Dequeue a member from a queue and have the member's call begin executing the TwiML document at that URL

Operation: UpdateMember | Tags: Api20100401Member

Required Parameters

ParameterTypeDescription
Urlstring (uri)The absolute URL of the Queue resource.

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Method | string (http-method) | How to pass the update request data. Can be GET or POST and the default is POST. POST sends the data as encoded form data and GET sends the data as query parameters. Values: GET, POST |