Twilio.Api.V2010.Recording.AddOnResultService (twilio_elixir v0.1.1)

Copy Markdown View Source

The results of an Add-on API call

Operations: list, fetch, delete

Summary

Functions

Delete a result and purge all associated Payloads

Fetch an instance of an AddOnResult

Retrieve a list of results belonging to the recording

Stream: Retrieve a list of results belonging to the recording (lazy auto-pagination).

Functions

delete(client, reference_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a result and purge all associated Payloads

Operation: DeleteRecordingAddOnResult | Tags: Api20100401AddOnResult

fetch(client, reference_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Recording.AddOnResult.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch an instance of an AddOnResult

Operation: FetchRecordingAddOnResult | Tags: Api20100401AddOnResult

list(client, reference_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of results belonging to the recording

Operation: ListRecordingAddOnResult | Tags: Api20100401AddOnResult

stream(client, reference_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of results belonging to the recording (lazy auto-pagination).