Twilio.Api.V2010.RecordingService (twilio_elixir v0.1.1)

Copy Markdown View Source

Recordings of phone calls

Operations: list, fetch, delete

Summary

Functions

Delete a recording from your account

Fetch an instance of a recording

Retrieve a list of recordings belonging to the account used to make the request

Stream: Retrieve a list of recordings belonging to the account used to make the request (lazy auto-pagination).

Functions

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a recording from your account

Operation: DeleteRecording | Tags: Api20100401Recording

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Recording.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch an instance of a recording

Operation: FetchRecording | Tags: Api20100401Recording

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| IncludeSoftDeleted | boolean | A boolean parameter indicating whether to retrieve soft deleted recordings or not. Recordings metadata are kept after deletion for a retention period of 40 days. |

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of recordings belonging to the account used to make the request

Operation: ListRecording | Tags: Api20100401Recording

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreated | string (date-time) | Only include recordings that were created on this date. Specify a date as YYYY-MM-DD in GMT, for example: 2009-07-06, to read recordings that were created on this date. You can also specify an inequality, such as DateCreated<=YYYY-MM-DD, to read recordings that were created on or before midnight of this date, and DateCreated>=YYYY-MM-DD to read recordings that were created on or after midnight of this date. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreated< | string (date-time) | Only include recordings that were created on this date. Specify a date as YYYY-MM-DD in GMT, for example: 2009-07-06, to read recordings that were created on this date. You can also specify an inequality, such as DateCreated<=YYYY-MM-DD, to read recordings that were created on or before midnight of this date, and DateCreated>=YYYY-MM-DD to read recordings that were created on or after midnight of this date. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DateCreated>string (date-time)Only include recordings that were created on this date. Specify a date as YYYY-MM-DD in GMT, for example: 2009-07-06, to read recordings that were created on this date. You can also specify an inequality, such as DateCreated<=YYYY-MM-DD, to read recordings that were created on or before midnight of this date, and DateCreated>=YYYY-MM-DD to read recordings that were created on or after midnight of this date.
CallSidstringThe Call SID of the resources to read.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ConferenceSid | string | The Conference SID that identifies the conference associated with the recording to read. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| IncludeSoftDeleted | boolean | A boolean parameter indicating whether to retrieve soft deleted recordings or not. Recordings metadata are kept after deletion for a retention period of 40 days. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of recordings belonging to the account used to make the request (lazy auto-pagination).