Twilio.Api.V2010.SIP.Domain.Auth.Call.AuthCallsIpAccessControlListMappingService (twilio_elixir v0.1.1)

Copy Markdown View Source

IP address lists for SIP calls

Operations: list, create, fetch, delete

Summary

Functions

Create a new IP Access Control List mapping

Delete an IP Access Control List mapping from the requested domain

Fetch a specific instance of an IP Access Control List mapping

Retrieve a list of IP Access Control List mappings belonging to the domain used in the request

Stream: Retrieve a list of IP Access Control List mappings belonging to the domain used in the request (lazy auto-pagination).

Functions

create(client, domain_sid, params \\ %{}, opts \\ [])

Create a new IP Access Control List mapping

Operation: CreateSipAuthCallsIpAccessControlListMapping | Tags: Api20100401AuthCallsIpAccessControlListMapping

Required Parameters

ParameterTypeDescription
IpAccessControlListSidstringThe SID of the IpAccessControlList resource to map to the SIP domain.

delete(client, domain_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete an IP Access Control List mapping from the requested domain

Operation: DeleteSipAuthCallsIpAccessControlListMapping | Tags: Api20100401AuthCallsIpAccessControlListMapping

fetch(client, domain_sid, sid, opts \\ [])

Fetch a specific instance of an IP Access Control List mapping

Operation: FetchSipAuthCallsIpAccessControlListMapping | Tags: Api20100401AuthCallsIpAccessControlListMapping

list(client, domain_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of IP Access Control List mappings belonging to the domain used in the request

Operation: ListSipAuthCallsIpAccessControlListMapping | Tags: Api20100401AuthCallsIpAccessControlListMapping

stream(client, domain_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of IP Access Control List mappings belonging to the domain used in the request (lazy auto-pagination).