Twilio.Api.V2010.SIP.IpAccessControlListService (twilio_elixir v0.1.1)

Copy Markdown View Source

Access control lists of IP address resources

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new IpAccessControlList resource

Delete an IpAccessControlList from the requested account

Fetch a specific instance of an IpAccessControlList

Retrieve a list of IpAccessControlLists that belong to the account used to make the request

Stream: Retrieve a list of IpAccessControlLists that belong to the account used to make the request (lazy auto-pagination).

Rename an IpAccessControlList

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.SIP.IpAccessControlList.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new IpAccessControlList resource

Operation: CreateSipIpAccessControlList | Tags: Api20100401IpAccessControlList

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A human readable descriptive text that describes the IpAccessControlList, up to 255 characters long. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete an IpAccessControlList from the requested account

Operation: DeleteSipIpAccessControlList | Tags: Api20100401IpAccessControlList

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.SIP.IpAccessControlList.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific instance of an IpAccessControlList

Operation: FetchSipIpAccessControlList | Tags: Api20100401IpAccessControlList

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of IpAccessControlLists that belong to the account used to make the request

Operation: ListSipIpAccessControlList | Tags: Api20100401IpAccessControlList

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of IpAccessControlLists that belong to the account used to make the request (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.SIP.IpAccessControlList.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Rename an IpAccessControlList

Operation: UpdateSipIpAccessControlList | Tags: Api20100401IpAccessControlList

Required Parameters

ParameterTypeDescription
FriendlyNamestringA human readable descriptive text, up to 255 characters long.