Twilio.Api.V2010.TranscriptionService (twilio_elixir v0.1.1)

Copy Markdown View Source

Text transcriptions of call recordings

Operations: list, fetch, delete

Summary

Functions

Delete a transcription from the account used to make the request

Fetch an instance of a Transcription

Retrieve a list of transcriptions belonging to the account used to make the request

Stream: Retrieve a list of transcriptions belonging to the account used to make the request (lazy auto-pagination).

Functions

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a transcription from the account used to make the request

Operation: DeleteTranscription | Tags: Api20100401Transcription

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Api.V2010.Transcription.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch an instance of a Transcription

Operation: FetchTranscription | Tags: Api20100401Transcription

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of transcriptions belonging to the account used to make the request

Operation: ListTranscription | Tags: Api20100401Transcription

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of transcriptions belonging to the account used to make the request (lazy auto-pagination).