Credentials for push notifications channels
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateCredential | Tags: ChatV1Credential
Operation: DeleteCredential | Tags: ChatV1Credential
Operation: FetchCredential | Tags: ChatV1Credential
Operation: ListCredential | Tags: ChatV1Credential
Stream: (lazy auto-pagination).
Operation: UpdateCredential | Tags: ChatV1Credential
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V1.Credential.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateCredential | Tags: ChatV1Credential
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Type | string | Values: gcm, apn, fcm |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ApiKey | string | [GCM only] The API key for the project that was obtained from the Google Developer console for your GCM Service application credential. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Certificate | string | [APN only] The URL encoded representation of the certificate. For example, -----BEGIN CERTIFICATE----- MIIFnTCCBIWgAwIBAgIIAjy9H849+E8wDQYJKoZIhvcNAQEFBQAwgZYxCzAJBgNV.....A== -----END CERTIFICATE----- |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the new resource. It can be up to 64 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| PrivateKey | string | [APN only] The URL encoded representation of the private key. For example, -----BEGIN RSA PRIVATE KEY----- MIIEpQIBAAKCAQEAuyf/lNrH9ck8DmNyo3fGgvCI1l9s+cmBY3WIz+cUDqmxiieR. -----END RSA PRIVATE KEY----- |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Sandbox | boolean | [APN only] Whether to send the credential to sandbox APNs. Can be true to send to sandbox APNs or false to send to production. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Secret | string | [FCM only] The Server key of your project from the Firebase console, found under Settings / Cloud messaging. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteCredential | Tags: ChatV1Credential
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Chat.V1.Credential.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchCredential | Tags: ChatV1Credential
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListCredential | Tags: ChatV1Credential
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V1.Credential.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateCredential | Tags: ChatV1Credential
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ApiKey | string | [GCM only] The API key for the project that was obtained from the Google Developer console for your GCM Service application credential. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Certificate | string | [APN only] The URL encoded representation of the certificate. For example, -----BEGIN CERTIFICATE----- MIIFnTCCBIWgAwIBAgIIAjy9H849+E8wDQYJKoZIhvcNAQEFBQAwgZYxCzAJBgNV.....A== -----END CERTIFICATE----- |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| PrivateKey | string | [APN only] The URL encoded representation of the private key. For example, -----BEGIN RSA PRIVATE KEY----- MIIEpQIBAAKCAQEAuyf/lNrH9ck8DmNyo3fGgvCI1l9s+cmBY3WIz+cUDqmxiieR. -----END RSA PRIVATE KEY----- |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Sandbox | boolean | [APN only] Whether to send the credential to sandbox APNs. Can be true to send to sandbox APNs or false to send to production. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Secret | string | [FCM only] The Server key of your project from the Firebase console, found under Settings / Cloud messaging. |