Twilio.Chat.V1.Service.Channel.MemberService (twilio_elixir v0.1.1)

Copy Markdown View Source

Users joined to specific channels

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateMember | Tags: ChatV1Member

Operation: DeleteMember | Tags: ChatV1Member

Operation: FetchMember | Tags: ChatV1Member

Operation: ListMember | Tags: ChatV1Member

Functions

create(client, service_sid, channel_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V1.Service.Channel.Member.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateMember | Tags: ChatV1Member

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | string | The identity value that uniquely identifies the new resource's User within the Service. See access tokens for more details. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| RoleSid | string | The SID of the Role to assign to the member. The default roles are those specified on the Service. |

delete(client, service_sid, channel_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteMember | Tags: ChatV1Member

fetch(client, service_sid, channel_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V1.Service.Channel.Member.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchMember | Tags: ChatV1Member

list(client, service_sid, channel_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListMember | Tags: ChatV1Member

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | array | The User's identity value of the resources to read. See access tokens for more details. |

stream(client, service_sid, channel_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: (lazy auto-pagination).

update(client, service_sid, channel_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V1.Service.Channel.Member.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateMember | Tags: ChatV1Member

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LastConsumedMessageIndex | integer | The index of the last Message that the Member has read within the Channel. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| RoleSid | string | The SID of the Role to assign to the member. The default roles are those specified on the Service. |