Twilio.Chat.V1.Service.UserService (twilio_elixir v0.1.1)

Copy Markdown View Source

Unique chat users within a chat service

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateUser | Tags: ChatV1User

Operation: DeleteUser | Tags: ChatV1User

Operation: FetchUser | Tags: ChatV1User

Operation: ListUser | Tags: ChatV1User

Operation: UpdateUser | Tags: ChatV1User

Functions

create(client, service_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V1.Service.User.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateUser | Tags: ChatV1User

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | string | The identity value that uniquely identifies the new resource's User within the Service. This value is often a username or email address. See the Identity documentation for more details. |

Optional Parameters

ParameterTypeDescription
AttributesstringA valid JSON string that contains application-specific data.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the new resource. This value is often used for display purposes. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| RoleSid | string | The SID of the Role assigned to the new User. |

delete(client, service_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteUser | Tags: ChatV1User

fetch(client, service_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V1.Service.User.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchUser | Tags: ChatV1User

list(client, service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListUser | Tags: ChatV1User

stream(client, service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, service_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V1.Service.User.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateUser | Tags: ChatV1User

Optional Parameters

ParameterTypeDescription
AttributesstringA valid JSON string that contains application-specific data.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

FriendlyNamestringA descriptive string that you create to describe the resource. It is often used for display purposes.
RoleSidstringThe SID of the Role assigned to this user.