Twilio.Chat.V2.Service.Channel.MemberService (twilio_elixir v0.1.1)

Copy Markdown View Source

Users joined to specific channels

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateMember | Tags: ChatV2Member

Operation: DeleteMember | Tags: ChatV2Member

Operation: FetchMember | Tags: ChatV2Member

Operation: ListMember | Tags: ChatV2Member

Functions

create(client, service_sid, channel_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V2.Service.Channel.Member.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateMember | Tags: ChatV2Member

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | string | The identity value that uniquely identifies the new resource's User within the Service. See access tokens for more info. |

Optional Parameters

ParameterTypeDescription
AttributesstringA valid JSON string that contains application-specific data.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreated | string (date-time) | The date, specified in ISO 8601 format, to assign to the resource as the date it was created. The default value is the current time set by the Chat service. Note that this parameter should only be used when a Member is being recreated from a backup/separate source. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateUpdated | string (date-time) | The date, specified in ISO 8601 format, to assign to the resource as the date it was last updated. The default value is null. Note that this parameter should only be used when a Member is being recreated from a backup/separate source and where a Member was previously updated. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LastConsumedMessageIndex | integer | The index of the last Message in the Channel that the Member has read. This parameter should only be used when recreating a Member from a backup/separate source. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LastConsumptionTimestamp | string (date-time) | The ISO 8601 timestamp of the last Message read event for the Member within the Channel. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| RoleSid | string | The SID of the Role to assign to the member. The default roles are those specified on the Service. |

delete(client, service_sid, channel_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteMember | Tags: ChatV2Member

fetch(client, service_sid, channel_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V2.Service.Channel.Member.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchMember | Tags: ChatV2Member

list(client, service_sid, channel_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListMember | Tags: ChatV2Member

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | array | The User's identity value of the Member resources to read. See access tokens for more details. |

stream(client, service_sid, channel_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: (lazy auto-pagination).

update(client, service_sid, channel_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V2.Service.Channel.Member.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateMember | Tags: ChatV2Member

Optional Parameters

ParameterTypeDescription
AttributesstringA valid JSON string that contains application-specific data.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreated | string (date-time) | The date, specified in ISO 8601 format, to assign to the resource as the date it was created. The default value is the current time set by the Chat service. Note that this parameter should only be used when a Member is being recreated from a backup/separate source. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateUpdated | string (date-time) | The date, specified in ISO 8601 format, to assign to the resource as the date it was last updated. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LastConsumedMessageIndex | integer | The index of the last Message that the Member has read within the Channel. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LastConsumptionTimestamp | string (date-time) | The ISO 8601 timestamp of the last Message read event for the Member within the Channel. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| RoleSid | string | The SID of the Role to assign to the member. The default roles are those specified on the Service. |