Twilio.Chat.V2.Service.Channel.MessageService (twilio_elixir v0.1.1)

Copy Markdown View Source

Individual chat messages

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateMessage | Tags: ChatV2Message

Operation: DeleteMessage | Tags: ChatV2Message

Operation: FetchMessage | Tags: ChatV2Message

Operation: ListMessage | Tags: ChatV2Message

Operation: UpdateMessage | Tags: ChatV2Message

Functions

create(client, service_sid, channel_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V2.Service.Channel.Message.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateMessage | Tags: ChatV2Message

Optional Parameters

ParameterTypeDescription
AttributesstringA valid JSON string that contains application-specific data.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Body | string | The message to send to the channel. Can be an empty string or null, which sets the value as an empty string. You can send structured data in the body by serializing it as a string. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreated | string (date-time) | The date, specified in ISO 8601 format, to assign to the resource as the date it was created. The default value is the current time set by the Chat service. This parameter should only be used when a Chat's history is being recreated from a backup/separate source. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateUpdated | string (date-time) | The date, specified in ISO 8601 format, to assign to the resource as the date it was last updated. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| From | string | The Identity of the new message's author. The default value is system. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LastUpdatedBy | string | The Identity of the User who last updated the Message, if applicable. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MediaSid | string | The SID of the Media to attach to the new Message. |

delete(client, service_sid, channel_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteMessage | Tags: ChatV2Message

fetch(client, service_sid, channel_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V2.Service.Channel.Message.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchMessage | Tags: ChatV2Message

list(client, service_sid, channel_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListMessage | Tags: ChatV2Message

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Order | string | The sort order of the returned messages. Can be: asc (ascending) or desc (descending) with asc as the default. |

stream(client, service_sid, channel_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: (lazy auto-pagination).

update(client, service_sid, channel_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V2.Service.Channel.Message.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateMessage | Tags: ChatV2Message

Optional Parameters

ParameterTypeDescription
AttributesstringA valid JSON string that contains application-specific data.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Body | string | The message to send to the channel. Can be an empty string or null, which sets the value as an empty string. You can send structured data in the body by serializing it as a string. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreated | string (date-time) | The date, specified in ISO 8601 format, to assign to the resource as the date it was created. The default value is the current time set by the Chat service. This parameter should only be used when a Chat's history is being recreated from a backup/separate source. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DateUpdatedstring (date-time)The date, specified in ISO 8601 format, to assign to the resource as the date it was last updated.
FromstringThe Identity of the message's author.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LastUpdatedBy | string | The Identity of the User who last updated the Message, if applicable. |