Twilio.Chat.V2.Service.User.ChannelService (twilio_elixir v0.1.1)

Copy Markdown View Source

List of channels for a given user

Operations: list, fetch, update, delete

Summary

Functions

Removes User from selected Channel.

Operation: FetchUserChannel | Tags: ChatV2UserChannel

Stream: List all Channels for a given User. (lazy auto-pagination).

Operation: UpdateUserChannel | Tags: ChatV2UserChannel

Functions

delete(client, service_sid, user_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Removes User from selected Channel.

Operation: DeleteUserChannel | Tags: ChatV2UserChannel

fetch(client, service_sid, user_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V2.Service.User.Channel.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchUserChannel | Tags: ChatV2UserChannel

list(client, service_sid, user_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

List all Channels for a given User.

Operation: ListUserChannel | Tags: ChatV2UserChannel

stream(client, service_sid, user_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: List all Channels for a given User. (lazy auto-pagination).

update(client, service_sid, user_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V2.Service.User.Channel.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateUserChannel | Tags: ChatV2UserChannel

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LastConsumedMessageIndex | integer | The index of the last Message in the Channel that the Member has read. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

LastConsumptionTimestampstring (date-time)The ISO 8601 timestamp of the last Message read event for the Member within the Channel.
NotificationLevelstringValues: default, muted