Twilio.Chat.V3.Service.ChannelService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Channel resource represents a chat/conversation channel with an ordered list of messages and a participant roster.

Operations: update

Summary

Functions

update(client, service_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Chat.V3.Service.Channel.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update a specific Channel.

Operation: UpdateChannel | Tags: ChatV3Channel

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

MessagingServiceSidstringThe unique ID of the Messaging Service this channel belongs to.
TypestringValues: public, private