Twilio.Content.V1.ContentAndApprovalsService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Content resource represents rich messaging content and its respective approval request status.

Operations: list

Summary

Functions

Retrieve a list of Contents with approval statuses belonging to the account used to make the request

Stream: Retrieve a list of Contents with approval statuses belonging to the account used to make the request (lazy auto-pagination).

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of Contents with approval statuses belonging to the account used to make the request

Operation: ListContentAndApprovals | Tags: Contentv1ContentAndApprovals

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of Contents with approval statuses belonging to the account used to make the request (lazy auto-pagination).