Twilio.Content.V1.ContentService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Content resource represents rich messaging content.

Operations: list, create, fetch, delete

Summary

Functions

Create a Content resource

Deletes a Content resource

Fetch a Content resource by its unique Content Sid

Retrieve a list of Contents belonging to the account used to make the request

Stream: Retrieve a list of Contents belonging to the account used to make the request (lazy auto-pagination).

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Content.V1.Content.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a Content resource

Operation: CreateContent | Tags: Contentv1Content

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Deletes a Content resource

Operation: DeleteContent | Tags: Contentv1Content

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Content.V1.Content.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a Content resource by its unique Content Sid

Operation: FetchContent | Tags: Contentv1Content

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of Contents belonging to the account used to make the request

Operation: ListContent | Tags: Contentv1Content

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of Contents belonging to the account used to make the request (lazy auto-pagination).