Twilio.Content.V2.ContentAndApprovalsService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Content resource represents rich messaging content and its respective approval request status.

Operations: list

Summary

Functions

Retrieve a list of Contents with approval statuses belonging to the account used to make the request

Stream: Retrieve a list of Contents with approval statuses belonging to the account used to make the request (lazy auto-pagination).

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of Contents with approval statuses belonging to the account used to make the request

Operation: ListContentAndApprovals | Tags: ContentV2ContentAndApprovals

Query Parameters

ParameterTypeDescription
SortByDatestringWhether to sort by ascending or descending date updated
SortByContentNamestringWhether to sort by ascending or descending content name
DateCreatedAfterstring (date-time)Filter by >=[date-time]
DateCreatedBeforestring (date-time)Filter by <=[date-time]
ContentNamestringFilter by Regex Pattern in content name
ContentstringFilter by Regex Pattern in template content
LanguagearrayFilter by array of valid language(s)
ContentTypearrayFilter by array of contentType(s)

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ChannelEligibility | array | Filter by array of ChannelEligibility(s), where ChannelEligibility=<channel>:<status> |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of Contents with approval statuses belonging to the account used to make the request (lazy auto-pagination).