Twilio.Conversations.V1.Configuration.AddressService (twilio_elixir v0.1.1)

Copy Markdown View Source

Address Configuration resource manages the configurations related to a unique address within Conversations

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new address configuration

Remove an existing address configuration

Fetch an address configuration

Retrieve a list of address configurations for an account

Stream: Retrieve a list of address configurations for an account (lazy auto-pagination).

Update an existing address configuration

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Configuration.Address.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new address configuration

Operation: CreateConfigurationAddress | Tags: ConversationsV1AddressConfiguration

Required Parameters

ParameterTypeDescription
AddressstringThe unique address to be configured. The address can be a whatsapp address or phone number
TypestringValues: sms, whatsapp, messenger, gbm, email, rcs, apple, chat

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AddressCountry | string | An ISO 3166-1 alpha-2n country code which the address belongs to. This is currently only applicable to short code addresses. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AutoCreation.ConversationServiceSidstringConversation Service for the auto-created conversation. If not set, the conversation is created in the default service.
AutoCreation.EnabledbooleanEnable/Disable auto-creating conversations for messages to this address

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AutoCreation.StudioFlowSidstringFor type studio, the studio flow SID where the webhook should be sent to.
AutoCreation.StudioRetryCountintegerFor type studio, number of times to retry the webhook request
AutoCreation.TypestringValues: webhook, studio, default

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AutoCreation.WebhookFiltersarrayThe list of events, firing webhook event for this Conversation. Values can be any of the following: onMessageAdded, onMessageUpdated, onMessageRemoved, onConversationUpdated, onConversationStateUpdated, onConversationRemoved, onParticipantAdded, onParticipantUpdated, onParticipantRemoved, onDeliveryUpdated
AutoCreation.WebhookMethodstringValues: get, post
AutoCreation.WebhookUrlstringFor type webhook, the url for the webhook request.
FriendlyNamestringThe human-readable name of this configuration, limited to 256 characters. Optional.

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Remove an existing address configuration

Operation: DeleteConfigurationAddress | Tags: ConversationsV1AddressConfiguration

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Configuration.Address.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch an address configuration

Operation: FetchConfigurationAddress | Tags: ConversationsV1AddressConfiguration

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of address configurations for an account

Operation: ListConfigurationAddress | Tags: ConversationsV1AddressConfiguration

Query Parameters

ParameterTypeDescription
TypestringFilter the address configurations by its type. This value can be one of: whatsapp, sms.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of address configurations for an account (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Configuration.Address.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update an existing address configuration

Operation: UpdateConfigurationAddress | Tags: ConversationsV1AddressConfiguration

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AutoCreation.ConversationServiceSidstringConversation Service for the auto-created conversation. If not set, the conversation is created in the default service.
AutoCreation.EnabledbooleanEnable/Disable auto-creating conversations for messages to this address

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AutoCreation.StudioFlowSidstringFor type studio, the studio flow SID where the webhook should be sent to.
AutoCreation.StudioRetryCountintegerFor type studio, number of times to retry the webhook request
AutoCreation.TypestringValues: webhook, studio, default

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AutoCreation.WebhookFiltersarrayThe list of events, firing webhook event for this Conversation. Values can be any of the following: onMessageAdded, onMessageUpdated, onMessageRemoved, onConversationUpdated, onConversationStateUpdated, onConversationRemoved, onParticipantAdded, onParticipantUpdated, onParticipantRemoved, onDeliveryUpdated
AutoCreation.WebhookMethodstringValues: get, post
AutoCreation.WebhookUrlstringFor type webhook, the url for the webhook request.
FriendlyNamestringThe human-readable name of this configuration, limited to 256 characters. Optional.