Twilio.Conversations.V1.Conversation.Message.ReceiptService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Message Receipt resource represents a delivery/read receipt of a message in a conversation.

Operations: list, fetch

Summary

Functions

Fetch the delivery and read receipts of the conversation message

Retrieve a list of all delivery and read receipts of the conversation message

Stream: Retrieve a list of all delivery and read receipts of the conversation message (lazy auto-pagination).

Functions

fetch(client, conversation_sid, message_sid, sid, opts \\ [])

Fetch the delivery and read receipts of the conversation message

Operation: FetchConversationMessageReceipt | Tags: ConversationsV1DeliveryReceipt

list(client, conversation_sid, message_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all delivery and read receipts of the conversation message

Operation: ListConversationMessageReceipt | Tags: ConversationsV1DeliveryReceipt

stream(client, conversation_sid, message_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: Retrieve a list of all delivery and read receipts of the conversation message (lazy auto-pagination).