Twilio.Conversations.V1.Conversation.ParticipantService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Participant resource represents a member of the conversation.

Operations: list, create, fetch, update, delete

Summary

Functions

Add a new participant to the conversation

Remove a participant from the conversation

Fetch a participant of the conversation

Retrieve a list of all participants of the conversation

Stream: Retrieve a list of all participants of the conversation (lazy auto-pagination).

Update an existing participant in the conversation

Functions

create(client, conversation_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Conversation.Participant.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Add a new participant to the conversation

Operation: CreateConversationParticipant | Tags: ConversationsV1Participant

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AttributesstringAn optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.
DateCreatedstring (date-time)The date that this resource was created.
DateUpdatedstring (date-time)The date that this resource was last updated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | string | A unique string identifier for the conversation participant as Conversation User. This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessagingBinding.Address | string | The address of the participant's device, e.g. a phone or WhatsApp number. Together with the Proxy address, this determines a participant uniquely. This field (with proxy_address) is only null when the participant is interacting from an SDK endpoint (see the 'identity' field). |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessagingBinding.ProjectedAddress | string | The address of the Twilio phone number that is used in Group MMS. Communication mask for the Conversation participant with Identity. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessagingBinding.ProxyAddress | string | The address of the Twilio phone number (or WhatsApp number) that the participant is in contact with. This field, together with participant address, is only null when the participant is interacting from an SDK endpoint (see the 'identity' field). |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| RoleSid | string | The SID of a conversation-level Role to assign to the participant. |

delete(client, conversation_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Remove a participant from the conversation

Operation: DeleteConversationParticipant | Tags: ConversationsV1Participant

fetch(client, conversation_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Conversation.Participant.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a participant of the conversation

Operation: FetchConversationParticipant | Tags: ConversationsV1Participant

list(client, conversation_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all participants of the conversation

Operation: ListConversationParticipant | Tags: ConversationsV1Participant

stream(client, conversation_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all participants of the conversation (lazy auto-pagination).

update(client, conversation_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Conversation.Participant.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update an existing participant in the conversation

Operation: UpdateConversationParticipant | Tags: ConversationsV1Participant

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AttributesstringAn optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.
DateCreatedstring (date-time)The date that this resource was created.
DateUpdatedstring (date-time)The date that this resource was last updated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | string | A unique string identifier for the conversation participant as Conversation User. This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LastReadMessageIndex | integer | Index of last “read” message in the Conversation for the Participant. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LastReadTimestamp | string | Timestamp of last “read” message in the Conversation for the Participant. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessagingBinding.ProjectedAddress | string | The address of the Twilio phone number that is used in Group MMS. 'null' value will remove it. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessagingBinding.ProxyAddress | string | The address of the Twilio phone number that the participant is in contact with. 'null' value will remove it. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| RoleSid | string | The SID of a conversation-level Role to assign to the participant. |