Twilio.Conversations.V1.Conversation.WebhookService
(twilio_elixir v0.1.1)
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
A Scoped Webhook resource manages a set of callback URLs and their configuration for receiving events specific to one conversation.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new webhook scoped to the conversation
Remove an existing webhook scoped to the conversation
Fetch the configuration of a conversation-scoped webhook
Retrieve a list of all webhooks scoped to the conversation
Stream: Retrieve a list of all webhooks scoped to the conversation (lazy auto-pagination).
Update an existing conversation-scoped webhook
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Conversation.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new webhook scoped to the conversation
Operation: CreateConversationScopedWebhook | Tags: ConversationsV1Webhook
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Target | string | Values: webhook, trigger, studio |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Configuration.Filters | array | The list of events, firing webhook event for this Conversation. |
Configuration.FlowSid | string | The studio flow SID, where the webhook should be sent to. |
Configuration.Method | string | Values: get, post |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Configuration.ReplayAfter | integer | The message index for which and it's successors the webhook will be replayed. Not set by default |
Configuration.Triggers | array | The list of keywords, firing webhook event for this Conversation. |
Configuration.Url | string | The absolute url the webhook request should be sent to. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Remove an existing webhook scoped to the conversation
Operation: DeleteConversationScopedWebhook | Tags: ConversationsV1Webhook
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Conversation.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch the configuration of a conversation-scoped webhook
Operation: FetchConversationScopedWebhook | Tags: ConversationsV1Webhook
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all webhooks scoped to the conversation
Operation: ListConversationScopedWebhook | Tags: ConversationsV1Webhook
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all webhooks scoped to the conversation (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Conversation.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an existing conversation-scoped webhook
Operation: UpdateConversationScopedWebhook | Tags: ConversationsV1Webhook
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Configuration.Filters | array | The list of events, firing webhook event for this Conversation. |
Configuration.FlowSid | string | The studio flow SID, where the webhook should be sent to. |
Configuration.Method | string | Values: get, post |
Configuration.Triggers | array | The list of keywords, firing webhook event for this Conversation. |
Configuration.Url | string | The absolute url the webhook request should be sent to. |