Twilio.Conversations.V1.ConversationWithParticipantsService (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

A Conversation resource represents an omnichannel group conversation with an ordered list of messages and a participant roster.

Operations: create

Summary

Functions

Create a new conversation with the list of participants in your account's default service

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.ConversationWithParticipants.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new conversation with the list of participants in your account's default service

Operation: CreateConversationWithParticipants | Tags: ConversationsV1ConversationWithParticipants

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Attributes | string | An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Bindings.Email.Address | string | The default email address that will be used when sending outbound emails in this conversation. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Bindings.Email.NamestringThe default name that will be used when sending outbound emails in this conversation.
DateCreatedstring (date-time)The date that this resource was created.
DateUpdatedstring (date-time)The date that this resource was last updated.
FriendlyNamestringThe human-readable name of this conversation, limited to 256 characters. Optional.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessagingServiceSid | string | The unique ID of the Messaging Service this conversation belongs to. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ParticipantarrayThe participant to be added to the conversation in JSON format. The JSON object attributes are as parameters in Participant Resource. The maximum number of participants that can be added in a single request is 10.
StatestringValues: initializing, inactive, active, closed

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Timers.Closed | string | ISO8601 duration when conversation will be switched to closed state. Minimum value for this timer is 10 minutes. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Timers.Inactive | string | ISO8601 duration when conversation will be switched to inactive state. Minimum value for this timer is 1 minute. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UniqueName | string | An application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource's sid in the URL. |