Twilio.Conversations.V1.CredentialService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Credential resource represents a push notification credential.

Operations: list, create, fetch, update, delete

Summary

Functions

Add a new push notification credential to your account

Remove a push notification credential from your account

Fetch a push notification credential from your account

Retrieve a list of all push notification credentials on your account

Stream: Retrieve a list of all push notification credentials on your account (lazy auto-pagination).

Update an existing push notification credential on your account

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Credential.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Add a new push notification credential to your account

Operation: CreateCredential | Tags: ConversationsV1Credential

Required Parameters

ParameterTypeDescription
TypestringValues: apn, gcm, fcm

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ApiKey | string | [GCM only] The API key for the project that was obtained from the Google Developer console for your GCM Service application credential. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Certificate | string | [APN only] The URL encoded representation of the certificate. For example, -----BEGIN CERTIFICATE----- MIIFnTCCBIWgAwIBAgIIAjy9H849+E8wDQYJKoZIhvcNAQEF.....A== -----END CERTIFICATE-----. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the new resource. It can be up to 64 characters long. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| PrivateKey | string | [APN only] The URL encoded representation of the private key. For example, -----BEGIN RSA PRIVATE KEY----- MIIEpQIBAAKCAQEAuyf/lNrH9ck8DmNyo3fG... -----END RSA PRIVATE KEY-----. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Sandbox | boolean | [APN only] Whether to send the credential to sandbox APNs. Can be true to send to sandbox APNs or false to send to production. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Secret | string | [FCM only] The Server key of your project from the Firebase console, found under Settings / Cloud messaging. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Remove a push notification credential from your account

Operation: DeleteCredential | Tags: ConversationsV1Credential

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Credential.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a push notification credential from your account

Operation: FetchCredential | Tags: ConversationsV1Credential

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all push notification credentials on your account

Operation: ListCredential | Tags: ConversationsV1Credential

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all push notification credentials on your account (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Credential.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update an existing push notification credential on your account

Operation: UpdateCredential | Tags: ConversationsV1Credential

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ApiKey | string | [GCM only] The API key for the project that was obtained from the Google Developer console for your GCM Service application credential. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Certificate | string | [APN only] The URL encoded representation of the certificate. For example, -----BEGIN CERTIFICATE----- MIIFnTCCBIWgAwIBAgIIAjy9H849+E8wDQYJKoZIhvcNAQEF.....A== -----END CERTIFICATE-----. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the new resource. It can be up to 64 characters long. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| PrivateKey | string | [APN only] The URL encoded representation of the private key. For example, -----BEGIN RSA PRIVATE KEY----- MIIEpQIBAAKCAQEAuyf/lNrH9ck8DmNyo3fG... -----END RSA PRIVATE KEY-----. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Sandbox | boolean | [APN only] Whether to send the credential to sandbox APNs. Can be true to send to sandbox APNs or false to send to production. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Secretstring[FCM only] The Server key of your project from the Firebase console, found under Settings / Cloud messaging.
TypestringValues: apn, gcm, fcm