Twilio.Conversations.V1.Service.BindingService (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

A Binding resource represents a push notification binding and its configuration, for delivering conversation events to mobile or web endpoints.

Operations: list, fetch, delete

Summary

Functions

Remove a push notification binding from the conversation service

Fetch a push notification binding from the conversation service

Retrieve a list of all push notification bindings in the conversation service

Stream: Retrieve a list of all push notification bindings in the conversation service (lazy auto-pagination).

Functions

delete(client, chat_service_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Remove a push notification binding from the conversation service

Operation: DeleteServiceBinding | Tags: ConversationsV1Binding

fetch(client, chat_service_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Service.Binding.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a push notification binding from the conversation service

Operation: FetchServiceBinding | Tags: ConversationsV1Binding

list(client, chat_service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all push notification bindings in the conversation service

Operation: ListServiceBinding | Tags: ConversationsV1Binding

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BindingType | array | The push technology used by the Binding resources to read. Can be: apn, gcm, fcm, or twilsock. See push notification configuration for more info. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | array | The identity of a Conversation User this binding belongs to. See access tokens for more details. |

stream(client, chat_service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all push notification bindings in the conversation service (lazy auto-pagination).