Twilio.Conversations.V1.Service.Configuration.NotificationService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Service Notification resource manages a set of settings to determine push notification behavior at service level.

Operations: fetch, update

Summary

Functions

Fetch push notification service settings

Update push notification service settings

Functions

fetch(client, chat_service_sid, opts \\ [])

Fetch push notification service settings

Operation: FetchServiceNotification | Tags: ConversationsV1Notification

update(client, chat_service_sid, params \\ %{}, opts \\ [])

Update push notification service settings

Operation: UpdateServiceNotification | Tags: ConversationsV1Notification

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AddedToConversation.Enabled | boolean | Whether to send a notification when a participant is added to a conversation. The default is false. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AddedToConversation.Sound | string | The name of the sound to play when a participant is added to a conversation and added_to_conversation.enabled is true. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AddedToConversation.TemplatestringThe template to use to create the notification text displayed when a participant is added to a conversation and added_to_conversation.enabled is true.
LogEnabledbooleanWeather the notification logging is enabled.
NewMessage.BadgeCountEnabledbooleanWhether the new message badge is enabled. The default is false.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| NewMessage.Enabled | boolean | Whether to send a notification when a new message is added to a conversation. The default is false. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| NewMessage.Sound | string | The name of the sound to play when a new message is added to a conversation and new_message.enabled is true. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| NewMessage.Template | string | The template to use to create the notification text displayed when a new message is added to a conversation and new_message.enabled is true. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| NewMessage.WithMedia.Enabled | boolean | Whether to send a notification when a new message with media/file attachments is added to a conversation. The default is false. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| NewMessage.WithMedia.Template | string | The template to use to create the notification text displayed when a new message with media/file attachments is added to a conversation and new_message.attachments.enabled is true. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| RemovedFromConversation.Enabled | boolean | Whether to send a notification to a user when they are removed from a conversation. The default is false. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| RemovedFromConversation.Sound | string | The name of the sound to play to a user when they are removed from a conversation and removed_from_conversation.enabled is true. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| RemovedFromConversation.Template | string | The template to use to create the notification text displayed to a user when they are removed from a conversation and removed_from_conversation.enabled is true. |