Twilio.Conversations.V1.Service.Configuration.WebhookService (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

A service webhook configuration resource manages a service-level set of callback URLs and their configuration for receiving all the corresponding service events.

Operations: fetch, update

Summary

Functions

Fetch a specific service webhook configuration.

Functions

fetch(client, chat_service_sid, opts \\ [])

Fetch a specific service webhook configuration.

Operation: FetchServiceWebhookConfiguration | Tags: ConversationsV1Webhook

update(client, chat_service_sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Service.Configuration.Webhook.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update a specific Webhook.

Operation: UpdateServiceWebhookConfiguration | Tags: ConversationsV1Webhook

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

FiltersarrayThe list of events that your configured webhook targets will receive. Events not configured here will not fire. Possible values are onParticipantAdd, onParticipantAdded, onDeliveryUpdated, onConversationUpdated, onConversationRemove, onParticipantRemove, onConversationUpdate, onMessageAdd, onMessageRemoved, onParticipantUpdated, onConversationAdded, onMessageAdded, onConversationAdd, onConversationRemoved, onParticipantUpdate, onMessageRemove, onMessageUpdated, onParticipantRemoved, onMessageUpdate or onConversationStateUpdated.
MethodstringThe HTTP method to be used when sending a webhook request. One of GET or POST.
PostWebhookUrlstring (uri)The absolute url the post-event webhook request should be sent to.
PreWebhookUrlstring (uri)The absolute url the pre-event webhook request should be sent to.