Twilio.Conversations.V1.Service.ConfigurationService
(twilio_elixir v0.1.1)
A Service Configuration resource manages service-level settings applicable to the Conversation API.
Operations: fetch, update
Summary
Functions
Fetch the configuration of a conversation service
Update configuration settings of a conversation service
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Service.Configuration.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch the configuration of a conversation service
Operation: FetchServiceConfiguration | Tags: ConversationsV1Configuration
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Service.Configuration.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update configuration settings of a conversation service
Operation: UpdateServiceConfiguration | Tags: ConversationsV1Configuration
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DefaultChatServiceRoleSid | string | The service-level role assigned to users when they are added to the service. See Conversation Role for more info about roles. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DefaultConversationCreatorRoleSid | string | The conversation-level role assigned to a conversation creator when they join a new conversation. See Conversation Role for more info about roles. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DefaultConversationRoleSid | string | The conversation-level role assigned to users when they are added to a conversation. See Conversation Role for more info about roles. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ReachabilityEnabled | boolean | Whether the Reachability Indicator is enabled for this Conversations Service. The default is false. |