Twilio.Conversations.V1.Service.Conversation.Message.ReceiptService
(twilio_elixir v0.1.1)
A Service Message Receipt resource represents a delivery/read receipt of a message in a conversation.
Operations: list, fetch
Summary
Functions
Fetch the delivery and read receipts of the conversation message
Retrieve a list of all delivery and read receipts of the conversation message
Stream: Retrieve a list of all delivery and read receipts of the conversation message (lazy auto-pagination).
Functions
@spec fetch( Twilio.Client.t(), String.t(), String.t(), String.t(), String.t(), keyword() ) :: {:ok, Twilio.Resources.Conversations.V1.Service.Conversation.Message.Receipt.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch the delivery and read receipts of the conversation message
Operation: FetchServiceConversationMessageReceipt | Tags: ConversationsV1DeliveryReceipt
@spec list(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all delivery and read receipts of the conversation message
Operation: ListServiceConversationMessageReceipt | Tags: ConversationsV1DeliveryReceipt
@spec stream(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all delivery and read receipts of the conversation message (lazy auto-pagination).