Twilio.Conversations.V1.Service.Conversation.MessageService
(twilio_elixir v0.1.1)
A Service Message resource represents a message in a conversation within a specific service.
Operations: list, create, fetch, update, delete
Summary
Functions
Add a new message to the conversation in a specific service
Remove a message from the conversation
Fetch a message from the conversation
Retrieve a list of all messages in the conversation
Stream: Retrieve a list of all messages in the conversation (lazy auto-pagination).
Update an existing message in the conversation
Functions
@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Service.Conversation.Message.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Add a new message to the conversation in a specific service
Operation: CreateServiceConversationMessage | Tags: ConversationsV1Message
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Attributes | string | A string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned. |
Author | string | The channel specific identifier of the message's author. Defaults to system. |
Body | string | The content of the message, can be up to 1,600 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ContentSid | string | The unique ID of the multi-channel Rich Content template, required for template-generated messages. Note that if this field is set, Body and MediaSid parameters are ignored. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
ContentVariables | string | A structurally valid JSON string that contains values to resolve Rich Content template variables. |
DateCreated | string (date-time) | The date that this resource was created. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
DateUpdated | string (date-time) | The date that this resource was last updated. null if the message has not been edited. |
MediaSid | string | The Media SID to be attached to the new Message. |
Subject | string | The subject of the message, can be up to 256 characters long. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Remove a message from the conversation
Operation: DeleteServiceConversationMessage | Tags: ConversationsV1Message
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Service.Conversation.Message.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a message from the conversation
Operation: FetchServiceConversationMessage | Tags: ConversationsV1Message
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all messages in the conversation
Operation: ListServiceConversationMessage | Tags: ConversationsV1Message
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Order | string | The sort order of the returned messages. Can be: asc (ascending) or desc (descending), with asc as the default. |
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all messages in the conversation (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Service.Conversation.Message.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an existing message in the conversation
Operation: UpdateServiceConversationMessage | Tags: ConversationsV1Message
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Attributes | string | A string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned. |
Author | string | The channel specific identifier of the message's author. Defaults to system. |
Body | string | The content of the message, can be up to 1,600 characters long. |
DateCreated | string (date-time) | The date that this resource was created. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
DateUpdated | string (date-time) | The date that this resource was last updated. null if the message has not been edited. |
Subject | string | The subject of the message, can be up to 256 characters long. |