Twilio.Conversations.V1.Service.Conversation.WebhookService (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

A Conversation-scoped Webhook resource manages a set of callback URLs and their configuration for receiving events specific to one conversation.

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new webhook scoped to the conversation in a specific service

Remove an existing webhook scoped to the conversation

Fetch the configuration of a conversation-scoped webhook

Retrieve a list of all webhooks scoped to the conversation

Stream: Retrieve a list of all webhooks scoped to the conversation (lazy auto-pagination).

Functions

create(client, chat_service_sid, conversation_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Service.Conversation.Webhook.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new webhook scoped to the conversation in a specific service

Operation: CreateServiceConversationScopedWebhook | Tags: ConversationsV1Webhook

Required Parameters

ParameterTypeDescription
TargetstringValues: webhook, trigger, studio

Optional Parameters

ParameterTypeDescription
Configuration.FiltersarrayThe list of events, firing webhook event for this Conversation.
Configuration.FlowSidstringThe studio flow SID, where the webhook should be sent to.
Configuration.MethodstringValues: get, post

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Configuration.ReplayAfterintegerThe message index for which and it's successors the webhook will be replayed. Not set by default
Configuration.TriggersarrayThe list of keywords, firing webhook event for this Conversation.
Configuration.UrlstringThe absolute url the webhook request should be sent to.

delete(client, chat_service_sid, conversation_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Remove an existing webhook scoped to the conversation

Operation: DeleteServiceConversationScopedWebhook | Tags: ConversationsV1Webhook

fetch(client, chat_service_sid, conversation_sid, sid, opts \\ [])

Fetch the configuration of a conversation-scoped webhook

Operation: FetchServiceConversationScopedWebhook | Tags: ConversationsV1Webhook

list(client, chat_service_sid, conversation_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all webhooks scoped to the conversation

Operation: ListServiceConversationScopedWebhook | Tags: ConversationsV1Webhook

stream(client, chat_service_sid, conversation_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: Retrieve a list of all webhooks scoped to the conversation (lazy auto-pagination).

update(client, chat_service_sid, conversation_sid, sid, params \\ %{}, opts \\ [])

Update an existing conversation-scoped webhook

Operation: UpdateServiceConversationScopedWebhook | Tags: ConversationsV1Webhook

Optional Parameters

ParameterTypeDescription
Configuration.FiltersarrayThe list of events, firing webhook event for this Conversation.
Configuration.FlowSidstringThe studio flow SID, where the webhook should be sent to.
Configuration.MethodstringValues: get, post
Configuration.TriggersarrayThe list of keywords, firing webhook event for this Conversation.
Configuration.UrlstringThe absolute url the webhook request should be sent to.