Twilio.Conversations.V1.Service.ParticipantConversationService (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Service Participant Conversations resource represents a list of Conversations that this Participant belongs to belonging to a specific conversation service.

Operations: list

Summary

Functions

Stream: Retrieve a list of all Conversations that this Participant belongs to by identity or by address. Only one parameter should be specified. (lazy auto-pagination).

Functions

list(client, chat_service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Retrieve a list of all Conversations that this Participant belongs to by identity or by address. Only one parameter should be specified.

Operation: ListServiceParticipantConversation | Tags: ConversationsV1ParticipantConversation

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | string | A unique string identifier for the conversation participant as Conversation User. This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Address | string | A unique string identifier for the conversation participant who's not a Conversation User. This parameter could be found in messaging_binding.address field of Participant resource. It should be url-encoded. |

stream(client, chat_service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Conversations that this Participant belongs to by identity or by address. Only one parameter should be specified. (lazy auto-pagination).