Twilio.Conversations.V1.ServiceService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Service resource is a top-level conversation resource container that serves as a data silo.

Operations: list, create, fetch, delete

Summary

Functions

Create a new conversation service on your account

Remove a conversation service with all its nested resources from your account

Fetch a conversation service from your account

Retrieve a list of all conversation services on your account

Stream: Retrieve a list of all conversation services on your account (lazy auto-pagination).

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new conversation service on your account

Operation: CreateService | Tags: ConversationsV1Service

Required Parameters

ParameterTypeDescription
FriendlyNamestringThe human-readable name of this service, limited to 256 characters. Optional.

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Remove a conversation service with all its nested resources from your account

Operation: DeleteService | Tags: ConversationsV1Service

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a conversation service from your account

Operation: FetchService | Tags: ConversationsV1Service

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all conversation services on your account

Operation: ListService | Tags: ConversationsV1Service

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all conversation services on your account (lazy auto-pagination).