Twilio.Conversations.V1.User.ConversationService (twilio_elixir v0.1.1)

Copy Markdown View Source

A User Conversation resource represents a conversation of the user belonging to a default conversation service.

Operations: list, fetch, update, delete

Summary

Functions

Delete a specific User Conversation.

Fetch a specific User Conversation.

Retrieve a list of all User Conversations for the User.

Stream: Retrieve a list of all User Conversations for the User. (lazy auto-pagination).

Update a specific User Conversation.

Functions

delete(client, user_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific User Conversation.

Operation: DeleteUserConversation | Tags: ConversationsV1UserConversation

fetch(client, user_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.User.Conversation.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific User Conversation.

Operation: FetchUserConversation | Tags: ConversationsV1UserConversation

list(client, user_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all User Conversations for the User.

Operation: ListUserConversation | Tags: ConversationsV1UserConversation

stream(client, user_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all User Conversations for the User. (lazy auto-pagination).

update(client, user_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Conversations.V1.User.Conversation.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update a specific User Conversation.

Operation: UpdateUserConversation | Tags: ConversationsV1UserConversation

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LastReadMessageIndex | integer | The index of the last Message in the Conversation that the Participant has read. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

LastReadTimestampstring (date-time)The date of the last message read in conversation by the user, given in ISO 8601 format.
NotificationLevelstringValues: default, muted