Validate sink
Operations: create
Summary
Functions
Validate that a test event for a Sink was received.
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Events.V1.Sink.Validate.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Validate that a test event for a Sink was received.
Operation: CreateSinkValidate | Tags: EventsV1SinkValidate
Required Parameters
| Parameter | Type | Description |
|---|---|---|
TestId | string | A 34 character string that uniquely identifies the test event for a Sink being validated. |