Twilio.Events.V1.TypeService (twilio_elixir v0.1.1)

Copy Markdown View Source

Event Types available

Operations: list, fetch

Summary

Functions

Fetch a specific Event Type.

Retrieve a paginated list of all the available Event Types.

Stream: Retrieve a paginated list of all the available Event Types. (lazy auto-pagination).

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Events.V1.Type.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Event Type.

Operation: FetchEventType | Tags: EventsV1EventType

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a paginated list of all the available Event Types.

Operation: ListEventType | Tags: EventsV1EventType

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| SchemaId | string | A string parameter filtering the results to return only the Event Types using a given schema. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a paginated list of all the available Event Types. (lazy auto-pagination).