Twilio.Flex.V1.ChannelService (twilio_elixir v0.1.1)

Copy Markdown View Source

Flex chat channels

Operations: list, create, fetch, delete

Summary

Functions

Operation: CreateChannel | Tags: FlexV1Channel

Operation: DeleteChannel | Tags: FlexV1Channel

Operation: FetchChannel | Tags: FlexV1Channel

Operation: ListChannel | Tags: FlexV1Channel

Stream: (lazy auto-pagination).

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Flex.V1.Channel.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateChannel | Tags: FlexV1Channel

Required Parameters

ParameterTypeDescription
ChatFriendlyNamestringThe chat channel's friendly name.
ChatUserFriendlyNamestringThe chat participant's friendly name.
FlexFlowSidstringThe SID of the Flex Flow.
IdentitystringThe identity value that uniquely identifies the new resource's chat User.

Optional Parameters

ParameterTypeDescription
ChatUniqueNamestringThe chat channel's unique name.
LongLivedbooleanWhether to create the channel as long-lived.
PreEngagementDatastringThe pre-engagement data.
TargetstringThe Target Contact Identity, for example the phone number of an SMS.
TaskAttributesstringThe Task attributes to be added for the TaskRouter Task.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| TaskSid | string | The SID of the TaskRouter Task. Only valid when integration type is task. null for integration types studio & external |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteChannel | Tags: FlexV1Channel

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Flex.V1.Channel.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchChannel | Tags: FlexV1Channel

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListChannel | Tags: FlexV1Channel

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).