Twilio.Flex.V1.Insight.QualityManagement.Assessment.CommentService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Comment API operations.

Operations: list, create

Summary

Functions

To create a comment assessment for a conversation

To create a comment assessment for a conversation

Stream: To create a comment assessment for a conversation (lazy auto-pagination).

Functions

create(client, params \\ %{}, opts \\ [])

To create a comment assessment for a conversation

Operation: CreateInsightsAssessmentsComment | Tags: FlexV1InsightsAssessmentsComment

Required Parameters

ParameterTypeDescription
AgentIdstringThe id of the agent.
CategoryIdstringThe ID of the category
CategoryNamestringThe name of the category
CommentstringThe Assessment comment.
OffsetnumberThe offset
SegmentIdstringThe id of the segment.

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

To create a comment assessment for a conversation

Operation: ListInsightsAssessmentsComment | Tags: FlexV1InsightsAssessmentsComment

Query Parameters

ParameterTypeDescription
SegmentIdstringThe id of the segment.
AgentIdstringThe id of the agent.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: To create a comment assessment for a conversation (lazy auto-pagination).