Twilio.Flex.V1.Insight.QualityManagement.AssessmentsService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Assessments API operations.

Operations: list, create, update

Summary

Functions

Get assessments done for a conversation by logged in user

Stream: Get assessments done for a conversation by logged in user (lazy auto-pagination).

Update a specific Assessment assessed earlier

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Flex.V1.Insight.QualityManagement.Assessments.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Add assessments against conversation to dynamo db. Used in assessments screen by user. Users can select the questionnaire and pick up answers for each and every question.

Operation: CreateInsightsAssessments | Tags: FlexV1Assessments

Required Parameters

ParameterTypeDescription
AgentIdstringThe id of the Agent
AnswerIdstringThe id of the answer selected by user
AnswerTextstringThe answer text selected by user
CategoryNamestringThe name of the category
CategorySidstringThe SID of the category
MetricIdstringThe question SID selected for assessment
MetricNamestringThe question name of the assessment
OffsetnumberThe offset of the conversation.
QuestionnaireSidstringQuestionnaire SID of the associated question
SegmentIdstringSegment Id of the conversation

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Get assessments done for a conversation by logged in user

Operation: ListInsightsAssessments | Tags: FlexV1Assessments

Query Parameters

ParameterTypeDescription
SegmentIdstringThe id of the segment.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Get assessments done for a conversation by logged in user (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Flex.V1.Insight.QualityManagement.Assessments.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update a specific Assessment assessed earlier

Operation: UpdateInsightsAssessments | Tags: FlexV1Assessments

Required Parameters

ParameterTypeDescription
AnswerIdstringThe id of the answer selected by user
AnswerTextstringThe answer text selected by user
OffsetnumberThe offset of the conversation