Twilio.Flex.V1.Insight.QualityManagement.InsightsQuestionnairesService
(twilio_elixir v0.1.1)
Service for InsightsQuestionnaires API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
To create a Questionnaire
To delete the questionnaire
To get the Questionnaire Detail
To get all questionnaires with questions
Stream: To get all questionnaires with questions (lazy auto-pagination).
To update the questionnaire
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.Insight.QualityManagement.InsightsQuestionnaires.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To create a Questionnaire
Operation: CreateInsightsQuestionnaires | Tags: FlexV1InsightsQuestionnaires
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Name | string | The name of this questionnaire |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Active | boolean | The flag to enable or disable questionnaire |
Description | string | The description of this questionnaire |
QuestionSids | array | The list of questions sids under a questionnaire |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To delete the questionnaire
Operation: DeleteInsightsQuestionnaires | Tags: FlexV1InsightsQuestionnaires
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.Insight.QualityManagement.InsightsQuestionnaires.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To get the Questionnaire Detail
Operation: FetchInsightsQuestionnaires | Tags: FlexV1InsightsQuestionnaires
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To get all questionnaires with questions
Operation: ListInsightsQuestionnaires | Tags: FlexV1InsightsQuestionnaires
Query Parameters
| Parameter | Type | Description |
|---|---|---|
IncludeInactive | boolean | Flag indicating whether to include inactive questionnaires or not |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: To get all questionnaires with questions (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.Insight.QualityManagement.InsightsQuestionnaires.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To update the questionnaire
Operation: UpdateInsightsQuestionnaires | Tags: FlexV1InsightsQuestionnaires
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Active | boolean | The flag to enable or disable questionnaire |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Description | string | The description of this questionnaire |
Name | string | The name of this questionnaire |
QuestionSids | array | The list of questions sids under a questionnaire |