Twilio.Flex.V1.Insight.QualityManagement.QuestionService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Question API operations.

Operations: list, create, update, delete

Summary

Functions

To create a question for a Category

Operation: DeleteInsightsQuestionnairesQuestion | Tags: FlexV1InsightsQuestionnairesQuestion

To get all the question for the given categories

Stream: To get all the question for the given categories (lazy auto-pagination).

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Flex.V1.Insight.QualityManagement.Question.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

To create a question for a Category

Operation: CreateInsightsQuestionnairesQuestion | Tags: FlexV1InsightsQuestionnairesQuestion

Required Parameters

ParameterTypeDescription
AllowNabooleanThe flag to enable for disable NA for answer.
AnswerSetIdstringThe answer_set for the question.
CategorySidstringThe SID of the category
QuestionstringThe question.

Optional Parameters

ParameterTypeDescription
DescriptionstringThe description for the question.

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteInsightsQuestionnairesQuestion | Tags: FlexV1InsightsQuestionnairesQuestion

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

To get all the question for the given categories

Operation: ListInsightsQuestionnairesQuestion | Tags: FlexV1InsightsQuestionnairesQuestion

Query Parameters

ParameterTypeDescription
CategorySidarrayThe list of category SIDs

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: To get all the question for the given categories (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Flex.V1.Insight.QualityManagement.Question.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

To update the question

Operation: UpdateInsightsQuestionnairesQuestion | Tags: FlexV1InsightsQuestionnairesQuestion

Required Parameters

ParameterTypeDescription
AllowNabooleanThe flag to enable for disable NA for answer.

Optional Parameters

ParameterTypeDescription
AnswerSetIdstringThe answer_set for the question.
CategorySidstringThe SID of the category
DescriptionstringThe description for the question.
QuestionstringThe question.