Twilio.Flex.V1.Insight.QualityManagement.Setting.CommentTagService
(twilio_elixir v0.1.1)
Service for CommentTag API operations.
Operations: list
Summary
Functions
To get the Comment Settings for an Account
Stream: To get the Comment Settings for an Account (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To get the Comment Settings for an Account
Operation: FetchInsightsSettingsComment | Tags: FlexV1InsightsSettingsComment
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: To get the Comment Settings for an Account (lazy auto-pagination).