Service for Session API operations.
Operations: update
Summary
Functions
To obtain session details for fetching reports and dashboards
Functions
@spec update(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.Insight.Session.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To obtain session details for fetching reports and dashboards
Operation: CreateInsightsSession | Tags: FlexV1InsightsSession