Twilio.Flex.V1.Interaction.Channel.InteractionChannelParticipantService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for InteractionChannelParticipant API operations.

Operations: list, create, update

Summary

Functions

create(client, interaction_sid, channel_sid, params \\ %{}, opts \\ [])

Add a Participant to a Channel.

Operation: CreateInteractionChannelParticipant | Tags: FlexV1InteractionChannelParticipant

Required Parameters

ParameterTypeDescription
MediaPropertiesstringJSON representing the Media Properties for the new Participant.
TypestringValues: supervisor, customer, external, agent, unknown

Optional Parameters

ParameterTypeDescription
RoutingPropertiesstringObject representing the Routing Properties for the new Participant.

list(client, interaction_sid, channel_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

List all Participants for a Channel.

Operation: ListInteractionChannelParticipant | Tags: FlexV1InteractionChannelParticipant

stream(client, interaction_sid, channel_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: List all Participants for a Channel. (lazy auto-pagination).

update(client, interaction_sid, channel_sid, sid, params \\ %{}, opts \\ [])

Update an existing Channel Participant.

Operation: UpdateInteractionChannelParticipant | Tags: FlexV1InteractionChannelParticipant

Required Parameters

ParameterTypeDescription
StatusstringValues: closed, wrapup