Twilio.Flex.V1.Interaction.InteractionChannelService
(twilio_elixir v0.1.1)
Service for InteractionChannel API operations.
Operations: list, fetch, update
Summary
Functions
Fetch a Channel for an Interaction.
List all Channels for an Interaction.
Stream: List all Channels for an Interaction. (lazy auto-pagination).
Update an existing Interaction Channel.
Functions
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.Interaction.InteractionChannel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a Channel for an Interaction.
Operation: FetchInteractionChannel | Tags: FlexV1InteractionChannel
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
List all Channels for an Interaction.
Operation: ListInteractionChannel | Tags: FlexV1InteractionChannel
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: List all Channels for an Interaction. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.Interaction.InteractionChannel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an existing Interaction Channel.
Operation: UpdateInteractionChannel | Tags: FlexV1InteractionChannel
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Status | string | Values: closed, inactive |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Routing | string | It changes the state of associated tasks. Routing status is required, When the channel status is set to inactive. Allowed Value for routing status is closed. Otherwise Optional, if not specified, all tasks will be set to wrapping. |