Twilio.Flex.V1.PluginService.PluginService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Plugin API operations.

Operations: list, create, fetch, update

Summary

Functions

Operation: CreatePlugin | Tags: FlexV1Plugin

Operation: FetchPlugin | Tags: FlexV1Plugin

Operation: ListPlugin | Tags: FlexV1Plugin

Stream: (lazy auto-pagination).

Operation: UpdatePlugin | Tags: FlexV1Plugin

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Flex.V1.PluginService.Plugin.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreatePlugin | Tags: FlexV1Plugin

Required Parameters

ParameterTypeDescription
UniqueNamestringThe Flex Plugin's unique name.

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DescriptionstringA descriptive string that you create to describe the plugin resource. It can be up to 500 characters long
FriendlyNamestringThe Flex Plugin's friendly name.

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Flex.V1.PluginService.Plugin.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchPlugin | Tags: FlexV1Plugin

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListPlugin | Tags: FlexV1Plugin

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Flex.V1.PluginService.Plugin.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdatePlugin | Tags: FlexV1Plugin

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DescriptionstringA descriptive string that you update to describe the plugin resource. It can be up to 500 characters long
FriendlyNamestringThe Flex Plugin's friendly name.