Service for User API operations.
Operations: fetch, update
Summary
Functions
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Flex.V2.Instance.User.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch flex user for the given flex user sid
Operation: FetchFlexUser | Tags: FlexV2FlexUser
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V2.Instance.User.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update flex user for the given flex user sid
Operation: UpdateFlexUser | Tags: FlexV2FlexUser
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Email | string | Email of the User. |
Locale | string | The locale preference of the user. |
UserSid | string | The unique SID identifier of the Twilio Unified User. |