Twilio.Flex.V2.WebChannelsService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for WebChannels API operations.

Operations: create

Summary

Functions

Operation: CreateWebChannel | Tags: FlexV2WebChannels

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Flex.V2.WebChannels.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateWebChannel | Tags: FlexV2WebChannels

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AddressSid | string | The SID of the Conversations Address. See Address Configuration Resource for configuration details. When a conversation is created on the Flex backend, the callback URL will be set to the corresponding Studio Flow SID or webhook URL in your address configuration. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ChatFriendlyName | string | The Conversation's friendly name. See the Conversation resource for an example. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CustomerFriendlyName | string | The Conversation participant's friendly name. See the Conversation Participant Resource for an example. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

IdentitystringThe Identity of the guest user. See the Conversation User Resource for an example.
PreEngagementDatastringThe pre-engagement data.