Twilio.Frontline.V1.UserService (twilio_elixir v0.1.1)

Copy Markdown View Source

A User resource represents a frontline user.

Operations: fetch, update

Summary

Functions

Fetch a frontline user

Update an existing frontline user

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Frontline.V1.User.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a frontline user

Operation: FetchUser | Tags: FrontlineV1User

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Frontline.V1.User.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update an existing frontline user

Operation: UpdateUser | Tags: FrontlineV1User

Optional Parameters

ParameterTypeDescription
AvatarstringThe avatar URL which will be shown in Frontline application.
FriendlyNamestringThe string that you assigned to describe the User.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

IsAvailablebooleanWhether the User is available for new conversations. Set to false to prevent User from receiving new inbound conversations if you are using Pool Routing.
StatestringValues: active, deactivated