Twilio.Iam.Organizations.AuthorizeService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Authorize API operations.

Operations: list

Summary

Functions

List Authorize resources.

Stream all resources with lazy auto-pagination.

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

List Authorize resources.

Operation: FetchAuthorize | Tags: OauthV1Authorize

Query Parameters

ParameterTypeDescription
response_typestringResponse Type
client_idstringThe Client Identifier
redirect_uristringThe url to which response will be redirected to
scopestringThe scope of the access request
statestringAn opaque value which can be used to maintain state between the request and callback

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream all resources with lazy auto-pagination.