Service for Token API operations.
Operations: create
Summary
Functions
Create a new Token.
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Iam.Organizations.Token.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Token.
Operation: CreateToken | Tags: OauthV1Token
Required Parameters
| Parameter | Type | Description |
|---|---|---|
client_id | string | A 34 character string that uniquely identifies this OAuth App. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| grant_type | string | Grant type is a credential representing resource owner's authorization which can be used by client to obtain access token. |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
audience | string | The targeted audience uri |
client_secret | string | The credential for confidential OAuth App. |
code | string | JWT token related to the authorization code grant type. |
redirect_uri | string | The redirect uri |
refresh_token | string | JWT token related to refresh access token. |
scope | string | The scope of token |