Twilio.Iam.V1.TokenService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Token API operations.

Operations: create

Summary

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Iam.V1.Token.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Token.

Operation: CreateToken | Tags: OauthV1Token

Required Parameters

ParameterTypeDescription
client_idstringA 34 character string that uniquely identifies this OAuth App.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| grant_type | string | Grant type is a credential representing resource owner's authorization which can be used by client to obtain access token. |

Optional Parameters

ParameterTypeDescription
audiencestringThe targeted audience uri
client_secretstringThe credential for confidential OAuth App.
codestringJWT token related to the authorization code grant type.
redirect_uristringThe redirect uri
refresh_tokenstringJWT token related to refresh access token.
scopestringThe scope of token