Twilio.Insights.V1.Conference.ParticipantService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Participant API operations.

Operations: list, fetch

Summary

Functions

Get a specific Conference Participant Summary for a Conference.

Get a list of Conference Participants Summaries for a Conference.

Stream: Get a list of Conference Participants Summaries for a Conference. (lazy auto-pagination).

Functions

fetch(client, conference_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Insights.V1.Conference.Participant.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Get a specific Conference Participant Summary for a Conference.

Operation: FetchConferenceParticipant | Tags: InsightsV1ConferenceParticipant

Query Parameters

ParameterTypeDescription
EventsstringConference events generated by application or participant activity; e.g. hold, mute, etc.
MetricsstringObject. Contains participant call quality metrics.

list(client, conference_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Get a list of Conference Participants Summaries for a Conference.

Operation: ListConferenceParticipant | Tags: InsightsV1ConferenceParticipant

Query Parameters

ParameterTypeDescription
ParticipantSidstringThe unique SID identifier of the Participant.
LabelstringUser-specified label for a participant.
EventsstringConference events generated by application or participant activity; e.g. hold, mute, etc.

stream(client, conference_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Get a list of Conference Participants Summaries for a Conference. (lazy auto-pagination).