Twilio.Insights.V1.ConferenceService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Conference API operations.

Operations: list, fetch

Summary

Functions

Get a specific Conference Summary.

Get a list of Conference Summaries.

Stream: Get a list of Conference Summaries. (lazy auto-pagination).

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Insights.V1.Conference.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Get a specific Conference Summary.

Operation: FetchConference | Tags: InsightsV1Conference

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Get a list of Conference Summaries.

Operation: ListConference | Tags: InsightsV1Conference

Query Parameters

ParameterTypeDescription
ConferenceSidstringThe SID of the conference.
FriendlyNamestringCustom label for the conference resource, up to 64 characters.
StatusstringConference status.
CreatedAfterstringConferences created after the provided timestamp specified in ISO 8601 format
CreatedBeforestringConferences created before the provided timestamp specified in ISO 8601 format.
MixerRegionstringTwilio region where the conference media was mixed.
TagsstringTags applied by Twilio for common potential configuration, quality, or performance issues.
SubaccountstringAccount SID for the subaccount whose resources you wish to retrieve.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DetectedIssuesstringPotential configuration, behavior, or performance issues detected during the conference.
EndReasonstringConference end reason; e.g. last participant left, modified by API, etc.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Get a list of Conference Summaries. (lazy auto-pagination).