Twilio.Insights.V1.Video.Room.ParticipantService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Participant API operations.

Operations: list, fetch

Summary

Functions

Get Video Log Analyzer data for a Room Participant.

Get a list of room participants.

Stream: Get a list of room participants. (lazy auto-pagination).

Functions

fetch(client, room_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Insights.V1.Video.Room.Participant.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Get Video Log Analyzer data for a Room Participant.

Operation: FetchVideoParticipantSummary | Tags: InsightsV1Participant

list(client, room_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Get a list of room participants.

Operation: ListVideoParticipantSummary | Tags: InsightsV1Participant

stream(client, room_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Get a list of room participants. (lazy auto-pagination).