Service for Event API operations.
Operations: list
Summary
Functions
Get a list of Call Insight Events for a Call.
Stream: Get a list of Call Insight Events for a Call. (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Get a list of Call Insight Events for a Call.
Operation: ListEvent | Tags: InsightsV1Event
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Edge | string | The Edge of this Event. One of unknown_edge, carrier_edge, sip_edge, sdk_edge or client_edge. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Get a list of Call Insight Events for a Call. (lazy auto-pagination).