Twilio.Insights.V1.Voice.MetricService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Metric API operations.

Operations: list

Summary

Functions

Get a list of Call Metrics for a Call.

Stream: Get a list of Call Metrics for a Call. (lazy auto-pagination).

Functions

list(client, call_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Get a list of Call Metrics for a Call.

Operation: ListMetric | Tags: InsightsV1Metric

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

EdgestringThe Edge of this Metric. One of unknown_edge, carrier_edge, sip_edge, sdk_edge or client_edge.
DirectionstringThe Direction of this Metric. One of unknown, inbound, outbound or both.

stream(client, call_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Get a list of Call Metrics for a Call. (lazy auto-pagination).