Twilio.Intelligence.V2.Operator.CustomService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Custom API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new Custom Operator for the given Account

Delete a specific Custom Operator.

Fetch a specific Custom Operator.

Retrieves a list of all Custom Operators for an Account.

Stream: Retrieves a list of all Custom Operators for an Account. (lazy auto-pagination).

Update a specific Custom Operator.

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Intelligence.V2.Operator.Custom.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Custom Operator for the given Account

Operation: CreateCustomOperator | Tags: IntelligenceV2CustomOperator

Required Parameters

ParameterTypeDescription
ConfigstringOperator configuration, following the schema defined by the Operator Type.
FriendlyNamestringA human readable description of the new Operator, up to 64 characters.
OperatorTypestringOperator Type for this Operator. References an existing Operator Type resource.

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Custom Operator.

Operation: DeleteCustomOperator | Tags: IntelligenceV2CustomOperator

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Intelligence.V2.Operator.Custom.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Custom Operator.

Operation: FetchCustomOperator | Tags: IntelligenceV2CustomOperator

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieves a list of all Custom Operators for an Account.

Operation: ListCustomOperator | Tags: IntelligenceV2CustomOperator

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AvailabilitystringReturns Custom Operators with the provided availability type. Possible values: internal, beta, public, retired.
LanguageCodestringReturns Custom Operators that support the provided language code.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieves a list of all Custom Operators for an Account. (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Intelligence.V2.Operator.Custom.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update a specific Custom Operator.

Operation: UpdateCustomOperator | Tags: IntelligenceV2CustomOperator

Required Parameters

ParameterTypeDescription
ConfigstringOperator configuration, following the schema defined by the Operator Type.
FriendlyNamestringA human-readable name of this resource, up to 64 characters.