Twilio.Intelligence.V2.OperatorService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Operator API operations.

Operations: list, fetch

Summary

Functions

Fetch a specific Operator. Works for both Custom and Pre-built Operators.

Retrieves a list of all Operators for an Account, both Custom and Pre-built.

Stream: Retrieves a list of all Operators for an Account, both Custom and Pre-built. (lazy auto-pagination).

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Intelligence.V2.Operator.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Operator. Works for both Custom and Pre-built Operators.

Operation: FetchOperator | Tags: IntelligenceV2Operator

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieves a list of all Operators for an Account, both Custom and Pre-built.

Operation: ListOperator | Tags: IntelligenceV2Operator

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AvailabilitystringReturns Operators with the provided availability type. Possible values: internal, beta, public, retired.
LanguageCodestringReturns Operators that support the provided language code.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieves a list of all Operators for an Account, both Custom and Pre-built. (lazy auto-pagination).