Service for OperatorType API operations.
Operations: list, fetch
Summary
Functions
Fetch a specific Operator Type.
Retrieves a list of all Operator Types for an Account.
Stream: Retrieves a list of all Operator Types for an Account. (lazy auto-pagination).
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Intelligence.V2.OperatorType.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Operator Type.
Operation: FetchOperatorType | Tags: IntelligenceV2OperatorType
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieves a list of all Operator Types for an Account.
Operation: ListOperatorType | Tags: IntelligenceV2OperatorType
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieves a list of all Operator Types for an Account. (lazy auto-pagination).