Twilio.Intelligence.V2.ServiceService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Service API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new Service for the given Account

Delete a specific Service.

Fetch a specific Service.

Retrieves a list of all Services for an account.

Stream: Retrieves a list of all Services for an account. (lazy auto-pagination).

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Intelligence.V2.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Service for the given Account

Operation: CreateService | Tags: IntelligenceV2Service

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UniqueName | string | Provides a unique and addressable name to be assigned to this Service, assigned by the developer, to be optionally used in addition to SID. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AutoRedaction | boolean | Instructs the Speech Recognition service to automatically redact PII from all transcripts made on this service. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AutoTranscribe | boolean | Instructs the Speech Recognition service to automatically transcribe all recordings made on the account. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DataLogging | boolean | Data logging allows Twilio to improve the quality of the speech recognition & language understanding services through using customer data to refine, fine tune and evaluate machine learning models. Note: Data logging cannot be activated via API, only via www.twilio.com, as it requires additional consent. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

EncryptionCredentialSidstringThe unique SID identifier of the Public Key resource used to encrypt the sentences and operator results.
FriendlyNamestringA human readable description of this resource, up to 64 characters.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| LanguageCode | string | The language code set during Service creation determines the Transcription language for all call recordings processed by that Service. The default is en-US if no language code is set. A Service can only support one language code, and it cannot be updated once it's set. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

MediaRedactionbooleanInstructs the Speech Recognition service to automatically redact PII from all transcripts media made on this service. The auto_redaction flag must be enabled, results in error otherwise.
WebhookHttpMethodstringValues: GET, POST, NULL
WebhookUrlstringThe URL Twilio will request when executing the Webhook.

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Service.

Operation: DeleteService | Tags: IntelligenceV2Service

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Intelligence.V2.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Service.

Operation: FetchService | Tags: IntelligenceV2Service

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieves a list of all Services for an account.

Operation: ListService | Tags: IntelligenceV2Service

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieves a list of all Services for an account. (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Intelligence.V2.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update a specific Service.

Operation: UpdateService | Tags: IntelligenceV2Service

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AutoRedaction | boolean | Instructs the Speech Recognition service to automatically redact PII from all transcripts made on this service. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AutoTranscribe | boolean | Instructs the Speech Recognition service to automatically transcribe all recordings made on the account. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DataLogging | boolean | Data logging allows Twilio to improve the quality of the speech recognition & language understanding services through using customer data to refine, fine tune and evaluate machine learning models. Note: Data logging cannot be activated via API, only via www.twilio.com, as it requires additional consent. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

EncryptionCredentialSidstringThe unique SID identifier of the Public Key resource used to encrypt the sentences and operator results.
FriendlyNamestringA human readable description of this resource, up to 64 characters.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MediaRedaction | boolean | Instructs the Speech Recognition service to automatically redact PII from all transcripts media made on this service. The auto_redaction flag must be enabled, results in error otherwise. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

UniqueNamestringProvides a unique and addressable name to be assigned to this Service, assigned by the developer, to be optionally used in addition to SID.
WebhookHttpMethodstringValues: GET, POST, NULL
WebhookUrlstringThe URL Twilio will request when executing the Webhook.