Twilio.Intelligence.V2.TranscriptService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Transcript API operations.

Operations: list, create, fetch, delete

Summary

Functions

Create a new Transcript for the service

Delete a specific Transcript.

Fetch a specific Transcript.

Retrieve a list of Transcripts for a given service.

Stream: Retrieve a list of Transcripts for a given service. (lazy auto-pagination).

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Intelligence.V2.Transcript.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Transcript for the service

Operation: CreateTranscript | Tags: IntelligenceV2Transcript

Required Parameters

ParameterTypeDescription
ChannelstringJSON object describing Media Channel including Source and Participants
ServiceSidstringThe unique SID identifier of the Service.

Optional Parameters

ParameterTypeDescription
CustomerKeystringUsed to store client provided metadata. Maximum of 64 double-byte UTF8 characters.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MediaStartTime | string (date-time) | The date that this Transcript's media was started, given in ISO 8601 format. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Transcript.

Operation: DeleteTranscript | Tags: IntelligenceV2Transcript

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Intelligence.V2.Transcript.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Transcript.

Operation: FetchTranscript | Tags: IntelligenceV2Transcript

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of Transcripts for a given service.

Operation: ListTranscript | Tags: IntelligenceV2Transcript

Query Parameters

ParameterTypeDescription
ServiceSidstringThe unique SID identifier of the Service.
BeforeStartTimestringFilter by before StartTime.
AfterStartTimestringFilter by after StartTime.
BeforeDateCreatedstringFilter by before DateCreated.
AfterDateCreatedstringFilter by after DateCreated.
StatusstringFilter by status.
LanguageCodestringFilter by Language Code.
SourceSidstringFilter by SourceSid.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of Transcripts for a given service. (lazy auto-pagination).