Twilio.Marketplace.V1.InstalledAddOn.InstalledAddOnUsageService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for InstalledAddOnUsage API operations.

Operations: create

Summary

Functions

Allows Twilio Marketplace publishers to manually report customer usage on No-code Partner Listings that they own.

Functions

create(client, installed_add_on_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Allows Twilio Marketplace publishers to manually report customer usage on No-code Partner Listings that they own.

Operation: CreateBillingUsage | Tags: MarketplaceBillingUsage