Twilio.Marketplace.V1.InstalledAddOnService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for InstalledAddOn API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

Install an Add-on for the Account specified.

Remove an Add-on installation from your account

Fetch an instance of an Add-on currently installed on this Account.

Retrieve a list of Add-ons currently installed on this Account.

Stream: Retrieve a list of Add-ons currently installed on this Account. (lazy auto-pagination).

Update an Add-on installation for the Account specified.

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Marketplace.V1.InstalledAddOn.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Install an Add-on for the Account specified.

Operation: CreateInstalledAddOn | Tags: MarketplaceInstalledAddOn

Required Parameters

ParameterTypeDescription
AcceptTermsOfServicebooleanWhether the Terms of Service were accepted.
AvailableAddOnSidstringThe SID of the AvaliableAddOn to install.

Optional Parameters

ParameterTypeDescription
ConfigurationstringThe JSON object that represents the configuration of the new Add-on being installed.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UniqueName | string | An application-defined string that uniquely identifies the resource. This value must be unique within the Account. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Remove an Add-on installation from your account

Operation: DeleteInstalledAddOn | Tags: MarketplaceInstalledAddOn

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Marketplace.V1.InstalledAddOn.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch an instance of an Add-on currently installed on this Account.

Operation: FetchInstalledAddOn | Tags: MarketplaceInstalledAddOn

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of Add-ons currently installed on this Account.

Operation: ListInstalledAddOn | Tags: MarketplaceInstalledAddOn

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of Add-ons currently installed on this Account. (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Marketplace.V1.InstalledAddOn.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update an Add-on installation for the Account specified.

Operation: UpdateInstalledAddOn | Tags: MarketplaceInstalledAddOn

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Configuration | string | Valid JSON object that conform to the configuration schema exposed by the associated AvailableAddOn resource. This is only required by Add-ons that need to be configured |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UniqueName | string | An application-defined string that uniquely identifies the resource. This value must be unique within the Account. |