Twilio.Messaging.V1.A2p.BrandRegistrationService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Messaging Service resource to add and fetch Brand Registrations.

Operations: list, create, fetch, update

Summary

Functions

Operation: CreateBrandRegistrations | Tags: MessagingV1BrandRegistration

Operation: FetchBrandRegistrations | Tags: MessagingV1BrandRegistration

Operation: ListBrandRegistrations | Tags: MessagingV1BrandRegistration

Stream: (lazy auto-pagination).

Operation: UpdateBrandRegistrations | Tags: MessagingV1BrandRegistration

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Messaging.V1.A2p.BrandRegistration.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateBrandRegistrations | Tags: MessagingV1BrandRegistration

Required Parameters

ParameterTypeDescription
A2PProfileBundleSidstringA2P Messaging Profile Bundle Sid.
CustomerProfileBundleSidstringCustomer Profile Bundle Sid.

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BrandType | string | Type of brand being created. One of: "STANDARD", "SOLE_PROPRIETOR". SOLE_PROPRIETOR is for low volume, SOLE_PROPRIETOR use cases. STANDARD is for all other use cases. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Mock | boolean | A boolean that specifies whether brand should be a mock or not. If true, brand will be registered as a mock brand. Defaults to false if no value is provided. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| SkipAutomaticSecVet | boolean | A flag to disable automatic secondary vetting for brands which it would otherwise be done. |

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Messaging.V1.A2p.BrandRegistration.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchBrandRegistrations | Tags: MessagingV1BrandRegistration

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListBrandRegistrations | Tags: MessagingV1BrandRegistration

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Messaging.V1.A2p.BrandRegistration.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateBrandRegistrations | Tags: MessagingV1BrandRegistration