Twilio.Messaging.V1.Service.Compliance.Usa2p.UsecaseService (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Messaging Service Use Case resource. Fetch possible use cases for service. The Use Cases API returns an empty list if there is an issue with the customer's A2P brand registration. This Brand cannot register any campaign use cases. Customers are requested to contact support with their A2P brand information.

Operations: list

Summary

Functions

Operation: FetchUsAppToPersonUsecase | Tags: MessagingV1UsAppToPersonUsecase

Functions

list(client, messaging_service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchUsAppToPersonUsecase | Tags: MessagingV1UsAppToPersonUsecase

Query Parameters

ParameterTypeDescription
BrandRegistrationSidstringThe unique string to identify the A2P brand.

stream(client, messaging_service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).