Twilio.Messaging.V1.Service.DestinationAlphaSenderService (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

A Messaging Service resource to add, fetch or remove Destination and Default Alpha Sender IDs from a Messaging Service. Destination Alpha Sender can send to a particular ISO country code. Default Alpha Senders can send to all countries.

Operations: list, create, fetch, delete

Summary

Functions

Operation: CreateDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender

Operation: DeleteDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender

Operation: FetchDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender

Operation: ListDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender

Functions

create(client, service_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Messaging.V1.Service.DestinationAlphaSender.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AlphaSender | string | The Alphanumeric Sender ID string. Can be up to 11 characters long. Valid characters are A-Z, a-z, 0-9, space, hyphen -, plus +, underscore _ and ampersand &. This value cannot contain only numbers. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| IsoCountryCode | string | The Optional Two Character ISO Country Code the Alphanumeric Sender ID will be used for. If the IsoCountryCode is not provided, a default Alpha Sender will be created that can be used across all countries. |

delete(client, service_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender

fetch(client, service_sid, sid, opts \\ [])

Operation: FetchDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender

list(client, service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| IsoCountryCode | string | Optional filter to return only alphanumeric sender IDs associated with the specified two-character ISO country code. |

stream(client, service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).