Twilio.Messaging.V1.Service.PreregisteredUsa2pService (twilio_elixir v0.1.1)

Copy Markdown View Source

Resource to associate preregistered campaign with Messaging Service.

Operations: create

Summary

Functions

Operation: CreateExternalCampaign | Tags: MessagingV1ExternalCampaign

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Messaging.V1.Service.PreregisteredUsa2p.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateExternalCampaign | Tags: MessagingV1ExternalCampaign

Required Parameters

ParameterTypeDescription
CampaignIdstringID of the preregistered campaign.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessagingServiceSid | string | The SID of the Messaging Service that the resource is associated with. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CnpMigration | boolean | Customers should use this flag during the ERC registration process to indicate to Twilio that the campaign being registered is undergoing CNP migration. It is important for the user to first trigger the CNP migration process for said campaign in their CSP portal and have Twilio accept the sharing request, before making this api call. |