Twilio.Messaging.V1.ServiceService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Messaging Service resource to create, fetch, update, delete or add/remove senders from Messaging Services.

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateService | Tags: MessagingV1Service

Operation: DeleteService | Tags: MessagingV1Service

Operation: FetchService | Tags: MessagingV1Service

Operation: ListService | Tags: MessagingV1Service

Stream: (lazy auto-pagination).

Operation: UpdateService | Tags: MessagingV1Service

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Messaging.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateService | Tags: MessagingV1Service

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AreaCodeGeomatch | boolean | Whether to enable Area Code Geomatch on the Service Instance. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FallbackMethod | string (http-method) | The HTTP method we should use to call fallback_url. Can be: GET or POST. Values: GET, POST |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FallbackToLongCode | boolean | [OBSOLETE] Former feature used to fallback to long code sender after certain short code message failures. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FallbackUrl | string (uri) | The URL that we call using fallback_method if an error occurs while retrieving or executing the TwiML from the Inbound Request URL. If the use_inbound_webhook_on_number field is enabled then the webhook url defined on the phone number will override the fallback_url defined for the Messaging Service. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| InboundMethod | string (http-method) | The HTTP method we should use to call inbound_request_url. Can be GET or POST and the default is POST. Values: GET, POST |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| InboundRequestUrl | string (uri) | The URL we call using inbound_method when a message is received by any phone number or short code in the Service. When this property is null, receiving inbound messages is disabled. All messages sent to the Twilio phone number or short code will not be logged and received on the Account. If the use_inbound_webhook_on_number field is enabled then the webhook url defined on the phone number will override the inbound_request_url defined for the Messaging Service. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

MmsConverterbooleanWhether to enable the MMS Converter for messages sent through the Service instance.
ScanMessageContentstringValues: inherit, enable, disable

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| SmartEncoding | boolean | Whether to enable Smart Encoding for messages sent through the Service instance. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| StatusCallback | string (uri) | The URL we should call to pass status updates about message delivery. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

StickySenderbooleanWhether to enable Sticky Sender on the Service instance.
SynchronousValidationbooleanReserved.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UseInboundWebhookOnNumber | boolean | A boolean value that indicates either the webhook url configured on the phone number will be used or inbound_request_url/fallback_url url will be called when a message is received from the phone number. If this field is enabled then the webhook url defined on the phone number will override the inbound_request_url/fallback_url defined for the Messaging Service. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Usecase | string | A string that describes the scenario in which the Messaging Service will be used. Possible values are notifications, marketing, verification, discussion, poll, undeclared. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ValidityPeriod | integer | How long, in seconds, messages sent from the Service are valid. Can be an integer from 1 to 36,000. Default value is 36,000. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteService | Tags: MessagingV1Service

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Messaging.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchService | Tags: MessagingV1Service

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListService | Tags: MessagingV1Service

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Messaging.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateService | Tags: MessagingV1Service

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AreaCodeGeomatch | boolean | Whether to enable Area Code Geomatch on the Service Instance. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FallbackMethod | string (http-method) | The HTTP method we should use to call fallback_url. Can be: GET or POST. Values: GET, POST |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FallbackToLongCode | boolean | [OBSOLETE] Former feature used to fallback to long code sender after certain short code message failures. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FallbackUrl | string (uri) | The URL that we call using fallback_method if an error occurs while retrieving or executing the TwiML from the Inbound Request URL. If the use_inbound_webhook_on_number field is enabled then the webhook url defined on the phone number will override the fallback_url defined for the Messaging Service. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| InboundMethod | string (http-method) | The HTTP method we should use to call inbound_request_url. Can be GET or POST and the default is POST. Values: GET, POST |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| InboundRequestUrl | string (uri) | The URL we call using inbound_method when a message is received by any phone number or short code in the Service. When this property is null, receiving inbound messages is disabled. All messages sent to the Twilio phone number or short code will not be logged and received on the Account. If the use_inbound_webhook_on_number field is enabled then the webhook url defined on the phone number will override the inbound_request_url defined for the Messaging Service. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

MmsConverterbooleanWhether to enable the MMS Converter for messages sent through the Service instance.
ScanMessageContentstringValues: inherit, enable, disable

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| SmartEncoding | boolean | Whether to enable Smart Encoding for messages sent through the Service instance. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| StatusCallback | string (uri) | The URL we should call to pass status updates about message delivery. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

StickySenderbooleanWhether to enable Sticky Sender on the Service instance.
SynchronousValidationbooleanReserved.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UseInboundWebhookOnNumber | boolean | A boolean value that indicates either the webhook url configured on the phone number will be used or inbound_request_url/fallback_url url will be called when a message is received from the phone number. If this field is enabled then the webhook url defined on the phone number will override the inbound_request_url/fallback_url defined for the Messaging Service. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Usecase | string | A string that describes the scenario in which the Messaging Service will be used. Possible values are notifications, marketing, verification, discussion, poll, undeclared. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ValidityPeriod | integer | How long, in seconds, messages sent from the Service are valid. Can be an integer from 1 to 36,000. Default value is 36,000. |