Twilio.Messaging.V1.Tollfree.VerificationService (twilio_elixir v0.1.1)

Copy Markdown View Source

A Messaging resource to create and retrieve Tollfree Verifications.

Operations: list, create, fetch, update, delete

Summary

Functions

Create a tollfree verification

Delete a tollfree verification

Retrieve a tollfree verification

List tollfree verifications

Stream: List tollfree verifications (lazy auto-pagination).

Edit a tollfree verification

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Messaging.V1.Tollfree.Verification.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a tollfree verification

Operation: CreateTollfreeVerification | Tags: MessagingV1TollfreeVerification

Required Parameters

ParameterTypeDescription
BusinessNamestringThe name of the business or organization using the Tollfree number.
BusinessWebsitestringThe website of the business or organization using the Tollfree number.
MessageVolumestringEstimate monthly volume of messages from the Tollfree Number.
NotificationEmailstringThe email address to receive the notification about the verification result. .

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| OptInImageUrls | array | Link to an image that shows the opt-in workflow. Multiple images allowed and must be a publicly hosted URL. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

OptInTypestringValues: VERBAL, WEB_FORM, PAPER_FORM, VIA_TEXT, MOBILE_QR_CODE, IMPORT, IMPORT_PLEASE_REPLACE
ProductionMessageSamplestringAn example of message content, i.e. a sample message.
TollfreePhoneNumberSidstringThe SID of the Phone Number associated with the Tollfree Verification.
UseCaseCategoriesarrayThe category of the use case for the Tollfree Number. List as many are applicable..
UseCaseSummarystringUse this to further explain how messaging is used by the business or organization.

Optional Parameters

ParameterTypeDescription
AdditionalInformationstringAdditional information to be provided for verification.
AgeGatedContentbooleanIndicates if the content is age gated.
BusinessCitystringThe city of the business or organization using the Tollfree number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BusinessContactEmail | string | The email address of the contact for the business or organization using the Tollfree number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BusinessContactFirstName | string | The first name of the contact for the business or organization using the Tollfree number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BusinessContactLastName | string | The last name of the contact for the business or organization using the Tollfree number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

BusinessContactPhonestring (phone-number)The E.164 formatted phone number of the contact for the business or organization using the Tollfree number.
BusinessCountrystringThe country of the business or organization using the Tollfree number.
BusinessPostalCodestringThe postal code of the business or organization using the Tollfree number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BusinessRegistrationAuthority | string | The organizational authority for business registrations. Required for all business types except SOLE_PROPRIETOR. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BusinessRegistrationCountry | string | The country where the business is registered. Required for all business types except SOLE_PROPRIETOR. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

BusinessRegistrationNumberstringA legally recognized business registration number. Required for all business types except SOLE_PROPRIETOR.
BusinessRegistrationPhoneNumberstringThe E.164 formatted number associated with the business.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

BusinessStateProvinceRegionstringThe state/province/region of the business or organization using the Tollfree number.
BusinessStreetAddressstringThe address of the business or organization using the Tollfree number.
BusinessStreetAddress2stringThe address of the business or organization using the Tollfree number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

BusinessTypestringThe type of business, valid values are PRIVATE_PROFIT, PUBLIC_PROFIT, NON_PROFIT, SOLE_PROPRIETOR, GOVERNMENT. Required field.
CustomerProfileSidstringCustomer's Profile Bundle BundleSid.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DoingBusinessAs | string | Trade name, sub entity, or downstream business name of business being submitted for verification |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ExternalReferenceIdstringAn optional external reference ID supplied by customer and echoed back on status retrieval.
HelpMessageSamplestringA sample help message provided to users.
OptInConfirmationMessagestringThe confirmation message sent to users when they opt in to receive messages.
OptInKeywordsarrayList of keywords that users can text in to opt in to receive messages.
PrivacyPolicyUrlstringThe URL to the privacy policy for the business or organization.
TermsAndConditionsUrlstringThe URL to the terms and conditions for the business or organization.
VettingIdstringThe unique ID of the vetting
VettingProviderstringValues: CAMPAIGN_VERIFY

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a tollfree verification

Operation: DeleteTollfreeVerification | Tags: MessagingV1TollfreeVerification

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Messaging.V1.Tollfree.Verification.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a tollfree verification

Operation: FetchTollfreeVerification | Tags: MessagingV1TollfreeVerification

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

List tollfree verifications

Operation: ListTollfreeVerification | Tags: MessagingV1TollfreeVerification

Query Parameters

ParameterTypeDescription
TollfreePhoneNumberSidstringThe SID of the Phone Number associated with the Tollfree Verification.
StatusstringThe compliance status of the Tollfree Verification record.
ExternalReferenceIdstringCustomer supplied reference id for the Tollfree Verification record.
IncludeSubAccountsbooleanWhether to include Tollfree Verifications from sub accounts in list response.
TrustProductSidarrayThe trust product sids / tollfree bundle sids of tollfree verifications

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: List tollfree verifications (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Messaging.V1.Tollfree.Verification.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Edit a tollfree verification

Operation: UpdateTollfreeVerification | Tags: MessagingV1TollfreeVerification

Optional Parameters

ParameterTypeDescription
AdditionalInformationstringAdditional information to be provided for verification.
AgeGatedContentbooleanIndicates if the content is age gated.
BusinessCitystringThe city of the business or organization using the Tollfree number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BusinessContactEmail | string | The email address of the contact for the business or organization using the Tollfree number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BusinessContactFirstName | string | The first name of the contact for the business or organization using the Tollfree number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BusinessContactLastName | string | The last name of the contact for the business or organization using the Tollfree number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

BusinessContactPhonestring (phone-number)The E.164 formatted phone number of the contact for the business or organization using the Tollfree number.
BusinessCountrystringThe country of the business or organization using the Tollfree number.
BusinessNamestringThe name of the business or organization using the Tollfree number.
BusinessPostalCodestringThe postal code of the business or organization using the Tollfree number.
BusinessRegistrationAuthoritystringThe organizational authority for business registrations
BusinessRegistrationCountrystringCountry business is registered in
BusinessRegistrationNumberstringA legaly recognized business registration number
BusinessRegistrationPhoneNumberstringThe E.164 formatted number associated with the business.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

BusinessStateProvinceRegionstringThe state/province/region of the business or organization using the Tollfree number.
BusinessStreetAddressstringThe address of the business or organization using the Tollfree number.
BusinessStreetAddress2stringThe address of the business or organization using the Tollfree number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

BusinessTypestringThe type of business, valid values are PRIVATE_PROFIT, PUBLIC_PROFIT, NON_PROFIT, SOLE_PROPRIETOR, GOVERNMENT
BusinessWebsitestringThe website of the business or organization using the Tollfree number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DoingBusinessAs | string | Trade name, sub entity, or downstream business name of business being submitted for verification |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

EditReasonstringDescribe why the verification is being edited. If the verification was rejected because of a technical issue, such as the website being down, and the issue has been resolved this parameter should be set to something similar to 'Website fixed'.
HelpMessageSamplestringA sample help message provided to users.
MessageVolumestringEstimate monthly volume of messages from the Tollfree Number.
NotificationEmailstringThe email address to receive the notification about the verification result. .
OptInConfirmationMessagestringThe confirmation message sent to users when they opt in to receive messages.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

OptInImageUrlsarrayLink to an image that shows the opt-in workflow. Multiple images allowed and must be a publicly hosted URL.
OptInKeywordsarrayList of keywords that users can text in to opt in to receive messages.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

OptInTypestringValues: VERBAL, WEB_FORM, PAPER_FORM, VIA_TEXT, MOBILE_QR_CODE, IMPORT, IMPORT_PLEASE_REPLACE
PrivacyPolicyUrlstringThe URL to the privacy policy for the business or organization.
ProductionMessageSamplestringAn example of message content, i.e. a sample message.
TermsAndConditionsUrlstringThe URL to the terms and conditions for the business or organization.
UseCaseCategoriesarrayThe category of the use case for the Tollfree Number. List as many are applicable..
UseCaseSummarystringUse this to further explain how messaging is used by the business or organization.
VettingIdstringThe unique ID of the vetting
VettingProviderstringValues: CAMPAIGN_VERIFY