Debugger alerts
Operations: list, fetch
Summary
Functions
Operation: FetchAlert | Tags: MonitorV1Alert
Operation: ListAlert | Tags: MonitorV1Alert
Stream: (lazy auto-pagination).
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Monitor.V1.Alert.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchAlert | Tags: MonitorV1Alert
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListAlert | Tags: MonitorV1Alert
Query Parameters
| Parameter | Type | Description |
|---|---|---|
LogLevel | string | Only show alerts for this log-level. Can be: error, warning, notice, or debug. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| StartDate | string (date-time) | Only include alerts that occurred on or after this date and time. Specify the date and time in GMT and format as YYYY-MM-DD or YYYY-MM-DDThh:mm:ssZ. Queries for alerts older than 30 days are not supported. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| EndDate | string (date-time) | Only include alerts that occurred on or before this date and time. Specify the date and time in GMT and format as YYYY-MM-DD or YYYY-MM-DDThh:mm:ssZ. Queries for alerts older than 30 days are not supported. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).