Twilio.Monitor.V1.EventService (twilio_elixir v0.1.1)

Copy Markdown View Source

Debugger events

Operations: list, fetch

Summary

Functions

Operation: FetchEvent | Tags: MonitorV1Event

Returns a list of events in the account, sorted by event-date.

Stream: Returns a list of events in the account, sorted by event-date. (lazy auto-pagination).

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Monitor.V1.Event.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchEvent | Tags: MonitorV1Event

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Returns a list of events in the account, sorted by event-date.

Operation: ListEvent | Tags: MonitorV1Event

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ActorSid | string | Only include events initiated by this Actor. Useful for auditing actions taken by specific users or API credentials. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| EventType | string | Only include events of this Event Type. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ResourceSid | string | Only include events that refer to this resource. Useful for discovering the history of a specific resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| SourceIpAddress | string | Only include events that originated from this IP address. Useful for tracking suspicious activity originating from the API or the Twilio Console. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| StartDate | string (date-time) | Only include events that occurred on or after this date. Specify the date in GMT and ISO 8601 format. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| EndDate | string (date-time) | Only include events that occurred on or before this date. Specify the date in GMT and ISO 8601 format. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Returns a list of events in the account, sorted by event-date. (lazy auto-pagination).