Service for Credential API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateCredential | Tags: NotifyV1Credential
Operation: DeleteCredential | Tags: NotifyV1Credential
Operation: FetchCredential | Tags: NotifyV1Credential
Operation: ListCredential | Tags: NotifyV1Credential
Stream: (lazy auto-pagination).
Operation: UpdateCredential | Tags: NotifyV1Credential
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Notify.V1.Credential.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateCredential | Tags: NotifyV1Credential
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Type | string | Values: gcm, apn, fcm |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ApiKey | string | [GCM only] The Server key of your project from Firebase console under Settings / Cloud messaging. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Certificate | string | [APN only] The URL-encoded representation of the certificate. Strip everything outside of the headers, e.g. -----BEGIN CERTIFICATE-----MIIFnTCCBIWgAwIBAgIIAjy9H849+E8wDQYJKoZIhvcNAQEFBQAwgZYxCzAJBgNV.....A==-----END CERTIFICATE----- |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| PrivateKey | string | [APN only] The URL-encoded representation of the private key. Strip everything outside of the headers, e.g. -----BEGIN RSA PRIVATE KEY-----MIIEpQIBAAKCAQEAuyf/lNrH9ck8DmNyo3fGgvCI1l9s+cmBY3WIz+cUDqmxiieR .-----END RSA PRIVATE KEY----- |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Sandbox | boolean | [APN only] Whether to send the credential to sandbox APNs. Can be true to send to sandbox APNs or false to send to production. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Secret | string | [FCM only] The Server key of your project from Firebase console under Settings / Cloud messaging. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteCredential | Tags: NotifyV1Credential
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Notify.V1.Credential.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchCredential | Tags: NotifyV1Credential
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListCredential | Tags: NotifyV1Credential
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Notify.V1.Credential.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateCredential | Tags: NotifyV1Credential
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ApiKey | string | [GCM only] The Server key of your project from Firebase console under Settings / Cloud messaging. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Certificate | string | [APN only] The URL-encoded representation of the certificate. Strip everything outside of the headers, e.g. -----BEGIN CERTIFICATE-----MIIFnTCCBIWgAwIBAgIIAjy9H849+E8wDQYJKoZIhvcNAQEFBQAwgZYxCzAJBgNV.....A==-----END CERTIFICATE----- |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| PrivateKey | string | [APN only] The URL-encoded representation of the private key. Strip everything outside of the headers, e.g. -----BEGIN RSA PRIVATE KEY-----MIIEpQIBAAKCAQEAuyf/lNrH9ck8DmNyo3fGgvCI1l9s+cmBY3WIz+cUDqmxiieR .-----END RSA PRIVATE KEY----- |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Sandbox | boolean | [APN only] Whether to send the credential to sandbox APNs. Can be true to send to sandbox APNs or false to send to production. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Secret | string | [FCM only] The Server key of your project from Firebase console under Settings / Cloud messaging. |