Twilio.Notify.V1.Service.BindingService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Binding API operations.

Operations: list, create, fetch, delete

Summary

Functions

Operation: CreateBinding | Tags: NotifyV1Binding

Operation: DeleteBinding | Tags: NotifyV1Binding

Operation: FetchBinding | Tags: NotifyV1Binding

Operation: ListBinding | Tags: NotifyV1Binding

Functions

create(client, service_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Notify.V1.Service.Binding.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateBinding | Tags: NotifyV1Binding

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AddressstringThe channel-specific address. For APNS, the device token. For FCM and GCM, the registration token. For SMS, a phone number in E.164 format. For Facebook Messenger, the Messenger ID of the user or a phone number in E.164 format.
BindingTypestringValues: apn, gcm, sms, fcm, facebook-messenger, alexa

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | string | The identity value that uniquely identifies the new resource's User within the Service. Up to 20 Bindings can be created for the same Identity in a given Service. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

CredentialSidstringThe SID of the Credential resource to be used to send notifications to this Binding. If present, this overrides the Credential specified in the Service resource. Applies to only apn, fcm, and gcm type Bindings.
EndpointstringDeprecated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| NotificationProtocolVersion | string | The protocol version to use to send the notification. This defaults to the value of default_xxxx_notification_protocol_version for the protocol in the Service. The current version is "3" for apn, fcm, and gcm type Bindings. The parameter is not applicable to sms and facebook-messenger type Bindings as the data format is fixed. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Tag | array | A tag that can be used to select the Bindings to notify. Repeat this parameter to specify more than one tag, up to a total of 20 tags. |

delete(client, service_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteBinding | Tags: NotifyV1Binding

fetch(client, service_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Notify.V1.Service.Binding.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchBinding | Tags: NotifyV1Binding

list(client, service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListBinding | Tags: NotifyV1Binding

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| StartDate | string (date) | Only include usage that has occurred on or after this date. Specify the date in GMT and format as YYYY-MM-DD. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| EndDate | string (date) | Only include usage that occurred on or before this date. Specify the date in GMT and format as YYYY-MM-DD. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | array | The User's identity value of the resources to read. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Tag | array | Only list Bindings that have all of the specified Tags. The following implicit tags are available: all, apn, fcm, gcm, sms, facebook-messenger. Up to 5 tags are allowed. |

stream(client, service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).