Twilio.Notify.V1.ServiceService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Service API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateService | Tags: NotifyV1Service

Operation: DeleteService | Tags: NotifyV1Service

Operation: FetchService | Tags: NotifyV1Service

Operation: ListService | Tags: NotifyV1Service

Stream: (lazy auto-pagination).

Operation: UpdateService | Tags: NotifyV1Service

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Notify.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateService | Tags: NotifyV1Service

Optional Parameters

ParameterTypeDescription
AlexaSkillIdstringDeprecated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ApnCredentialSidstringThe SID of the Credential to use for APN Bindings.
DefaultAlexaNotificationProtocolVersionstringDeprecated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DefaultApnNotificationProtocolVersion | string | The protocol version to use for sending APNS notifications. Can be overridden on a Binding by Binding basis when creating a Binding resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DefaultFcmNotificationProtocolVersion | string | The protocol version to use for sending FCM notifications. Can be overridden on a Binding by Binding basis when creating a Binding resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DefaultGcmNotificationProtocolVersionstringThe protocol version to use for sending GCM notifications. Can be overridden on a Binding by Binding basis when creating a Binding resource.
DeliveryCallbackEnabledbooleanCallback configuration that enables delivery callbacks, default false
DeliveryCallbackUrlstringURL to send delivery status callback.
FacebookMessengerPageIdstringDeprecated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FcmCredentialSid | string | The SID of the Credential to use for FCM Bindings. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

GcmCredentialSidstringThe SID of the Credential to use for GCM Bindings.
LogEnabledbooleanWhether to log notifications. Can be: true or false and the default is true.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessagingServiceSid | string | The SID of the Messaging Service to use for SMS Bindings. This parameter must be set in order to send SMS notifications. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteService | Tags: NotifyV1Service

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Notify.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchService | Tags: NotifyV1Service

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListService | Tags: NotifyV1Service

Query Parameters

ParameterTypeDescription
FriendlyNamestringThe string that identifies the Service resources to read.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Notify.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateService | Tags: NotifyV1Service

Optional Parameters

ParameterTypeDescription
AlexaSkillIdstringDeprecated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ApnCredentialSidstringThe SID of the Credential to use for APN Bindings.
DefaultAlexaNotificationProtocolVersionstringDeprecated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DefaultApnNotificationProtocolVersion | string | The protocol version to use for sending APNS notifications. Can be overridden on a Binding by Binding basis when creating a Binding resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DefaultFcmNotificationProtocolVersion | string | The protocol version to use for sending FCM notifications. Can be overridden on a Binding by Binding basis when creating a Binding resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DefaultGcmNotificationProtocolVersionstringThe protocol version to use for sending GCM notifications. Can be overridden on a Binding by Binding basis when creating a Binding resource.
DeliveryCallbackEnabledbooleanCallback configuration that enables delivery callbacks, default false
DeliveryCallbackUrlstringURL to send delivery status callback.
FacebookMessengerPageIdstringDeprecated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FcmCredentialSid | string | The SID of the Credential to use for FCM Bindings. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

GcmCredentialSidstringThe SID of the Credential to use for GCM Bindings.
LogEnabledbooleanWhether to log notifications. Can be: true or false and the default is true.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessagingServiceSid | string | The SID of the Messaging Service to use for SMS Bindings. This parameter must be set in order to send SMS notifications. |