Twilio.Numbers.V1.Porting.PortIn.PhoneNumberService
(twilio_elixir v0.1.1)
Service for PhoneNumber API operations.
Operations: fetch, delete
Summary
Functions
Allows to cancel a port in request phone number by SID
Fetch a phone number by port in request SID and phone number SID
Functions
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Allows to cancel a port in request phone number by SID
Operation: DeletePortingPortInPhoneNumber | Tags: NumbersV1PortingPortInPhoneNumber
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Numbers.V1.Porting.PortIn.PhoneNumber.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a phone number by port in request SID and phone number SID
Operation: FetchPortingPortInPhoneNumber | Tags: NumbersV1PortingPortInPhoneNumber