Twilio.Numbers.V1.Porting.PortInService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for PortIn API operations.

Operations: create, fetch, delete

Summary

Functions

Allows to create a new port in request

Allows to cancel a port in request by SID

Fetch a port in request by SID

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Numbers.V1.Porting.PortIn.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Allows to create a new port in request

Operation: CreatePortingPortIn | Tags: NumbersV1PortingPortIn

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Allows to cancel a port in request by SID

Operation: DeletePortingPortIn | Tags: NumbersV1PortingPortIn

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Numbers.V1.Porting.PortIn.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a port in request by SID

Operation: FetchPortingPortIn | Tags: NumbersV1PortingPortIn