Twilio.Numbers.V1.Porting.Portability.PhoneNumberService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for PhoneNumber API operations.

Operations: fetch

Summary

Functions

Check if a single phone number can be ported to Twilio

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Numbers.V1.Porting.Portability.PhoneNumber.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Check if a single phone number can be ported to Twilio

Operation: FetchPortingPortability | Tags: NumbersV1PortingPortability

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

TargetAccountSidstringAccount Sid to which the number will be ported. This can be used to determine if a sub account already has the number in its inventory or a different sub account. If this is not provided, the authenticated account will be assumed to be the target account.
AddressSidstringAddress Sid of customer to which the number will be ported.