Twilio.Numbers.V2.HostedNumber.AuthorizationDocument.DependentHostedNumberOrderService
(twilio_elixir v0.1.1)
Service for DependentHostedNumberOrder API operations.
Operations: list
Summary
Functions
Retrieve a list of dependent HostedNumberOrders belonging to the AuthorizationDocument.
Stream: Retrieve a list of dependent HostedNumberOrders belonging to the AuthorizationDocument. (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of dependent HostedNumberOrders belonging to the AuthorizationDocument.
Operation: ListDependentHostedNumberOrder | Tags: NumbersV2DependentHostedNumberOrder
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Status | string | Status of an instance resource. It can hold one of the values: 1. opened 2. signing, 3. signed LOA, 4. canceled, 5. failed. See the section entitled Status Values for more information on each of these statuses. |
PhoneNumber | string (phone-number) | An E164 formatted phone number hosted by this HostedNumberOrder. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
IncomingPhoneNumberSid | string | A 34 character string that uniquely identifies the IncomingPhoneNumber resource created by this HostedNumberOrder. |
FriendlyName | string | A human readable description of this resource, up to 128 characters. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of dependent HostedNumberOrders belonging to the AuthorizationDocument. (lazy auto-pagination).