Twilio.Numbers.V2.HostedNumber.AuthorizationDocumentService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for AuthorizationDocument API operations.

Operations: list, create, fetch, delete

Summary

Functions

Create an AuthorizationDocument for authorizing the hosting of phone number capabilities on Twilio's platform.

Cancel the AuthorizationDocument request.

Fetch a specific AuthorizationDocument.

Retrieve a list of AuthorizationDocuments belonging to the account initiating the request.

Stream: Retrieve a list of AuthorizationDocuments belonging to the account initiating the request. (lazy auto-pagination).

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Numbers.V2.HostedNumber.AuthorizationDocument.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create an AuthorizationDocument for authorizing the hosting of phone number capabilities on Twilio's platform.

Operation: CreateAuthorizationDocument | Tags: NumbersV2AuthorizationDocument

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AddressSid | string | A 34 character string that uniquely identifies the Address resource that is associated with this AuthorizationDocument. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ContactPhoneNumberstring (phone-number)The contact phone number of the person authorized to sign the Authorization Document.
EmailstringEmail that this AuthorizationDocument will be sent to for signing.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| HostedNumberOrderSids | array | A list of HostedNumberOrder sids that this AuthorizationDocument will authorize for hosting phone number capabilities on Twilio's platform. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CcEmails | array | Email recipients who will be informed when an Authorization Document has been sent and signed. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ContactTitle | string | The title of the person authorized to sign the Authorization Document for this phone number. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Cancel the AuthorizationDocument request.

Operation: DeleteAuthorizationDocument | Tags: NumbersV2AuthorizationDocument

fetch(client, sid, opts \\ [])

Fetch a specific AuthorizationDocument.

Operation: FetchAuthorizationDocument | Tags: NumbersV2AuthorizationDocument

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of AuthorizationDocuments belonging to the account initiating the request.

Operation: ListAuthorizationDocument | Tags: NumbersV2AuthorizationDocument

Query Parameters

ParameterTypeDescription
EmailstringEmail that this AuthorizationDocument will be sent to for signing.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Status | string | Status of an instance resource. It can hold one of the values: 1. opened 2. signing, 3. signed LOA, 4. canceled, 5. failed. See the section entitled Status Values for more information on each of these statuses. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of AuthorizationDocuments belonging to the account initiating the request. (lazy auto-pagination).