Twilio.Numbers.V2.RegulatoryCompliance.Bundle.CopyService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Copy API operations.

Operations: list, create

Summary

Functions

Retrieve a list of all Bundles Copies for a Bundle.

Stream: Retrieve a list of all Bundles Copies for a Bundle. (lazy auto-pagination).

Functions

create(client, bundle_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.Bundle.Copy.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Creates a new copy of a Bundle. It will internally create copies of all the bundle items (identities and documents) of the original bundle

Operation: CreateBundleCopy | Tags: NumbersV2BundleCopy

Optional Parameters

ParameterTypeDescription
FriendlyNamestringThe string that you assigned to describe the copied bundle.

list(client, bundle_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Bundles Copies for a Bundle.

Operation: ListBundleCopy | Tags: NumbersV2BundleCopy

stream(client, bundle_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Bundles Copies for a Bundle. (lazy auto-pagination).