Twilio.Numbers.V2.RegulatoryCompliance.Bundle.ReplaceItemsService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for ReplaceItems API operations.

Operations: create

Summary

Functions

create(client, bundle_sid, params \\ %{}, opts \\ [])

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Replaces all bundle items in the target bundle (specified in the path) with all the bundle items of the source bundle (specified by the from_bundle_sid body param)

Operation: CreateReplaceItems | Tags: NumbersV2ReplaceItems

Required Parameters

ParameterTypeDescription
FromBundleSidstringThe source bundle sid to copy the item assignments from.