Twilio.Numbers.V2.RegulatoryCompliance.EndUserService
(twilio_elixir v0.1.1)
Service for EndUser API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new End User.
Delete a specific End User.
Fetch specific End User Instance.
Retrieve a list of all End User for an account.
Stream: Retrieve a list of all End User for an account. (lazy auto-pagination).
Update an existing End User.
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.EndUser.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new End User.
Operation: CreateEndUser | Tags: NumbersV2EndUser
Required Parameters
| Parameter | Type | Description |
|---|---|---|
FriendlyName | string | The string that you assigned to describe the resource. |
Type | string | Values: individual, business |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Attributes | string | The set of parameters that are the attributes of the End User resource which are derived End User Types. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific End User.
Operation: DeleteEndUser | Tags: NumbersV2EndUser
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.EndUser.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch specific End User Instance.
Operation: FetchEndUser | Tags: NumbersV2EndUser
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all End User for an account.
Operation: ListEndUser | Tags: NumbersV2EndUser
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all End User for an account. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.EndUser.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an existing End User.
Operation: UpdateEndUser | Tags: NumbersV2EndUser
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Attributes | string | The set of parameters that are the attributes of the End User resource which are derived End User Types. |
FriendlyName | string | The string that you assigned to describe the resource. |