Twilio.Numbers.V2.RegulatoryCompliance.RegulationService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Regulation API operations.

Operations: list, fetch

Summary

Functions

Fetch specific Regulation Instance.

Retrieve a list of all Regulations.

Stream: Retrieve a list of all Regulations. (lazy auto-pagination).

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.Regulation.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch specific Regulation Instance.

Operation: FetchRegulation | Tags: NumbersV2Regulation

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| IncludeConstraints | boolean | A boolean parameter indicating whether to include constraints or not for supporting end user, documents and their fields |

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Regulations.

Operation: ListRegulation | Tags: NumbersV2Regulation

Query Parameters

ParameterTypeDescription
EndUserTypestringThe type of End User the regulation requires - can be individual or business.
IsoCountrystringThe ISO country code of the phone number's country.
NumberTypestringThe type of phone number that the regulatory requiremnt is restricting.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| IncludeConstraints | boolean | A boolean parameter indicating whether to include constraints or not for supporting end user, documents and their fields |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Regulations. (lazy auto-pagination).