Twilio.Numbers.V2.RegulatoryCompliance.SupportingDocumentService
(twilio_elixir v0.1.1)
Service for SupportingDocument API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new Supporting Document.
Delete a specific Supporting Document.
Fetch specific Supporting Document Instance.
Retrieve a list of all Supporting Document for an account.
Stream: Retrieve a list of all Supporting Document for an account. (lazy auto-pagination).
Update an existing Supporting Document.
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.SupportingDocument.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Supporting Document.
Operation: CreateSupportingDocument | Tags: NumbersV2SupportingDocument
Required Parameters
| Parameter | Type | Description |
|---|---|---|
FriendlyName | string | The string that you assigned to describe the resource. |
Type | string | The type of the Supporting Document. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Attributes | string | The set of parameters that are the attributes of the Supporting Documents resource which are derived Supporting Document Types. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Supporting Document.
Operation: DeleteSupportingDocument | Tags: NumbersV2SupportingDocument
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.SupportingDocument.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch specific Supporting Document Instance.
Operation: FetchSupportingDocument | Tags: NumbersV2SupportingDocument
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Supporting Document for an account.
Operation: ListSupportingDocument | Tags: NumbersV2SupportingDocument
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Supporting Document for an account. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.SupportingDocument.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an existing Supporting Document.
Operation: UpdateSupportingDocument | Tags: NumbersV2SupportingDocument
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Attributes | string | The set of parameters that are the attributes of the Supporting Document resource which are derived Supporting Document Types. |
FriendlyName | string | The string that you assigned to describe the resource. |