Twilio.Oauth.V1.AuthorizeService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Authorize API operations.

Operations: list

Summary

Functions

Retrieves authorize uri

Stream: Retrieves authorize uri (lazy auto-pagination).

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieves authorize uri

Operation: FetchAuthorize | Tags: OauthV1Authorize

Query Parameters

ParameterTypeDescription
ResponseTypestringResponse Type
ClientIdstringThe Client Identifier
RedirectUristringThe url to which response will be redirected to
ScopestringThe scope of the access request
StatestringAn opaque value which can be used to maintain state between the request and callback

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieves authorize uri (lazy auto-pagination).