Twilio.Oauth.V1.TokenService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Token API operations.

Operations: create

Summary

Functions

Issues a new Access token (optionally identity_token & refresh_token) in exchange of Oauth grant

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Oauth.V1.Token.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Issues a new Access token (optionally identity_token & refresh_token) in exchange of Oauth grant

Operation: CreateToken | Tags: OauthV1Token

Required Parameters

ParameterTypeDescription
ClientIdstringA 34 character string that uniquely identifies this OAuth App.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| GrantType | string | Grant type is a credential representing resource owner's authorization which can be used by client to obtain access token. |

Optional Parameters

ParameterTypeDescription
AudiencestringThe targeted audience uri
ClientSecretstringThe credential for confidential OAuth App.
CodestringJWT token related to the authorization code grant type.
RedirectUristringThe redirect uri
RefreshTokenstringJWT token related to refresh access token.
ScopestringThe scope of token