Twilio.Oauth.V2.TokenService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Token API operations.

Operations: create

Summary

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Oauth.V2.Token.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Token.

Operation: CreateOauth2Token | Tags: OauthV2Token

Optional Parameters

ParameterTypeDescription
audiencestringThe targeted audience uri
client_idstringA 34 character string that uniquely identifies this OAuth App.
client_secretstringThe credential for confidential OAuth App.
codestringJWT token related to the authorization code grant type.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

grant_typestringGrant type is a credential representing resource owner's authorization which can be used by client to obtain access token.
redirect_uristringThe redirect uri
refresh_tokenstringJWT token related to refresh access token.
scopestringThe scope of token

Query Parameters

ParameterTypeDescription
account_sidstringOptional Account SID to perform on behalf of requests.