Twilio.Preview.HostedNumber.AuthorizationDocument.DependentHostedNumberOrderService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for DependentHostedNumberOrder API operations.

Operations: list

Summary

Functions

Retrieve a list of dependent HostedNumberOrders belonging to the AuthorizationDocument.

Stream: Retrieve a list of dependent HostedNumberOrders belonging to the AuthorizationDocument. (lazy auto-pagination).

Functions

list(client, signing_document_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of dependent HostedNumberOrders belonging to the AuthorizationDocument.

Operation: ListHostedNumbersDependentHostedNumberOrder | Tags: PreviewHostedNumbersDependentHostedNumberOrder

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

StatusstringStatus of an instance resource. It can hold one of the values: 1. opened 2. signing, 3. signed LOA, 4. canceled, 5. failed. See the section entitled Status Values for more information on each of these statuses.
PhoneNumberstring (phone-number)An E164 formatted phone number hosted by this HostedNumberOrder.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

IncomingPhoneNumberSidstringA 34 character string that uniquely identifies the IncomingPhoneNumber resource created by this HostedNumberOrder.
FriendlyNamestringA human readable description of this resource, up to 64 characters.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UniqueName | string | Provides a unique and addressable name to be assigned to this HostedNumberOrder, assigned by the developer, to be optionally used in addition to SID. |

stream(client, signing_document_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of dependent HostedNumberOrders belonging to the AuthorizationDocument. (lazy auto-pagination).