Twilio.Preview.HostedNumber.AuthorizationDocumentService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for AuthorizationDocument API operations.

Operations: list, create, fetch, update

Summary

Functions

Create an AuthorizationDocument for authorizing the hosting of phone number capabilities on Twilio's platform.

Fetch a specific AuthorizationDocument.

Retrieve a list of AuthorizationDocuments belonging to the account initiating the request.

Stream: Retrieve a list of AuthorizationDocuments belonging to the account initiating the request. (lazy auto-pagination).

Updates a specific AuthorizationDocument.

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Preview.HostedNumber.AuthorizationDocument.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create an AuthorizationDocument for authorizing the hosting of phone number capabilities on Twilio's platform.

Operation: CreateHostedNumbersAuthorizationDocument | Tags: PreviewHostedNumbersAuthorizationDocument

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AddressSid | string | A 34 character string that uniquely identifies the Address resource that is associated with this AuthorizationDocument. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ContactPhoneNumber | string | The contact phone number of the person authorized to sign the Authorization Document. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ContactTitlestringThe title of the person authorized to sign the Authorization Document for this phone number.
EmailstringEmail that this AuthorizationDocument will be sent to for signing.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| HostedNumberOrderSids | array | A list of HostedNumberOrder sids that this AuthorizationDocument will authorize for hosting phone number capabilities on Twilio's platform. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CcEmails | array | Email recipients who will be informed when an Authorization Document has been sent and signed. |

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Preview.HostedNumber.AuthorizationDocument.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific AuthorizationDocument.

Operation: FetchHostedNumbersAuthorizationDocument | Tags: PreviewHostedNumbersAuthorizationDocument

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of AuthorizationDocuments belonging to the account initiating the request.

Operation: ListHostedNumbersAuthorizationDocument | Tags: PreviewHostedNumbersAuthorizationDocument

Query Parameters

ParameterTypeDescription
EmailstringEmail that this AuthorizationDocument will be sent to for signing.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Status | string | Status of an instance resource. It can hold one of the values: 1. opened 2. signing, 3. signed LOA, 4. canceled, 5. failed. See the section entitled Status Values for more information on each of these statuses. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of AuthorizationDocuments belonging to the account initiating the request. (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Preview.HostedNumber.AuthorizationDocument.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Updates a specific AuthorizationDocument.

Operation: UpdateHostedNumbersAuthorizationDocument | Tags: PreviewHostedNumbersAuthorizationDocument

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AddressSidstringA 34 character string that uniquely identifies the Address resource that is associated with this AuthorizationDocument.
CcEmailsarrayEmail recipients who will be informed when an Authorization Document has been sent and signed

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ContactPhoneNumber | string | The contact phone number of the person authorized to sign the Authorization Document. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ContactTitlestringThe title of the person authorized to sign the Authorization Document for this phone number.
EmailstringEmail that this AuthorizationDocument will be sent to for signing.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

HostedNumberOrderSidsarrayA list of HostedNumberOrder sids that this AuthorizationDocument will authorize for hosting phone number capabilities on Twilio's platform.
StatusstringValues: opened, signing, signed, canceled, failed