Twilio.Preview.Marketplace.InstalledAddOn.InstalledAddOnExtensionService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for InstalledAddOnExtension API operations.

Operations: list, fetch, update

Summary

Functions

Fetch an instance of an Extension for the Installed Add-on.

Retrieve a list of Extensions for the Installed Add-on.

Stream: Retrieve a list of Extensions for the Installed Add-on. (lazy auto-pagination).

Update an Extension for an Add-on installation.

Functions

fetch(client, installed_add_on_sid, sid, opts \\ [])

Fetch an instance of an Extension for the Installed Add-on.

Operation: FetchMarketplaceInstalledAddOnExtension | Tags: PreviewMarketplaceInstalledAddOnExtension

list(client, installed_add_on_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of Extensions for the Installed Add-on.

Operation: ListMarketplaceInstalledAddOnExtension | Tags: PreviewMarketplaceInstalledAddOnExtension

stream(client, installed_add_on_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of Extensions for the Installed Add-on. (lazy auto-pagination).

update(client, installed_add_on_sid, sid, params \\ %{}, opts \\ [])

Update an Extension for an Add-on installation.

Operation: UpdateMarketplaceInstalledAddOnExtension | Tags: PreviewMarketplaceInstalledAddOnExtension

Required Parameters

ParameterTypeDescription
EnabledbooleanWhether the Extension should be invoked.