Service for InstalledAddOn API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Install an Add-on for the Account specified.
Remove an Add-on installation from your account
Fetch an instance of an Add-on currently installed on this Account.
Retrieve a list of Add-ons currently installed on this Account.
Stream: Retrieve a list of Add-ons currently installed on this Account. (lazy auto-pagination).
Update an Add-on installation for the Account specified.
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Preview.Marketplace.InstalledAddOn.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Install an Add-on for the Account specified.
Operation: CreateMarketplaceInstalledAddOn | Tags: PreviewMarketplaceInstalledAddOn
Required Parameters
| Parameter | Type | Description |
|---|---|---|
AcceptTermsOfService | boolean | Whether the Terms of Service were accepted. |
AvailableAddOnSid | string | The SID of the AvaliableAddOn to install. |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Configuration | string | The JSON object that represents the configuration of the new Add-on being installed. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. This value must be unique within the Account. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Remove an Add-on installation from your account
Operation: DeleteMarketplaceInstalledAddOn | Tags: PreviewMarketplaceInstalledAddOn
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Preview.Marketplace.InstalledAddOn.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch an instance of an Add-on currently installed on this Account.
Operation: FetchMarketplaceInstalledAddOn | Tags: PreviewMarketplaceInstalledAddOn
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Add-ons currently installed on this Account.
Operation: ListMarketplaceInstalledAddOn | Tags: PreviewMarketplaceInstalledAddOn
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Add-ons currently installed on this Account. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Preview.Marketplace.InstalledAddOn.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an Add-on installation for the Account specified.
Operation: UpdateMarketplaceInstalledAddOn | Tags: PreviewMarketplaceInstalledAddOn
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Configuration | string | Valid JSON object that conform to the configuration schema exposed by the associated AvailableAddOn resource. This is only required by Add-ons that need to be configured |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. This value must be unique within the Account. |