Trunking pricing for a specific phone number
Operations: fetch
Summary
Functions
Fetch pricing information for a specific destination and, optionally, origination phone number.
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Pricing.V2.Trunking.Number.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch pricing information for a specific destination and, optionally, origination phone number.
Operation: FetchTrunkingNumber | Tags: PricingV2Number
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| OriginationNumber | string (phone-number) | The origination phone number, in E.164 format, for which to fetch the origin-based voice pricing information. E.164 format consists of a + followed by the country code and subscriber number. |