Twilio.Pricing.V2.Voice.NumberService (twilio_elixir v0.1.1)

Copy Markdown View Source

Voice pricing for a specific phone number

Operations: fetch

Summary

Functions

Fetch pricing information for a specific destination and, optionally, origination phone number.

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Pricing.V2.Voice.Number.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch pricing information for a specific destination and, optionally, origination phone number.

Operation: FetchVoiceNumber | Tags: PricingV2Number

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| OriginationNumber | string (phone-number) | The origination phone number, in E.164 format, for which to fetch the origin-based voice pricing information. E.164 format consists of a + followed by the country code and subscriber number. |