Service for Interaction API operations.
Operations: list, fetch, delete
Summary
Functions
Delete a specific Interaction.
Retrieve a list of Interactions for a given Session.
Retrieve a list of all Interactions for a Session. A maximum of 100 records will be returned per page.
Stream: Retrieve a list of all Interactions for a Session. A maximum of 100 records will be returned per page. (lazy auto-pagination).
Functions
@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Interaction.
Operation: DeleteInteraction | Tags: ProxyV1Interaction
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Proxy.V1.Service.Session.Interaction.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Interactions for a given Session.
Operation: FetchInteraction | Tags: ProxyV1Interaction
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Interactions for a Session. A maximum of 100 records will be returned per page.
Operation: ListInteraction | Tags: ProxyV1Interaction
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Interactions for a Session. A maximum of 100 records will be returned per page. (lazy auto-pagination).