Twilio.Proxy.V1.Service.Session.Participant.MessageInteractionService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for MessageInteraction API operations.

Operations: list, create, fetch

Summary

Functions

create(client, service_sid, session_sid, participant_sid, params \\ %{}, opts \\ [])

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Create a new message Interaction to send directly from your system to one Participant. The inbound properties for the Interaction will always be empty.

Operation: CreateMessageInteraction | Tags: ProxyV1MessageInteraction

Optional Parameters

ParameterTypeDescription
BodystringThe message to send to the participant
MediaUrlarrayReserved. Not currently supported.

fetch(client, service_sid, session_sid, participant_sid, sid, opts \\ [])

Operation: FetchMessageInteraction | Tags: ProxyV1MessageInteraction

list(client, service_sid, session_sid, participant_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListMessageInteraction | Tags: ProxyV1MessageInteraction

stream(client, service_sid, session_sid, participant_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: (lazy auto-pagination).