Twilio.Resources.Accounts.V1.AuthToken.Promote (twilio_elixir v0.1.1)

Copy Markdown View Source

Auth Token promotion

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that the secondary Auth Token was created for.
auth_tokenThe promoted Auth Token that must be used to authenticate future API requests.. PII: sensitive

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in UTC when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
urlThe URI for this resource, relative to https://accounts.twilio.com. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Accounts.V1.AuthToken.Promote{
  account_sid: String.t() | nil,
  auth_token: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()