Twilio.Resources.Accounts.V1.AuthToken.Secondary (twilio_elixir v0.1.1)

Copy Markdown View Source

Secondary Auth Token

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that the secondary Auth Token was created for. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in UTC when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in UTC when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

secondary_auth_tokenThe generated secondary Auth Token that can be used to authenticate future API requests.. PII: sensitive
urlThe URI for this resource, relative to https://accounts.twilio.com. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Accounts.V1.AuthToken.Secondary{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  secondary_auth_token: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()