Twilio.Resources.Accounts.V1.Credential.PublicKey (twilio_elixir v0.1.1)

Copy Markdown View Source

User provided public keys

SID prefix: CR

Parent: /Credentials

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Credential that the PublicKey resource belongs to. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.. PII: standard
sidThe unique string that that we created to identify the PublicKey resource.
urlThe URI for this resource, relative to https://accounts.twilio.com. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Accounts.V1.Credential.PublicKey{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()