Twilio.Resources.Api.V2010.Call.Event (twilio_elixir v0.1.1)

Copy Markdown View Source

API and webhook requests and responses. Contains parameters and TwiML for application control.

Parent: /Accounts/{AccountSid}/Calls/{Sid}.json

Properties

FieldDescription
requestContains a dictionary representing the request of the call.. PII: sensitive

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| response | Contains a dictionary representing the call response, including a list of the call events.. PII: sensitive |

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.Call.Event{
  request: String.t() | nil,
  response: String.t() | nil
}

Functions

object_name()