Twilio.Resources.Api.V2010.Call.Payment (twilio_elixir v0.1.1)

Copy Markdown View Source

Twilio enabled secure payments solution for accepting credit and ACH payments over the phone.

SID prefix: PK

Parent: /Accounts/{AccountSid}/Calls/{Sid}.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Payments resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| call_sid | The SID of the Call the Payments resource is associated with. This will refer to the call sid that is producing the payment card (credit/ACH) information thru DTMF. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time-rfc-2822
sidThe SID of the Payments resource.
uriThe URI of the resource, relative to https://api.twilio.com.

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.Call.Payment{
  account_sid: String.t() | nil,
  call_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  sid: String.t() | nil,
  uri: String.t() | nil
}

Functions

object_name()

sid_prefix()