Twilio.Resources.Api.V2010.Call.Transcription (twilio_elixir v0.1.1)

Copy Markdown View Source

Transcription resource.

SID prefix: GT

Parent: /Accounts/{AccountSid}/Calls/{Sid}.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created this Transcription resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| call_sid | The SID of the Call the Transcription resource is associated with. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT that this resource was last updated, specified in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

nameThe user-specified name of this Transcription, if one was given when the Transcription was created. This may be used to stop the Transcription.
sidThe SID of the Transcription resource.
statusThe status - one of stopped, in-flight. Values: in-progress, stopped

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.Call.Transcription{
  account_sid: String.t() | nil,
  call_sid: String.t() | nil,
  date_updated: String.t() | nil,
  name: String.t() | nil,
  sid: String.t() | nil,
  status: String.t(),
  uri: String.t() | nil
}

Functions

object_name()

sid_prefix()