Twilio.Resources.Api.V2010.Call.UserDefinedMessage (twilio_elixir v0.1.1)

Copy Markdown View Source

Allows your server-side application to send messages to the Voice SDK end user during an active Call.

SID prefix: KX

Parent: /Accounts/{AccountSid}/Calls/{Sid}.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created User Defined Message. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| call_sid | The SID of the Call the User Defined Message is associated with. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_createdThe date that this User Defined Message was created, given in RFC 2822 format.. Format: date-time-rfc-2822
sidThe SID that uniquely identifies this User Defined Message.

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.Call.UserDefinedMessage{
  account_sid: String.t() | nil,
  call_sid: String.t() | nil,
  date_created: String.t() | nil,
  sid: String.t() | nil
}

Functions

object_name()

sid_prefix()