Twilio.Resources.Api.V2010.Call.UserDefinedMessageSubscription (twilio_elixir v0.1.1)

Copy Markdown View Source

Subscription for server-side application access to messages sent from the Voice SDK for an active Call.

SID prefix: ZY

Parent: /Accounts/{AccountSid}/Calls/{Sid}.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that subscribed to the User Defined Messages. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| call_sid | The SID of the Call the User Defined Message Subscription is associated with. This refers to the Call SID that is producing the User Defined Messages. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_createdThe date that this User Defined Message Subscription was created, given in RFC 2822 format.. Format: date-time-rfc-2822
sidThe SID that uniquely identifies this User Defined Message Subscription.
uriThe URI of the User Defined Message Subscription Resource, relative to https://api.twilio.com.

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.Call.UserDefinedMessageSubscription{
  account_sid: String.t() | nil,
  call_sid: String.t() | nil,
  date_created: String.t() | nil,
  sid: String.t() | nil,
  uri: String.t() | nil
}

Functions

object_name()

sid_prefix()