Twilio.Resources.Api.V2010.IncomingPhoneNumber.AssignedAddOn (twilio_elixir v0.1.1)

Copy Markdown View Source

AssignedAddOn resource.

SID prefix: XE

Parent: /Accounts/{AccountSid}/IncomingPhoneNumbers/{Sid}.json

Sub-resources

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

  • extensions/2010-04-01/Accounts/{account_sid}/IncomingPhoneNumbers/{resource_sid}/AssignedAddOns/{assigned_add_on_sid}/Extensions.json

Properties

FieldDescription
account_sidThe SID of the Account that created the resource.
configurationA JSON string that represents the current configuration of this Add-on installation.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time-rfc-2822
descriptionA short description of the functionality that the Add-on provides.
friendly_nameThe string that you assigned to describe the resource.. PII: standard
resource_sidThe SID of the Phone Number to which the Add-on is assigned.
sidThe unique string that that we created to identify the resource.
subresource_urisA list of related resources identified by their relative URIs.. Format: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unique_nameAn application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource.
uriThe URI of the resource, relative to https://api.twilio.com.

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.IncomingPhoneNumber.AssignedAddOn{
  account_sid: String.t() | nil,
  configuration: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  description: String.t() | nil,
  friendly_name: String.t() | nil,
  resource_sid: String.t() | nil,
  sid: String.t() | nil,
  subresource_uris: map() | nil,
  unique_name: String.t() | nil,
  uri: String.t() | nil
}

Functions

object_name()

sid_prefix()