Twilio.Resources.Api.V2010.IncomingPhoneNumber.Local (twilio_elixir v0.1.1)

Copy Markdown View Source

Incoming local phone numbers on a Twilio account/project

SID prefix: PN

Parent: /Accounts/{AccountSid}/IncomingPhoneNumbers.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

address_requirementsWhether the phone number requires an Address registered with Twilio. Can be: none, any, local, or foreign.. Values: none, any, local, foreign
account_sidThe SID of the Account that created the resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sms_fallback_url | The URL that we call when an error occurs while retrieving or executing the TwiML from sms_url.. Format: uri |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| emergency_status | The parameter displays if emergency calling is enabled for this number. Active numbers may place emergency calls by dialing valid emergency numbers for the country.. Values: Active, Inactive |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

voice_fallback_methodThe HTTP method we use to call voice_fallback_url. Can be: GET or POST.. Values: GET, POST. Format: http-method
betaWhether the phone number is new to the Twilio platform. Can be: true or false.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

status_callback_methodThe HTTP method we use to call status_callback. Can be: GET or POST.. Values: GET, POST. Format: http-method
api_versionThe API version used to start a new TwiML session.
sms_urlThe URL we call when the phone number receives an incoming SMS message.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| phone_number | The phone number in E.164 format, which consists of a + followed by the country code and subscriber number.. Format: phone-number |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

sms_methodThe HTTP method we use to call sms_url. Can be: GET or POST.. Values: GET, POST. Format: http-method
friendly_nameThe string that you assigned to describe the resource.. PII: standard

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sms_fallback_method | The HTTP method we use to call sms_fallback_url. Can be: GET or POST.. Values: GET, POST. Format: http-method |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| capabilities | The set of Boolean properties that indicate whether a phone number can receive calls or messages. Capabilities are Voice, SMS, and MMS and each capability can be: true or false.. Format: phone-number-capabilities |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| voice_fallback_url | The URL that we call when an error occurs retrieving or executing the TwiML requested by url.. Format: uri |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| identity_sid | The SID of the Identity resource that we associate with the phone number. Some regions require an Identity to meet local regulations. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| bundle_sid | The SID of the Bundle resource that you associate with the phone number. Some regions require a Bundle to meet local Regulations. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| emergency_address_status | The status of address registration with emergency services. A registered emergency address will be used during handling of emergency calls from this number.. Values: registered, unregistered, pending-registration, registration-failure, pending-unregistration, unregistration-failure |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sms_application_sid | The SID of the application that handles SMS messages sent to the phone number. If an sms_application_sid is present, we ignore all sms_*_url values and use those of the application. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| voice_application_sid | The SID of the application that handles calls to the phone number. If a voice_application_sid is present, we ignore all of the voice urls and use those set on the application. Setting a voice_application_sid will automatically delete your trunk_sid and vice versa. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

trunk_sidThe SID of the Trunk that handles calls to the phone number. If a trunk_sid is present, we ignore all of the voice urls and voice applications and use those set on the Trunk. Setting a trunk_sid will automatically delete your voice_application_sid and vice versa.
address_sidThe SID of the Address resource associated with the phone number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

voice_caller_id_lookupWhether we look up the caller's caller-ID name from the CNAM database ($0.01 per look up). Can be: true or false.
voice_receive_modeValues: voice, fax
sidThe unique string that that we created to identify the resource.
uriThe URI of the resource, relative to https://api.twilio.com.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| emergency_address_sid | The SID of the emergency address configuration that we use for emergency calling from this phone number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| origin | The phone number's origin. twilio identifies Twilio-owned phone numbers and hosted identifies hosted phone numbers. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| status_callback | The URL we call using the status_callback_method to send status information to your application.. Format: uri |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| voice_method | The HTTP method we use to call voice_url. Can be: GET or POST.. Values: GET, POST. Format: http-method |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| voice_url | The URL we call when this phone number receives a call. The voice_url will not be used if a voice_application_sid or a trunk_sid is set.. Format: uri |

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.IncomingPhoneNumber.Local{
  account_sid: String.t() | nil,
  address_requirements: String.t(),
  address_sid: String.t() | nil,
  api_version: String.t() | nil,
  beta: boolean() | nil,
  bundle_sid: String.t() | nil,
  capabilities: map() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  emergency_address_sid: String.t() | nil,
  emergency_address_status: String.t(),
  emergency_status: String.t(),
  friendly_name: String.t() | nil,
  identity_sid: String.t() | nil,
  origin: String.t() | nil,
  phone_number: String.t() | nil,
  sid: String.t() | nil,
  sms_application_sid: String.t() | nil,
  sms_fallback_method: String.t() | nil,
  sms_fallback_url: String.t() | nil,
  sms_method: String.t() | nil,
  sms_url: String.t() | nil,
  status: String.t() | nil,
  status_callback: String.t() | nil,
  status_callback_method: String.t() | nil,
  trunk_sid: String.t() | nil,
  uri: String.t() | nil,
  voice_application_sid: String.t() | nil,
  voice_caller_id_lookup: boolean() | nil,
  voice_fallback_method: String.t() | nil,
  voice_fallback_url: String.t() | nil,
  voice_method: String.t() | nil,
  voice_receive_mode: String.t(),
  voice_url: String.t() | nil
}

Functions

object_name()

sid_prefix()