Twilio.Resources.Api.V2010.Key (twilio_elixir v0.1.1)

Copy Markdown View Source

API keys

SID prefix: SK

Parent: /Accounts/{Sid}.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time-rfc-2822
friendly_nameThe string that you assigned to describe the resource.. PII: standard
sidThe unique string that that we created to identify the Key resource.

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.Key{
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  sid: String.t() | nil
}

Functions

object_name()

sid_prefix()