Twilio.Resources.Api.V2010.Message.Media (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

The Media subresource of a Message resource represents a piece of media, such as an image, that is associated with the Message.

SID prefix: ME

Parent: /Accounts/{AccountSid}/Messages/{Sid}.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account associated with this Media resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| content_type | The default MIME type of the media, for example image/jpeg, image/png, or image/gif. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when this Media resource was created, specified in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when this Media resource was last updated, specified in RFC 2822 format.. Format: date-time-rfc-2822
parent_sidThe SID of the Message resource that is associated with this Media resource.
sidThe unique string that identifies this Media resource.
uriThe URI of this Media resource, relative to https://api.twilio.com.

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.Message.Media{
  account_sid: String.t() | nil,
  content_type: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  parent_sid: String.t() | nil,
  sid: String.t() | nil,
  uri: String.t() | nil
}

Functions

object_name()

sid_prefix()