Twilio.Resources.Api.V2010.Queue (twilio_elixir v0.1.1)

Copy Markdown View Source

Queues of calls

SID prefix: QU

Parent: /Accounts/{Sid}.json

Sub-resources

  • members/2010-04-01/Accounts/{account_sid}/Queues/{queue_sid}/Members.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created this Queue resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

average_wait_timeThe average wait time in seconds of the members in this queue. This is calculated at the time of the request.
current_sizeThe number of calls currently in the queue.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT that this resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT that this resource was last updated, specified in RFC 2822 format.. Format: date-time-rfc-2822
friendly_nameA string that you assigned to describe this resource.
max_sizeThe maximum number of calls that can be in the queue. The default is 1000 and the maximum is 5000.
sidThe unique string that that we created to identify this Queue resource.
uriThe URI of this resource, relative to https://api.twilio.com.

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.Queue{
  account_sid: String.t() | nil,
  average_wait_time: integer(),
  current_size: integer(),
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  max_size: integer(),
  sid: String.t() | nil,
  uri: String.t() | nil
}

Functions

object_name()

sid_prefix()