Twilio.Resources.Api.V2010.Queue.Member (twilio_elixir v0.1.1)

Copy Markdown View Source

Calls in a call queue

Parent: /Accounts/{AccountSid}/Queues/{Sid}.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

call_sidThe SID of the Call the Member resource is associated with.
date_enqueuedThe date that the member was enqueued, given in RFC 2822 format.. Format: date-time-rfc-2822
positionThis member's current position in the queue.
queue_sidThe SID of the Queue the member is in.
uriThe URI of the resource, relative to https://api.twilio.com.
wait_timeThe number of seconds the member has been in the queue.

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.Queue.Member{
  call_sid: String.t() | nil,
  date_enqueued: String.t() | nil,
  position: integer(),
  queue_sid: String.t() | nil,
  uri: String.t() | nil,
  wait_time: integer()
}

Functions

object_name()