Twilio.Resources.Api.V2010.SIP.CredentialList (twilio_elixir v0.1.1)

Copy Markdown View Source

Lists of SIP credentials

SID prefix: CL

Parent: /Accounts/{AccountSid}/SIP.json

Sub-resources

  • credentials/2010-04-01/Accounts/{account_sid}/SIP/CredentialLists/{credential_list_sid}/Credentials.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The unique id of the Account that owns this resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date that this resource was created, given as GMT in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date that this resource was last updated, given as GMT in RFC 2822 format.. Format: date-time-rfc-2822
friendly_nameA human readable descriptive text that describes the CredentialList, up to 64 characters long.
sidA 34 character string that uniquely identifies this resource.
subresource_urisA list of credentials associated with this credential list.. Format: uri-map
uriThe URI for this resource, relative to https://api.twilio.com.

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.SIP.CredentialList{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  sid: String.t() | nil,
  subresource_uris: map() | nil,
  uri: String.t() | nil
}

Functions

object_name()

sid_prefix()