Twilio.Resources.Api.V2010.SIP.CredentialList.Credential (twilio_elixir v0.1.1)

Copy Markdown View Source

Username and password information for SIP Domains

SID prefix: CR

Parent: /Accounts/{AccountSid}/SIP/CredentialLists/{Sid}.json

Properties

FieldDescription
account_sidThe unique id of the Account that is responsible for this resource.
credential_list_sidThe unique id that identifies the credential list that includes this credential.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date that this resource was created, given as GMT in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date that this resource was last updated, given as GMT in RFC 2822 format.. Format: date-time-rfc-2822
sidA 34 character string that uniquely identifies this resource.
uriThe URI for this resource, relative to https://api.twilio.com
usernameThe username for this credential.. PII: standard

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.SIP.CredentialList.Credential{
  account_sid: String.t() | nil,
  credential_list_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  sid: String.t() | nil,
  uri: String.t() | nil,
  username: String.t() | nil
}

Functions

object_name()

sid_prefix()