Twilio.Resources.Api.V2010.SIP.Domain.Auth.Call.AuthCallsCredentialListMapping (twilio_elixir v0.1.1)

Copy Markdown View Source

Credential lists for SIP calls

SID prefix: CL

Parent: /Accounts/{AccountSid}/SIP/Domains/{DomainSid}/Auth/Calls.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the CredentialListMapping resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time-rfc-2822
friendly_nameThe string that you assigned to describe the resource.. PII: standard
sidThe unique string that that we created to identify the CredentialListMapping resource.

Summary

Types

t()

@type t() ::
  %Twilio.Resources.Api.V2010.SIP.Domain.Auth.Call.AuthCallsCredentialListMapping{
    account_sid: String.t() | nil,
    date_created: String.t() | nil,
    date_updated: String.t() | nil,
    friendly_name: String.t() | nil,
    sid: String.t() | nil
  }

Functions

object_name()

sid_prefix()