Twilio.Resources.Api.V2010.SIP.IpAccessControlList (twilio_elixir v0.1.1)

Copy Markdown View Source

Access control lists of IP address resources

SID prefix: AL

Parent: /Accounts/{AccountSid}/SIP.json

Sub-resources

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

  • ip_addresses/2010-04-01/Accounts/{account_sid}/SIP/IpAccessControlLists/{ip_access_control_list_sid}/IpAddresses.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The unique id of the Account that owns this resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date that this resource was created, given as GMT in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date that this resource was last updated, given as GMT in RFC 2822 format.. Format: date-time-rfc-2822
friendly_nameA human readable descriptive text, up to 255 characters long.
sidA 34 character string that uniquely identifies this resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

subresource_urisA list of the IpAddress resources associated with this IP access control list resource.. Format: uri-map
uriThe URI for this resource, relative to https://api.twilio.com

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.SIP.IpAccessControlList{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  sid: String.t() | nil,
  subresource_uris: map() | nil,
  uri: String.t() | nil
}

Functions

object_name()

sid_prefix()