Twilio.Resources.Api.V2010.Token (twilio_elixir v0.1.1)

Copy Markdown View Source

Credentials for ICE servers

Parent: /Accounts/{Sid}.json

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Token resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time-rfc-2822
ice_serversAn array representing the ephemeral credentials and the STUN and TURN server URIs.
passwordThe temporary password that the username will use when authenticating with Twilio.
ttlThe duration in seconds for which the username and password are valid.
usernameThe temporary username that uniquely identifies a Token.

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.Token{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  ice_servers: list() | nil,
  password: String.t() | nil,
  ttl: String.t() | nil,
  username: String.t() | nil
}

Functions

object_name()