Twilio.Resources.Api.V2010.Usage.Record.LastMonth (twilio_elixir v0.1.1)

Copy Markdown View Source

Usage records for last month

Parent: /Accounts/{AccountSid}/Usage/Records.json

Properties

FieldDescription
account_sidThe SID of the Account that accrued the usage.
api_versionThe API version used to create the resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| as_of | Usage records up to date as of this timestamp, formatted as YYYY-MM-DDTHH:MM:SS+00:00. All timestamps are in GMT |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

categoryThe category of usage. For more information, see Usage Categories.
countThe number of usage events, such as the number of calls.
count_unitThe units in which count is measured, such as calls for calls or messages for SMS.
descriptionA plain-language description of the usage category.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

end_dateThe last date for which usage is included in the UsageRecord. The date is specified in GMT and formatted as YYYY-MM-DD.. Format: date
priceThe total price of the usage in the currency specified in price_unit and associated with the account.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| price_unit | The currency in which price is measured, in ISO 4127 format, such as usd, eur, and jpy.. Format: currency |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| start_date | The first date for which usage is included in this UsageRecord. The date is specified in GMT and formatted as YYYY-MM-DD.. Format: date |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

subresource_urisA list of related resources identified by their URIs. For more information, see List Subresources.. Format: uri-map
uriThe URI of the resource, relative to https://api.twilio.com.
usageThe amount used to bill usage and measured in units described in usage_unit.
usage_unitThe units in which usage is measured, such as minutes for calls or messages for SMS.

Summary

Types

t()

@type t() :: %Twilio.Resources.Api.V2010.Usage.Record.LastMonth{
  account_sid: String.t() | nil,
  api_version: String.t() | nil,
  as_of: String.t() | nil,
  category: String.t() | nil,
  count: String.t() | nil,
  count_unit: String.t() | nil,
  description: String.t() | nil,
  end_date: String.t() | nil,
  price: float() | nil,
  price_unit: String.t() | nil,
  start_date: String.t() | nil,
  subresource_uris: map() | nil,
  uri: String.t() | nil,
  usage: String.t() | nil,
  usage_unit: String.t() | nil
}

Functions

object_name()