Twilio.Resources.Assistants.V1.Assistant.Feedback (twilio_elixir v0.1.1)

Copy Markdown View Source

Feedback resource.

Parent: /Assistants/{id}

Properties

FieldDescription
account_sidThe SID of the Account that created the Feedback.
assistant_idThe Assistant ID.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Feedback was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the Feedback was last updated specified in ISO 8601 format.. Format: date-time
idThe Feedback ID.
message_idThe Message ID.
scoreThe Score to provide as Feedback (0-1). Format: float
session_idThe Session ID.
textThe text to be given as feedback.
user_sidThe SID of the User created the Feedback.

Summary

Types

t()

@type t() :: %Twilio.Resources.Assistants.V1.Assistant.Feedback{
  account_sid: String.t(),
  assistant_id: String.t(),
  date_created: String.t(),
  date_updated: String.t(),
  id: String.t(),
  message_id: String.t(),
  score: float(),
  session_id: String.t(),
  text: String.t(),
  user_sid: String.t()
}

Functions

object_name()