Twilio.Resources.Assistants.V1.Assistant.Knowledge (twilio_elixir v0.1.1)

Copy Markdown View Source

Knowledge resource.

Parent: /Assistants/{id}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Knowledge resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Knowledge was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the Knowledge was last updated specified in ISO 8601 format.. Format: date-time
descriptionThe type of knowledge source.
embedding_modelThe embedding model to be used for the knowledge source.
idThe description of knowledge.
knowledge_source_detailsThe details of the knowledge source based on the type.
nameThe name of the knowledge source.
statusThe status of processing the knowledge source ('QUEUED', 'PROCESSING', 'COMPLETED', 'FAILED')
typeThe type of knowledge source ('Web', 'Database', 'Text', 'File')
urlThe url of the knowledge resource.

Summary

Types

t()

@type t() :: %Twilio.Resources.Assistants.V1.Assistant.Knowledge{
  account_sid: String.t(),
  date_created: String.t(),
  date_updated: String.t(),
  description: String.t(),
  embedding_model: String.t(),
  id: String.t(),
  knowledge_source_details: map(),
  name: String.t(),
  status: String.t(),
  type: String.t(),
  url: String.t()
}

Functions

object_name()