Twilio.Resources.Assistants.V1.Assistant.Message (twilio_elixir v0.1.1)

Copy Markdown View Source

Message resource.

Parent: /Assistants/{id}

Properties

FieldDescription
abortedThis property will denote whether the request was aborted or not.
account_sidThe SID of the Account that sent the Message.
bodyIf successful, the body of the generated response
errorThe error message if generation was not successful
flaggedIf successful, this property will denote whether the response was flagged or not.
session_idThe unique name for the session.
statussuccess or failure based on whether the request successfully generated a response.

Summary

Types

t()

@type t() :: %Twilio.Resources.Assistants.V1.Assistant.Message{
  aborted: boolean(),
  account_sid: String.t(),
  body: String.t(),
  error: String.t(),
  flagged: boolean(),
  session_id: String.t(),
  status: String.t()
}

Functions

object_name()