Twilio.Resources.Assistants.V1.Assistant.Tool (twilio_elixir v0.1.1)

Copy Markdown View Source

Tool resource.

Parent: /Assistants/{id}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Tool resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Tool was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the Tool was last updated specified in ISO 8601 format.. Format: date-time
descriptionThe description of the tool.
enabledTrue if the tool is enabled.
idThe tool ID.
metaThe metadata related to method, url, input_schema to used with the Tool.
nameThe name of the tool.
requires_authThe authentication requirement for the tool.
typeThe type of the tool. ('WEBHOOK')
urlThe url of the tool resource.

Summary

Types

t()

@type t() :: %Twilio.Resources.Assistants.V1.Assistant.Tool{
  account_sid: String.t(),
  date_created: String.t(),
  date_updated: String.t(),
  description: String.t(),
  enabled: boolean(),
  id: String.t(),
  meta: map(),
  name: String.t(),
  requires_auth: boolean(),
  type: String.t(),
  url: String.t()
}

Functions

object_name()