Twilio.Resources.Assistants.V1.Knowledge.Chunk (twilio_elixir v0.1.1)

Copy Markdown View Source

Chunk resource.

Parent: /Knowledge/{id}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Knowledge resource.
contentThe chunk content.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Chunk was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the Chunk was updated specified in ISO 8601 format.. Format: date-time
metadataThe metadata of the chunk.

Summary

Types

t()

@type t() :: %Twilio.Resources.Assistants.V1.Knowledge.Chunk{
  account_sid: String.t(),
  content: String.t(),
  date_created: String.t(),
  date_updated: String.t(),
  metadata: map()
}

Functions

object_name()