Twilio.Resources.Assistants.V1.Knowledge.Status (twilio_elixir v0.1.1)

Copy Markdown View Source

Status resource.

Parent: /Knowledge/{id}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Knowledge resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the Knowledge was last updated specified in ISO 8601 format.. Format: date-time
last_statusThe last status of processing the knowledge source ('QUEUED', 'PROCESSING', 'COMPLETED', 'FAILED')
statusThe status of processing the knowledge source ('QUEUED', 'PROCESSING', 'COMPLETED', 'FAILED')

Summary

Types

t()

@type t() :: %Twilio.Resources.Assistants.V1.Knowledge.Status{
  account_sid: String.t(),
  date_updated: String.t(),
  last_status: String.t(),
  status: String.t()
}

Functions

object_name()