Twilio.Resources.Assistants.V1.Session.Message (twilio_elixir v0.1.1)

Copy Markdown View Source

Message resource.

Parent: /Sessions/{id}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Message resource.
assistant_idThe Assistant ID.
contentThe content of the message.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Message was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the Message was last updated specified in ISO 8601 format.. Format: date-time
idThe message ID.
identityThe identity of the user.
metaThe metadata of the message.
roleThe role of the user associated with the message.
session_idThe Session ID.

Summary

Types

t()

@type t() :: %Twilio.Resources.Assistants.V1.Session.Message{
  account_sid: String.t(),
  assistant_id: String.t(),
  content: map(),
  date_created: String.t(),
  date_updated: String.t(),
  id: String.t(),
  identity: String.t(),
  meta: map(),
  role: String.t(),
  session_id: String.t()
}

Functions

object_name()