Day resource.
Parent: /Exports/{ResourceType}
Properties
| Field | Description |
|---|---|
create_date | The ISO 8601 format date when resources is created |
day | The ISO 8601 format date of the resources in the file, for a UTC day |
friendly_name | The friendly name specified when creating the job |
resource_type | The type of communication – Messages, Calls, Conferences, and Participants |
size | The size of the day's data file in bytes |