Twilio.Resources.Bulkexports.V1.Export.Job (twilio_elixir v0.1.1)

Copy Markdown View Source

Job resource.

Parent: /Exports/{ResourceType}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

detailsThe details of a job which is an object that contains an array of status grouped by status state. Each status object has a status string, a count which is the number of days in that status, and list of days in that status. The day strings are in the format yyyy-MM-dd. As an example, a currently running job may have a status object for COMPLETED and a status object for SUBMITTED each with its own count and list of days.
emailThe optional email to send the completion notification to
end_dayThe end day for the export specified when creating the job

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

estimated_completion_timethis is the time estimated until your job is complete. This is calculated each time you request the job list. The time is calculated based on the current rate of job completion (which may vary) and your job queue position
friendly_nameThe friendly name specified when creating the job

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

job_queue_positionThis is the job position from the 1st in line. Your queue position will never increase. As jobs ahead of yours in the queue are processed, the queue position number will decrease
job_sidThe unique job_sid returned when the custom export was created
resource_typeThe type of communication – Messages, Calls, Conferences, and Participants
start_dayThe start day for the custom export specified when creating the job

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| webhook_method | This is the method used to call the webhook on completion of the job. If this is supplied, WebhookUrl must also be supplied. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| webhook_url | The optional webhook url called on completion of the job. If this is supplied, WebhookMethod must also be supplied. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Bulkexports.V1.Export.Job{
  details: list() | nil,
  email: String.t() | nil,
  end_day: String.t() | nil,
  estimated_completion_time: String.t() | nil,
  friendly_name: String.t() | nil,
  job_queue_position: String.t() | nil,
  job_sid: String.t() | nil,
  resource_type: String.t() | nil,
  start_day: String.t() | nil,
  webhook_method: String.t() | nil,
  webhook_url: String.t() | nil
}

Functions

object_name()