Twilio.Resources.Chat.V1.Service.Channel.Invite (twilio_elixir v0.1.1)

Copy Markdown View Source

Pending invitations to users to become channel members

SID prefix: IN

Parent: /Services/{ServiceSid}/Channels/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Invite resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

channel_sidThe SID of the Channel the resource belongs to.
created_byThe identity of the User that created the invite.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

identityThe application-defined string that uniquely identifies the resource's User within the Service. See access tokens for more info.. PII: standard
role_sidThe SID of the Role assigned to the resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service the resource is associated with.
sidThe unique string that we created to identify the Invite resource.
urlThe absolute URL of the Invite resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Chat.V1.Service.Channel.Invite{
  account_sid: String.t() | nil,
  channel_sid: String.t() | nil,
  created_by: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  identity: String.t() | nil,
  role_sid: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()