Twilio.Resources.Chat.V1.Service.Channel.Message (twilio_elixir v0.1.1)

Copy Markdown View Source

Individual chat messages

SID prefix: IM

Parent: /Services/{ServiceSid}/Channels/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Message resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

attributesThe JSON string that stores application-specific data. Note If this property has been assigned a value, it's only displayed in a FETCH action that returns a single resource; otherwise, it's null. If the attributes have not been set, {} is returned.. PII: sensitive
bodyThe content of the message.. PII: sensitive

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| channel_sid | The unique ID of the Channel the Message resource belongs to. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

fromThe identity of the message's author. The default value is system.. PII: standard
indexThe index of the message within the Channel.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service the resource is associated with.
sidThe unique string that we created to identify the Message resource.
toThe SID of the Channel that the message was sent to.
urlThe absolute URL of the Message resource.. Format: uri
was_editedWhether the message has been edited since it was created.

Summary

Types

t()

@type t() :: %Twilio.Resources.Chat.V1.Service.Channel.Message{
  account_sid: String.t() | nil,
  attributes: String.t() | nil,
  body: String.t() | nil,
  channel_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  from: String.t() | nil,
  index: integer(),
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  to: String.t() | nil,
  url: String.t() | nil,
  was_edited: boolean() | nil
}

Functions

object_name()

sid_prefix()