Twilio.Resources.Chat.V1.Service.Role (twilio_elixir v0.1.1)

Copy Markdown View Source

Roles determining user or member permissions

SID prefix: RL

Parent: /Services/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Role resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.. PII: standard
permissionsAn array of the permissions the role has been granted, formatted as a JSON string.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service the resource is associated with.
sidThe unique string that we created to identify the Role resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

typeThe type of role. Can be: channel for Channel roles or deployment for Service roles.. Values: channel, deployment
urlThe absolute URL of the Role resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Chat.V1.Service.Role{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  permissions: list() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  type: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()