Twilio.Resources.Chat.V1.Service.User (twilio_elixir v0.1.1)

Copy Markdown View Source

Unique chat users within a chat service

SID prefix: US

Parent: /Services/{Sid}

Sub-resources

  • user_channels/v1/Services/{service_sid}/Users/{user_sid}/Channels

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the User resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| attributes | The JSON string that stores application-specific data. Note If this property has been assigned a value, it's only displayed in a FETCH action that returns a single resource; otherwise, it's null. If the attributes have not been set, {} is returned.. PII: sensitive |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.. PII: standard

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| identity | The application-defined string that uniquely identifies the resource's User within the Service. This value is often a username or an email address. See access tokens for more info.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| is_notifiable | Whether the User has a potentially valid Push Notification registration (APN or GCM) for the Service instance. If at least one registration exists, true; otherwise false. This value is only returned by Fetch actions that return a single resource and null is always returned by a Read action. This value is null if the Service's reachability_enabled is false, and if the User has never had a notification registration, even if the Service's reachability_enabled is true. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

is_onlineWhether the User is actively connected to the Service instance and online. This value is only returned by Fetch actions that return a single resource and null is always returned by a Read action. This value is null if the Service's reachability_enabled is false, if the User has never been online for the Service instance, even if the Service's reachability_enabled is true.
joined_channels_countThe number of Channels this User is a Member of.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

linksThe absolute URLs of the Channel and Binding resources related to the user.. Format: uri-map
role_sidThe SID of the Role assigned to the user.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service the resource is associated with.
sidThe unique string that we created to identify the User resource.
urlThe absolute URL of the User resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Chat.V1.Service.User{
  account_sid: String.t() | nil,
  attributes: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  identity: String.t() | nil,
  is_notifiable: boolean() | nil,
  is_online: boolean() | nil,
  joined_channels_count: integer(),
  links: map() | nil,
  role_sid: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()