Twilio.Resources.Chat.V2.Credential (twilio_elixir v0.1.1)

Copy Markdown View Source

Credentials for push notifications channels

SID prefix: CR

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Credential resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.. PII: standard

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

sandbox[APN only] Whether to send the credential to sandbox APNs. Can be true to send to sandbox APNs or false to send to production.
sidThe unique string that we created to identify the Credential resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

typeThe type of push-notification service the credential is for. Can be: gcm, fcm, or apn.. Values: gcm, apn, fcm
urlThe absolute URL of the Credential resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Chat.V2.Credential{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  sandbox: String.t() | nil,
  sid: String.t() | nil,
  type: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()