Twilio.Resources.Chat.V2.Service.Channel (twilio_elixir v0.1.1)

Copy Markdown View Source

Channels represent chat rooms

SID prefix: CH

Parent: /Services/{Sid}

Sub-resources

  • invites/v2/Services/{service_sid}/Channels/{channel_sid}/Invites
  • members/v2/Services/{service_sid}/Channels/{channel_sid}/Members
  • messages/v2/Services/{service_sid}/Channels/{channel_sid}/Messages
  • webhooks/v2/Services/{service_sid}/Channels/{channel_sid}/Webhooks

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Channel resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| attributes | The JSON string that stores application-specific data. If attributes have not been set, {} is returned.. PII: sensitive |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| created_by | The identity of the User that created the channel. If the Channel was created by using the API, the value is system.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.. PII: standard

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

linksThe absolute URLs of the Members, Messages, Invites, Webhooks and, if it exists, the last Message for the Channel.. Format: uri-map
members_countThe number of Members in the Channel.
messages_countThe number of Messages that have been passed in the Channel.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service the Channel resource is associated with.
sidThe unique string that we created to identify the Channel resource.
typeThe visibility of the channel. Can be: public or private.. Values: public, private

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unique_nameAn application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource's sid in the URL.. PII: standard
urlThe absolute URL of the Channel resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Chat.V2.Service.Channel{
  account_sid: String.t() | nil,
  attributes: String.t() | nil,
  created_by: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  links: map() | nil,
  members_count: integer(),
  messages_count: integer(),
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  type: String.t(),
  unique_name: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()