Twilio.Resources.Chat.V2.Service.Channel.Message (twilio_elixir v0.1.1)

Copy Markdown View Source

Individual chat messages

SID prefix: IM

Parent: /Services/{ServiceSid}/Channels/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Message resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

attributesThe JSON string that stores application-specific data. If attributes have not been set, {} is returned.. PII: sensitive
bodyThe content of the message.. PII: sensitive

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| channel_sid | The SID of the Channel the Message resource belongs to. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| from | The Identity of the message's author. The default value is system.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| index | The index of the message within the Channel. Indices may skip numbers, but will always be in order of when the message was received. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| last_updated_by | The Identity of the User who last updated the Message, if applicable.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| media | An object that describes the Message's media, if the message contains media. The object contains these fields: content_type with the MIME type of the media, filename with the name of the media, sid with the SID of the Media resource, and size with the media object's file size in bytes. If the Message has no media, this value is null.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service the Message resource is associated with.
sidThe unique string that we created to identify the Message resource.
toThe SID of the Channel that the message was sent to.
typeThe Message type. Can be: text or media.
urlThe absolute URL of the Message resource.. Format: uri
was_editedWhether the message has been edited since it was created.

Summary

Types

t()

@type t() :: %Twilio.Resources.Chat.V2.Service.Channel.Message{
  account_sid: String.t() | nil,
  attributes: String.t() | nil,
  body: String.t() | nil,
  channel_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  from: String.t() | nil,
  index: integer(),
  last_updated_by: String.t() | nil,
  media: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  to: String.t() | nil,
  type: String.t() | nil,
  url: String.t() | nil,
  was_edited: boolean() | nil
}

Functions

object_name()

sid_prefix()