Twilio.Resources.Chat.V2.Service.User.Binding (twilio_elixir v0.1.1)

Copy Markdown View Source

List of bindings for a given user

SID prefix: BS

Parent: /Services/{ServiceSid}/Users/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the User Binding resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| binding_type | The push technology to use for the User Binding. Can be: apn, gcm, or fcm. See push notification configuration for more info.. Values: gcm, apn, fcm |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| credential_sid | The SID of the Credential for the binding. See push notification configuration for more info. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| endpoint | The unique endpoint identifier for the User Binding. The format of the value depends on the binding_type.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| identity | The application-defined string that uniquely identifies the resource's User within the Service. See access tokens for more info.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| message_types | The Programmable Chat message types the binding is subscribed to. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service the User Binding resource is associated with.
sidThe unique string that we created to identify the User Binding resource.
urlThe absolute URL of the User Binding resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| user_sid | The SID of the User with the User Binding resource. See push notification configuration for more info. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Chat.V2.Service.User.Binding{
  account_sid: String.t() | nil,
  binding_type: String.t(),
  credential_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  endpoint: String.t() | nil,
  identity: String.t() | nil,
  message_types: list() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil,
  user_sid: String.t() | nil
}

Functions

object_name()

sid_prefix()