Twilio.Resources.Chat.V2.Service.User.Channel (twilio_elixir v0.1.1)

Copy Markdown View Source

List of channels for a given user

Parent: /Services/{ServiceSid}/Users/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the User Channel resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| channel_sid | The SID of the Channel the User Channel resource belongs to. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| last_consumed_message_index | The index of the last Message in the Channel that the Member has read. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| links | The absolute URLs of the Members, Messages , Invites and, if it exists, the last Message for the Channel.. Format: uri-map |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| member_sid | The SID of a Member that represents the User on the Channel. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| notification_level | The push notification level of the User for the Channel. Can be: default or muted.. Values: default, muted |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| service_sid | The SID of the Service the User Channel resource is associated with. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| status | The status of the User on the Channel. Can be: joined, invited, or notParticipating.. Values: joined, invited, notParticipating |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unread_messages_countThe number of unread Messages in the Channel for the User. Note that retrieving messages on a client endpoint does not mean that messages are consumed or read. See Consumption Horizon feature to learn how to mark messages as consumed.
urlThe absolute URL of the User Channel resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| user_sid | The SID of the User the User Channel belongs to. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Chat.V2.Service.User.Channel{
  account_sid: String.t() | nil,
  channel_sid: String.t() | nil,
  last_consumed_message_index: integer() | nil,
  links: map() | nil,
  member_sid: String.t() | nil,
  notification_level: String.t(),
  service_sid: String.t() | nil,
  status: String.t(),
  unread_messages_count: integer() | nil,
  url: String.t() | nil,
  user_sid: String.t() | nil
}

Functions

object_name()