Twilio.Resources.Content.V1.Content.ApprovalRequest (twilio_elixir v0.1.1)

Copy Markdown View Source

An Approval Fetch resource represents the approval status of a Content resource.

SID prefix: HX

Parent: /Content/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created Content resource.
sidThe unique string that that we created to identify the Content resource.
urlThe URL of the resource, relative to https://content.twilio.com.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| whatsapp | Contains the whatsapp approval information for the Content resource, with fields such as approval status, rejection reason, and category, amongst others. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Content.V1.Content.ApprovalRequest{
  account_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil,
  whatsapp: map() | nil
}

Functions

object_name()

sid_prefix()