Twilio.Resources.Content.V1.ContentAndApprovals (twilio_elixir v0.1.1)

Copy Markdown View Source

A Content resource represents rich messaging content and its respective approval request status.

SID prefix: HX

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created Content resource.
approval_requestsThe submitted information and approval request status of the Content resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time
friendly_nameA string name used to describe the Content resource. Not visible to the end recipient.
languageTwo-letter (ISO 639-1) language code (e.g., en) identifying the language the Content resource is in.
sidThe unique string that that we created to identify the Content resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| types | The Content types (e.g. twilio/text) for this Content resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| variables | Defines the default placeholder values for variables included in the Content resource. e.g. {"1": "Customer_Name"}. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Content.V1.ContentAndApprovals{
  account_sid: String.t() | nil,
  approval_requests: map() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  language: String.t() | nil,
  sid: String.t() | nil,
  types: map() | nil,
  variables: map() | nil
}

Functions

object_name()

sid_prefix()