Twilio.Resources.Conversations.V1.Configuration.Address (twilio_elixir v0.1.1)

Copy Markdown View Source

Address Configuration resource manages the configurations related to a unique address within Conversations

SID prefix: IG

Properties

FieldDescription
account_sidThe unique ID of the Account the address belongs to

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| address | The unique address to be configured. The address can be a whatsapp address or phone number. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

address_countryAn ISO 3166-1 alpha-2n country code which the address belongs to. This is currently only applicable to short code addresses.
auto_creationAuto Creation configuration for the address.
date_createdThe date that this resource was created.. Format: date-time
date_updatedThe date that this resource was last updated.. Format: date-time
friendly_nameThe human-readable name of this configuration, limited to 256 characters. Optional.
sidA 34 character string that uniquely identifies this resource.
typeType of Address, value can be whatsapp or sms.
urlAn absolute API resource URL for this address configuration.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Conversations.V1.Configuration.Address{
  account_sid: String.t() | nil,
  address: String.t() | nil,
  address_country: String.t() | nil,
  auto_creation: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  sid: String.t() | nil,
  type: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()