Twilio.Resources.Conversations.V1.Configuration.Webhook (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

A Webhook resource manages a service-level set of callback URLs and their configuration for receiving all conversation events.

Parent: /Configuration

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The unique ID of the Account responsible for this conversation. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

filtersThe list of webhook event triggers that are enabled for this Service: onMessageAdded, onMessageUpdated, onMessageRemoved, onMessageAdd, onMessageUpdate, onMessageRemove, onConversationUpdated, onConversationRemoved, onConversationAdd, onConversationAdded, onConversationRemove, onConversationUpdate, onConversationStateUpdated, onParticipantAdded, onParticipantUpdated, onParticipantRemoved, onParticipantAdd, onParticipantRemove, onParticipantUpdate, onDeliveryUpdated, onUserAdded, onUserUpdate, onUserUpdated
methodThe HTTP method to be used when sending a webhook request.. Values: GET, POST
post_webhook_urlThe absolute url the post-event webhook request should be sent to.
pre_webhook_urlThe absolute url the pre-event webhook request should be sent to.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

targetThe routing target of the webhook. Can be ordinary or route internally to Flex. Values: webhook, flex
urlAn absolute API resource API resource URL for this webhook.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Conversations.V1.Configuration.Webhook{
  account_sid: String.t() | nil,
  filters: list() | nil,
  method: String.t(),
  post_webhook_url: String.t() | nil,
  pre_webhook_url: String.t() | nil,
  target: String.t(),
  url: String.t() | nil
}

Functions

object_name()