Twilio.Resources.Conversations.V1.Conversation.Message.Receipt (twilio_elixir v0.1.1)

Copy Markdown View Source

A Message Receipt resource represents a delivery/read receipt of a message in a conversation.

SID prefix: DY

Parent: /Conversations/{ConversationSid}/Messages/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The unique ID of the Account responsible for this participant. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| channel_message_sid | A messaging channel-specific identifier for the message delivered to participant e.g. SMxx for SMS, WAxx for Whatsapp etc. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

conversation_sidThe unique ID of the Conversation for this message.
date_createdThe date that this resource was created.. Format: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date that this resource was last updated. null if the delivery receipt has not been updated.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| error_code | The message delivery error code for a failed status, |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

message_sidThe SID of the message within a Conversation the delivery receipt belongs to
participant_sidThe unique ID of the participant the delivery receipt belongs to.
sidA 34 character string that uniquely identifies this resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe message delivery status, can be read, failed, delivered, undelivered, sent or null.. Values: read, failed, delivered, undelivered, sent
urlAn absolute API resource URL for this delivery receipt.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Conversations.V1.Conversation.Message.Receipt{
  account_sid: String.t() | nil,
  channel_message_sid: String.t() | nil,
  conversation_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  error_code: integer(),
  message_sid: String.t() | nil,
  participant_sid: String.t() | nil,
  sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()