Twilio.Resources.Conversations.V1.Conversation.Participant
(twilio_elixir v0.1.1)
A Participant resource represents a member of the conversation.
SID prefix: MB
Parent: /Conversations/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The unique ID of the Account responsible for this participant. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| attributes | An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.. PII: sensitive |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
conversation_sid | The unique ID of the Conversation for this participant. |
date_created | The date that this resource was created.. Format: date-time |
date_updated | The date that this resource was last updated.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| identity | A unique string identifier for the conversation participant as Conversation User. This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| last_read_message_index | Index of last “read” message in the Conversation for the Participant. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| last_read_timestamp | Timestamp of last “read” message in the Conversation for the Participant. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| messaging_binding | Information about how this participant exchanges messages with the conversation. A JSON parameter consisting of type and address fields of the participant.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
role_sid | The SID of a conversation-level Role to assign to the participant. |
sid | A 34 character string that uniquely identifies this resource. |
url | An absolute API resource URL for this participant.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Conversations.V1.Conversation.Participant{ account_sid: String.t() | nil, attributes: String.t() | nil, conversation_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, identity: String.t() | nil, last_read_message_index: integer() | nil, last_read_timestamp: String.t() | nil, messaging_binding: String.t() | nil, role_sid: String.t() | nil, sid: String.t() | nil, url: String.t() | nil }