Twilio.Resources.Conversations.V1.ConversationWithParticipants (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

A Conversation resource represents an omnichannel group conversation with an ordered list of messages and a participant roster.

SID prefix: CH

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The unique ID of the Account responsible for this conversation. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| attributes | An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.. PII: sensitive |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

chat_service_sidThe unique ID of the Conversation Service this conversation belongs to.
date_createdThe date that this resource was created.. Format: date-time
date_updatedThe date that this resource was last updated.. Format: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| friendly_name | The human-readable name of this conversation, limited to 256 characters. Optional.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| links | Contains absolute URLs to access the participants, messages and webhooks of this conversation.. Format: uri-map |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

messaging_service_sidThe unique ID of the Messaging Service this conversation belongs to.
sidA 34 character string that uniquely identifies this resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

stateCurrent state of this conversation. Can be either initializing, active, inactive or closed and defaults to active. Values: initializing, inactive, active, closed
timersTimer date values representing state update for this conversation.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unique_nameAn application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource's sid in the URL.. PII: standard
urlAn absolute API resource URL for this conversation.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Conversations.V1.ConversationWithParticipants{
  account_sid: String.t() | nil,
  attributes: String.t() | nil,
  bindings: String.t() | nil,
  chat_service_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  links: map() | nil,
  messaging_service_sid: String.t() | nil,
  sid: String.t() | nil,
  state: String.t(),
  timers: String.t() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()