Twilio.Resources.Conversations.V1.ParticipantConversation (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Participant Conversations resource represents a list of Conversations that this Participant belongs to belonging to a default conversation service.

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The unique ID of the Account responsible for this conversation. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| chat_service_sid | The unique ID of the Conversation Service this conversation belongs to. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

conversation_attributesAn optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.. PII: sensitive
conversation_created_byIdentity of the creator of this Conversation.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| conversation_date_created | The date that this conversation was created, given in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| conversation_date_updated | The date that this conversation was last updated, given in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| conversation_friendly_name | The human-readable name of this conversation, limited to 256 characters. Optional.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| conversation_sid | The unique ID of the Conversation this Participant belongs to. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

conversation_stateThe current state of this User Conversation. One of inactive, active or closed.. Values: inactive, active, closed
conversation_timersTimer date values representing state update for this conversation.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| conversation_unique_name | An application-defined string that uniquely identifies the Conversation resource.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| links | Contains absolute URLs to access the participant and conversation of this conversation.. Format: uri-map |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| participant_identity | A unique string identifier for the conversation participant as Conversation User. This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| participant_messaging_binding | Information about how this participant exchanges messages with the conversation. A JSON parameter consisting of type and address fields of the participant.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| participant_sid | The unique ID of the Participant. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| participant_user_sid | The unique string that identifies the conversation participant as Conversation User. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Conversations.V1.ParticipantConversation{
  account_sid: String.t() | nil,
  chat_service_sid: String.t() | nil,
  conversation_attributes: String.t() | nil,
  conversation_created_by: String.t() | nil,
  conversation_date_created: String.t() | nil,
  conversation_date_updated: String.t() | nil,
  conversation_friendly_name: String.t() | nil,
  conversation_sid: String.t() | nil,
  conversation_state: String.t(),
  conversation_timers: String.t() | nil,
  conversation_unique_name: String.t() | nil,
  links: map() | nil,
  participant_identity: String.t() | nil,
  participant_messaging_binding: String.t() | nil,
  participant_sid: String.t() | nil,
  participant_user_sid: String.t() | nil
}

Functions

object_name()