Twilio.Resources.Conversations.V1.Service (twilio_elixir v0.1.1)

Copy Markdown View Source

A Service resource is a top-level conversation resource container that serves as a data silo.

SID prefix: IS

Sub-resources

  • bindings/v1/Services/{chat_service_sid}/Bindings
  • configuration/v1/Services/{chat_service_sid}/Configuration
  • conversation_with_participants/v1/Services/{chat_service_sid}/ConversationWithParticipants
  • conversations/v1/Services/{chat_service_sid}/Conversations
  • participant_conversations/v1/Services/{chat_service_sid}/ParticipantConversations
  • roles/v1/Services/{chat_service_sid}/Roles
  • users/v1/Services/{chat_service_sid}/Users

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe unique ID of the Account responsible for this service.
date_createdThe date that this resource was created.. Format: date-time
date_updatedThe date that this resource was last updated.. Format: date-time
friendly_nameThe human-readable name of this service, limited to 256 characters. Optional.. PII: standard

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

linksContains absolute API resource URLs to access conversations, users, roles, bindings and configuration of this service.. Format: uri-map
sidA 34 character string that uniquely identifies this resource.
urlAn absolute API resource URL for this service.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Conversations.V1.Service{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()