Twilio.Resources.Conversations.V1.Service.Binding (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

A Binding resource represents a push notification binding and its configuration, for delivering conversation events to mobile or web endpoints.

SID prefix: BS

Parent: /Services/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The unique ID of the Account responsible for this binding. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| binding_type | The push technology to use for the Binding. Can be: apn, gcm, fcm, or twilsock. See push notification configuration for more info.. Values: apn, gcm, fcm, twilsock |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| chat_service_sid | The SID of the Conversation Service the Binding resource is associated with. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

credential_sidThe SID of the Credential for the binding. See push notification configuration for more info.
date_createdThe date that this resource was created.. Format: date-time
date_updatedThe date that this resource was last updated.. Format: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| endpoint | The unique endpoint identifier for the Binding. The format of this value depends on the binding_type.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| identity | The application-defined string that uniquely identifies the Conversation User within the Conversation Service. See access tokens for more info.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

message_typesThe Conversation message types the binding is subscribed to.
sidA 34 character string that uniquely identifies this resource.
urlAn absolute API resource URL for this binding.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Conversations.V1.Service.Binding{
  account_sid: String.t() | nil,
  binding_type: String.t(),
  chat_service_sid: String.t() | nil,
  credential_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  endpoint: String.t() | nil,
  identity: String.t() | nil,
  message_types: list() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()