Twilio.Resources.Conversations.V1.Service.Configuration.Notification (twilio_elixir v0.1.1)

Copy Markdown View Source

A Service Notification resource manages a set of settings to determine push notification behavior at service level.

Parent: /Services/{ChatServiceSid}/Configuration

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe unique ID of the Account responsible for this configuration.
added_to_conversationThe Push Notification configuration for being added to a Conversation.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

chat_service_sidThe SID of the Conversation Service the Configuration applies to.
log_enabledWeather the notification logging is enabled.
new_messageThe Push Notification configuration for New Messages.
removed_from_conversationThe Push Notification configuration for being removed from a Conversation.
urlAn absolute API resource URL for this configuration.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Conversations.V1.Service.Configuration.Notification{
  account_sid: String.t() | nil,
  added_to_conversation: String.t() | nil,
  chat_service_sid: String.t() | nil,
  log_enabled: boolean() | nil,
  new_message: String.t() | nil,
  removed_from_conversation: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()