Twilio.Resources.Conversations.V1.Service.Conversation.Message (twilio_elixir v0.1.1)

Copy Markdown View Source

A Service Message resource represents a message in a conversation within a specific service.

SID prefix: IM

Parent: /Services/{ChatServiceSid}/Conversations/{Sid}

Sub-resources

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

  • channel_metadata/v1/Services/{chat_service_sid}/Conversations/{conversation_sid}/Messages/{message_sid}/ChannelMetadata

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

  • delivery_receipts/v1/Services/{chat_service_sid}/Conversations/{conversation_sid}/Messages/{message_sid}/Receipts

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The unique ID of the Account responsible for this message. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

attributesA string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.. PII: sensitive
authorThe channel specific identifier of the message's author. Defaults to system.. PII: standard
bodyThe content of the message, can be up to 1,600 characters long.. PII: sensitive

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

chat_service_sidThe SID of the Conversation Service the Participant resource is associated with.
content_sidThe unique ID of the multi-channel Rich Content template.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

conversation_sidThe unique ID of the Conversation for this message.
date_createdThe date that this resource was created.. Format: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date that this resource was last updated. null if the message has not been edited.. Format: date-time
deliveryAn object that contains the summary of delivery statuses for the message to non-chat participants.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| index | The index of the message within the Conversation. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| links | Contains an absolute API resource URL to access the delivery & read receipts of this message.. Format: uri-map |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

mediaAn array of objects that describe the Message's media, if the message contains media. Each object contains these fields: content_type with the MIME type of the media, filename with the name of the media, sid with the SID of the Media resource, and size with the media object's file size in bytes. If the Message has no media, this value is null.. PII: standard
participant_sidThe unique ID of messages's author participant. Null in case of system sent message.
sidA 34 character string that uniquely identifies this resource.
urlAn absolute API resource URL for this message.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Conversations.V1.Service.Conversation.Message{
  account_sid: String.t() | nil,
  attributes: String.t() | nil,
  author: String.t() | nil,
  body: String.t() | nil,
  chat_service_sid: String.t() | nil,
  content_sid: String.t() | nil,
  conversation_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  delivery: String.t() | nil,
  index: integer(),
  links: map() | nil,
  media: list() | nil,
  participant_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()