Twilio.Resources.Conversations.V1.User.Conversation (twilio_elixir v0.1.1)

Copy Markdown View Source

A User Conversation resource represents a conversation of the user belonging to a default conversation service.

Parent: /Users/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The unique ID of the Account responsible for this conversation. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| attributes | An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.. PII: sensitive |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| chat_service_sid | The unique ID of the Conversation Service this conversation belongs to. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| conversation_sid | The unique ID of the Conversation for this User Conversation. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

conversation_stateThe current state of this User Conversation. One of inactive, active or closed.. Values: inactive, active, closed
created_byIdentity of the creator of this Conversation.
date_createdThe date that this conversation was created, given in ISO 8601 format.. Format: date-time
date_updatedThe date that this conversation was last updated, given in ISO 8601 format.. Format: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

friendly_nameThe human-readable name of this conversation, limited to 256 characters. Optional.. PII: standard
last_read_message_indexThe index of the last Message in the Conversation that the Participant has read.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| links | Contains absolute URLs to access the participant and conversation of this conversation.. Format: uri-map |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| notification_level | The Notification Level of this User Conversation. One of default or muted.. Values: default, muted |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

participant_sidThe unique ID of the participant the user conversation belongs to.
timersTimer date values representing state update for this conversation.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unique_nameAn application-defined string that uniquely identifies the Conversation resource. It can be used to address the resource in place of the resource's conversation_sid in the URL.. PII: standard
unread_messages_countThe number of unread Messages in the Conversation for the Participant.
urlFormat: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| user_sid | The unique string that identifies the User resource. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Conversations.V1.User.Conversation{
  account_sid: String.t() | nil,
  attributes: String.t() | nil,
  chat_service_sid: String.t() | nil,
  conversation_sid: String.t() | nil,
  conversation_state: String.t(),
  created_by: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  last_read_message_index: integer() | nil,
  links: map() | nil,
  notification_level: String.t(),
  participant_sid: String.t() | nil,
  timers: String.t() | nil,
  unique_name: String.t() | nil,
  unread_messages_count: integer() | nil,
  url: String.t() | nil,
  user_sid: String.t() | nil
}

Functions

object_name()