Twilio.Resources.Events.V1.Schema (twilio_elixir v0.1.1)

Copy Markdown View Source

Versioned Schema definitions for Event Types

Sub-resources

  • versions/v1/Schemas/{id}/Versions

Properties

FieldDescription
idThe unique identifier of the schema. Each schema can have multiple versions, that share the same id.
latest_versionThe latest version published of this schema.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

latest_version_date_createdThe date that the latest schema version was created, given in ISO 8601 format.. Format: date-time
linksContains a dictionary of URL links to nested resources of this schema.. Format: uri-map
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Events.V1.Schema{
  id: String.t() | nil,
  latest_version: integer(),
  latest_version_date_created: String.t() | nil,
  links: map() | nil,
  url: String.t() | nil
}

Functions

object_name()