Twilio.Resources.Events.V1.Schema.SchemaVersion (twilio_elixir v0.1.1)

Copy Markdown View Source

Version of the Schema

Parent: /Schemas/{Id}

Properties

FieldDescription
date_createdThe date the schema version was created, given in ISO 8601 format.. Format: date-time
idThe unique identifier of the schema. Each schema can have multiple versions, that share the same id.
rawFormat: uri
schema_versionThe version of this schema.
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Events.V1.Schema.SchemaVersion{
  date_created: String.t() | nil,
  id: String.t() | nil,
  raw: String.t() | nil,
  schema_version: integer(),
  url: String.t() | nil
}

Functions

object_name()