Twilio.Resources.Events.V1.Sink (twilio_elixir v0.1.1)

Copy Markdown View Source

Sink destination to send events to

SID prefix: DG

Sub-resources

  • sink_test/v1/Sinks/{sid}/Test
  • sink_validate/v1/Sinks/{sid}/Validate

Properties

FieldDescription
date_createdThe date that this Sink was created, given in ISO 8601 format.. Format: date-time
date_updatedThe date that this Sink was updated, given in ISO 8601 format.. Format: date-time
descriptionA human readable description for the Sink
linksContains a dictionary of URL links to nested resources of this Sink.. Format: uri-map
sidA 34 character string that uniquely identifies this Sink.
sink_configurationThe information required for Twilio to connect to the provided Sink encoded as JSON.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sink_type | The Sink type. Can only be "kinesis" or "webhook" currently.. Values: kinesis, webhook, segment, email |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe Status of this Sink. One of initialized, validating, active or failed.. Values: initialized, validating, active, failed
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Events.V1.Sink{
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  description: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  sink_configuration: String.t() | nil,
  sink_type: String.t(),
  status: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()