Twilio.Resources.Events.V1.Subscription (twilio_elixir v0.1.1)

Copy Markdown View Source

Subscription to send Event Types to a Sink

SID prefix: DF

Sub-resources

  • subscribed_events/v1/Subscriptions/{subscription_sid}/SubscribedEvents

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.
date_createdThe date that this Subscription was created, given in ISO 8601 format.. Format: date-time
date_updatedThe date that this Subscription was updated, given in ISO 8601 format.. Format: date-time
descriptionA human readable description for the Subscription
linksContains a dictionary of URL links to nested resources of this Subscription.. Format: uri-map
sidA 34 character string that uniquely identifies this Subscription.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

sink_sidThe SID of the sink that events selected by this subscription should be sent to. Sink must be active for the subscription to be created.
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Events.V1.Subscription{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  description: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  sink_sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()