Twilio.Resources.Events.V1.Type (twilio_elixir v0.1.1)

Copy Markdown View Source

Event Types available

Properties

FieldDescription
date_createdThe date that this Event Type was created, given in ISO 8601 format.. Format: date-time
date_updatedThe date that this Event Type was updated, given in ISO 8601 format.. Format: date-time
descriptionA human readable description for this Event Type.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

documentation_urlThe URL to the documentation or to the most relevant Twilio Changelog entry of this Event Type.
linksFormat: uri-map
schema_idA string that uniquely identifies the Schema this Event Type adheres to.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusA string that describes how this Event Type can be used. For example: available, deprecated, restricted, discontinued. When the status is available, the Event Type can be used normally.
typeA string that uniquely identifies this Event Type.
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Events.V1.Type{
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  description: String.t() | nil,
  documentation_url: String.t() | nil,
  links: map() | nil,
  schema_id: String.t() | nil,
  status: String.t() | nil,
  type: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()