Twilio.Resources.Flex.V1.Channel (twilio_elixir v0.1.1)

Copy Markdown View Source

Flex chat channels

SID prefix: CH

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Channel resource and owns this Workflow. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Flex chat channel was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the Flex chat channel was last updated specified in ISO 8601 format.. Format: date-time
flex_flow_sidThe SID of the Flex Flow.
sidThe unique string that we created to identify the Channel resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

task_sidThe SID of the TaskRouter Task. Only valid when integration type is task. null for integration types studio & external
urlThe absolute URL of the Flex chat channel resource.. Format: uri
user_sidThe SID of the chat user.

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.Channel{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  flex_flow_sid: String.t() | nil,
  sid: String.t() | nil,
  task_sid: String.t() | nil,
  url: String.t() | nil,
  user_sid: String.t() | nil
}

Functions

object_name()

sid_prefix()