Twilio.Resources.Flex.V1.Configuration (twilio_elixir v0.1.1)

Copy Markdown View Source

Configuration for a Flex instance

Properties

FieldDescription
taskrouter_offline_activity_sidThe TaskRouter SID of the offline activity.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Configuration resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the Configuration resource was last updated specified in ISO 8601 format.. Format: date-time
taskrouter_worker_attributesThe TaskRouter Worker attributes.
taskrouter_target_taskqueue_sidThe SID of the TaskRouter Target TaskQueue.
ui_dependenciesThe object that defines the NPM packages and versions to be used in Hosted Flex.
public_attributesThe list of public attributes, which are visible to unauthenticated clients.
crm_fallback_urlThe CRM Fallback URL.
plugin_service_attributesThe plugin service attributes.
citrix_voice_vdiCitrix voice vdi configuration and settings.
flex_insights_drilldownSetting this to true will redirect Flex UI to the URL set in flex_url
flex_ui_status_reportConfigurable parameters for Flex UI Status report.
messaging_service_instance_sidThe SID of the Messaging service instance.
flex_urlURL to redirect to in case drilldown is enabled.
taskrouter_taskqueuesThe list of TaskRouter TaskQueues.
agent_conv_end_methodsAgent conversation end methods.
call_recording_enabledWhether call recording is enabled.
urlThe absolute URL of the Configuration resource.. Format: uri
ui_attributesThe object that describes Flex UI characteristics and settings.
chat_service_instance_sidThe SID of the chat service this user belongs to.
service_versionThe Flex Service version.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

integrationsA list of objects that contain the configurations for the Integrations supported in this configuration.
taskrouter_skillsThe Skill description for TaskRouter workers.
crm_enabledWhether CRM is present for Flex.
runtime_domainThe URL where the Flex instance is hosted.
channel_configsSettings for different limits for Flex Conversations channels attachments.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_createdThe date and time in GMT when the Configuration resource was created specified in ISO 8601 format.. Format: date-time
taskrouter_worker_channelsThe TaskRouter default channel capacities and availability for workers.
taskrouter_workspace_sidThe SID of the TaskRouter Workspace.
queue_stats_configurationConfigurable parameters for Queues Statistics.
flex_instance_sidThe SID of the Flex instance.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe status of the Flex onboarding. Can be: ok, inprogress,notstarted.. Values: ok, inprogress, notstarted
crm_callback_urlThe CRM Callback URL.
debugger_integrationConfigurable parameters for Debugger Integration.
ui_versionThe Pinned UI version.
notificationsConfigurable parameters for Notifications.
offline_configPresence and presence ttl configuration
crm_attributesAn object that contains the CRM attributes.
outbound_call_flowsThe list of outbound call flows.
markdownConfigurable parameters for Markdown.
crm_typeThe CRM type.
plugin_service_enabledWhether the plugin service enabled.
call_recording_webhook_urlThe call recording webhook URL.
ui_languageThe primary language of the Flex UI.
attributesAn object that contains application-specific data.
flex_insights_hrObject with enabled/disabled flag with list of workspaces.
flex_service_instance_sidThe SID of the Flex service instance.
serverless_service_sidsThe list of serverless service SIDs.
taskrouter_target_workflow_sidThe SID of the TaskRouter target Workflow.

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.Configuration{
  account_sid: String.t() | nil,
  agent_conv_end_methods: String.t() | nil,
  attributes: String.t() | nil,
  call_recording_enabled: boolean() | nil,
  call_recording_webhook_url: String.t() | nil,
  channel_configs: list() | nil,
  chat_service_instance_sid: String.t() | nil,
  citrix_voice_vdi: String.t() | nil,
  crm_attributes: String.t() | nil,
  crm_callback_url: String.t() | nil,
  crm_enabled: boolean() | nil,
  crm_fallback_url: String.t() | nil,
  crm_type: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  debugger_integration: String.t() | nil,
  flex_insights_drilldown: boolean() | nil,
  flex_insights_hr: String.t() | nil,
  flex_instance_sid: String.t() | nil,
  flex_service_instance_sid: String.t() | nil,
  flex_ui_status_report: String.t() | nil,
  flex_url: String.t() | nil,
  integrations: list() | nil,
  markdown: String.t() | nil,
  messaging_service_instance_sid: String.t() | nil,
  notifications: String.t() | nil,
  offline_config: String.t() | nil,
  outbound_call_flows: String.t() | nil,
  plugin_service_attributes: String.t() | nil,
  plugin_service_enabled: boolean() | nil,
  public_attributes: String.t() | nil,
  queue_stats_configuration: String.t() | nil,
  runtime_domain: String.t() | nil,
  serverless_service_sids: list() | nil,
  service_version: String.t() | nil,
  status: String.t(),
  taskrouter_offline_activity_sid: String.t() | nil,
  taskrouter_skills: list() | nil,
  taskrouter_target_taskqueue_sid: String.t() | nil,
  taskrouter_target_workflow_sid: String.t() | nil,
  taskrouter_taskqueues: list() | nil,
  taskrouter_worker_attributes: String.t() | nil,
  taskrouter_worker_channels: String.t() | nil,
  taskrouter_workspace_sid: String.t() | nil,
  ui_attributes: String.t() | nil,
  ui_dependencies: String.t() | nil,
  ui_language: String.t() | nil,
  ui_version: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()