Twilio.Resources.Flex.V1.Insight.QualityManagement.Assessment.Comment (twilio_elixir v0.1.1)

Copy Markdown View Source

Comment resource.

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Flex Insights resource and owns this resource.
agent_idThe id of the agent.
assessment_sidThe SID of the assessment.
commentThe comment added for assessment.
offsetThe offset
reportThe flag indicating if this assessment is part of report
segment_idThe id of the segment.
timestampThe timestamp when the record is inserted
urlFormat: uri
user_emailThe email id of the user.
user_nameThe name of the user.
weightThe weightage given to this comment

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.Insight.QualityManagement.Assessment.Comment{
  account_sid: String.t() | nil,
  agent_id: String.t() | nil,
  assessment_sid: String.t() | nil,
  comment: String.t() | nil,
  offset: String.t() | nil,
  report: boolean() | nil,
  segment_id: String.t() | nil,
  timestamp: String.t() | nil,
  url: String.t() | nil,
  user_email: String.t() | nil,
  user_name: String.t() | nil,
  weight: String.t() | nil
}

Functions

object_name()