Twilio.Resources.Flex.V1.Insight.QualityManagement.InsightsQuestionnaires (twilio_elixir v0.1.1)

Copy Markdown View Source

InsightsQuestionnaires resource.

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Flex Insights resource and owns this resource.
activeThe flag to enable or disable questionnaire
descriptionThe description of this questionnaire
nameThe name of this category.
questionnaire_sidThe sid of this questionnaire
questionsThe list of questions with category for a questionnaire
urlFormat: uri

Summary

Types

t()

@type t() ::
  %Twilio.Resources.Flex.V1.Insight.QualityManagement.InsightsQuestionnaires{
    account_sid: String.t() | nil,
    active: boolean() | nil,
    description: String.t() | nil,
    name: String.t() | nil,
    questionnaire_sid: String.t() | nil,
    questions: list() | nil,
    url: String.t() | nil
  }

Functions

object_name()