Twilio.Resources.Flex.V1.Insight.QualityManagement.Question (twilio_elixir v0.1.1)

Copy Markdown View Source

Question resource.

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Flex Insights resource and owns this resource.
allow_naThe flag to enable for disable NA for answer.
answer_setSet of answers for the question
answer_set_idThe answer_set for the question.
categoryThe Category for the question.
descriptionThe description for the question.
questionThe question.
question_sidThe SID of the question
urlFormat: uri
usageInteger value that tells a particular question is used by how many questionnaires

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.Insight.QualityManagement.Question{
  account_sid: String.t() | nil,
  allow_na: boolean() | nil,
  answer_set: String.t() | nil,
  answer_set_id: String.t() | nil,
  category: String.t() | nil,
  description: String.t() | nil,
  question: String.t() | nil,
  question_sid: String.t() | nil,
  url: String.t() | nil,
  usage: integer()
}

Functions

object_name()