Twilio.Resources.Flex.V1.Interaction (twilio_elixir v0.1.1)

Copy Markdown View Source

Interaction resource.

SID prefix: KD

Sub-resources

  • channels/v1/Interactions/{interaction_sid}/Channels

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

channelA JSON object that defines the Interaction’s communication channel and includes details about the channel. See the Outbound SMS and inbound (API-initiated) Channel object examples.
linksFormat: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

routingA JSON Object representing the routing rules for the Interaction Channel. See Outbound SMS Example for an example Routing object. The Interactions resource uses TaskRouter for all routing functionality. All attributes in the Routing object on your Interaction request body are added “as is” to the task. For a list of known attributes consumed by the Flex UI and/or Flex Insights, see Known Task Attributes.
sidThe unique string created by Twilio to identify an Interaction resource, prefixed with KD.
urlFormat: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.Interaction{
  channel: String.t() | nil,
  interaction_context_sid: String.t() | nil,
  links: map() | nil,
  routing: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil,
  webhook_ttid: String.t() | nil
}

Functions

object_name()

sid_prefix()