Twilio.Resources.Flex.V1.Interaction.Channel.InteractionChannelInvite (twilio_elixir v0.1.1)

Copy Markdown View Source

InteractionChannelInvite resource.

SID prefix: KG

Parent: /Interactions/{InteractionSid}/Channels/{Sid}

Properties

FieldDescription
channel_sidThe Channel SID for this Invite.
interaction_sidThe Interaction SID for this Channel.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

routingA JSON object representing the routing rules for the Interaction Channel. See Outbound SMS Example for an example Routing object. The Interactions resource uses TaskRouter for all routing functionality. All attributes in the Routing object on your Interaction request body are added “as is” to the task. For a list of known attributes consumed by the Flex UI and/or Flex Insights, see Known Task Attributes.
sidThe unique string created by Twilio to identify an Interaction Channel Invite resource.
urlFormat: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.Interaction.Channel.InteractionChannelInvite{
  channel_sid: String.t() | nil,
  interaction_sid: String.t() | nil,
  routing: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()