Twilio.Resources.Flex.V1.Interaction.Channel.InteractionTransfer (twilio_elixir v0.1.1)

Copy Markdown View Source

InteractionTransfer resource.

SID prefix: UX

Parent: /Interactions/{InteractionSid}/Channels/{Sid}

Properties

FieldDescription
account_sidThe SID of the Account that created the Transfer.
channel_sidThe Channel Sid for this Transfer.
date_createdThe date and time when the Transfer was created.. Format: date-time
date_updatedThe date and time when the Transfer was last updated.. Format: date-time
execution_sidThe Execution SID associated with the Transfer.
fromThe SID of the Participant initiating the Transfer.
instance_sidThe SID of the Instance associated with the Transfer.
interaction_sidThe Interaction Sid for this channel.
note_sidThe SID of the Note associated with the Transfer.
sidThe unique string created by Twilio to identify an Interaction Transfer resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe status of the Transfer. Can be: active, completed, failed.. Values: active, failed, completed
summary_sidThe SID of the Summary associated with the Transfer.
toThe SID of the Participant receiving the Transfer.
typeThe type of the Transfer. Can be: cold, warm.. Values: warm, cold, external
urlFormat: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.Interaction.Channel.InteractionTransfer{
  account_sid: String.t() | nil,
  channel_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  execution_sid: String.t() | nil,
  from: String.t() | nil,
  instance_sid: String.t() | nil,
  interaction_sid: String.t() | nil,
  note_sid: String.t() | nil,
  sid: String.t() | nil,
  status: String.t(),
  summary_sid: String.t() | nil,
  to: String.t() | nil,
  type: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()