Twilio.Resources.Flex.V1.Interaction.InteractionChannel (twilio_elixir v0.1.1)

Copy Markdown View Source

InteractionChannel resource.

SID prefix: UO

Parent: /Interactions/{Sid}

Sub-resources

  • invites/v1/Interactions/{interaction_sid}/Channels/{channel_sid}/Invites
  • participants/v1/Interactions/{interaction_sid}/Channels/{channel_sid}/Participants
  • transfers/v1/Interactions/{interaction_sid}/Channels/{channel_sid}/Transfers

Properties

FieldDescription
error_codeThe Twilio error code for a failed channel.
error_messageThe error message for a failed channel.
interaction_sidThe unique string created by Twilio to identify an Interaction resource, prefixed with KD.
linksFormat: uri-map
sidThe unique string created by Twilio to identify an Interaction Channel resource, prefixed with UO.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| status | The status of this channel.. Values: setup, active, failed, closed, inactive, pause, transfer |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

typeThe Interaction Channel's type. Can be: sms, email, chat, whatsapp, web, messenger, or gbm. Note: These can be different from the task channel type specified in the Routing attributes. Task channel type corresponds to channel capacity while this channel type is the actual media type. Values: voice, sms, email, web, whatsapp, chat, messenger, gbm
urlFormat: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.Interaction.InteractionChannel{
  error_code: integer() | nil,
  error_message: String.t() | nil,
  interaction_sid: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  status: String.t(),
  type: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()