Twilio.Resources.Flex.V1.PluginService.Configuration
(twilio_elixir v0.1.1)
Configuration resource.
SID prefix: FJ
Sub-resources
plugins—/v1/PluginService/Configurations/{configuration_sid}/Plugins
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Flex Plugin Configuration resource and owns this resource. |
archived | Whether the Flex Plugin Configuration is archived. The default value is false. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_created | The date and time in GMT when the Flex Plugin Configuration was created specified in ISO 8601 format.. Format: date-time |
description | The description of the Flex Plugin Configuration resource.. PII: standard |
links | Format: uri-map |
name | The name of this Flex Plugin Configuration. |
sid | The unique string that we created to identify the Flex Plugin Configuration resource. |
url | The absolute URL of the Flex Plugin Configuration resource.. Format: uri |