Twilio.Resources.Flex.V1.PluginService.Configuration.Archive (twilio_elixir v0.1.1)

Copy Markdown View Source

Archive resource.

SID prefix: FJ

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Flex Plugin Configuration resource and owns this resource.
archivedWhether the Flex Plugin Configuration is archived. The default value is false.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_createdThe date and time in GMT when the Flex Plugin Configuration was created specified in ISO 8601 format.. Format: date-time
descriptionThe description of the Flex Plugin Configuration resource.. PII: standard
nameThe name of this Flex Plugin Configuration.
sidThe unique string that we created to identify the Flex Plugin Configuration resource.
urlThe absolute URL of the Flex Plugin Configuration resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.PluginService.Configuration.Archive{
  account_sid: String.t() | nil,
  archived: boolean() | nil,
  date_created: String.t() | nil,
  description: String.t() | nil,
  name: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()