Twilio.Resources.Flex.V1.PluginService.Configuration.ConfiguredPlugin (twilio_elixir v0.1.1)

Copy Markdown View Source

ConfiguredPlugin resource.

Parent: /PluginService/Configurations/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that the Flex Plugin resource is installed for.
changelogA changelog that describes the changes this Flex Plugin Version brings.
configuration_sidThe SID of the Flex Plugin Configuration that this Flex Plugin belongs to.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Flex Plugin was installed specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

descriptionA descriptive string that you create to describe the plugin resource. It can be up to 500 characters long
friendly_nameThe friendly name of this Flex Plugin resource.
phaseThe phase this Flex Plugin would initialize at runtime.
plugin_archivedWhether the Flex Plugin is archived. The default value is false.
plugin_sidThe SID of the Flex Plugin.
plugin_urlThe URL of where the Flex Plugin Version JavaScript bundle is hosted on.. PII: standard
plugin_version_archivedWhether the Flex Plugin Version is archived. The default value is false.
plugin_version_sidThe SID of the Flex Plugin Version.
privateWhether to validate the request is authorized to access the Flex Plugin Version.
unique_nameThe name that uniquely identifies this Flex Plugin resource.. PII: standard
urlThe absolute URL of the Flex Plugin resource.. Format: uri
versionThe latest version of this Flex Plugin Version.

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.PluginService.Configuration.ConfiguredPlugin{
  account_sid: String.t() | nil,
  changelog: String.t() | nil,
  configuration_sid: String.t() | nil,
  date_created: String.t() | nil,
  description: String.t() | nil,
  friendly_name: String.t() | nil,
  phase: integer(),
  plugin_archived: boolean() | nil,
  plugin_sid: String.t() | nil,
  plugin_url: String.t() | nil,
  plugin_version_archived: boolean() | nil,
  plugin_version_sid: String.t() | nil,
  private: boolean() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil,
  version: String.t() | nil
}

Functions

object_name()