Twilio.Resources.Flex.V1.PluginService.Plugin.Archive (twilio_elixir v0.1.1)

Copy Markdown View Source

Archive resource.

SID prefix: FP

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Flex Plugin resource and owns this resource.
archivedWhether the Flex Plugin is archived. The default value is false.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Flex Plugin was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the Flex Plugin was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

descriptionA descriptive string that you create to describe the plugin resource. It can be up to 500 characters long. PII: standard
friendly_nameThe friendly name this Flex Plugin resource.. PII: standard
sidThe unique string that we created to identify the Flex Plugin resource.
unique_nameThe name that uniquely identifies this Flex Plugin resource.. PII: standard
urlThe absolute URL of the Flex Plugin resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.PluginService.Plugin.Archive{
  account_sid: String.t() | nil,
  archived: boolean() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  description: String.t() | nil,
  friendly_name: String.t() | nil,
  sid: String.t() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()