Twilio.Resources.Flex.V1.PluginService.Plugin.PluginVersions (twilio_elixir v0.1.1)

Copy Markdown View Source

PluginVersions resource.

SID prefix: FV

Parent: /PluginService/Plugins/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Flex Plugin Version resource and owns this resource.
archivedWhether the Flex Plugin Version is archived. The default value is false.
changelogA changelog that describes the changes this Flex Plugin Version brings.. PII: standard

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_createdThe date and time in GMT when the Flex Plugin Version was created specified in ISO 8601 format.. Format: date-time
plugin_sidThe SID of the Flex Plugin resource this Flex Plugin Version belongs to.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

plugin_urlThe URL of where the Flex Plugin Version JavaScript bundle is hosted on.. Format: uri. PII: standard
privateWhether the Flex Plugin Version is validated. The default value is false.
sidThe unique string that we created to identify the Flex Plugin Version resource.
urlThe absolute URL of the Flex Plugin Version resource.. Format: uri
versionThe unique version of this Flex Plugin Version.

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.PluginService.Plugin.PluginVersions{
  account_sid: String.t() | nil,
  archived: boolean() | nil,
  changelog: String.t() | nil,
  date_created: String.t() | nil,
  plugin_sid: String.t() | nil,
  plugin_url: String.t() | nil,
  private: boolean() | nil,
  sid: String.t() | nil,
  url: String.t() | nil,
  validated: boolean() | nil,
  version: String.t() | nil
}

Functions

object_name()

sid_prefix()