Twilio.Resources.Flex.V1.PluginService.Release (twilio_elixir v0.1.1)

Copy Markdown View Source

Release resource.

SID prefix: FK

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Plugin Release resource and owns this resource.
configuration_sidThe SID of the Plugin Configuration resource to release.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_createdThe date and time in GMT when the Flex Plugin Release was created specified in ISO 8601 format.. Format: date-time
sidThe unique string that we created to identify the Plugin Release resource.
urlThe absolute URL of the Plugin Release resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.PluginService.Release{
  account_sid: String.t() | nil,
  configuration_sid: String.t() | nil,
  date_created: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()