Twilio.Resources.Flex.V1.WebChannel (twilio_elixir v0.1.1)

Copy Markdown View Source

WebChannel resource.

SID prefix: CH

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the WebChannel resource and owns this Workflow. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
flex_flow_sidThe SID of the Flex Flow.
sidThe unique string that we created to identify the WebChannel resource.
urlThe absolute URL of the WebChannel resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V1.WebChannel{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  flex_flow_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()