Twilio.Resources.Flex.V2.Instance.User (twilio_elixir v0.1.1)

Copy Markdown View Source

User resource.

Properties

FieldDescription
account_sidThe unique SID of the account that created the resource.
created_dateThe date that this user was created, given in ISO 8601 format.. Format: date-time
emailEmail of the User.
flex_team_sidThe unique SID identifier of the Flex Team.
flex_user_sidThe unique SID identifier of the Flex User.
instance_sidThe unique ID created by Twilio to identify a Flex instance.
localeThe locale preference of the user.
rolesThe roles of the user.
updated_dateThe date that this user was updated, given in ISO 8601 format.. Format: date-time
urlFormat: uri
user_sidThe unique SID identifier of the Twilio Unified User.
usernameUsername of the User.
versionThe current version of the user.
worker_sidThe unique SID identifier of the worker.
workspace_sidThe unique SID identifier of the workspace.

Summary

Types

t()

@type t() :: %Twilio.Resources.Flex.V2.Instance.User{
  account_sid: String.t() | nil,
  created_date: String.t() | nil,
  email: String.t() | nil,
  flex_team_sid: String.t() | nil,
  flex_user_sid: String.t() | nil,
  instance_sid: String.t() | nil,
  locale: String.t() | nil,
  roles: list() | nil,
  updated_date: String.t() | nil,
  url: String.t() | nil,
  user_sid: String.t() | nil,
  username: String.t() | nil,
  version: integer(),
  worker_sid: String.t() | nil,
  workspace_sid: String.t() | nil
}

Functions

object_name()