Twilio.Resources.Frontline.V1.User (twilio_elixir v0.1.1)

Copy Markdown View Source

A User resource represents a frontline user.

SID prefix: US

Properties

FieldDescription
avatarThe avatar URL which will be shown in Frontline application.
friendly_nameThe string that you assigned to describe the User.. PII: standard

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

identityThe application-defined string that uniquely identifies the resource's User. This value is often a username or an email address, and is case-sensitive.. PII: standard
is_availableWhether the User is available for new conversations. Defaults to false for new users.
sidThe unique string that we created to identify the User resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

stateCurrent state of this user. Can be either active or deactivated and defaults to active. Values: active, deactivated
urlAn absolute API resource URL for this user.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Frontline.V1.User{
  avatar: String.t() | nil,
  friendly_name: String.t() | nil,
  identity: String.t() | nil,
  is_available: boolean() | nil,
  sid: String.t() | nil,
  state: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()