Twilio.Resources.Insights.V1.Conference.Participant (twilio_elixir v0.1.1)

Copy Markdown View Source

Participant resource.

Parent: /Conferences/{ConferenceSid}

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.
call_directionCall direction of the participant; inbound or outbound.. Values: inbound, outbound
call_sidUnique SID identifier of the call that generated the Participant resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| call_status | Call status of the call that generated the participant.. Values: answered, completed, busy, fail, noanswer, ringing, canceled |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

call_typeThe Call Type of this Conference Participant. One of carrier, client or sip.. Values: carrier, client, sip
coached_participantsCall SIDs coached by this participant.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

conference_regionThe Conference Region of this Conference Participant. One of us1, us2, au1, br1, ie1, jp1, sg1 or de1.. Values: us1, us2, au1, br1, ie1, jp1, sg1, de1, in1
conference_sidThe unique SID identifier of the Conference.
country_codeISO alpha-2 country code of the participant based on caller ID or called number.
duration_secondsParticipant durations in seconds.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

eventsObject containing information of actions taken by participants. Contains a dictionary of URL links to nested resources of this Conference Participant.
fromCaller ID of the calling party.. PII: standard
is_coachBoolean. Indicated whether participant was a coach.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| is_moderator | Boolean. Indicates whether participant had startConferenceOnEnter=true or endConferenceOnExit=true. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

jitter_buffer_sizeThe Jitter Buffer Size of this Conference Participant. One of large, small, medium or off.. Values: large, small, medium, off
join_timeISO 8601 timestamp of participant join event.. Format: date-time
labelThe user-specified label of this participant.. PII: standard
leave_timeISO 8601 timestamp of participant leave event.. Format: date-time
metricsObject. Contains participant call quality metrics.
outbound_queue_lengthAdd Participant API only. Estimated time in queue at call creation.
outbound_time_in_queueAdd Participant API only. Actual time in queue in seconds.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

participant_regionTwilio region where the participant media originates.. Values: us1, us2, au1, br1, ie1, jp1, sg1, de1, in1
participant_sidSID for this participant.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

processing_stateProcessing state of the Participant Summary. Will be in_progress while data is being aggregated, timeout if Twilio couldn't process the summary in 24hrs, and complete once aggregations and analysis has ended.. Values: complete, in_progress, timeout
propertiesParticipant properties and metadata.
toCalled party.. PII: standard
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Insights.V1.Conference.Participant{
  account_sid: String.t() | nil,
  call_direction: String.t() | nil,
  call_sid: String.t() | nil,
  call_status: String.t() | nil,
  call_type: String.t() | nil,
  coached_participants: list() | nil,
  conference_region: String.t() | nil,
  conference_sid: String.t() | nil,
  country_code: String.t() | nil,
  duration_seconds: integer() | nil,
  events: String.t() | nil,
  from: String.t() | nil,
  is_coach: boolean() | nil,
  is_moderator: boolean() | nil,
  jitter_buffer_size: String.t() | nil,
  join_time: String.t() | nil,
  label: String.t() | nil,
  leave_time: String.t() | nil,
  metrics: String.t() | nil,
  outbound_queue_length: integer() | nil,
  outbound_time_in_queue: integer() | nil,
  participant_region: String.t() | nil,
  participant_sid: String.t() | nil,
  processing_state: String.t() | nil,
  properties: String.t() | nil,
  to: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()