Twilio.Resources.Insights.V1.Video.Room (twilio_elixir v0.1.1)

Copy Markdown View Source

Room resource.

Sub-resources

  • participants/v1/Video/Rooms/{room_sid}/Participants

Properties

FieldDescription
account_sidAccount SID associated with this room.
codecsCodecs used by participants in the room. Can be VP8, H264, or VP9.
concurrent_participantsActual number of concurrent participants.
create_timeCreation time of the room.. Format: date-time
created_methodHow the room was created. Can be sdk, ad_hoc, or api.. Values: sdk, ad_hoc, api
duration_secTotal room duration from create time to end time.. Format: int64

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| edge_location | Edge location of Twilio media servers for the room. See the list of public edge locations for the possible values.. Values: ashburn, dublin, frankfurt, singapore, sydney, sao_paulo, roaming, umatilla, tokyo |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

end_reasonReason the room ended. Can be room_ended_via_api or timeout.. Values: room_ended_via_api, timeout
end_timeEnd time for the room.. Format: date-time
linksRoom subresources.. Format: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

max_concurrent_participantsMaximum number of participants allowed in the room at the same time allowed by the application settings.
max_participantsMax number of total participants allowed by the application settings.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| media_region | Region of Twilio media servers for the room. See the list of possible media servers here.. Values: us1, us2, au1, br1, ie1, jp1, sg1, in1, de1, gll |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

processing_stateVideo Log Analyzer resource state. Will be either in-progress or complete. in-progress indicates that more details may be appended to the resource. complete indicates no further information will be added.. Values: complete, in_progress, timeout, not_started
recording_enabledBoolean indicating if recording is enabled for the room.
room_nameRoom friendly name.
room_sidUnique identifier for the room.
room_statusStatus of the room. Can be in_progress or completed.. Values: in_progress, completed

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

room_typeType of room. Can be go, peer_to_peer, group, or group_small.. Values: go, peer_to_peer, group, group_small
status_callbackWebhook provided for status callbacks.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

status_callback_methodHTTP method provided for status callback URL.. Values: GET, POST. Format: http-method
total_participant_duration_secCombined amount of participant time in the room.. Format: int64
total_recording_duration_secCombined amount of recorded seconds for participants in the room.. Format: int64
unique_participant_identitiesUnique number of participant identities.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unique_participantsNumber of participants. May include duplicate identities for participants who left and rejoined.
urlURL for the room resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Insights.V1.Video.Room{
  account_sid: String.t() | nil,
  codecs: list() | nil,
  concurrent_participants: integer() | nil,
  create_time: String.t() | nil,
  created_method: String.t() | nil,
  duration_sec: integer() | nil,
  edge_location: String.t() | nil,
  end_reason: String.t() | nil,
  end_time: String.t() | nil,
  links: map() | nil,
  max_concurrent_participants: integer() | nil,
  max_participants: integer() | nil,
  media_region: String.t() | nil,
  processing_state: String.t() | nil,
  recording_enabled: boolean() | nil,
  room_name: String.t() | nil,
  room_sid: String.t() | nil,
  room_status: String.t() | nil,
  room_type: String.t() | nil,
  status_callback: String.t() | nil,
  status_callback_method: String.t() | nil,
  total_participant_duration_sec: integer() | nil,
  total_recording_duration_sec: integer() | nil,
  unique_participant_identities: integer() | nil,
  unique_participants: integer() | nil,
  url: String.t() | nil
}

Functions

object_name()