Twilio.Resources.Insights.V1.Video.Room.Participant (twilio_elixir v0.1.1)

Copy Markdown View Source

Participant resource.

Parent: /Video/Rooms/{RoomSid}

Properties

FieldDescription
account_sidAccount SID associated with the room.
codecsCodecs detected from the participant. Can be VP8, H264, or VP9.
duration_secAmount of time in seconds the participant was in the room.. Format: int64

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| edge_location | Name of the edge location the participant connected to. See the list of public edge locations for the possible values.. Values: ashburn, dublin, frankfurt, singapore, sydney, sao_paulo, roaming, umatilla, tokyo |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

end_reasonReason the participant left the room. See the list of possible values here.
error_codeErrors encountered by the participant.
error_code_urlTwilio error code dictionary link.
join_timeWhen the participant joined the room.. Format: date-time
leave_timeWhen the participant left the room.. Format: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

media_regionTwilio media region the participant connected to. See the list of possible media servers here.. Values: us1, us2, au1, br1, ie1, jp1, sg1, in1, de1, gll
participant_identityThe application-defined string that uniquely identifies the participant within a Room.
participant_sidUnique identifier for the participant.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| properties | Object containing information about the participant's data from the room. See below for more information. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

publisher_infoObject containing information about the SDK name and version. See below for more information.
room_sidUnique identifier for the room.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusStatus of the room. Can be in_progress or completed.. Values: in_progress, connected, completed, disconnected
urlURL of the participant resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Insights.V1.Video.Room.Participant{
  account_sid: String.t() | nil,
  codecs: list() | nil,
  duration_sec: integer() | nil,
  edge_location: String.t() | nil,
  end_reason: String.t() | nil,
  error_code: integer() | nil,
  error_code_url: String.t() | nil,
  join_time: String.t() | nil,
  leave_time: String.t() | nil,
  media_region: String.t() | nil,
  participant_identity: String.t() | nil,
  participant_sid: String.t() | nil,
  properties: String.t() | nil,
  publisher_info: String.t() | nil,
  room_sid: String.t() | nil,
  status: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()