Twilio.Resources.Insights.V1.Voice.CallSummaries (twilio_elixir v0.1.1)

Copy Markdown View Source

CallSummaries resource.

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

answered_byThe Answered By value for the summarized call based on Answering Machine Detection (AMD). One of unknown, machine_start, machine_end_beep, machine_end_silence, machine_end_other, human or fax. Refer to AMD for more detail.. Values: unknown, machine_start, machine_end_beep, machine_end_silence, machine_end_other, human, fax
attributesAttributes capturing call-flow-specific details.
call_sidThe unique SID identifier of the Call.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| call_state | The Call State of the summarized Call. One of ringing, completed, busy, fail, noanswer, canceled, answered, undialed.. Values: ringing, completed, busy, fail, noanswer, canceled, answered, undialed |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

call_typeThe Call Type of the summarized Call. One of carrier, sip, trunking or client.. Values: carrier, sip, trunking, client, whatsapp
carrier_edgeContains metrics and properties for the Twilio media gateway of a PSTN call.
client_edgeContains metrics and properties for the Twilio media gateway of a Client call.
connect_durationDuration between when the call was answered and when it ended

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

created_timeThe time at which the Call was created, given in ISO 8601 format. Can be different from start_time in the event of queueing due to CPS. Format: date-time
durationDuration between when the call was initiated and the call was ended
end_timeThe time at which the Call was ended, given in ISO 8601 format.. Format: date-time
fromThe calling party.. PII: standard

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

processing_stateThe Processing State of the Call Summary. The Processing State will be partial until the assembly of the Call Summary finishes, which occurs approximately 30 minutes after Call end. Then the Processing State changes to complete. Values: complete, partial
propertiesContains edge-agnostic call-level details.
sdk_edgeContains metrics and properties for the SDK sensor library for Client calls.
sip_edgeContains metrics and properties for the Twilio media gateway of a SIP Interface or Trunking call.
start_timeThe time at which the Call was started, given in ISO 8601 format.. Format: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

tagsTags applied to calls by Voice Insights analysis indicating a condition that could result in subjective degradation of the call quality.
toThe called party.. PII: standard
trustContains trusted communications details including Branded Call and verified caller ID.
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Insights.V1.Voice.CallSummaries{
  account_sid: String.t() | nil,
  annotation: String.t() | nil,
  answered_by: String.t() | nil,
  attributes: String.t() | nil,
  call_sid: String.t() | nil,
  call_state: String.t() | nil,
  call_type: String.t() | nil,
  carrier_edge: String.t() | nil,
  client_edge: String.t() | nil,
  connect_duration: integer() | nil,
  created_time: String.t() | nil,
  duration: integer() | nil,
  end_time: String.t() | nil,
  from: String.t() | nil,
  processing_state: String.t() | nil,
  properties: String.t() | nil,
  sdk_edge: String.t() | nil,
  sip_edge: String.t() | nil,
  start_time: String.t() | nil,
  tags: list() | nil,
  to: String.t() | nil,
  trust: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()