Twilio.Resources.Insights.V1.Voice.Event (twilio_elixir v0.1.1)

Copy Markdown View Source

Event resource.

Parent: /Voice/{Sid}

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.
call_sidThe unique SID identifier of the Call.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| carrier_edge | Represents the connection between Twilio and our immediate carrier partners. The events here describe the call lifecycle as reported by Twilio's carrier media gateways. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| client_edge | Represents the Twilio media gateway for Client calls. The events here describe the call lifecycle as reported by Twilio's Voice SDK media gateways. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

edgeThe Edge of this Event. One of unknown_edge, carrier_edge, sip_edge, sdk_edge or client_edge.. Values: unknown_edge, carrier_edge, sip_edge, sdk_edge, client_edge
groupEvent group.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

levelThe Level of this Event. One of UNKNOWN, DEBUG, INFO, WARNING or ERROR.. Values: UNKNOWN, DEBUG, INFO, WARNING, ERROR
nameEvent name.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sdk_edge | Represents the Voice SDK running locally in the browser or in the Android/iOS application. The events here are emitted by the Voice SDK in response to certain call progress events, network changes, or call quality conditions. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

sip_edgeRepresents the Twilio media gateway for SIP interface and SIP trunking calls. The events here describe the call lifecycle as reported by Twilio's public media gateways.
timestampEvent time.

Summary

Types

t()

@type t() :: %Twilio.Resources.Insights.V1.Voice.Event{
  account_sid: String.t() | nil,
  call_sid: String.t() | nil,
  carrier_edge: String.t() | nil,
  client_edge: String.t() | nil,
  edge: String.t() | nil,
  group: String.t() | nil,
  level: String.t() | nil,
  name: String.t() | nil,
  sdk_edge: String.t() | nil,
  sip_edge: String.t() | nil,
  timestamp: String.t() | nil
}

Functions

object_name()