Twilio.Resources.Insights.V1.Voice.Setting (twilio_elixir v0.1.1)

Copy Markdown View Source

Setting resource.

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.
advanced_featuresA boolean flag indicating whether Advanced Features for Voice Insights are enabled.
urlThe URL of this resource.. Format: uri
voice_traceA boolean flag indicating whether Voice Trace is enabled.

Summary

Types

t()

@type t() :: %Twilio.Resources.Insights.V1.Voice.Setting{
  account_sid: String.t() | nil,
  advanced_features: boolean() | nil,
  url: String.t() | nil,
  voice_trace: boolean() | nil
}

Functions

object_name()