Twilio.Resources.Intelligence.V2.Operator.PreBuilt (twilio_elixir v0.1.1)

Copy Markdown View Source

PreBuilt resource.

SID prefix: LY

Properties

FieldDescription
account_sidThe unique SID identifier of the Account the Pre-built Operator belongs to.
authorThe creator of the Operator. Pre-built Operators can only be created by Twilio.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| availability | Operator availability status. Possible values: internal, beta, public, retired.. Values: internal, beta, public, retired, general-availability |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

configOperator configuration, following the schema defined by the Operator Type. Only available on Custom Operators created by the Account, will be empty for Pre-Built Operators.
date_createdThe date that this Pre-built Operator was created, given in ISO 8601 format.. Format: date-time
date_updatedThe date that this Pre-built Operator was updated, given in ISO 8601 format.. Format: date-time
descriptionA human-readable description of this resource, longer than the friendly name.
friendly_nameA human-readable name of this resource, up to 64 characters.
operator_typeOperator Type for this Operator. References an existing Operator Type resource.
sidA 34 character string that uniquely identifies this Pre-built Operator.
urlThe URL of this resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| version | Numeric Operator version. Incremented with each update on the resource, used to ensure integrity when updating the Operator. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Intelligence.V2.Operator.PreBuilt{
  account_sid: String.t() | nil,
  author: String.t() | nil,
  availability: String.t(),
  config: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  description: String.t() | nil,
  friendly_name: String.t() | nil,
  operator_type: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil,
  version: integer()
}

Functions

object_name()

sid_prefix()