Twilio.Resources.Intelligence.V2.Service (twilio_elixir v0.1.1)

Copy Markdown View Source

Service resource.

Properties

FieldDescription
account_sidThe unique SID identifier of the Account the Service belongs to.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| auto_redaction | Instructs the Speech Recognition service to automatically redact PII from all transcripts made on this service. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| auto_transcribe | Instructs the Speech Recognition service to automatically transcribe all recordings made on the account. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

data_loggingData logging allows Twilio to improve the quality of the speech recognition & language understanding services through using customer data to refine, fine tune and evaluate machine learning models. Note: Data logging cannot be activated via API, only via www.twilio.com, as it requires additional consent.
date_createdThe date that this Service was created, given in ISO 8601 format.. Format: date-time
date_updatedThe date that this Service was updated, given in ISO 8601 format.. Format: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

encryption_credential_sidThe unique SID identifier of the Public Key resource used to encrypt the sentences and operator results.
friendly_nameA human readable description of this resource, up to 64 characters.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| language_code | The language code set during Service creation determines the Transcription language for all call recordings processed by that Service. The default is en-US if no language code is set. A Service can only support one language code, and it cannot be updated once it's set. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

media_redactionInstructs the Speech Recognition service to automatically redact PII from all transcripts media made on this service. The auto_redaction flag must be enabled, results in error otherwise.
read_only_attached_operator_sidsOperator sids attached to this service, read only
sidA 34 character string that uniquely identifies this Service.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unique_nameProvides a unique and addressable name to be assigned to this Service, assigned by the developer, to be optionally used in addition to SID.
urlThe URL of this resource.. Format: uri
versionThe version number of this Service.
webhook_http_methodThe HTTP method for the Webhook. One of GET or POST.. Values: GET, POST, NULL
webhook_urlThe URL Twilio will request when executing the Webhook.

Summary

Types

t()

@type t() :: %Twilio.Resources.Intelligence.V2.Service{
  account_sid: String.t() | nil,
  auto_redaction: boolean() | nil,
  auto_transcribe: boolean() | nil,
  data_logging: boolean() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  encryption_credential_sid: String.t() | nil,
  friendly_name: String.t() | nil,
  language_code: String.t() | nil,
  media_redaction: boolean() | nil,
  read_only_attached_operator_sids: list() | nil,
  sid: String.t() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil,
  version: integer(),
  webhook_http_method: String.t(),
  webhook_url: String.t() | nil
}

Functions

object_name()