Twilio.Resources.Intelligence.V2.Transcript (twilio_elixir v0.1.1)

Copy Markdown View Source

Transcript resource.

SID prefix: GT

Sub-resources

  • encrypted_operator_results/v2/Transcripts/{transcript_sid}/OperatorResults/Encrypted
  • encrypted_sentences/v2/Transcripts/{transcript_sid}/Sentences/Encrypted
  • media/v2/Transcripts/{sid}/Media
  • operator_results/v2/Transcripts/{transcript_sid}/OperatorResults
  • sentences/v2/Transcripts/{transcript_sid}/Sentences

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.
channelMedia Channel describing Transcript Source and Participant Mapping

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

data_loggingData logging allows Twilio to improve the quality of the speech recognition & language understanding services through using customer data to refine, fine tune and evaluate machine learning models. Note: Data logging cannot be activated via API, only via www.twilio.com, as it requires additional consent.
date_createdThe date that this Transcript was created, given in ISO 8601 format.. Format: date-time
date_updatedThe date that this Transcript was updated, given in ISO 8601 format.. Format: date-time
durationThe duration of this Transcript's source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

encryption_credential_sidThe unique SID identifier of the Public Key resource used to encrypt the sentences and operator results.
language_codeThe default language code of the audio.
linksFormat: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

media_start_timeThe date that this Transcript's media was started, given in ISO 8601 format.. Format: date-time
redactionIf the transcript has been redacted, a redacted alternative of the transcript will be available.
service_sidThe unique SID identifier of the Service.
sidA 34 character string that uniquely identifies this Transcript.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe Status of this Transcript. One of queued, in-progress, completed, failed or canceled.. Values: queued, in-progress, completed, new, failed, canceled, error
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Intelligence.V2.Transcript{
  account_sid: String.t() | nil,
  channel: String.t() | nil,
  customer_key: String.t() | nil,
  data_logging: boolean() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  duration: integer(),
  encryption_credential_sid: String.t() | nil,
  language_code: String.t() | nil,
  links: map() | nil,
  media_start_time: String.t() | nil,
  redaction: boolean() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()