Chunk resource.
Parent: /Knowledge/{id}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Knowledge resource. |
content | The chunk content. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the Chunk was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the Chunk was updated specified in ISO 8601 format.. Format: date-time |
metadata | The metadata of the chunk. |