Twilio.Resources.Marketplace.V1.AvailableAddOn (twilio_elixir v0.1.1)

Copy Markdown View Source

AvailableAddOn resource.

SID prefix: XB

Sub-resources

  • extensions/v1/AvailableAddOns/{available_add_on_sid}/Extensions

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

configuration_schemaThe JSON object with the configuration that must be provided when installing a given Add-on.
descriptionA short description of the Add-on's functionality.
friendly_nameThe string that you assigned to describe the resource.
linksThe URLs of related resources.. Format: uri-map
pricing_typeHow customers are charged for using this Add-on.
sidThe unique string that we created to identify the AvailableAddOn resource.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Marketplace.V1.AvailableAddOn{
  configuration_schema: map() | nil,
  description: String.t() | nil,
  friendly_name: String.t() | nil,
  links: map() | nil,
  pricing_type: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()