Twilio.Resources.Marketplace.V1.InstalledAddOn.InstalledAddOnExtension (twilio_elixir v0.1.1)

Copy Markdown View Source

InstalledAddOnExtension resource.

SID prefix: XF

Parent: /InstalledAddOns/{Sid}

Properties

FieldDescription
enabledWhether the Extension will be invoked.
friendly_nameThe string that you assigned to describe the resource.
installed_add_on_sidThe SID of the InstalledAddOn resource to which this extension applies.
product_nameThe name of the Product this Extension is used within.
sidThe unique string that we created to identify the InstalledAddOn Extension resource.
unique_nameAn application-defined string that uniquely identifies the resource.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Marketplace.V1.InstalledAddOn.InstalledAddOnExtension{
  enabled: boolean() | nil,
  friendly_name: String.t() | nil,
  installed_add_on_sid: String.t() | nil,
  product_name: String.t() | nil,
  sid: String.t() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()