Twilio.Resources.Marketplace.V1.Listing (twilio_elixir v0.1.1)

Copy Markdown View Source

Listing resource.

SID prefix: XB

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| configuration | A JSON object for providing listing specific configuration. Contains button setup, notification url, among others. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| description | A JSON object describing the module and is displayed under the Description tab of the Module detail page. You can define the main body of the description, highlight key features or aspects of the module and if applicable, provide code samples for developers |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| documentation | A JSON object for providing comprehensive information, instructions, and resources related to the module |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| module_info | A JSON object containing essential attributes that define a module. This information is presented on the Module detail page in the Twilio Marketplace Catalog. You can pass the following attributes in the JSON object |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

policiesA JSON object describing the module's privacy and legal policies and is displayed under the Policies tab of the Module detail page. The maximum file size for Policies is 5MB
pricingA JSON object for providing Listing specific pricing information.
sidModuleSid that identifies this Listing.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

supportA JSON object containing information on how customers can obtain support for the module. Use this parameter to provide details such as contact information and support description.
urlURL to query the subresource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Marketplace.V1.Listing{
  configuration: map() | nil,
  description: map() | nil,
  documentation: map() | nil,
  module_info: map() | nil,
  policies: map() | nil,
  pricing: map() | nil,
  sid: String.t() | nil,
  support: map() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()