Twilio.Resources.Messaging.V1.A2p.BrandRegistration (twilio_elixir v0.1.1)

Copy Markdown View Source

A Messaging Service resource to add and fetch Brand Registrations.

SID prefix: BN

Sub-resources

  • brand_registration_otps/v1/a2p/BrandRegistrations/{brand_registration_sid}/SmsOtp
  • brand_vettings/v1/a2p/BrandRegistrations/{brand_sid}/Vettings

Properties

FieldDescription
a2p_profile_bundle_sidA2P Messaging Profile Bundle BundleSid.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Brand Registration resource.
brand_feedbackDEPRECATED. Feedback on how to improve brand score

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| brand_score | The secondary vetting score if it was done. Otherwise, it will be the brand score if it's returned from TCR. It may be null if no score is available. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

brand_typeType of brand. One of: "STANDARD", "SOLE_PROPRIETOR". SOLE_PROPRIETOR is for the low volume, SOLE_PROPRIETOR campaign use case. There can only be one SOLE_PROPRIETOR campaign created per SOLE_PROPRIETOR brand. STANDARD is for all other campaign use cases. Multiple campaign use cases can be created per STANDARD brand.
customer_profile_bundle_sidA2P Messaging Profile Bundle BundleSid.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
errorsA list of errors that occurred during the brand registration process.
failure_reasonDEPRECATED. A reason why brand registration has failed. Only applicable when status is FAILED.
government_entityIdentified as a government entity

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

identity_statusWhen a brand is registered, TCR will attempt to verify the identity of the brand based on the supplied information.. Values: SELF_DECLARED, UNVERIFIED, VERIFIED, VETTED_VERIFIED
linksFormat: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

mockA boolean that specifies whether brand should be a mock or not. If true, brand will be registered as a mock brand. Defaults to false if no value is provided.
russell_3000Publicly traded company identified in the Russell 3000 Index
sidThe unique string to identify Brand Registration.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| skip_automatic_sec_vet | A flag to disable automatic secondary vetting for brands which it would otherwise be done. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusBrand Registration status. One of "PENDING", "APPROVED", "FAILED", "IN_REVIEW", "DELETION_PENDING", "DELETION_FAILED", "SUSPENDED".. Values: PENDING, APPROVED, FAILED, IN_REVIEW, DELETION_PENDING, DELETION_FAILED, SUSPENDED
tax_exempt_statusNonprofit organization tax-exempt status per section 501 of the U.S. tax code.
tcr_idCampaign Registry (TCR) Brand ID. Assigned only after successful brand registration.
urlThe absolute URL of the Brand Registration resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Messaging.V1.A2p.BrandRegistration{
  a2p_profile_bundle_sid: String.t() | nil,
  account_sid: String.t() | nil,
  brand_feedback: list() | nil,
  brand_score: integer() | nil,
  brand_type: String.t() | nil,
  customer_profile_bundle_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  errors: list() | nil,
  failure_reason: String.t() | nil,
  government_entity: boolean() | nil,
  identity_status: String.t(),
  links: map() | nil,
  mock: boolean() | nil,
  russell_3000: boolean() | nil,
  sid: String.t() | nil,
  skip_automatic_sec_vet: boolean() | nil,
  status: String.t(),
  tax_exempt_status: String.t() | nil,
  tcr_id: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()