Twilio.Resources.Messaging.V1.A2p.BrandRegistration.SmsOtp (twilio_elixir v0.1.1)

Copy Markdown View Source

A Messaging Service resource to retry OTP verification for Sole Proprietor Brand Registrations.

Parent: /a2p/BrandRegistrations/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Brand Registration resource.
brand_registration_sidThe unique string to identify Brand Registration of Sole Proprietor Brand

Summary

Types

t()

@type t() :: %Twilio.Resources.Messaging.V1.A2p.BrandRegistration.SmsOtp{
  account_sid: String.t() | nil,
  brand_registration_sid: String.t() | nil
}

Functions

object_name()