Twilio.Resources.Messaging.V1.A2p.BrandRegistration.Vetting (twilio_elixir v0.1.1)

Copy Markdown View Source

A Messaging Service resource to add and get Brand Vettings.

Parent: /a2p/BrandRegistrations/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the vetting record.
brand_sidThe unique string to identify Brand Registration.
brand_vetting_sidThe Twilio SID of the third-party vetting record.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
urlThe absolute URL of the Brand Vetting resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

vetting_classThe type of vetting that has been conducted. One of “STANDARD” (Aegis) or “POLITICAL” (Campaign Verify).
vetting_idThe unique identifier of the vetting from the third-party provider.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

vetting_providerThe third-party provider that has conducted the vetting. One of “CampaignVerify” (Campaign Verify tokens) or “AEGIS” (Secondary Vetting).. Values: campaign-verify, aegis
vetting_statusThe status of the import vetting attempt. One of “PENDING,” “SUCCESS,” or “FAILED”.

Summary

Types

t()

@type t() :: %Twilio.Resources.Messaging.V1.A2p.BrandRegistration.Vetting{
  account_sid: String.t() | nil,
  brand_sid: String.t() | nil,
  brand_vetting_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  url: String.t() | nil,
  vetting_class: String.t() | nil,
  vetting_id: String.t() | nil,
  vetting_provider: String.t(),
  vetting_status: String.t() | nil
}

Functions

object_name()