Twilio.Resources.Messaging.V1.LinkShortening.Domain.DomainCerts (twilio_elixir v0.1.1)

Copy Markdown View Source

DomainCerts resource.

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

cert_in_validationOptional JSON field describing the status and upload date of a new certificate in the process of validation
certificate_sidThe unique string that we created to identify this Certificate resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | Date that this Domain was registered to the Twilio platform to create a new Domain object.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_expiresDate that the private certificate associated with this domain expires. You will need to update the certificate before that date to ensure your shortened links will continue to work.. Format: date-time
date_updatedDate that this Domain was last updated.. Format: date-time
domain_nameFull url path for this domain.. Format: uri
domain_sidThe unique string that we created to identify the Domain resource.
urlFormat: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Messaging.V1.LinkShortening.Domain.DomainCerts{
  cert_in_validation: String.t() | nil,
  certificate_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_expires: String.t() | nil,
  date_updated: String.t() | nil,
  domain_name: String.t() | nil,
  domain_sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()