Twilio.Resources.Messaging.V1.LinkShortening.MessagingService.Domain
(twilio_elixir v0.1.1)
Domain resource.
Properties
| Field | Description |
|---|---|
domain_sid | The unique string that we created to identify the Domain resource. |
messaging_service_sid | The unique string that identifies the messaging service |
url | Format: uri |