A Messaging Service resource to add, fetch or remove an Alpha Sender ID from a Messaging Service.
SID prefix: AI
Parent: /Services/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the AlphaSender resource. |
alpha_sender | The Alphanumeric Sender ID string. |
capabilities | An array of values that describe whether the number can receive calls or messages. Can be: SMS. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
service_sid | The SID of the Service the resource is associated with. |
sid | The unique string that we created to identify the AlphaSender resource. |
url | The absolute URL of the AlphaSender resource.. Format: uri |