Twilio.Resources.Messaging.V1.Service.ChannelSender (twilio_elixir v0.1.1)

Copy Markdown View Source

A Messaging Service resource to read, fetch all Channel Senders associated with a Messaging Service.

SID prefix: XE

Parent: /Services/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the ChannelSender resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| country_code | The 2-character ISO Country Code of the number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

messaging_service_sidThe SID of the Service the resource is associated with.
senderThe unique string that identifies the sender e.g whatsapp:+123456XXXX.
sender_typeA string value that identifies the sender type e.g WhatsApp, Messenger.
sidThe unique string that we created to identify the ChannelSender resource.
urlThe absolute URL of the ChannelSender resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Messaging.V1.Service.ChannelSender{
  account_sid: String.t() | nil,
  country_code: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  messaging_service_sid: String.t() | nil,
  sender: String.t() | nil,
  sender_type: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()