Twilio.Resources.Messaging.V1.Service.DestinationAlphaSender (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

A Messaging Service resource to add, fetch or remove Destination and Default Alpha Sender IDs from a Messaging Service. Destination Alpha Sender can send to a particular ISO country code. Default Alpha Senders can send to all countries.

SID prefix: AI

Parent: /Services/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the AlphaSender resource.
alpha_senderThe Alphanumeric Sender ID string.
capabilitiesAn array of values that describe whether the number can receive calls or messages. Can be: SMS.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| iso_country_code | The Two Character ISO Country Code the Alphanumeric Sender ID will be used for. For Default Alpha Senders that work across countries, this value will be an empty string |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service the resource is associated with.
sidThe unique string that we created to identify the AlphaSender resource.
urlThe absolute URL of the AlphaSender resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Messaging.V1.Service.DestinationAlphaSender{
  account_sid: String.t() | nil,
  alpha_sender: String.t() | nil,
  capabilities: list() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  iso_country_code: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()