Twilio.Resources.Messaging.V1.Service.PhoneNumber (twilio_elixir v0.1.1)

Copy Markdown View Source

A Messaging Service resource to add, fetch or remove phone numbers from a Messaging Service.

SID prefix: PN

Parent: /Services/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the PhoneNumber resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| capabilities | An array of values that describe whether the number can receive calls or messages. Can be: Voice, SMS, and MMS. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| country_code | The 2-character ISO Country Code of the number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| phone_number | The phone number in E.164 format, which consists of a + followed by the country code and subscriber number.. Format: phone-number |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service the resource is associated with.
sidThe unique string that we created to identify the PhoneNumber resource.
urlThe absolute URL of the PhoneNumber resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Messaging.V1.Service.PhoneNumber{
  account_sid: String.t() | nil,
  capabilities: list() | nil,
  country_code: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  phone_number: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()