Twilio.Resources.Messaging.V1.Service.ShortCode (twilio_elixir v0.1.1)

Copy Markdown View Source

A Messaging Service resource to add, fetch or remove short code numbers from a Messaging Service.

SID prefix: SC

Parent: /Services/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the ShortCode resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| capabilities | An array of values that describe whether the number can receive calls or messages. Can be: SMS and MMS. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| country_code | The 2-character ISO Country Code of the number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service the resource is associated with.
short_codeThe E.164 format of the short code.
sidThe unique string that we created to identify the ShortCode resource.
urlThe absolute URL of the ShortCode resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Messaging.V1.Service.ShortCode{
  account_sid: String.t() | nil,
  capabilities: list() | nil,
  country_code: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  service_sid: String.t() | nil,
  short_code: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()