Twilio.Resources.Messaging.V1.Tollfree.Verification (twilio_elixir v0.1.1)

Copy Markdown View Source

A Messaging resource to create and retrieve Tollfree Verifications.

SID prefix: HH

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

edit_allowedIf a rejected verification is allowed to be edited/resubmitted. Some rejection reasons allow editing and some do not.
business_registration_authorityThe organizational authority for business registrations
age_gated_contentIndicates if the content is age gated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Tollfree Verification resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

opt_in_image_urlsLink to an image that shows the opt-in workflow. Multiple images allowed and must be a publicly hosted URL.
rejection_reasonThe rejection reason given when a Tollfree Verification has been rejected.
use_case_summaryUse this to further explain how messaging is used by the business or organization.
additional_informationAdditional information to be provided for verification.
opt_in_keywordsList of keywords that users can send to opt in or out of messages.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

business_contact_first_nameThe first name of the contact for the business or organization using the Tollfree number.
business_registration_countryCountry business is registered in
regulated_item_sidThe SID of the Regulated Item.
message_volumeEstimate monthly volume of messages from the Tollfree Number.
business_street_address2The address of the business or organization using the Tollfree number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

tollfree_phone_numberThe E.164 formatted toll-free phone number associated with the verification.. Format: phone-number
terms_and_conditions_urlThe URL of the terms and conditions for the business or organization.. Format: uri
error_codeThe error code given when a Tollfree Verification has been rejected.
urlThe absolute URL of the Tollfree Verification resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

business_state_province_regionThe state/province/region of the business or organization using the Tollfree number.
business_cityThe city of the business or organization using the Tollfree number.
use_case_categoriesThe category of the use case for the Tollfree Number. List as many are applicable..
privacy_policy_urlThe URL to the privacy policy for the business or organization.. Format: uri
business_websiteThe website of the business or organization using the Tollfree number.
help_message_sampleA sample help message provided to users.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

business_contact_phoneThe E.164 formatted phone number of the contact for the business or organization using the Tollfree number.. Format: phone-number
production_message_sampleAn example of message content, i.e. a sample message.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

business_contact_emailThe email address of the contact for the business or organization using the Tollfree number.
business_countryThe country of the business or organization using the Tollfree number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe compliance status of the Tollfree Verification record.. Values: PENDING_REVIEW, IN_REVIEW, TWILIO_APPROVED, TWILIO_REJECTED
business_street_addressThe address of the business or organization using the Tollfree number.
business_registration_numberA legally recognized business registration number
tollfree_phone_number_sidThe SID of the Phone Number associated with the Tollfree Verification.
vetting_id_expirationFormat: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

opt_in_typeDescribe how a user opts-in to text messages.. Values: VERBAL, WEB_FORM, PAPER_FORM, VIA_TEXT, MOBILE_QR_CODE, IMPORT, IMPORT_PLEASE_REPLACE
vetting_providerThe third-party political vetting provider.. Values: CAMPAIGN_VERIFY

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

business_contact_last_nameThe last name of the contact for the business or organization using the Tollfree number.
business_nameThe name of the business or organization using the Tollfree number.
sidThe unique string to identify Tollfree Verification.
resource_linksThe URLs of the documents associated with the Tollfree Verification resource.
edit_expirationThe date and time when the ability to edit a rejected verification expires.. Format: date-time
opt_in_confirmation_messageThe confirmation message sent to users when they opt in to receive messages.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

business_typeThe type of business, valid values are PRIVATE_PROFIT, PUBLIC_PROFIT, NON_PROFIT, SOLE_PROPRIETOR, GOVERNMENT. Values: PRIVATE_PROFIT, PUBLIC_PROFIT, SOLE_PROPRIETOR, NON_PROFIT, GOVERNMENT
notification_emailThe email address to receive the notification about the verification result. .
business_postal_codeThe postal code of the business or organization using the Tollfree number.
trust_product_sidTollfree TrustProduct Bundle BundleSid.
business_registration_phone_numberThe E.164 formatted number associated with the business.
customer_profile_sidCustomer's Profile Bundle BundleSid.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| doing_business_as | Trade name, sub entity, or downstream business name of business being submitted for verification |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| external_reference_id | An optional external reference ID supplied by customer and echoed back on status retrieval. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| rejection_reasons | A list of rejection reasons and codes describing why a Tollfree Verification has been rejected. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Messaging.V1.Tollfree.Verification{
  account_sid: String.t() | nil,
  additional_information: String.t() | nil,
  age_gated_content: boolean() | nil,
  business_city: String.t() | nil,
  business_contact_email: String.t() | nil,
  business_contact_first_name: String.t() | nil,
  business_contact_last_name: String.t() | nil,
  business_contact_phone: String.t() | nil,
  business_country: String.t() | nil,
  business_name: String.t() | nil,
  business_postal_code: String.t() | nil,
  business_registration_authority: String.t() | nil,
  business_registration_country: String.t() | nil,
  business_registration_number: String.t() | nil,
  business_registration_phone_number: String.t() | nil,
  business_state_province_region: String.t() | nil,
  business_street_address: String.t() | nil,
  business_street_address2: String.t() | nil,
  business_type: String.t() | nil,
  business_website: String.t() | nil,
  customer_profile_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  doing_business_as: String.t() | nil,
  edit_allowed: boolean() | nil,
  edit_expiration: String.t() | nil,
  error_code: integer() | nil,
  external_reference_id: String.t() | nil,
  help_message_sample: String.t() | nil,
  message_volume: String.t() | nil,
  notification_email: String.t() | nil,
  opt_in_confirmation_message: String.t() | nil,
  opt_in_image_urls: list() | nil,
  opt_in_keywords: list() | nil,
  opt_in_type: String.t(),
  privacy_policy_url: String.t() | nil,
  production_message_sample: String.t() | nil,
  regulated_item_sid: String.t() | nil,
  rejection_reason: String.t() | nil,
  rejection_reasons: list() | nil,
  resource_links: String.t() | nil,
  sid: String.t() | nil,
  status: String.t(),
  terms_and_conditions_url: String.t() | nil,
  tollfree_phone_number: String.t() | nil,
  tollfree_phone_number_sid: String.t() | nil,
  trust_product_sid: String.t() | nil,
  url: String.t() | nil,
  use_case_categories: list() | nil,
  use_case_summary: String.t() | nil,
  vetting_id: String.t() | nil,
  vetting_id_expiration: String.t() | nil,
  vetting_provider: String.t()
}

Functions

object_name()

sid_prefix()