Twilio.Resources.Monitor.V1.Event (twilio_elixir v0.1.1)

Copy Markdown View Source

Debugger events

SID prefix: AE

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Event resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| actor_sid | The SID of the actor that caused the event, if available. This can be either a User ID (matching the pattern ^US[0-9a-fA-F]{32}$) or an Account SID (matching the pattern ^AC[0-9a-fA-F]{32}$). If the actor's SID isn't available, this field will be null. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

actor_typeThe type of actor that caused the event. Can be: user for a change made by a logged-in user in the Twilio Console, account for an event caused by an API request by an authenticating Account, twilio-admin for an event caused by a Twilio employee, and so on.
descriptionA description of the event. Can be null.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| event_data | An object with additional data about the event. The contents depend on event_type. For example, event-types of the form RESOURCE.updated, this value contains a resource_properties dictionary that describes the previous and updated properties of the resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| event_date | The date and time in GMT when the event was recorded specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

event_typeThe event's type. Event-types are typically in the form: RESOURCE_TYPE.ACTION, where RESOURCE_TYPE is the type of resource that was affected and ACTION is what happened to it. For example, phone-number.created. For a full list of all event-types, see the Monitor Event Types.
linksThe absolute URLs of related resources.. Format: uri-map
resource_sidThe SID of the resource that was affected.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

resource_typeThe type of resource that was affected. For a full list of all resource-types, see the Monitor Event Types.
sidThe unique string that we created to identify the Event resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| source | The originating system or interface that caused the event. Can be: web for events caused by user action in the Twilio Console, api for events caused by a request to our API, or twilio for events caused by an automated or internal Twilio system. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

source_ip_addressThe IP address of the source, if the source is outside the Twilio cloud. This value is null for events with source of twilio
urlThe absolute URL of the resource that was affected. Can be null.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Monitor.V1.Event{
  account_sid: String.t() | nil,
  actor_sid: String.t() | nil,
  actor_type: String.t() | nil,
  description: String.t() | nil,
  event_data: String.t() | nil,
  event_date: String.t() | nil,
  event_type: String.t() | nil,
  links: map() | nil,
  resource_sid: String.t() | nil,
  resource_type: String.t() | nil,
  sid: String.t() | nil,
  source: String.t() | nil,
  source_ip_address: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()