Twilio.Resources.Notify.V1.Service.Binding (twilio_elixir v0.1.1)

Copy Markdown View Source

Binding resource.

SID prefix: BS

Parent: /Services/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Binding resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| address | The channel-specific address. For APNS, the device token. For FCM and GCM, the registration token. For SMS, a phone number in E.164 format. For Facebook Messenger, the Messenger ID of the user or a phone number in E.164 format.. PII: sensitive |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| binding_type | The transport technology to use for the Binding. Can be: apn, fcm, gcm, sms, or facebook-messenger. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| credential_sid | The SID of the Credential resource to be used to send notifications to this Binding. If present, this overrides the Credential specified in the Service resource. Applicable only to apn, fcm, and gcm type Bindings. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time
endpointDeprecated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

identityThe identity value that uniquely identifies the resource's User within the Service. Up to 20 Bindings can be created for the same Identity in a given Service.. PII: standard
linksThe URLs of related resources.. Format: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| notification_protocol_version | The protocol version to use to send the notification. This defaults to the value of default_xxxx_notification_protocol_version in the Service for the protocol. The current version is "3" for apn, fcm, and gcm type Bindings. The parameter is not applicable to sms and facebook-messenger type Bindings as the data format is fixed. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service the resource is associated with.
sidThe unique string that we created to identify the Binding resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

tagsThe list of tags associated with this Binding. Tags can be used to select the Bindings to use when sending a notification. Maximum 20 tags are allowed.. PII: standard
urlThe absolute URL of the Binding resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Notify.V1.Service.Binding{
  account_sid: String.t() | nil,
  address: String.t() | nil,
  binding_type: String.t() | nil,
  credential_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  endpoint: String.t() | nil,
  identity: String.t() | nil,
  links: map() | nil,
  notification_protocol_version: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  tags: list() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()