Twilio.Resources.Numbers.V1.HostedNumber.Eligibility.Bulk (twilio_elixir v0.1.1)

Copy Markdown View Source

Bulk resource.

Properties

FieldDescription
date_completedFormat: date-time
date_createdFormat: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

friendly_nameThis is the string that you assigned as a friendly name for describing the eligibility check request.
request_idThe SID of the bulk eligibility check that you want to know about.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

resultsThe result set that contains the eligibility check response for each requested number, each result has at least the following attributes: phone_number: The requested phone number ,hosting_account_sid: The account sid where the phone number will be hosted, country: Phone number’s country, eligibility_status: Indicates the eligibility status of the PN (Eligible/Ineligible), eligibility_sub_status: Indicates the sub status of the eligibility , ineligibility_reason: Reason for number's ineligibility (if applicable), next_step: Suggested next step in the hosting process based on the eligibility status.
statusThis is the status of the bulk eligibility check request. (Example: COMPLETE, IN_PROGRESS)
urlThis is the url of the request that you're trying to reach out to locate the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Numbers.V1.HostedNumber.Eligibility.Bulk{
  date_completed: String.t() | nil,
  date_created: String.t() | nil,
  friendly_name: String.t() | nil,
  request_id: String.t() | nil,
  results: list() | nil,
  status: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()