Twilio.Resources.Numbers.V1.Porting.Configuration.Webhook (twilio_elixir v0.1.1)

Copy Markdown View Source

Webhook resource.

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

notifications_ofA list to filter what notification events to receive for this account and its sub accounts. If it is an empty list, then it means that there are no filters for the notifications events to send in each webhook and all events will get sent.
port_in_target_date_createdCreation date for the port in webhook configuration. Format: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

port_in_target_urlThe complete webhook url that will be called when a notification event for port in request or port in phone number happens. Format: uri
port_out_target_date_createdCreation date for the port out webhook configuration. Format: date-time

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

port_out_target_urlThe complete webhook url that will be called when a notification event for a port out phone number happens.. Format: uri
urlThe URL of the webhook configuration request. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Numbers.V1.Porting.Configuration.Webhook{
  notifications_of: list() | nil,
  port_in_target_date_created: String.t() | nil,
  port_in_target_url: String.t() | nil,
  port_out_target_date_created: String.t() | nil,
  port_out_target_url: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()