Twilio.Resources.Numbers.V1.Porting.Portability.PhoneNumber (twilio_elixir v0.1.1)

Copy Markdown View Source

PhoneNumber resource.

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidAccount Sid that the phone number belongs to in Twilio. This is only returned for phone numbers that already exist in Twilio’s inventory and belong to your account or sub account.
countryCountry the phone number belongs to.. Format: iso-country-code
not_portable_reasonReason why the phone number cannot be ported into Twilio, null otherwise.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| not_portable_reason_code | The Portability Reason Code for the phone number if it cannot be ported into Twilio, null otherwise. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| number_type | The type of the requested phone number. One of LOCAL, UNKNOWN, MOBILE, TOLL-FREE.. Values: LOCAL, UNKNOWN, MOBILE, TOLL-FREE |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| phone_number | The phone number which portability is to be checked. Phone numbers are in E.164 format (e.g. +16175551212).. Format: phone-number. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

pin_and_account_number_requiredIndicates if the port in process will require a personal identification number (PIN) and an account number for this phone number. If this is true you will be required to submit both a PIN and account number from the losing carrier for this number when opening a port in request. These fields will be required in order to complete the port in process to Twilio.
portableBoolean flag indicates if the phone number can be ported into Twilio through the Porting API or not.
urlThis is the url of the request that you're trying to reach out to locate the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Numbers.V1.Porting.Portability.PhoneNumber{
  account_sid: String.t() | nil,
  country: String.t() | nil,
  not_portable_reason: String.t() | nil,
  not_portable_reason_code: integer() | nil,
  number_type: String.t(),
  phone_number: String.t() | nil,
  pin_and_account_number_required: boolean() | nil,
  portable: boolean() | nil,
  url: String.t() | nil
}

Functions

object_name()