Twilio.Resources.Numbers.V1.SigningRequest.Configuration (twilio_elixir v0.1.1)

Copy Markdown View Source

Configuration resource.

Properties

FieldDescription
countryThe country ISO code to apply the configuration.. Format: iso-country-code

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| email_message | Content of the email that the end client will receive ex: “This is a Hosting request from Twilio, please check the document and sign it”, maximum length of 5,000 characters. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| email_subject | Subject of the email that the end client will receive ex: “Twilio Hosting Request”, maximum length of 255 characters. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| friendly_name | This is the string that you assigned as a friendly name for describing the creation of the configuration. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

logo_sidThe SID of the document that includes the logo that will appear in the LOA. To upload documents follow the following guide: https://www.twilio.com/docs/phone-numbers/regulatory/getting-started/create-new-bundle-public-rest-apis#supporting-document-create
productThe product or service for which is requesting the signature.
urlFormat: uri
url_redirectionUrl the end client will be redirected after signing a document.

Summary

Types

t()

@type t() :: %Twilio.Resources.Numbers.V1.SigningRequest.Configuration{
  country: String.t() | nil,
  email_message: String.t() | nil,
  email_subject: String.t() | nil,
  friendly_name: String.t() | nil,
  logo_sid: String.t() | nil,
  product: String.t() | nil,
  url: String.t() | nil,
  url_redirection: String.t() | nil
}

Functions

object_name()