Twilio.Resources.Numbers.V2.HostedNumber.Order.Bulk
(twilio_elixir v0.1.1)
Bulk resource.
Properties
| Field | Description |
|---|---|
bulk_hosting_sid | A 34 character string that uniquely identifies this BulkHostedNumberOrder. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_completed | The date that this resource was completed, given as GMT RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date this resource was created, given as GMT RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| friendly_name | A 128 character string that is a human-readable text that describes this resource.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| notification_email | Email address used for send notifications about this Bulk hosted number request.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| request_status | A string that shows the status of the current Bulk Hosting request, it can vary between these values: 'QUEUED','IN_PROGRESS','PROCESSED'. Values: QUEUED, IN_PROGRESS, PROCESSED |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
results | Contains a list of all the individual hosting orders and their information, for this Bulk request. Each result object is grouped by its order status. To see a complete list of order status, please check 'https://www.twilio.com/docs/phone-numbers/hosted-numbers/hosted-numbers-api/hosted-number-order-resource#status-values'.. PII: standard |
total_count | The total count of phone numbers in this Bulk hosting request. |
url | The URL of this BulkHostedNumberOrder resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Numbers.V2.HostedNumber.Order.Bulk{ bulk_hosting_sid: String.t() | nil, date_completed: String.t() | nil, date_created: String.t() | nil, friendly_name: String.t() | nil, notification_email: String.t() | nil, request_status: String.t(), results: list() | nil, total_count: integer(), url: String.t() | nil }