Twilio.Resources.Numbers.V2.RegulatoryCompliance.Bundle.Evaluation (twilio_elixir v0.1.1)

Copy Markdown View Source

Evaluation resource.

SID prefix: EL

Parent: /RegulatoryCompliance/Bundles/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Bundle resource.
bundle_sidThe unique string that we created to identify the Bundle resource.
date_createdFormat: date-time
regulation_sidThe unique string of a regulation that is associated to the Bundle resource.
resultsThe results of the Evaluation which includes the valid and invalid attributes.
sidThe unique string that identifies the Evaluation resource.
statusThe compliance status of the Evaluation resource.. Values: compliant, noncompliant
urlFormat: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Numbers.V2.RegulatoryCompliance.Bundle.Evaluation{
  account_sid: String.t() | nil,
  bundle_sid: String.t() | nil,
  date_created: String.t() | nil,
  regulation_sid: String.t() | nil,
  results: list() | nil,
  sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()