Twilio.Resources.Numbers.V2.RegulatoryCompliance.Bundle.ItemAssignment (twilio_elixir v0.1.1)

Copy Markdown View Source

ItemAssignment resource.

SID prefix: BV

Parent: /RegulatoryCompliance/Bundles/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Item Assignment resource.
bundle_sidThe unique string that we created to identify the Bundle resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_createdThe date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time
object_sidThe SID of an object bag that holds information of the different items.
sidThe unique string that we created to identify the Item Assignment resource.
urlThe absolute URL of the Identity resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Numbers.V2.RegulatoryCompliance.Bundle.ItemAssignment{
  account_sid: String.t() | nil,
  bundle_sid: String.t() | nil,
  date_created: String.t() | nil,
  object_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()