Twilio.Resources.Numbers.V2.RegulatoryCompliance.Bundle.ReplaceItems (twilio_elixir v0.1.1)

Copy Markdown View Source

ReplaceItems resource.

SID prefix: BU

Parent: /RegulatoryCompliance/Bundles/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Bundle resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
emailThe email address that will receive updates when the Bundle resource changes status.
friendly_nameThe string that you assigned to describe the resource.
regulation_sidThe unique string of a regulation that is associated to the Bundle resource.
sidThe unique string that we created to identify the Bundle resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe verification status of the Bundle resource.. Values: draft, pending-review, in-review, twilio-rejected, twilio-approved, provisionally-approved
status_callbackThe URL we call to inform your application of status changes.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| valid_until | The date and time in GMT in ISO 8601 format when the resource will be valid until.. Format: date-time |

Summary

Types

t()

@type t() :: %Twilio.Resources.Numbers.V2.RegulatoryCompliance.Bundle.ReplaceItems{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  email: String.t() | nil,
  friendly_name: String.t() | nil,
  regulation_sid: String.t() | nil,
  sid: String.t() | nil,
  status: String.t(),
  status_callback: String.t() | nil,
  valid_until: String.t() | nil
}

Functions

object_name()

sid_prefix()