Twilio.Resources.Numbers.V2.RegulatoryCompliance.SupportingDocument (twilio_elixir v0.1.1)

Copy Markdown View Source

SupportingDocument resource.

SID prefix: RD

Parent: /RegulatoryCompliance

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Document resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| attributes | The set of parameters that are the attributes of the Supporting Documents resource which are listed in the Supporting Document Types.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
errorsA list of errors that occurred during the registering RC Bundle
failure_reasonThe failure reason of the Supporting Document Resource.
friendly_nameThe string that you assigned to describe the resource.
mime_typeThe image type uploaded in the Supporting Document container.
sidThe unique string created by Twilio to identify the Supporting Document resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe verification status of the Supporting Document resource.. Values: draft, pending-review, rejected, approved, expired, provisionally-approved
typeThe type of the Supporting Document.
urlThe absolute URL of the Supporting Document resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Numbers.V2.RegulatoryCompliance.SupportingDocument{
  account_sid: String.t() | nil,
  attributes: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  errors: list() | nil,
  failure_reason: String.t() | nil,
  friendly_name: String.t() | nil,
  mime_type: String.t() | nil,
  sid: String.t() | nil,
  status: String.t(),
  type: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()