Twilio.Resources.Numbers.V2.RegulatoryCompliance.SupportingDocumentType (twilio_elixir v0.1.1)

Copy Markdown View Source

SupportingDocumentType resource.

SID prefix: OY

Parent: /RegulatoryCompliance

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

fieldsThe required information for creating a Supporting Document. The required fields will change as regulatory needs change and will differ for businesses and individuals.
friendly_nameA human-readable description of the Supporting Document Type resource.
machine_nameThe machine-readable description of the Supporting Document Type resource.
sidThe unique string that identifies the Supporting Document Type resource.
urlThe absolute URL of the Supporting Document Type resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Numbers.V2.RegulatoryCompliance.SupportingDocumentType{
  fields: list() | nil,
  friendly_name: String.t() | nil,
  machine_name: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()