Twilio.Resources.Oauth.V1.Token (twilio_elixir v0.1.1)

Copy Markdown View Source

Token resource.

Properties

FieldDescription
access_tokenToken which carries the necessary information to access a Twilio resource directly.
expires_inFormat: int64
id_tokenToken which carries the information necessary of user profile.
refresh_tokenToken which carries the information necessary to get a new access token.
token_typeToken type

Summary

Types

t()

@type t() :: %Twilio.Resources.Oauth.V1.Token{
  access_token: String.t() | nil,
  expires_in: integer() | nil,
  id_token: String.t() | nil,
  refresh_token: String.t() | nil,
  token_type: String.t() | nil
}

Functions

object_name()