Twilio.Resources.Preview.Marketplace.AvailableAddOn.AvailableAddOnExtension (twilio_elixir v0.1.1)

Copy Markdown View Source

AvailableAddOnExtension resource.

SID prefix: XF

Parent: /AvailableAddOns/{Sid}

Properties

FieldDescription
available_add_on_sidThe SID of the AvailableAddOn resource to which this extension applies.
friendly_nameThe string that you assigned to describe the resource.
product_nameThe name of the Product this Extension is used within.
sidThe unique string that we created to identify the AvailableAddOnExtension resource.
unique_nameAn application-defined string that uniquely identifies the resource.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() ::
  %Twilio.Resources.Preview.Marketplace.AvailableAddOn.AvailableAddOnExtension{
    available_add_on_sid: String.t() | nil,
    friendly_name: String.t() | nil,
    product_name: String.t() | nil,
    sid: String.t() | nil,
    unique_name: String.t() | nil,
    url: String.t() | nil
  }

Functions

object_name()

sid_prefix()