Twilio.Resources.Preview.Marketplace.InstalledAddOn (twilio_elixir v0.1.1)

Copy Markdown View Source

InstalledAddOn resource.

SID prefix: XE

Sub-resources

  • extensions/marketplace/InstalledAddOns/{installed_add_on_sid}/Extensions
  • usage/marketplace/InstalledAddOns/{installed_add_on_sid}/Usage

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the InstalledAddOn resource.
configurationThe JSON object that represents the current configuration of installed Add-on.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
descriptionA short description of the Add-on's functionality.
friendly_nameThe string that you assigned to describe the resource.
linksThe URLs of related resources.. Format: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

sidThe unique string that we created to identify the InstalledAddOn resource. This Sid can also be found in the Console on that specific Add-ons page as the 'Available Add-on Sid'.
unique_nameAn application-defined string that uniquely identifies the resource.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Preview.Marketplace.InstalledAddOn{
  account_sid: String.t() | nil,
  configuration: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  description: String.t() | nil,
  friendly_name: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()