Twilio.Resources.Pricing.V1.Messaging.Country (twilio_elixir v0.1.1)

Copy Markdown View Source

Messaging pricing by country

Parent: /Messaging

Properties

FieldDescription
countryThe name of the country.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

inbound_sms_pricesThe list of InboundPrice records that describe the price to receive an inbound SMS to the different Twilio phone number types supported in this country
iso_countryThe ISO country code.. Format: iso-country-code

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| outbound_sms_prices | The list of OutboundSMSPrice records that represent the price to send a message for each MCC/MNC applicable in this country. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

price_unitThe currency in which prices are measured, specified in ISO 4127 format (e.g. usd, eur, jpy).. Format: currency
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Pricing.V1.Messaging.Country{
  country: String.t() | nil,
  inbound_sms_prices: list() | nil,
  iso_country: String.t() | nil,
  outbound_sms_prices: list() | nil,
  price_unit: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()