Twilio.Resources.Pricing.V1.Voice.Country (twilio_elixir v0.1.1)

Copy Markdown View Source

Voice pricing by country

Parent: /Voice

Properties

FieldDescription
countryThe name of the country.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

inbound_call_pricesThe list of InboundCallPrice records.
iso_countryThe ISO country code.. Format: iso-country-code

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| outbound_prefix_prices | The list of OutboundPrefixPrice records, which include a list of the prefixes, the friendly_name, base_price, and the current_price for those prefixes. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

price_unitThe currency in which prices are measured, specified in ISO 4127 format (e.g. usd, eur, jpy).. Format: currency
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Pricing.V1.Voice.Country{
  country: String.t() | nil,
  inbound_call_prices: list() | nil,
  iso_country: String.t() | nil,
  outbound_prefix_prices: list() | nil,
  price_unit: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()