Twilio.Resources.Pricing.V1.Voice.Number (twilio_elixir v0.1.1)

Copy Markdown View Source

Voice pricing for a specific phone number

Parent: /Voice

Properties

FieldDescription
countryThe name of the country.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

inbound_call_priceThe InboundCallPrice record. If null, the Phone Number is not a Twilio number owned by this account.. Format: inbound-call-price
iso_countryThe ISO country code.. Format: iso-country-code
numberThe phone number.. Format: phone-number

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| outbound_call_price | The OutboundCallPrice record, which includes a list of origination_prefixes and the base_price and current_price for those prefixes.. Format: outbound-call-price |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

price_unitThe currency in which prices are measured, specified in ISO 4127 format (e.g. usd, eur, jpy).. Format: currency
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Pricing.V1.Voice.Number{
  country: String.t() | nil,
  inbound_call_price: map() | nil,
  iso_country: String.t() | nil,
  number: String.t() | nil,
  outbound_call_price: map() | nil,
  price_unit: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()