Twilio.Resources.Proxy.V1.Service.PhoneNumber (twilio_elixir v0.1.1)

Copy Markdown View Source

PhoneNumber resource.

SID prefix: PN

Parent: /Services/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the PhoneNumber resource.
capabilitiesThe capabilities of the phone number.. Format: phone-number-capabilities

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The ISO 8601 date and time in GMT when the resource was created.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe ISO 8601 date and time in GMT when the resource was last updated.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| in_use | The number of open session assigned to the number. See the How many Phone Numbers do I need? guide for more information. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

is_reservedWhether the phone number should be reserved and not be assigned to a participant using proxy pool logic. See Reserved Phone Numbers for more information.
iso_countryThe ISO Country Code for the phone number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| phone_number | The phone number in E.164 format, which consists of a + followed by the country code and subscriber number.. Format: phone-number |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the PhoneNumber resource's parent Service resource.
sidThe unique string that we created to identify the PhoneNumber resource.
urlThe absolute URL of the PhoneNumber resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Proxy.V1.Service.PhoneNumber{
  account_sid: String.t() | nil,
  capabilities: map() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  in_use: integer(),
  is_reserved: boolean() | nil,
  iso_country: String.t() | nil,
  phone_number: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()