Twilio.Resources.Routes.V2.PhoneNumber (twilio_elixir v0.1.1)

Copy Markdown View Source

PhoneNumber resource.

SID prefix: QQ

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date that this phone number was assigned an Inbound Processing Region, given in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date that the Inbound Processing Region was updated for this phone number, given in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

friendly_nameA human readable description of the Inbound Processing Region assignments for this phone number, up to 64 characters.
phone_numberThe phone number in E.164 format

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

sidA 34 character string that uniquely identifies the Inbound Processing Region assignments for this phone number.
urlThe absolute URL of the resource.. Format: uri
voice_regionThe Inbound Processing Region used for this phone number for voice.

Summary

Types

t()

@type t() :: %Twilio.Resources.Routes.V2.PhoneNumber{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  phone_number: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil,
  voice_region: String.t() | nil
}

Functions

object_name()

sid_prefix()