Twilio.Resources.Serverless.V1.Service (twilio_elixir v0.1.1)

Copy Markdown View Source

The top-level resource for a Serverless application, which serves as a container for the application environments.

SID prefix: ZS

Sub-resources

  • assets/v1/Services/{service_sid}/Assets
  • builds/v1/Services/{service_sid}/Builds
  • environments/v1/Services/{service_sid}/Environments
  • functions/v1/Services/{service_sid}/Functions

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Service resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Service resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the Service resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

domain_baseThe base domain name for this Service, which is a combination of the unique name and a randomly generated string.
friendly_nameThe string that you assigned to describe the Service resource.. PII: standard
include_credentialsWhether to inject Account credentials into a function invocation context.
linksThe URLs of the Service's nested resources.. Format: uri-map
sidThe unique string that we created to identify the Service resource.
ui_editableWhether the Service resource's properties and subresources can be edited via the UI.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unique_nameA user-defined string that uniquely identifies the Service resource. It can be used in place of the Service resource's sid in the URL to address the Service resource.. PII: standard
urlThe absolute URL of the Service resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Serverless.V1.Service{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  domain_base: String.t() | nil,
  friendly_name: String.t() | nil,
  include_credentials: boolean() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  ui_editable: boolean() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()