Twilio.Resources.Serverless.V1.Service.Asset.Version (twilio_elixir v0.1.1)

Copy Markdown View Source

The content of an Asset.

SID prefix: ZN

Parent: /Services/{ServiceSid}/Assets/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Asset Version resource.
asset_sidThe SID of the Asset resource that is the parent of the Asset Version.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Asset Version resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

pathThe URL-friendly string by which the Asset Version can be referenced. It can be a maximum of 255 characters. All paths begin with a forward slash ('/'). If an Asset Version creation request is submitted with a path not containing a leading slash, the path will automatically be prepended with one.. PII: standard
service_sidThe SID of the Service that the Asset Version resource is associated with.
sidThe unique string that we created to identify the Asset Version resource.
urlThe absolute URL of the Asset Version resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| visibility | The access control that determines how the Asset Version resource can be accessed. Can be: public, protected, or private.. Values: public, private, protected |

Summary

Types

t()

@type t() :: %Twilio.Resources.Serverless.V1.Service.Asset.Version{
  account_sid: String.t() | nil,
  asset_sid: String.t() | nil,
  date_created: String.t() | nil,
  path: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil,
  visibility: String.t()
}

Functions

object_name()

sid_prefix()