Twilio.Resources.Serverless.V1.Service.Build (twilio_elixir v0.1.1)

Copy Markdown View Source

A collection of Function Versions, Asset Versions, Dependencies, and a Runtime that form a deployable unit.

SID prefix: ZB

Parent: /Services/{Sid}

Sub-resources

  • build_status/v1/Services/{service_sid}/Builds/{sid}/Status

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Build resource.
asset_versionsThe list of Asset Version resource SIDs that are included in the Build.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Build resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the Build resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

dependenciesA list of objects that describe the Dependencies included in the Build. Each object contains the name and version of the dependency.
function_versionsThe list of Function Version resource SIDs that are included in the Build.
linksFormat: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

runtimeThe Runtime version that will be used to run the Build resource when it is deployed.. Values: node8, node10, node12, node14, node16, node18, node20, node22
service_sidThe SID of the Service that the Build resource is associated with.
sidThe unique string that we created to identify the Build resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe status of the Build. Can be: building, completed, or failed.. Values: building, completed, failed
urlThe absolute URL of the Build resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Serverless.V1.Service.Build{
  account_sid: String.t() | nil,
  asset_versions: list() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  dependencies: list() | nil,
  function_versions: list() | nil,
  links: map() | nil,
  runtime: String.t(),
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()