Twilio.Resources.Serverless.V1.Service.Build.Status (twilio_elixir v0.1.1)

Copy Markdown View Source

The status of a Build resource.

SID prefix: ZB

Parent: /Services/{ServiceSid}/Builds/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Build resource.
service_sidThe SID of the Service that the Build resource is associated with.
sidThe unique string that we created to identify the Build resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe status of the Build. Can be: building, completed, or failed.. Values: building, completed, failed
urlThe absolute URL of the Build Status resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Serverless.V1.Service.Build.Status{
  account_sid: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()