Twilio.Resources.Serverless.V1.Service.Environment.Log (twilio_elixir v0.1.1)

Copy Markdown View Source

A record of an event that occurred related to a function invocation.

SID prefix: NO

Parent: /Services/{ServiceSid}/Environments/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Log resource.
build_sidThe SID of the build that corresponds to the log.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_createdThe date and time in GMT when the Log resource was created specified in ISO 8601 format.. Format: date-time
deployment_sidThe SID of the deployment that corresponds to the log.
environment_sidThe SID of the environment in which the log occurred.
function_sidThe SID of the function whose invocation produced the log.
levelThe log level.
messageThe log message.
request_sidThe SID of the request associated with the log.
service_sidThe SID of the Service that the Log resource is associated with.
sidThe unique string that we created to identify the Log resource.
urlThe absolute URL of the Log resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Serverless.V1.Service.Environment.Log{
  account_sid: String.t() | nil,
  build_sid: String.t() | nil,
  date_created: String.t() | nil,
  deployment_sid: String.t() | nil,
  environment_sid: String.t() | nil,
  function_sid: String.t() | nil,
  level: String.t() | nil,
  message: String.t() | nil,
  request_sid: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()