Twilio.Resources.Serverless.V1.Service.Environment.Variable (twilio_elixir v0.1.1)

Copy Markdown View Source

A key and value pair that is specific to an Environment.

SID prefix: ZV

Parent: /Services/{ServiceSid}/Environments/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Variable resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Variable resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the Variable resource was last updated specified in ISO 8601 format.. Format: date-time
environment_sidThe SID of the Environment in which the Variable exists.
keyA string by which the Variable resource can be referenced.. PII: standard
service_sidThe SID of the Service that the Variable resource is associated with.
sidThe unique string that we created to identify the Variable resource.
urlThe absolute URL of the Variable resource.. Format: uri
valueA string that contains the actual value of the Variable.. PII: standard

Summary

Types

t()

@type t() :: %Twilio.Resources.Serverless.V1.Service.Environment.Variable{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  environment_sid: String.t() | nil,
  key: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil,
  value: String.t() | nil
}

Functions

object_name()

sid_prefix()