Twilio.Resources.Serverless.V1.Service.Function.Version.Content (twilio_elixir v0.1.1)

Copy Markdown View Source

The code of a Function Version.

SID prefix: ZN

Parent: /Services/{ServiceSid}/Functions/{FunctionSid}/Versions/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Function Version resource.
contentThe content of the Function Version resource.
function_sidThe SID of the Function that is the parent of the Function Version.
service_sidThe SID of the Service that the Function Version resource is associated with.
sidThe unique string that we created to identify the Function Version resource.
urlFormat: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Serverless.V1.Service.Function.Version.Content{
  account_sid: String.t() | nil,
  content: String.t() | nil,
  function_sid: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()