Twilio.Resources.Studio.V1.Flow (twilio_elixir v0.1.1)

Copy Markdown View Source

Studio flows

SID prefix: FW

Sub-resources

  • engagements/v1/Flows/{flow_sid}/Engagements
  • executions/v1/Flows/{flow_sid}/Executions

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Flow resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
friendly_nameThe string that you assigned to describe the Flow.
linksThe URLs of the Flow's nested resources.. Format: uri-map
sidThe unique string that we created to identify the Flow resource.
statusThe status of the Flow. Can be: draft or published.. Values: draft, published
urlThe absolute URL of the resource.. Format: uri
versionThe latest version number of the Flow's definition.

Summary

Types

t()

@type t() :: %Twilio.Resources.Studio.V1.Flow{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil,
  version: integer()
}

Functions

object_name()

sid_prefix()