Twilio.Resources.Studio.V1.Flow.Engagement (twilio_elixir v0.1.1)

Copy Markdown View Source

[DEPRECATED] Excecutions of Studio flows

SID prefix: FN

Parent: /Flows/{Sid}

Sub-resources

  • engagement_context/v1/Flows/{flow_sid}/Engagements/{engagement_sid}/Context
  • steps/v1/Flows/{flow_sid}/Engagements/{engagement_sid}/Steps

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Engagement resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

contact_channel_addressThe phone number, SIP address or Client identifier that triggered this Engagement. Phone numbers are in E.164 format (+16175551212). SIP addresses are formatted as name@company.com. Client identifiers are formatted client:name.
contact_sidThe SID of the Contact.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| context | The current state of the execution flow. As your flow executes, we save the state in a flow context. Your widgets can access the data in the flow context as variables, either in configuration fields or in text areas as variable substitution. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the Engagement was created in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the Engagement was updated in ISO 8601 format.. Format: date-time
flow_sidThe SID of the Flow.
linksThe URLs of the Engagement's nested resources.. Format: uri-map
sidThe unique string that we created to identify the Engagement resource.
statusThe status of the Engagement. Can be: active or ended.. Values: active, ended
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Studio.V1.Flow.Engagement{
  account_sid: String.t() | nil,
  contact_channel_address: String.t() | nil,
  contact_sid: String.t() | nil,
  context: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  flow_sid: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()