Twilio.Resources.Studio.V1.Flow.Engagement.Context (twilio_elixir v0.1.1)

Copy Markdown View Source

[DEPRECATED] JSON context for engagements

Parent: /Flows/{FlowSid}/Engagements/{Sid}

Properties

FieldDescription
account_sidThe SID of the Account.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

contextAs your flow executes, we save the state in what's called the Flow Context. Any data in the flow context can be accessed by your widgets as variables, either in configuration fields or in text areas as variable substitution.
engagement_sidThe SID of the Engagement.
flow_sidThe SID of the Flow.
urlThe URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Studio.V1.Flow.Engagement.Context{
  account_sid: String.t() | nil,
  context: String.t() | nil,
  engagement_sid: String.t() | nil,
  flow_sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()