Twilio.Resources.Studio.V1.Flow.Engagement.Step.Context
(twilio_elixir v0.1.1)
JSON context for individual steps
Parent: /Flows/{FlowSid}/Engagements/{EngagementSid}/Steps/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the StepContext resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
context | The current state of the Flow's Execution. As a flow executes, we save its state in this context. We save data that your widgets can access as variables in configuration fields or in text areas as variable substitution.. PII: standard |
engagement_sid | The SID of the Engagement. |
flow_sid | The SID of the Flow. |
step_sid | The SID of the Step the context is associated with. |
url | The absolute URL of the resource.. Format: uri |