Twilio.Resources.Studio.V1.Flow.Execution (twilio_elixir v0.1.1)

Copy Markdown View Source

Executions of Studio flows

SID prefix: FN

Parent: /Flows/{Sid}

Sub-resources

  • execution_context/v1/Flows/{flow_sid}/Executions/{execution_sid}/Context
  • steps/v1/Flows/{flow_sid}/Executions/{execution_sid}/Steps

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Execution resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

contact_channel_addressThe phone number, SIP address or Client identifier that triggered the Execution. Phone numbers are in E.164 format (e.g. +16175551212). SIP addresses are formatted as name@company.com. Client identifiers are formatted client:name.. PII: standard
contact_sidThe SID of the Contact.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| context | The current state of the Flow's Execution. As a flow executes, we save its state in this context. We save data that your widgets can access as variables in configuration fields or in text areas as variable substitution.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
flow_sidThe SID of the Flow.
linksThe URLs of nested resources.. Format: uri-map
sidThe unique string that we created to identify the Execution resource.
statusThe status of the Execution. Can be: active or ended.. Values: active, ended
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Studio.V1.Flow.Execution{
  account_sid: String.t() | nil,
  contact_channel_address: String.t() | nil,
  contact_sid: String.t() | nil,
  context: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  flow_sid: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()