Twilio.Resources.Studio.V1.Flow.Execution.ExecutionStep (twilio_elixir v0.1.1)

Copy Markdown View Source

Individual steps within an execution

SID prefix: FT

Parent: /Flows/{FlowSid}/Executions/{Sid}

Sub-resources

  • step_context/v1/Flows/{flow_sid}/Executions/{execution_sid}/Steps/{step_sid}/Context

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the ExecutionStep resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| context | The current state of the Flow's Execution. As a flow executes, we save its state in this context. We save data that your widgets can access as variables in configuration fields or in text areas as variable substitution.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
execution_sidThe SID of the Step's Execution resource.
flow_sidThe SID of the Flow.
linksThe URLs of related resources.. Format: uri-map
nameThe event that caused the Flow to transition to the Step.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

parent_step_sidThis field shows the Step SID of the Widget in the parent Flow that started the Subflow. If this Step is not part of a Subflow execution, the value is null.
sidThe unique string that we created to identify the ExecutionStep resource.
transitioned_fromThe Widget that preceded the Widget for the Step.
transitioned_toThe Widget that will follow the Widget for the Step.
typeThe type of the widget that was executed.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Studio.V1.Flow.Execution.ExecutionStep{
  account_sid: String.t() | nil,
  context: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  execution_sid: String.t() | nil,
  flow_sid: String.t() | nil,
  links: map() | nil,
  name: String.t() | nil,
  parent_step_sid: String.t() | nil,
  sid: String.t() | nil,
  transitioned_from: String.t() | nil,
  transitioned_to: String.t() | nil,
  type: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()