Twilio.Resources.Studio.V1.Flow.Execution.Step.ExecutionStepContext
(twilio_elixir v0.1.1)
JSON context for an individual step within an execution
Parent: /Flows/{FlowSid}/Executions/{ExecutionSid}/Steps/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the ExecutionStepContext resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
context | The current state of the Flow's Execution. As a flow executes, we save its state in this context. We save data that your widgets can access as variables in configuration fields or in text areas as variable substitution.. PII: standard |
execution_sid | The SID of the context's Execution resource. |
flow_sid | The SID of the Flow. |
step_sid | The SID of the Step that the context is associated with. |
url | The absolute URL of the resource.. Format: uri |