Twilio.Resources.Studio.V2.Flow.Execution.Context (twilio_elixir v0.1.1)

Copy Markdown View Source

JSON context for executions

Parent: /Flows/{FlowSid}/Executions/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the ExecutionContext resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

contextThe current state of the Flow's Execution. As a flow executes, we save its state in this context. We save data that your widgets can access as variables in configuration fields or in text areas as variable substitution.. PII: standard
execution_sidThe SID of the context's Execution resource.
flow_sidThe SID of the Flow.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Studio.V2.Flow.Execution.Context{
  account_sid: String.t() | nil,
  context: String.t() | nil,
  execution_sid: String.t() | nil,
  flow_sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()