Twilio.Resources.Studio.V2.Flow.FlowRevision (twilio_elixir v0.1.1)

Copy Markdown View Source

Studio flows revisions

SID prefix: FW

Parent: /Flows/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Flow resource.
commit_messageDescription of change made in the revision.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
definitionJSON representation of flow definition.
errorsList of error in the flow definition.
friendly_nameThe string that you assigned to describe the Flow.
revisionThe latest revision number of the Flow's definition.
sidThe unique string that we created to identify the Flow resource.
statusThe status of the Flow. Can be: draft or published.. Values: draft, published
urlThe absolute URL of the resource.. Format: uri
validBoolean if the flow definition is valid.

Summary

Types

t()

@type t() :: %Twilio.Resources.Studio.V2.Flow.FlowRevision{
  account_sid: String.t() | nil,
  commit_message: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  definition: String.t() | nil,
  errors: list() | nil,
  friendly_name: String.t() | nil,
  revision: integer(),
  sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil,
  valid: boolean() | nil
}

Functions

object_name()

sid_prefix()