Twilio.Resources.Supersim.V1.ESimProfile (twilio_elixir v0.1.1)

Copy Markdown View Source

eSIM Profiles that can be loaded onto consumer eUICC SIMs

SID prefix: HP

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account to which the eSIM Profile resource belongs. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| activation_code | Combined machine-readable activation code for acquiring an eSIM Profile with the Activation Code download method. Can be used in a QR code to download an eSIM profile. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
eidIdentifier of the eUICC that can claim the eSIM Profile.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| error_code | Code indicating the failure if the download of the SIM Profile failed and the eSIM Profile is in failed state. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| error_message | Error message describing the failure if the download of the SIM Profile failed and the eSIM Profile is in failed state. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| iccid | The ICCID associated with the Sim resource.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

matching_idUnique identifier of the eSIM profile that can be used to identify and download the eSIM profile from the SM-DP+ server. Populated if generate_matching_id is set to true when creating the eSIM profile reservation.
sidThe unique string that we created to identify the eSIM Profile resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sim_sid | The SID of the Sim resource that this eSIM Profile controls. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| smdp_plus_address | Address of the SM-DP+ server from which the Profile will be downloaded. The URL will appear once the eSIM Profile reaches the status available.. Format: uri |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe status of the eSIM Profile. Can be: new, reserving, available, downloaded, installed or failed. See the eSIM Profile Status Values for a description of each.. Values: new, reserving, available, downloaded, installed, failed
urlThe absolute URL of the eSIM Profile resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Supersim.V1.ESimProfile{
  account_sid: String.t() | nil,
  activation_code: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  eid: String.t() | nil,
  error_code: String.t() | nil,
  error_message: String.t() | nil,
  iccid: String.t() | nil,
  matching_id: String.t() | nil,
  sid: String.t() | nil,
  sim_sid: String.t() | nil,
  smdp_plus_address: String.t() | nil,
  status: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()