Twilio.Resources.Supersim.V1.NetworkAccessProfile (twilio_elixir v0.1.1)

Copy Markdown View Source

NetworkAccessProfile resource.

SID prefix: HA

Sub-resources

  • networks/v1/NetworkAccessProfiles/{network_access_profile_sid}/Networks

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that the Network Access Profile belongs to. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
linksFormat: uri-map
sidThe unique string that identifies the Network Access Profile resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unique_nameAn application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource.
urlThe absolute URL of the Network Access Profile resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Supersim.V1.NetworkAccessProfile{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()