Twilio.Resources.Supersim.V1.NetworkAccessProfile.NetworkAccessProfileNetwork (twilio_elixir v0.1.1)

Copy Markdown View Source

Mobile operator networks which Network Access Profiles allow access to

SID prefix: HW

Parent: /NetworkAccessProfiles/{Sid}

Properties

FieldDescription
friendly_nameA human readable identifier of the Network this resource refers to.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

identifiersArray of objects identifying the MCC-MNCs that are included in the Network resource.
iso_countryThe ISO country code of the Network resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

network_access_profile_sidThe unique string that identifies the Network resource's Network Access Profile resource.
sidThe unique string that identifies the Network resource.
urlThe absolute URL of the Network resource.. Format: uri

Summary

Types

t()

@type t() ::
  %Twilio.Resources.Supersim.V1.NetworkAccessProfile.NetworkAccessProfileNetwork{
    friendly_name: String.t() | nil,
    identifiers: list() | nil,
    iso_country: String.t() | nil,
    network_access_profile_sid: String.t() | nil,
    sid: String.t() | nil,
    url: String.t() | nil
  }

Functions

object_name()

sid_prefix()