Twilio.Resources.Supersim.V1.SettingsUpdate (twilio_elixir v0.1.1)

Copy Markdown View Source

SettingsUpdate resource.

SID prefix: OB

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_completed | The time, given in ISO 8601 format, when the update successfully completed and the new settings were applied to the SIM.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date that this Settings Update was created, given in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date that this Settings Update was updated, given in ISO 8601 format.. Format: date-time
iccidThe ICCID associated with the SIM.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

packagesArray containing the different Settings Packages that will be applied to the SIM after the update completes. Each object within the array indicates the name and the version of the Settings Package that will be on the SIM if the update is successful.
sidThe unique identifier of this Settings Update.
sim_sidThe SID of the Super SIM to which this Settings Update was applied.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| status | The Status of this Settings Update. One of scheduled, in-progress, successful or failed.. Values: scheduled, in-progress, successful, failed |

Summary

Types

t()

@type t() :: %Twilio.Resources.Supersim.V1.SettingsUpdate{
  date_completed: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  iccid: String.t() | nil,
  packages: list() | nil,
  sid: String.t() | nil,
  sim_sid: String.t() | nil,
  status: String.t()
}

Functions

object_name()

sid_prefix()