Twilio.Resources.Supersim.V1.Sim.BillingPeriod (twilio_elixir v0.1.1)

Copy Markdown View Source

Billing Period for an IoT Super SIM

SID prefix: HB

Parent: /Sims/{Sid}

Properties

FieldDescription
account_sidThe SID of the Account the Super SIM belongs to.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

end_timeThe end time of the Billing Period specified in ISO 8601 format.. Format: date-time
period_typeThe type of Billing Period. Can be ready or active.. Values: ready, active
sidThe SID of the Billing Period.
sim_sidThe SID of the Super SIM the Billing Period belongs to.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| start_time | The start time of the Billing Period specified in ISO 8601 format.. Format: date-time |

Summary

Types

t()

@type t() :: %Twilio.Resources.Supersim.V1.Sim.BillingPeriod{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  end_time: String.t() | nil,
  period_type: String.t(),
  sid: String.t() | nil,
  sim_sid: String.t() | nil,
  start_time: String.t() | nil
}

Functions

object_name()

sid_prefix()