Twilio.Resources.Supersim.V1.SmsCommand (twilio_elixir v0.1.1)

Copy Markdown View Source

Machine-to-machine SMS Commands sent to/from SIMs

SID prefix: HC

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the SMS Command resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| direction | The direction of the SMS Command. Can be to_sim or from_sim. The value of to_sim is synonymous with the term mobile terminated, and from_sim is synonymous with the term mobile originated.. Values: to_sim, from_sim |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

payloadThe message body of the SMS Command sent to or from the SIM. For text mode messages, this can be up to 160 characters.. PII: standard
sidThe unique string that we created to identify the SMS Command resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sim_sid | The SID of the SIM that this SMS Command was sent to or from. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe status of the SMS Command. Can be: queued, sent, delivered, received or failed. See the SMS Command Status Values for a description of each.. Values: queued, sent, delivered, received, failed
urlThe absolute URL of the SMS Command resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Supersim.V1.SmsCommand{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  direction: String.t(),
  payload: String.t() | nil,
  sid: String.t() | nil,
  sim_sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()