Twilio.Resources.Sync.V1.Service.Document.Permission (twilio_elixir v0.1.1)

Copy Markdown View Source

Sync document permissions

Parent: /Services/{ServiceSid}/Documents/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Document Permission resource.
document_sidThe SID of the Sync Document to which the Document Permission applies.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

identityThe application-defined string that uniquely identifies the resource's User within the Service to an FPA token.. PII: standard
manageWhether the identity can delete the Sync Document.
readWhether the identity can read the Sync Document.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Sync Service the resource is associated with.
urlThe absolute URL of the Sync Document Permission resource.. Format: uri
writeWhether the identity can update the Sync Document.

Summary

Types

t()

@type t() :: %Twilio.Resources.Sync.V1.Service.Document.Permission{
  account_sid: String.t() | nil,
  document_sid: String.t() | nil,
  identity: String.t() | nil,
  manage: boolean() | nil,
  read: boolean() | nil,
  service_sid: String.t() | nil,
  url: String.t() | nil,
  write: boolean() | nil
}

Functions

object_name()