Twilio.Resources.Sync.V1.Service.List.Permission (twilio_elixir v0.1.1)

Copy Markdown View Source

Permissions for Sync list items

Parent: /Services/{ServiceSid}/Lists/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Sync List Permission resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

identityThe application-defined string that uniquely identifies the resource's User within the Service to an FPA token.. PII: standard
list_sidThe SID of the Sync List to which the Permission applies.
manageWhether the identity can delete the Sync List.
readWhether the identity can read the Sync List and its Items.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Sync Service the resource is associated with.
urlThe absolute URL of the Sync List Permission resource.. Format: uri
writeWhether the identity can create, update, and delete Items in the Sync List.

Summary

Types

t()

@type t() :: %Twilio.Resources.Sync.V1.Service.List.Permission{
  account_sid: String.t() | nil,
  identity: String.t() | nil,
  list_sid: String.t() | nil,
  manage: boolean() | nil,
  read: boolean() | nil,
  service_sid: String.t() | nil,
  url: String.t() | nil,
  write: boolean() | nil
}

Functions

object_name()