Twilio.Resources.Sync.V1.Service.Map (twilio_elixir v0.1.1)

Copy Markdown View Source

Sync map objects

SID prefix: MP

Parent: /Services/{Sid}

Sub-resources

  • items/v1/Services/{service_sid}/Maps/{map_sid}/Items
  • permissions/v1/Services/{service_sid}/Maps/{map_sid}/Permissions

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Sync Map resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| created_by | The identity of the Sync Map's creator. If the Sync Map is created from the client SDK, the value matches the Access Token's identity field. If the Sync Map was created from the REST API, the value is system.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_expires | The date and time in GMT when the Sync Map expires and will be deleted, specified in ISO 8601 format. If the Sync Map does not expire, this value is null. The Sync Map might not be deleted immediately after it expires.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
linksThe URLs of the Sync Map's nested resources.. Format: uri-map
revisionThe current revision of the Sync Map, represented as a string.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Sync Service the resource is associated with.
sidThe unique string that we created to identify the Sync Map resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unique_nameAn application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource.. PII: standard
urlThe absolute URL of the Sync Map resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Sync.V1.Service.Map{
  account_sid: String.t() | nil,
  created_by: String.t() | nil,
  date_created: String.t() | nil,
  date_expires: String.t() | nil,
  date_updated: String.t() | nil,
  links: map() | nil,
  revision: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()