Twilio.Resources.Sync.V1.Service.Map.Permission (twilio_elixir v0.1.1)

Copy Markdown View Source

Permission resource.

Parent: /Services/{ServiceSid}/Maps/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Sync Map Permission resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

identityThe application-defined string that uniquely identifies the resource's User within the Service to an FPA token.. PII: standard
manageWhether the identity can delete the Sync Map.
map_sidThe SID of the Sync Map to which the Permission applies.
readWhether the identity can read the Sync Map and its Items.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Sync Service the resource is associated with.
urlThe absolute URL of the Sync Map Permission resource.. Format: uri
writeWhether the identity can create, update, and delete Items in the Sync Map.

Summary

Types

t()

@type t() :: %Twilio.Resources.Sync.V1.Service.Map.Permission{
  account_sid: String.t() | nil,
  identity: String.t() | nil,
  manage: boolean() | nil,
  map_sid: String.t() | nil,
  read: boolean() | nil,
  service_sid: String.t() | nil,
  url: String.t() | nil,
  write: boolean() | nil
}

Functions

object_name()