Twilio.Resources.Sync.V1.Service.Stream (twilio_elixir v0.1.1)

Copy Markdown View Source

Stream resource.

SID prefix: TO

Parent: /Services/{Sid}

Sub-resources

  • messages/v1/Services/{service_sid}/Streams/{stream_sid}/Messages

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Sync Stream resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| created_by | The identity of the Stream's creator. If the Stream is created from the client SDK, the value matches the Access Token's identity field. If the Stream was created from the REST API, the value is 'system'.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_expires | The date and time in GMT when the Message Stream expires and will be deleted, specified in ISO 8601 format. If the Message Stream does not expire, this value is null. The Stream might not be deleted immediately after it expires.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
linksThe URLs of the Stream's nested resources.. Format: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Sync Service the resource is associated with.
sidThe unique string that we created to identify the Sync Stream resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unique_nameAn application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource.. PII: standard
urlThe absolute URL of the Message Stream resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Sync.V1.Service.Stream{
  account_sid: String.t() | nil,
  created_by: String.t() | nil,
  date_created: String.t() | nil,
  date_expires: String.t() | nil,
  date_updated: String.t() | nil,
  links: map() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()