Twilio.Resources.Taskrouter.V1.Workspace.Task.Reservation (twilio_elixir v0.1.1)

Copy Markdown View Source

Tasks reserved for workers

SID prefix: WR

Parent: /Workspaces/{WorkspaceSid}/Tasks/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the TaskReservation resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
linksThe URLs of related resources.. Format: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

reservation_statusThe current status of the reservation. Can be: pending, accepted, rejected, or timeout.. Values: pending, accepted, rejected, timeout, canceled, rescinded, wrapping, completed
sidThe unique string that we created to identify the TaskReservation resource.
task_sidThe SID of the reserved Task resource.
urlThe absolute URL of the TaskReservation reservation.. Format: uri
worker_nameThe friendly_name of the Worker that is reserved.
worker_sidThe SID of the reserved Worker resource.
workspace_sidThe SID of the Workspace that this task is contained within.

Summary

Types

t()

@type t() :: %Twilio.Resources.Taskrouter.V1.Workspace.Task.Reservation{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  links: map() | nil,
  reservation_status: String.t(),
  sid: String.t() | nil,
  task_sid: String.t() | nil,
  url: String.t() | nil,
  worker_name: String.t() | nil,
  worker_sid: String.t() | nil,
  workspace_sid: String.t() | nil
}

Functions

object_name()

sid_prefix()