Twilio.Resources.Taskrouter.V1.Workspace.TaskChannel (twilio_elixir v0.1.1)

Copy Markdown View Source

Types of tasks

SID prefix: TC

Parent: /Workspaces/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Task Channel resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| channel_optimized_routing | Whether the Task Channel will prioritize Workers that have been idle. When true, Workers that have been idle the longest are prioritized. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.
linksThe URLs of related resources.. Format: uri-map
sidThe unique string that we created to identify the Task Channel resource.
unique_nameAn application-defined string that uniquely identifies the Task Channel, such as voice or sms.
urlThe absolute URL of the Task Channel resource.. Format: uri
workspace_sidThe SID of the Workspace that contains the Task Channel.

Summary

Types

t()

@type t() :: %Twilio.Resources.Taskrouter.V1.Workspace.TaskChannel{
  account_sid: String.t() | nil,
  channel_optimized_routing: boolean() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil,
  workspace_sid: String.t() | nil
}

Functions

object_name()

sid_prefix()