Twilio.Resources.Taskrouter.V1.Workspace.TaskQueue.TaskQueueCumulativeStatistics (twilio_elixir v0.1.1)

Copy Markdown View Source

TaskQueueCumulativeStatistics resource.

Parent: /Workspaces/{WorkspaceSid}/TaskQueues/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the TaskQueue resource.
avg_task_acceptance_timeThe average time in seconds between Task creation and acceptance.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

end_timeThe end of the interval during which these statistics were calculated, in ISO 8601 format.. Format: date-time
reservations_acceptedThe total number of Reservations accepted for Tasks in the TaskQueue.
reservations_canceledThe total number of Reservations canceled for Tasks in the TaskQueue.
reservations_createdThe total number of Reservations created for Tasks in the TaskQueue.
reservations_rejectedThe total number of Reservations rejected for Tasks in the TaskQueue.
reservations_rescindedThe total number of Reservations rescinded.
reservations_timed_outThe total number of Reservations that timed out for Tasks in the TaskQueue.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| split_by_wait_time | A list of objects that describe the number of Tasks canceled and reservations accepted above and below the thresholds specified in seconds. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

start_timeThe beginning of the interval during which these statistics were calculated, in ISO 8601 format.. Format: date-time
task_queue_sidThe SID of the TaskQueue from which these statistics were calculated.
tasks_canceledThe total number of Tasks canceled in the TaskQueue.
tasks_completedThe total number of Tasks completed in the TaskQueue.
tasks_deletedThe total number of Tasks deleted in the TaskQueue.
tasks_enteredThe total number of Tasks entered into the TaskQueue.
tasks_movedThe total number of Tasks that were moved from one queue to another.
urlThe absolute URL of the TaskQueue statistics resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| wait_duration_in_queue_until_accepted | The relative wait duration statistics (avg, min, max, total) for Tasks accepted while in the TaskQueue. Calculation is based on the time when the Tasks entered the TaskQueue. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| wait_duration_until_accepted | The wait duration statistics (avg, min, max, total) for Tasks accepted while in the TaskQueue. Calculation is based on the time when the Tasks were created. For transfers, the wait duration is counted from the moment the Task was created, and not from when the transfer was initiated. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

wait_duration_until_canceledThe wait duration statistics (avg, min, max, total) for Tasks canceled while in the TaskQueue.
workspace_sidThe SID of the Workspace that contains the TaskQueue.

Summary

Types

t()

@type t() ::
  %Twilio.Resources.Taskrouter.V1.Workspace.TaskQueue.TaskQueueCumulativeStatistics{
    account_sid: String.t() | nil,
    avg_task_acceptance_time: integer(),
    end_time: String.t() | nil,
    reservations_accepted: integer(),
    reservations_canceled: integer(),
    reservations_created: integer(),
    reservations_rejected: integer(),
    reservations_rescinded: integer(),
    reservations_timed_out: integer(),
    split_by_wait_time: String.t() | nil,
    start_time: String.t() | nil,
    task_queue_sid: String.t() | nil,
    tasks_canceled: integer(),
    tasks_completed: integer(),
    tasks_deleted: integer(),
    tasks_entered: integer(),
    tasks_moved: integer(),
    url: String.t() | nil,
    wait_duration_in_queue_until_accepted: String.t() | nil,
    wait_duration_until_accepted: String.t() | nil,
    wait_duration_until_canceled: String.t() | nil,
    workspace_sid: String.t() | nil
  }

Functions

object_name()