Twilio.Resources.Taskrouter.V1.Workspace.Worker (twilio_elixir v0.1.1)

Copy Markdown View Source

Worker resource.

SID prefix: WK

Parent: /Workspaces/{Sid}

Sub-resources

  • cumulative_statistics/v1/Workspaces/{workspace_sid}/Workers/CumulativeStatistics
  • real_time_statistics/v1/Workspaces/{workspace_sid}/Workers/RealTimeStatistics
  • reservations/v1/Workspaces/{workspace_sid}/Workers/{worker_sid}/Reservations
  • statistics/v1/Workspaces/{workspace_sid}/Workers/{worker_sid}/Statistics
  • worker_channels/v1/Workspaces/{workspace_sid}/Workers/{worker_sid}/Channels

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Worker resource.
activity_nameThe friendly_name of the Worker's current Activity.
activity_sidThe SID of the Worker's current Activity.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

attributesThe JSON string that describes the Worker. For example: { "email": "Bob@example.com", "phone": "+5095551234" }. Note If this property has been assigned a value, it will only be displayed in FETCH actions that return a single resource. Otherwise, this property will be null, even if it has a value. This data is passed to the assignment_callback_url when TaskRouter assigns a Task to the Worker.. PII: sensitive
availableWhether the Worker is available to perform tasks.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_status_changed | The date and time in GMT of the last change to the Worker's activity specified in ISO 8601 format. Used to calculate Workflow statistics.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

friendly_nameThe string that you assigned to describe the resource. Friendly names are case insensitive, and unique within the TaskRouter Workspace.. PII: standard
linksThe URLs of related resources.. Format: uri-map
sidThe unique string that we created to identify the Worker resource.
urlThe absolute URL of the Worker resource.. Format: uri
workspace_sidThe SID of the Workspace that contains the Worker.

Summary

Types

t()

@type t() :: %Twilio.Resources.Taskrouter.V1.Workspace.Worker{
  account_sid: String.t() | nil,
  activity_name: String.t() | nil,
  activity_sid: String.t() | nil,
  attributes: String.t() | nil,
  available: boolean() | nil,
  date_created: String.t() | nil,
  date_status_changed: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  url: String.t() | nil,
  workspace_sid: String.t() | nil
}

Functions

object_name()

sid_prefix()