Twilio.Resources.Taskrouter.V1.Workspace.Worker.Channel (twilio_elixir v0.1.1)

Copy Markdown View Source

Channel resource.

SID prefix: WC

Parent: /Workspaces/{WorkspaceSid}/Workers/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Worker resource.
assigned_tasksThe total number of Tasks assigned to Worker for the TaskChannel type.
availableWhether the Worker should receive Tasks of the TaskChannel type.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| available_capacity_percentage | The current percentage of capacity the TaskChannel has available. Can be a number between 0 and 100. A value of 0 indicates that TaskChannel has no capacity available and a value of 100 means the Worker is available to receive any Tasks of this TaskChannel type. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| configured_capacity | The current configured capacity for the WorkerChannel. TaskRouter will not create any reservations after the assigned Tasks for the Worker reaches the value. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time
sidThe unique string that we created to identify the WorkerChannel resource.
task_channel_sidThe SID of the TaskChannel.
task_channel_unique_nameThe unique name of the TaskChannel, such as voice or sms.
urlThe absolute URL of the WorkerChannel resource.. Format: uri
worker_sidThe SID of the Worker that contains the WorkerChannel.
workspace_sidThe SID of the Workspace that contains the WorkerChannel.

Summary

Types

t()

@type t() :: %Twilio.Resources.Taskrouter.V1.Workspace.Worker.Channel{
  account_sid: String.t() | nil,
  assigned_tasks: integer(),
  available: boolean() | nil,
  available_capacity_percentage: integer(),
  configured_capacity: integer(),
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  sid: String.t() | nil,
  task_channel_sid: String.t() | nil,
  task_channel_unique_name: String.t() | nil,
  url: String.t() | nil,
  worker_sid: String.t() | nil,
  workspace_sid: String.t() | nil
}

Functions

object_name()

sid_prefix()