Twilio.Resources.Taskrouter.V1.Workspace.Worker.WorkerStatistics (twilio_elixir v0.1.1)

Copy Markdown View Source

WorkerStatistics resource.

Parent: /Workspaces/{WorkspaceSid}/Workers/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Worker resource.
cumulativeAn object that contains the cumulative statistics for the Worker.
urlThe absolute URL of the WorkerChannel statistics resource.. Format: uri
worker_sidThe SID of the Worker that contains the WorkerChannel.
workspace_sidThe SID of the Workspace that contains the WorkerChannel.

Summary

Types

t()

@type t() :: %Twilio.Resources.Taskrouter.V1.Workspace.Worker.WorkerStatistics{
  account_sid: String.t() | nil,
  cumulative: String.t() | nil,
  url: String.t() | nil,
  worker_sid: String.t() | nil,
  workspace_sid: String.t() | nil
}

Functions

object_name()