Twilio.Resources.Taskrouter.V1.Workspace.Workflow.WorkflowRealTimeStatistics (twilio_elixir v0.1.1)

Copy Markdown View Source

WorkflowRealTimeStatistics resource.

Parent: /Workspaces/{WorkspaceSid}/Workflows/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Workflow resource.
longest_task_waiting_ageThe age of the longest waiting Task.
longest_task_waiting_sidThe SID of the longest waiting Task.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| tasks_by_priority | The number of Tasks by priority. For example: {"0": "10", "99": "5"} shows 10 Tasks at priority 0 and 5 at priority 99. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

tasks_by_statusThe number of Tasks by their current status. For example: {"pending": "1", "reserved": "3", "assigned": "2", "completed": "5"}.
total_tasksThe total number of Tasks.
urlThe absolute URL of the Workflow statistics resource.. Format: uri
workflow_sidReturns the list of Tasks that are being controlled by the Workflow with the specified SID value.
workspace_sidThe SID of the Workspace that contains the Workflow.

Summary

Types

t()

@type t() ::
  %Twilio.Resources.Taskrouter.V1.Workspace.Workflow.WorkflowRealTimeStatistics{
    account_sid: String.t() | nil,
    longest_task_waiting_age: integer(),
    longest_task_waiting_sid: String.t() | nil,
    tasks_by_priority: String.t() | nil,
    tasks_by_status: String.t() | nil,
    total_tasks: integer(),
    url: String.t() | nil,
    workflow_sid: String.t() | nil,
    workspace_sid: String.t() | nil
  }

Functions

object_name()