Twilio.Resources.Taskrouter.V1.Workspace.Workflow.WorkflowStatistics (twilio_elixir v0.1.1)

Copy Markdown View Source

WorkflowStatistics resource.

Parent: /Workspaces/{WorkspaceSid}/Workflows/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Workflow resource.
cumulativeAn object that contains the cumulative statistics for the Workflow.
realtimeAn object that contains the real-time statistics for the Workflow.
urlThe absolute URL of the Workflow statistics resource.. Format: uri
workflow_sidReturns the list of Tasks that are being controlled by the Workflow with the specified SID value.
workspace_sidThe SID of the Workspace that contains the Workflow.

Summary

Types

t()

@type t() :: %Twilio.Resources.Taskrouter.V1.Workspace.Workflow.WorkflowStatistics{
  account_sid: String.t() | nil,
  cumulative: String.t() | nil,
  realtime: String.t() | nil,
  url: String.t() | nil,
  workflow_sid: String.t() | nil,
  workspace_sid: String.t() | nil
}

Functions

object_name()