Twilio.Resources.Taskrouter.V1.Workspace.WorkspaceCumulativeStatistics (twilio_elixir v0.1.1)

Copy Markdown View Source

WorkspaceCumulativeStatistics resource.

Parent: /Workspaces/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Workspace resource.
avg_task_acceptance_timeThe average time in seconds between Task creation and acceptance.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

end_timeThe end of the interval during which these statistics were calculated, in ISO 8601 format.. Format: date-time
reservations_acceptedThe total number of Reservations accepted by Workers.
reservations_canceledThe total number of Reservations that were canceled.
reservations_createdThe total number of Reservations that were created for Workers.
reservations_rejectedThe total number of Reservations that were rejected.
reservations_rescindedThe total number of Reservations that were rescinded.
reservations_timed_outThe total number of Reservations that were timed out.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| split_by_wait_time | A list of objects that describe the number of Tasks canceled and reservations accepted above and below the thresholds specified in seconds. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

start_timeThe beginning of the interval during which these statistics were calculated, in ISO 8601 format.. Format: date-time
tasks_canceledThe total number of Tasks that were canceled.
tasks_completedThe total number of Tasks that were completed.
tasks_createdThe total number of Tasks created.
tasks_deletedThe total number of Tasks that were deleted.
tasks_movedThe total number of Tasks that were moved from one queue to another.
tasks_timed_out_in_workflowThe total number of Tasks that were timed out of their Workflows (and deleted).
urlThe absolute URL of the Workspace statistics resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| wait_duration_until_accepted | The wait duration statistics (avg, min, max, total) for Tasks that were accepted. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

wait_duration_until_canceledThe wait duration statistics (avg, min, max, total) for Tasks that were canceled.
workspace_sidThe SID of the Workspace.

Summary

Types

t()

@type t() :: %Twilio.Resources.Taskrouter.V1.Workspace.WorkspaceCumulativeStatistics{
  account_sid: String.t() | nil,
  avg_task_acceptance_time: integer(),
  end_time: String.t() | nil,
  reservations_accepted: integer(),
  reservations_canceled: integer(),
  reservations_created: integer(),
  reservations_rejected: integer(),
  reservations_rescinded: integer(),
  reservations_timed_out: integer(),
  split_by_wait_time: String.t() | nil,
  start_time: String.t() | nil,
  tasks_canceled: integer(),
  tasks_completed: integer(),
  tasks_created: integer(),
  tasks_deleted: integer(),
  tasks_moved: integer(),
  tasks_timed_out_in_workflow: integer(),
  url: String.t() | nil,
  wait_duration_until_accepted: String.t() | nil,
  wait_duration_until_canceled: String.t() | nil,
  workspace_sid: String.t() | nil
}

Functions

object_name()