Twilio.Resources.Taskrouter.V1.Workspace.WorkspaceStatistics (twilio_elixir v0.1.1)

Copy Markdown View Source

WorkspaceStatistics resource.

Parent: /Workspaces/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Workspace resource.
cumulativeAn object that contains the cumulative statistics for the Workspace.
realtimeAn object that contains the real-time statistics for the Workspace.
urlThe absolute URL of the Workspace statistics resource.. Format: uri
workspace_sidThe SID of the Workspace.

Summary

Types

t()

@type t() :: %Twilio.Resources.Taskrouter.V1.Workspace.WorkspaceStatistics{
  account_sid: String.t() | nil,
  cumulative: String.t() | nil,
  realtime: String.t() | nil,
  url: String.t() | nil,
  workspace_sid: String.t() | nil
}

Functions

object_name()