Twilio.Resources.Trunking.V1.Trunk.CredentialList (twilio_elixir v0.1.1)

Copy Markdown View Source

List of credentials for accessing a trunk

SID prefix: CL

Parent: /Trunks/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the CredentialList resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.
sidThe unique string that we created to identify the CredentialList resource.
trunk_sidThe SID of the Trunk the credential list in associated with.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Trunking.V1.Trunk.CredentialList{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  sid: String.t() | nil,
  trunk_sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()