Twilio.Resources.Trunking.V1.Trunk.IpAccessControlList
(twilio_elixir v0.1.1)
List of IP addresses for accessing a trunk
SID prefix: AL
Parent: /Trunks/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the IpAccessControlList resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
friendly_name | The string that you assigned to describe the resource. |
sid | The unique string that we created to identify the IpAccessControlList resource. |
trunk_sid | The SID of the Trunk the resource is associated with. |
url | The absolute URL of the resource.. Format: uri |