Twilio.Resources.Trunking.V1.Trunk.PhoneNumber (twilio_elixir v0.1.1)

Copy Markdown View Source

Phone numbers associated with trunks

SID prefix: PN

Parent: /Trunks/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the PhoneNumber resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

address_requirementsWhether the phone number requires an Address registered with Twilio and, if so, what type. Can be: none, any, local, or foreign.. Values: none, any, local, foreign
api_versionThe API version used to start a new TwiML session.
betaWhether the phone number is new to the Twilio platform. Can be: true or false.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| capabilities | The set of Boolean properties that indicate whether a phone number can receive calls or messages. Capabilities are Voice, SMS, and MMS and each capability can be: true or false.. Format: phone-number-capabilities |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.. PII: standard
linksThe URLs of related resources.. Format: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

phone_numberThe phone number in E.164 format, which consists of a + followed by the country code and subscriber number.. Format: phone-number
sidThe unique string that we created to identify the PhoneNumber resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sms_application_sid | The SID of the application that handles SMS messages sent to the phone number. If an sms_application_sid is present, we ignore all sms_*_url values and use those of the application. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sms_fallback_method | The HTTP method we use to call sms_fallback_url. Can be: GET or POST.. Values: GET, POST. Format: http-method |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sms_fallback_url | The URL that we call using the sms_fallback_method when an error occurs while retrieving or executing the TwiML from sms_url.. Format: uri |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sms_method | The HTTP method we use to call sms_url. Can be: GET or POST.. Values: GET, POST. Format: http-method |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sms_url | The URL we call using the sms_method when the phone number receives an incoming SMS message.. Format: uri |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| status_callback | The URL we call using the status_callback_method to send status information to your application.. Format: uri |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| status_callback_method | The HTTP method we use to call status_callback. Can be: GET or POST.. Values: GET, POST. Format: http-method |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

trunk_sidThe SID of the Trunk that handles calls to the phone number. If a trunk_sid is present, we ignore all of the voice URLs and voice applications and use those set on the Trunk. Setting a trunk_sid will automatically delete your voice_application_sid and vice versa.
urlThe absolute URL of the resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| voice_application_sid | The SID of the application that handles calls to the phone number. If a voice_application_sid is present, we ignore all of the voice URLs and use those set on the application. Setting a voice_application_sid will automatically delete your trunk_sid and vice versa. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| voice_caller_id_lookup | Whether we look up the caller's caller-ID name from the CNAM database ($0.01 per look up). Can be: true or false. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| voice_fallback_method | The HTTP method that we use to call voice_fallback_url. Can be: GET or POST.. Values: GET, POST. Format: http-method |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| voice_fallback_url | The URL that we call using the voice_fallback_method when an error occurs retrieving or executing the TwiML requested by url.. Format: uri |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| voice_method | The HTTP method we use to call voice_url. Can be: GET or POST.. Values: GET, POST. Format: http-method |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| voice_url | The URL we call using the voice_method when the phone number receives a call. The voice_url is not be used if a voice_application_sid or a trunk_sid is set.. Format: uri |

Summary

Types

t()

@type t() :: %Twilio.Resources.Trunking.V1.Trunk.PhoneNumber{
  account_sid: String.t() | nil,
  address_requirements: String.t(),
  api_version: String.t() | nil,
  beta: boolean() | nil,
  capabilities: map() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  links: map() | nil,
  phone_number: String.t() | nil,
  sid: String.t() | nil,
  sms_application_sid: String.t() | nil,
  sms_fallback_method: String.t() | nil,
  sms_fallback_url: String.t() | nil,
  sms_method: String.t() | nil,
  sms_url: String.t() | nil,
  status_callback: String.t() | nil,
  status_callback_method: String.t() | nil,
  trunk_sid: String.t() | nil,
  url: String.t() | nil,
  voice_application_sid: String.t() | nil,
  voice_caller_id_lookup: boolean() | nil,
  voice_fallback_method: String.t() | nil,
  voice_fallback_url: String.t() | nil,
  voice_method: String.t() | nil,
  voice_url: String.t() | nil
}

Functions

object_name()

sid_prefix()