Twilio.Resources.Trusthub.V1.ComplianceInquiry.Customer.ComplianceInquiries (twilio_elixir v0.1.1)

Copy Markdown View Source

ComplianceInquiries resource.

Properties

FieldDescription
customer_idThe CustomerID matching the Customer Profile that should be resumed or resubmitted for editing.
inquiry_idThe unique ID used to start an embedded compliance registration session.
inquiry_session_tokenThe session token used to start an embedded compliance registration session.
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() ::
  %Twilio.Resources.Trusthub.V1.ComplianceInquiry.Customer.ComplianceInquiries{
    customer_id: String.t() | nil,
    inquiry_id: String.t() | nil,
    inquiry_session_token: String.t() | nil,
    url: String.t() | nil
  }

Functions

object_name()