Twilio.Resources.Trusthub.V1.ComplianceInquiry.Registration.RegulatoryCompliance.GB.ComplianceRegistrationInquiries
(twilio_elixir v0.1.1)
ComplianceRegistrationInquiries resource.
Properties
| Field | Description |
|---|
inquiry_id | The unique ID used to start an embedded compliance registration session. |
inquiry_session_token | The session token used to start an embedded compliance registration session. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
registration_id | The RegistrationId matching the Registration Profile that should be resumed or resubmitted for editing. |
url | The URL of this resource.. Format: uri |