Twilio.Resources.Trusthub.V1.ComplianceInquiry.Tollfree.ComplianceTollfreeInquiries (twilio_elixir v0.1.1)

Copy Markdown View Source

ComplianceTollfreeInquiries resource.

Properties

FieldDescription
inquiry_idThe unique ID used to start an embedded compliance registration session.
inquiry_session_tokenThe session token used to start an embedded compliance registration session.
registration_idThe TolfreeId matching the Tollfree Profile that should be resumed or resubmitted for editing.
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() ::
  %Twilio.Resources.Trusthub.V1.ComplianceInquiry.Tollfree.ComplianceTollfreeInquiries{
    inquiry_id: String.t() | nil,
    inquiry_session_token: String.t() | nil,
    registration_id: String.t() | nil,
    url: String.t() | nil
  }

Functions

object_name()