Twilio.Resources.Trusthub.V1.CustomerProfile.ChannelEndpointAssignment (twilio_elixir v0.1.1)

Copy Markdown View Source

ChannelEndpointAssignment resource.

SID prefix: RA

Parent: /CustomerProfiles/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Item Assignment resource.
channel_endpoint_sidThe SID of an channel endpoint
channel_endpoint_typeThe type of channel endpoint. eg: phone-number
customer_profile_sidThe unique string that we created to identify the CustomerProfile resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_createdThe date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time
sidThe unique string that we created to identify the Item Assignment resource.
urlThe absolute URL of the Identity resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Trusthub.V1.CustomerProfile.ChannelEndpointAssignment{
  account_sid: String.t() | nil,
  channel_endpoint_sid: String.t() | nil,
  channel_endpoint_type: String.t() | nil,
  customer_profile_sid: String.t() | nil,
  date_created: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()