Twilio.Resources.Trusthub.V1.CustomerProfile.CustomerProfilesEntityAssignments
(twilio_elixir v0.1.1)
CustomerProfilesEntityAssignments resource.
SID prefix: BV
Parent: /CustomerProfiles/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Item Assignment resource. |
customer_profile_sid | The unique string that we created to identify the CustomerProfile resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
object_sid | The SID of an object bag that holds information of the different items. |
sid | The unique string that we created to identify the Item Assignment resource. |
url | The absolute URL of the Identity resource.. Format: uri |