Twilio.Resources.Trusthub.V1.CustomerProfile.CustomerProfilesEvaluations (twilio_elixir v0.1.1)

Copy Markdown View Source

CustomerProfilesEvaluations resource.

SID prefix: EL

Parent: /CustomerProfiles/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the customer_profile resource.
customer_profile_sidThe unique string that we created to identify the customer_profile resource.
date_createdFormat: date-time
policy_sidThe unique string of a policy that is associated to the customer_profile resource.
resultsThe results of the Evaluation which includes the valid and invalid attributes.
sidThe unique string that identifies the Evaluation resource.
statusThe compliance status of the Evaluation resource.. Values: compliant, noncompliant
urlFormat: uri

Summary

Types

t()

@type t() ::
  %Twilio.Resources.Trusthub.V1.CustomerProfile.CustomerProfilesEvaluations{
    account_sid: String.t() | nil,
    customer_profile_sid: String.t() | nil,
    date_created: String.t() | nil,
    policy_sid: String.t() | nil,
    results: list() | nil,
    sid: String.t() | nil,
    status: String.t(),
    url: String.t() | nil
  }

Functions

object_name()

sid_prefix()