Twilio.Resources.Trusthub.V1.EndUser (twilio_elixir v0.1.1)

Copy Markdown View Source

EndUser resource.

SID prefix: IT

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the End User resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| attributes | The set of parameters that are the attributes of the End Users resource which are listed in the End User Types.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.
sidThe unique string created by Twilio to identify the End User resource.
typeThe type of end user of the Bundle resource - can be individual or business.
urlThe absolute URL of the End User resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Trusthub.V1.EndUser{
  account_sid: String.t() | nil,
  attributes: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  sid: String.t() | nil,
  type: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()