Twilio.Resources.Trusthub.V1.EndUserType (twilio_elixir v0.1.1)

Copy Markdown View Source

EndUserType resource.

SID prefix: OY

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| fields | The required information for creating an End-User. The required fields will change as regulatory needs change and will differ for businesses and individuals. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| friendly_name | A human-readable description that is assigned to describe the End-User Type resource. Examples can include first name, last name, email, business name, etc |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

machine_nameA machine-readable description of the End-User Type resource. Examples can include first_name, last_name, email, business_name, etc.
sidThe unique string that identifies the End-User Type resource.
urlThe absolute URL of the End-User Type resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Trusthub.V1.EndUserType{
  fields: list() | nil,
  friendly_name: String.t() | nil,
  machine_name: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()