Twilio.Resources.Trusthub.V1.Policies (twilio_elixir v0.1.1)

Copy Markdown View Source

Policies resource.

SID prefix: RN

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

friendly_nameA human-readable description that is assigned to describe the Policy resource. Examples can include Primary Customer profile policy
requirementsThe SID of an object that holds the policy information
sidThe unique string that identifies the Policy resource.
urlThe absolute URL of the Policy resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Trusthub.V1.Policies{
  friendly_name: String.t() | nil,
  requirements: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()