SupportingDocument resource.
SID prefix: RD
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Document resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| attributes | The set of parameters that are the attributes of the Supporting Documents resource which are listed in the Supporting Document Types.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
friendly_name | The string that you assigned to describe the resource. |
mime_type | The image type uploaded in the Supporting Document container. |
sid | The unique string created by Twilio to identify the Supporting Document resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
status | The verification status of the Supporting Document resource.. Values: DRAFT, PENDING_REVIEW, REJECTED, APPROVED, EXPIRED, PROVISIONALLY_APPROVED |
type | The type of the Supporting Document. |
url | The absolute URL of the Supporting Document resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Trusthub.V1.SupportingDocument{ account_sid: String.t() | nil, attributes: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, friendly_name: String.t() | nil, mime_type: String.t() | nil, sid: String.t() | nil, status: String.t(), type: String.t() | nil, url: String.t() | nil }