Twilio.Resources.Trusthub.V1.TrustProduct.TrustProductsEvaluations (twilio_elixir v0.1.1)

Copy Markdown View Source

TrustProductsEvaluations resource.

SID prefix: EL

Parent: /TrustProducts/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the trust_product resource.
date_createdFormat: date-time
policy_sidThe unique string of a policy that is associated to the trust_product resource.
resultsThe results of the Evaluation which includes the valid and invalid attributes.
sidThe unique string that identifies the Evaluation resource.
statusThe compliance status of the Evaluation resource.. Values: compliant, noncompliant
trust_product_sidThe unique string that we created to identify the trust_product resource.
urlFormat: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Trusthub.V1.TrustProduct.TrustProductsEvaluations{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  policy_sid: String.t() | nil,
  results: list() | nil,
  sid: String.t() | nil,
  status: String.t(),
  trust_product_sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()