Twilio.Resources.Verify.V2.Attempt (twilio_elixir v0.1.1)

Copy Markdown View Source

Attempt resource.

SID prefix: VL

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Verification resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

channelA string specifying the communication channel used for the verification attempt.. Values: sms, call, email, whatsapp, rbm
channel_dataAn object containing the channel specific information for an attempt.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| conversion_status | A string specifying the conversion status of the verification. A conversion happens when the user is able to provide the correct code. Possible values are CONVERTED and UNCONVERTED.. Values: converted, unconverted |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date that this Attempt was created, given in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date that this Attempt was updated, given in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| price | An object containing the charge for this verification attempt related to the channel costs and the currency used. The costs related to the succeeded verifications are not included. May not be immediately available. More information on pricing is available here. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

service_sidThe SID of the Service used to generate the attempt.
sidThe SID that uniquely identifies the verification attempt resource.
urlFormat: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| verification_sid | The SID of the Verification that generated the attempt. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Verify.V2.Attempt{
  account_sid: String.t() | nil,
  channel: String.t(),
  channel_data: String.t() | nil,
  conversion_status: String.t(),
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  price: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil,
  verification_sid: String.t() | nil
}

Functions

object_name()

sid_prefix()