Twilio.Resources.Verify.V2.Form (twilio_elixir v0.1.1)

Copy Markdown View Source

Form resource.

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

form_metaAdditional information for the available forms for this type. E.g. The separator string used for binding in a Factor push.
form_typeThe Type of this Form. Currently only form-push is supported.. Values: form-push

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

formsObject that contains the available forms for this type. This available forms are given in the standard JSON Schema format
urlThe URL to access the forms for this type.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Verify.V2.Form{
  form_meta: String.t() | nil,
  form_type: String.t(),
  forms: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()