Twilio.Resources.Verify.V2.Service.AccessToken (twilio_elixir v0.1.1)

Copy Markdown View Source

AccessToken resource.

SID prefix: YK

Parent: /Services/{Sid}

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_createdThe date that this access token was created, given in ISO 8601 format.. Format: date-time
entity_identityThe unique external identifier for the Entity of the Service.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

factor_friendly_nameA human readable description of this factor, up to 64 characters. For a push factor, this can be the device's name.. PII: standard
factor_typeThe Type of the Factor. Currently only push is supported.. Values: push
service_sidThe unique SID identifier of the Verify Service.
sidA 34 character string that uniquely identifies this Access Token.
tokenThe access token generated for enrollment, this is an encrypted json web token.
ttlHow long, in seconds, the access token is valid. Max: 5 minutes
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Verify.V2.Service.AccessToken{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  entity_identity: String.t() | nil,
  factor_friendly_name: String.t() | nil,
  factor_type: String.t(),
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  token: String.t() | nil,
  ttl: integer(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()