Twilio.Resources.Verify.V2.Service.Entity (twilio_elixir v0.1.1)

Copy Markdown View Source

Entity resource.

SID prefix: YE

Parent: /Services/{Sid}

Sub-resources

  • challenges/v2/Services/{service_sid}/Entities/{identity}/Challenges
  • factors/v2/Services/{service_sid}/Entities/{identity}/Factors
  • new_factors/v2/Services/{service_sid}/Entities/{identity}/Factors

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date that this Entity was created, given in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date that this Entity was updated, given in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

identityThe unique external identifier for the Entity of the Service. This identifier should be immutable, not PII, length between 8 and 64 characters, and generated by your external system, such as your user's UUID, GUID, or SID. It can only contain dash (-) separated alphanumeric characters.. PII: standard
linksContains a dictionary of URL links to nested resources of this Entity.. Format: uri-map
service_sidThe unique SID identifier of the Service.
sidA 34 character string that uniquely identifies this Entity.
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Verify.V2.Service.Entity{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  identity: String.t() | nil,
  links: map() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()