Twilio.Resources.Verify.V2.Service.Entity.Challenge.Notification (twilio_elixir v0.1.1)

Copy Markdown View Source

Notification resource.

SID prefix: NT

Parent: /Services/{ServiceSid}/Entities/{Identity}/Challenges/{Sid}

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.
challenge_sidThe unique SID identifier of the Challenge.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_createdThe date that this Notification was created, given in ISO 8601 format.. Format: date-time
entity_sidThe unique SID identifier of the Entity.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| identity | Customer unique identity for the Entity owner of the Challenge. This identifier should be immutable, not PII, length between 8 and 64 characters, and generated by your external system, such as your user's UUID, GUID, or SID. It can only contain dash (-) separated alphanumeric characters.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

priorityThe priority of the notification. For push Challenges it's always high which sends the notification immediately, and can wake up a sleeping device.
service_sidThe unique SID identifier of the Service.
sidA 34 character string that uniquely identifies this Notification.
ttlHow long, in seconds, the notification is valid. Max: 5 minutes

Summary

Types

t()

@type t() :: %Twilio.Resources.Verify.V2.Service.Entity.Challenge.Notification{
  account_sid: String.t() | nil,
  challenge_sid: String.t() | nil,
  date_created: String.t() | nil,
  entity_sid: String.t() | nil,
  identity: String.t() | nil,
  priority: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  ttl: integer()
}

Functions

object_name()

sid_prefix()