Twilio.Resources.Verify.V2.Service.Entity.Factor (twilio_elixir v0.1.1)

Copy Markdown View Source

Factor resource.

SID prefix: YF

Parent: /Services/{ServiceSid}/Entities/{Identity}

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.
configAn object that contains configurations specific to a factor_type.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date that this Factor was created, given in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date that this Factor was updated, given in ISO 8601 format.. Format: date-time
entity_sidThe unique SID identifier of the Entity.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| factor_type | The Type of this Factor. Currently push and totp are supported.. Values: push, totp, passkeys |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| friendly_name | A human readable description of this resource, up to 64 characters. For a push factor, this can be the device's name. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| identity | Customer unique identity for the Entity owner of the Factor. This identifier should be immutable, not PII, length between 8 and 64 characters, and generated by your external system, such as your user's UUID, GUID, or SID. It can only contain dash (-) separated alphanumeric characters.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

metadataCustom metadata associated with the factor. This is added by the Device/SDK directly to allow for the inclusion of device information. It must be a stringified JSON with only strings values eg. {"os": "Android"}. Can be up to 1024 characters in length.. PII: standard
service_sidThe unique SID identifier of the Service.
sidA 34 character string that uniquely identifies this Factor.
statusThe Status of this Factor. One of unverified or verified.. Values: unverified, verified
urlThe URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Verify.V2.Service.Entity.Factor{
  account_sid: String.t() | nil,
  config: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  entity_sid: String.t() | nil,
  factor_type: String.t(),
  friendly_name: String.t() | nil,
  identity: String.t() | nil,
  metadata: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()