Twilio.Resources.Verify.V2.Service.Webhook (twilio_elixir v0.1.1)

Copy Markdown View Source

Webhook resource.

SID prefix: YW

Parent: /Services/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Service resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

event_typesThe array of events that this Webhook is subscribed to. Possible event types: *, factor.deleted, factor.created, factor.verified, challenge.approved, challenge.denied
friendly_nameThe string that you assigned to describe the webhook. This value should not contain PII.
service_sidThe unique SID identifier of the Service.
sidThe unique string that we created to identify the Webhook resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe webhook status. Default value is enabled. One of: enabled or disabled. Values: enabled, disabled
urlThe absolute URL of the Webhook resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

versionThe webhook version. Default value is v2 which includes all the latest fields. Version v1 is legacy and may be removed in the future.. Values: v1, v2
webhook_methodThe method to be used when calling the webhook's URL.. Values: GET, POST
webhook_urlThe URL associated with this Webhook.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Verify.V2.Service.Webhook{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  event_types: list() | nil,
  friendly_name: String.t() | nil,
  service_sid: String.t() | nil,
  sid: String.t() | nil,
  status: String.t(),
  url: String.t() | nil,
  version: String.t(),
  webhook_method: String.t(),
  webhook_url: String.t() | nil
}

Functions

object_name()

sid_prefix()