Twilio.Resources.Verify.V2.Template (twilio_elixir v0.1.1)

Copy Markdown View Source

Template resource.

SID prefix: HJ

Properties

FieldDescription
account_sidThe unique SID identifier of the Account.
channelsA list of channels that support the Template. Can include: sms, voice.
friendly_nameA descriptive string that you create to describe a Template. It can be up to 32 characters long.
sidA 34 character string that uniquely identifies a Verification Template.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| translations | An object that contains the different translations of the template. Every translation is identified by the language short name and contains its respective information as the approval status, text and created/modified date. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Verify.V2.Template{
  account_sid: String.t() | nil,
  channels: list() | nil,
  friendly_name: String.t() | nil,
  sid: String.t() | nil,
  translations: String.t() | nil
}

Functions

object_name()

sid_prefix()