Twilio.Resources.Video.V1.CompositionSetting.CompositionSettings (twilio_elixir v0.1.1)

Copy Markdown View Source

Recording composition settings

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the CompositionSettings resource.
aws_credentials_sidThe SID of the stored Credential resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| aws_s3_url | The URL of the AWS S3 bucket where the compositions are stored. We only support DNS-compliant URLs like https://documentation-example-twilio-bucket/compositions, where compositions is the path in which you want the compositions to be stored. This URL accepts only URI-valid characters, as described in the RFC 3986.. Format: uri |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

aws_storage_enabledWhether all compositions are written to the aws_s3_url. When false, all compositions are stored in our cloud.
encryption_enabledWhether all compositions are stored in an encrypted form. The default is false.
encryption_key_sidThe SID of the Public Key resource used for encryption.
friendly_nameThe string that you assigned to describe the resource and that will be shown in the console
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Video.V1.CompositionSetting.CompositionSettings{
  account_sid: String.t() | nil,
  aws_credentials_sid: String.t() | nil,
  aws_s3_url: String.t() | nil,
  aws_storage_enabled: boolean() | nil,
  encryption_enabled: boolean() | nil,
  encryption_key_sid: String.t() | nil,
  friendly_name: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()