Recording settings
Properties
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the RecordingSettings resource. |
aws_credentials_sid | The SID of the stored Credential resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| aws_s3_url | The URL of the AWS S3 bucket where the recordings are stored. We only support DNS-compliant URLs like https://documentation-example-twilio-bucket/recordings, where recordings is the path in which you want the recordings to be stored. This URL accepts only URI-valid characters, as described in the RFC 3986.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
aws_storage_enabled | Whether all recordings are written to the aws_s3_url. When false, all recordings are stored in our cloud. |
encryption_enabled | Whether all recordings are stored in an encrypted form. The default is false. |
encryption_key_sid | The SID of the Public Key resource used for encryption. |
friendly_name | The string that you assigned to describe the resource and show the user in the console |
url | The absolute URL of the resource.. Format: uri |