Twilio.Resources.Video.V1.Room (twilio_elixir v0.1.1)

Copy Markdown View Source

Video rooms with one or more participants

SID prefix: RM

Sub-resources

  • participants/v1/Rooms/{room_sid}/Participants
  • recording_rules/v1/Rooms/{room_sid}/RecordingRules
  • recordings/v1/Rooms/{room_sid}/Recordings
  • transcriptions/v1/Rooms/{room_sid}/Transcriptions

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Room resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| audio_only | When set to true, indicates that the participants in the room will only publish audio. No video tracks will be allowed. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
durationThe duration of the room in seconds.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

empty_room_timeoutSpecifies how long (in minutes) a room will remain active after last participant leaves. Can be configured when creating a room via REST API. For Ad-Hoc rooms this value cannot be changed.
enable_turnDeprecated, now always considered to be true.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

end_timeThe UTC end time of the room in ISO 8601 format.. Format: date-time
large_roomIndicates if this is a large room.
linksThe URLs of related resources.. Format: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| max_concurrent_published_tracks | The maximum number of published audio, video, and data tracks all participants combined are allowed to publish in the room at the same time. Check Programmable Video Limits for more details. If it is set to 0 it means unconstrained. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

max_participant_durationThe maximum number of seconds a Participant can be connected to the room. The maximum possible value is 86400 seconds (24 hours). The default is 14400 seconds (4 hours).
max_participantsThe maximum number of concurrent Participants allowed in the room.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

media_regionThe region for the Room's media server. Can be one of the available Media Regions.
record_participants_on_connectWhether to start recording when Participants connect.
sidThe unique string that Twilio created to identify the Room resource.
statusValues: in-progress, completed, failed

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| status_callback | The URL Twilio calls using the status_callback_method to send status information to your application on every room event. See Status Callbacks for more info.. Format: uri |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

status_callback_methodThe HTTP method Twilio uses to call status_callback. Can be POST or GET and defaults to POST.. Values: GET, POST. Format: http-method
typeValues: go, peer-to-peer, group, group-small

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| unique_name | An application-defined string that uniquely identifies the resource. It can be used as a room_sid in place of the resource's sid in the URL to address the resource, assuming it does not contain any reserved characters that would need to be URL encoded. This value is unique for in-progress rooms. SDK clients can use this name to connect to the room. REST API clients can use this name in place of the Room SID to interact with the room as long as the room is in-progress. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unused_room_timeoutSpecifies how long (in minutes) a room will remain active if no one joins. Can be configured when creating a room via REST API. For Ad-Hoc rooms this value cannot be changed.
urlThe absolute URL of the resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| video_codecs | An array of the video codecs that are supported when publishing a track in the room. Can be: VP8 and H264. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Video.V1.Room{
  account_sid: String.t() | nil,
  audio_only: boolean() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  duration: integer() | nil,
  empty_room_timeout: integer(),
  enable_turn: boolean() | nil,
  end_time: String.t() | nil,
  large_room: boolean() | nil,
  links: map() | nil,
  max_concurrent_published_tracks: integer() | nil,
  max_participant_duration: integer(),
  max_participants: integer(),
  media_region: String.t() | nil,
  record_participants_on_connect: boolean() | nil,
  sid: String.t() | nil,
  status: String.t(),
  status_callback: String.t() | nil,
  status_callback_method: String.t() | nil,
  type: String.t(),
  unique_name: String.t() | nil,
  unused_room_timeout: integer(),
  url: String.t() | nil,
  video_codecs: list() | nil
}

Functions

object_name()

sid_prefix()