Twilio.Resources.Video.V1.Room.Participant.PublishedTrack (twilio_elixir v0.1.1)

Copy Markdown View Source

PublishedTrack resource.

SID prefix: MT

Parent: /Rooms/{RoomSid}/Participants/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
enabledWhether the track is enabled.
kindThe track type. Can be: audio, video or data.. Values: audio, video, data

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

nameThe track name. Must be no more than 128 characters, and be unique among the participant's published tracks.
participant_sidThe SID of the Participant resource with the published track.
room_sidThe SID of the Room resource where the track is published.
sidThe unique string that we created to identify the RoomParticipantPublishedTrack resource.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Video.V1.Room.Participant.PublishedTrack{
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  enabled: boolean() | nil,
  kind: String.t(),
  name: String.t() | nil,
  participant_sid: String.t() | nil,
  room_sid: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()