Twilio.Resources.Video.V1.Room.Participant.SubscribeRules (twilio_elixir v0.1.1)

Copy Markdown View Source

SubscribeRules resource.

Parent: /Rooms/{RoomSid}/Participants/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
participant_sidThe SID of the Participant resource for the Subscribe Rules.
room_sidThe SID of the Room resource for the Subscribe Rules

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| rules | A collection of Subscribe Rules that describe how to include or exclude matching tracks. See the Specifying Subscribe Rules section for further information. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Video.V1.Room.Participant.SubscribeRules{
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  participant_sid: String.t() | nil,
  room_sid: String.t() | nil,
  rules: list() | nil
}

Functions

object_name()