Twilio.Resources.Video.V1.Room.RecordingRules (twilio_elixir v0.1.1)

Copy Markdown View Source

RecordingRules resource.

Parent: /Rooms/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
room_sidThe SID of the Room resource for the Recording Rules
rulesA collection of Recording Rules that describe how to include or exclude matching tracks for recording

Summary

Types

t()

@type t() :: %Twilio.Resources.Video.V1.Room.RecordingRules{
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  room_sid: String.t() | nil,
  rules: list() | nil
}

Functions

object_name()