Twilio.Resources.Video.V1.Room.RoomRecording (twilio_elixir v0.1.1)

Copy Markdown View Source

Single-track, single-media room recordings

SID prefix: RT

Parent: /Rooms/{Sid}

Sub-resources

  • media/v1/Rooms/{room_sid}/Recordings/{sid}/Media

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the RoomRecording resource.
codecThe codec used for the recording. Can be: VP8 or H264.. Values: VP8, H264, OPUS, PCMU
container_formatValues: mka, mkv

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

durationThe duration of the recording rounded to the nearest second. Sub-second duration tracks have a duration of 1 second
grouping_sidsA list of SIDs related to the Recording. Includes the room_sid and participant_sid.
linksThe URLs of related resources.. Format: uri-map

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| media_external_location | The URL of the media file associated with the recording when stored externally. See External S3 Recordings for more details.. Format: uri |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

offsetThe time in milliseconds elapsed between an arbitrary point in time, common to all group rooms, and the moment when the source room of this track started. This information provides a synchronization mechanism for recordings belonging to the same room.. Format: int64
room_sidThe SID of the Room resource the recording is associated with.
sidThe unique string that we created to identify the RoomRecording resource.
sizeThe size of the recorded track in bytes.. Format: int64
source_sidThe SID of the recording source. For a Room Recording, this value is a track_sid.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| status | The status of the recording. Can be: processing, completed, or deleted. processing indicates the Recording is still being captured. completed indicates the Recording has been captured and is now available for download. deleted means the recording media has been deleted from the system, but its metadata is still available for historical purposes.. Values: processing, completed, deleted, failed |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

track_nameThe name that was given to the source track of the recording. If no name is given, the source_sid is used.
typeThe recording's media type. Can be: audio or video.. Values: audio, video, data
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Video.V1.Room.RoomRecording{
  account_sid: String.t() | nil,
  codec: String.t(),
  container_format: String.t(),
  date_created: String.t() | nil,
  duration: integer() | nil,
  grouping_sids: String.t() | nil,
  links: map() | nil,
  media_external_location: String.t() | nil,
  offset: integer() | nil,
  room_sid: String.t() | nil,
  sid: String.t() | nil,
  size: integer() | nil,
  source_sid: String.t() | nil,
  status: String.t(),
  track_name: String.t() | nil,
  type: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()