Twilio.Resources.Video.V1.Room.Transcriptions (twilio_elixir v0.1.1)

Copy Markdown View Source

transcriptions in video rooms

Parent: /Rooms/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Room resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| configuration | An JSON object that describes the video layout of the composition in terms of regions. See Specifying Video Layouts for more info.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| duration | The duration in seconds that the transcriptions were connected. Populated only after the transcriptions is stopped. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

end_timeThe time when the transcriptions disconnected from the room in ISO 8601 format.. Format: date-time
room_sidThe SID of the transcriptions's room.
source_sidThe SID of the transcriptions's associated call.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

start_timeThe time of transcriptions connected to the room in ISO 8601 format.. Format: date-time
statusThe status of the transcriptions resource.. Values: started, stopped, failed
ttidThe unique string that we created to identify the transcriptions resource.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Video.V1.Room.Transcriptions{
  account_sid: String.t() | nil,
  configuration: map() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  duration: integer() | nil,
  end_time: String.t() | nil,
  room_sid: String.t() | nil,
  source_sid: String.t() | nil,
  start_time: String.t() | nil,
  status: String.t(),
  ttid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()