Twilio.Resources.Voice.V1.ConnectionPolicy (twilio_elixir v0.1.1)

Copy Markdown View Source

Connection Policy for sending traffic to your communications infrastructure.

SID prefix: NY

Sub-resources

  • targets/v1/ConnectionPolicies/{connection_policy_sid}/Targets

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Connection Policy resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.
linksThe URLs of related resources.. Format: uri-map
sidThe unique string that we created to identify the Connection Policy resource.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Voice.V1.ConnectionPolicy{
  account_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  links: map() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()