Twilio.Resources.Voice.V1.ConnectionPolicy.ConnectionPolicyTarget (twilio_elixir v0.1.1)

Copy Markdown View Source

Network element entry points into your communications infrastructure

SID prefix: NE

Parent: /ConnectionPolicies/{Sid}

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the Target resource.
connection_policy_sidThe SID of the Connection Policy that owns the Target.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time
enabledWhether the target is enabled. The default is true.
friendly_nameThe string that you assigned to describe the resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

priorityThe relative importance of the target. Can be an integer from 0 to 65535, inclusive, and the default is 10. The lowest number represents the most important target.
sidThe unique string that we created to identify the Target resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

targetThe SIP address you want Twilio to route your calls to. This must be a sip: schema. sips is NOT supported.. Format: uri. PII: standard
urlThe absolute URL of the resource.. Format: uri

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| weight | The value that determines the relative share of the load the Target should receive compared to other Targets with the same priority. Can be an integer from 1 to 65535, inclusive, and the default is 10. Targets with higher values receive more load than those with lower ones with the same priority. |

Summary

Types

t()

@type t() :: %Twilio.Resources.Voice.V1.ConnectionPolicy.ConnectionPolicyTarget{
  account_sid: String.t() | nil,
  connection_policy_sid: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  enabled: boolean() | nil,
  friendly_name: String.t() | nil,
  priority: integer(),
  sid: String.t() | nil,
  target: String.t() | nil,
  url: String.t() | nil,
  weight: integer()
}

Functions

object_name()

sid_prefix()