Twilio.Resources.Voice.V1.DialingPermission.Country (twilio_elixir v0.1.1)

Copy Markdown View Source

Country resource.

Parent: /DialingPermissions

Sub-resources

  • highrisk_special_prefixes/v1/DialingPermissions/Countries/{iso_code}/HighRiskSpecialPrefixes

Properties

FieldDescription
continentThe name of the continent in which the country is located.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| country_codes | The E.164 assigned country codes(s) |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| high_risk_special_numbers_enabled | Whether dialing to high-risk special services numbers is enabled. These prefixes include number ranges allocated by the country and include premium numbers, special services, shared cost, and others |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

high_risk_tollfraud_numbers_enabledWhether dialing to high-risk toll fraud numbers is enabled. These prefixes include narrow number ranges that have a high-risk of international revenue sharing fraud (IRSF) attacks, also known as toll fraud. These prefixes are collected from anti-fraud databases and verified by analyzing calls on our network. These prefixes are not available for download and are updated frequently
iso_codeThe ISO country code.. Format: iso-country-code
linksA list of URLs related to this resource.. Format: uri-map
low_risk_numbers_enabledWhether dialing to low-risk numbers is enabled.
nameThe name of the country.
urlThe absolute URL of this resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Voice.V1.DialingPermission.Country{
  continent: String.t() | nil,
  country_codes: list() | nil,
  high_risk_special_numbers_enabled: boolean() | nil,
  high_risk_tollfraud_numbers_enabled: boolean() | nil,
  iso_code: String.t() | nil,
  links: map() | nil,
  low_risk_numbers_enabled: boolean() | nil,
  name: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()