Twilio.Resources.Voice.V1.IpRecord (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

IP Records hold information about the IP addresses and ranges (CIDR blocks) that your traffic will be associated with.

SID prefix: IL

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the IP Record resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| cidr_prefix_length | An integer representing the length of the CIDR prefix to use with this IP address. By default the entire IP address is used, which for IPv4 is value 32. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.
ip_addressAn IP address in dotted decimal notation, IPv4 only.. PII: standard
sidThe unique string that we created to identify the IP Record resource.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Voice.V1.IpRecord{
  account_sid: String.t() | nil,
  cidr_prefix_length: integer(),
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  ip_address: String.t() | nil,
  sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()