Twilio.Resources.Voice.V1.SourceIpMapping (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

With Source IP Mappings, Twilio can recognize your SIP requests based on where they are sent from. The Request-URI no longer has to have the FQDN (Fully Qualified Domain Name) of your SIP Domain.

SID prefix: IB

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time
ip_record_sidThe Twilio-provided string that uniquely identifies the IP Record resource to map from.
sidThe unique string that we created to identify the IP Record resource.
sip_domain_sidThe SID of the SIP Domain that the IP Record is mapped to.
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Voice.V1.SourceIpMapping{
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  ip_record_sid: String.t() | nil,
  sid: String.t() | nil,
  sip_domain_sid: String.t() | nil,
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()