Twilio.Resources.Wireless.V1.Command (twilio_elixir v0.1.1)

Copy Markdown View Source

Machine-to-machine commands sent to/from devices

SID prefix: DC

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| account_sid | The SID of the Account that created the Command resource. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| command | The message being sent to or from the SIM. For text mode messages, this can be up to 160 characters. For binary mode messages, this is a series of up to 140 bytes of data encoded using base64.. PII: standard |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| command_mode | The mode used to send the SMS message. Can be: text or binary. The default SMS mode is text.. Values: text, binary |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
delivery_receipt_requestedWhether to request a delivery receipt.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

directionThe direction of the Command. Can be to_sim or from_sim. The value of to_sim is synonymous with the term mobile terminated, and from_sim is synonymous with the term mobile originated.. Values: from_sim, to_sim
sidThe unique string that we created to identify the Command resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| sim_sid | The SID of the Sim resource that the Command was sent to or from. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

statusThe status of the Command. Can be: queued, sent, delivered, received, or failed. See Status Values for a description of each state.. Values: queued, sent, delivered, received, failed
transportThe type of transport used. Can be: sms or ip.. Values: sms, ip
urlThe absolute URL of the resource.. Format: uri

Summary

Types

t()

@type t() :: %Twilio.Resources.Wireless.V1.Command{
  account_sid: String.t() | nil,
  command: String.t() | nil,
  command_mode: String.t(),
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  delivery_receipt_requested: boolean() | nil,
  direction: String.t(),
  sid: String.t() | nil,
  sim_sid: String.t() | nil,
  status: String.t(),
  transport: String.t(),
  url: String.t() | nil
}

Functions

object_name()

sid_prefix()