Twilio.Resources.Wireless.V1.RatePlan (twilio_elixir v0.1.1)

Copy Markdown View Source

Capabilities and restrictions for SIMs

SID prefix: WP

Properties

FieldDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

account_sidThe SID of the Account that created the RatePlan resource.
data_enabledWhether SIMs can use GPRS/3G/4G/LTE data connectivity.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| data_limit | The total data usage (download and upload combined) in Megabytes that the Network allows during one month on the home network (T-Mobile USA). The metering period begins the day of activation and ends on the same day in the following month. Can be up to 2TB. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| data_metering | The model used to meter data usage. Can be: payg and quota-1, quota-10, and quota-50. Learn more about the available data metering models. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

date_updatedThe date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time
friendly_nameThe string that you assigned to describe the resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| international_roaming | The list of services that SIMs capable of using GPRS/3G/4G/LTE data connectivity can use outside of the United States. Can contain: data and messaging. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| international_roaming_data_limit | The total data usage (download and upload combined) in Megabytes that the Network allows during one month when roaming outside the United States. Can be up to 2TB. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| messaging_enabled | Whether SIMs can make, send, and receive SMS using Commands. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| national_roaming_data_limit | The total data usage (download and upload combined) in Megabytes that the Network allows during one month on non-home networks in the United States. The metering period begins the day of activation and ends on the same day in the following month. Can be up to 2TB. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

national_roaming_enabledWhether SIMs can roam on networks other than the home network (T-Mobile USA) in the United States. See national roaming.
sidThe unique string that we created to identify the RatePlan resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

unique_nameAn application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource.
urlThe absolute URL of the resource.. Format: uri
voice_enabledDeprecated. Whether SIMs can make and receive voice calls.

Summary

Types

t()

@type t() :: %Twilio.Resources.Wireless.V1.RatePlan{
  account_sid: String.t() | nil,
  data_enabled: boolean() | nil,
  data_limit: integer(),
  data_metering: String.t() | nil,
  date_created: String.t() | nil,
  date_updated: String.t() | nil,
  friendly_name: String.t() | nil,
  international_roaming: list() | nil,
  international_roaming_data_limit: integer(),
  messaging_enabled: boolean() | nil,
  national_roaming_data_limit: integer(),
  national_roaming_enabled: boolean() | nil,
  sid: String.t() | nil,
  unique_name: String.t() | nil,
  url: String.t() | nil,
  voice_enabled: boolean() | nil
}

Functions

object_name()

sid_prefix()