Twilio.Routes.V2.PhoneNumberService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for PhoneNumber API operations.

Operations: fetch, update

Summary

Functions

Fetch the Inbound Processing Region assigned to a phone number.

Assign an Inbound Processing Region to a phone number.

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Routes.V2.PhoneNumber.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch the Inbound Processing Region assigned to a phone number.

Operation: FetchPhoneNumber | Tags: RoutesV2PhoneNumber

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Routes.V2.PhoneNumber.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Assign an Inbound Processing Region to a phone number.

Operation: UpdatePhoneNumber | Tags: RoutesV2PhoneNumber

Optional Parameters

ParameterTypeDescription
FriendlyNamestringA human readable description of this resource, up to 64 characters.
VoiceRegionstringThe Inbound Processing Region used for this phone number for voice