Twilio.Routes.V2.TrunkService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Trunk API operations.

Operations: fetch, update

Summary

Functions

Fetch the Inbound Processing Region assigned to a SIP Trunk.

Assign an Inbound Processing Region to a SIP Trunk

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Routes.V2.Trunk.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch the Inbound Processing Region assigned to a SIP Trunk.

Operation: FetchTrunks | Tags: RoutesV2Trunk

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Routes.V2.Trunk.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Assign an Inbound Processing Region to a SIP Trunk

Operation: UpdateTrunks | Tags: RoutesV2Trunk

Optional Parameters

ParameterTypeDescription
FriendlyNamestringA human readable description of this resource, up to 64 characters.
VoiceRegionstringThe Inbound Processing Region used for this SIP Trunk for voice