Twilio.Serverless.V1.Service.AssetService (twilio_elixir v0.1.1)

Copy Markdown View Source

A wrapper that represents a static file and groups the different Versions of the static file.

Operations: list, create, fetch, update, delete

Summary

Functions

Retrieve a specific Asset resource.

Stream: Retrieve a list of all Assets. (lazy auto-pagination).

Functions

create(client, service_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Serverless.V1.Service.Asset.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Asset resource.

Operation: CreateAsset | Tags: ServerlessV1Asset

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the Asset resource. It can be a maximum of 255 characters. |

delete(client, service_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete an Asset resource.

Operation: DeleteAsset | Tags: ServerlessV1Asset

fetch(client, service_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Serverless.V1.Service.Asset.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a specific Asset resource.

Operation: FetchAsset | Tags: ServerlessV1Asset

list(client, service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Assets.

Operation: ListAsset | Tags: ServerlessV1Asset

stream(client, service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Assets. (lazy auto-pagination).

update(client, service_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Serverless.V1.Service.Asset.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update a specific Asset resource.

Operation: UpdateAsset | Tags: ServerlessV1Asset

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the Asset resource. It can be a maximum of 255 characters. |