Twilio.Serverless.V1.Service.BuildService (twilio_elixir v0.1.1)

Copy Markdown View Source

A collection of Function Versions, Asset Versions, Dependencies, and a Runtime that form a deployable unit.

Operations: list, create, fetch, delete

Summary

Functions

Create a new Build resource. At least one function version or asset version is required.

Retrieve a specific Build resource.

Stream: Retrieve a list of all Builds. (lazy auto-pagination).

Functions

create(client, service_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Serverless.V1.Service.Build.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Build resource. At least one function version or asset version is required.

Operation: CreateBuild | Tags: ServerlessV1Build

Optional Parameters

ParameterTypeDescription
AssetVersionsarrayThe list of Asset Version resource SIDs to include in the Build.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DependenciesstringA list of objects that describe the Dependencies included in the Build. Each object contains the name and version of the dependency.
FunctionVersionsarrayThe list of the Function Version resource SIDs to include in the Build.
RuntimestringThe Runtime version that will be used to run the Build resource when it is deployed.

delete(client, service_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a Build resource.

Operation: DeleteBuild | Tags: ServerlessV1Build

fetch(client, service_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Serverless.V1.Service.Build.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a specific Build resource.

Operation: FetchBuild | Tags: ServerlessV1Build

list(client, service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Builds.

Operation: ListBuild | Tags: ServerlessV1Build

stream(client, service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Builds. (lazy auto-pagination).