Twilio.Serverless.V1.Service.Environment.DeploymentService (twilio_elixir v0.1.1)

Copy Markdown View Source

An association of a Build with an Environment so that the Build is published in the Environment.

Operations: list, create, fetch

Summary

Functions

create(client, service_sid, environment_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Serverless.V1.Service.Environment.Deployment.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Deployment.

Operation: CreateDeployment | Tags: ServerlessV1Deployment

Optional Parameters

ParameterTypeDescription
BuildSidstringThe SID of the Build for the Deployment.
IsPluginbooleanWhether the Deployment is a plugin.

fetch(client, service_sid, environment_sid, sid, opts \\ [])

Retrieve a specific Deployment.

Operation: FetchDeployment | Tags: ServerlessV1Deployment

list(client, service_sid, environment_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Deployments.

Operation: ListDeployment | Tags: ServerlessV1Deployment

stream(client, service_sid, environment_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: Retrieve a list of all Deployments. (lazy auto-pagination).