Twilio.Serverless.V1.Service.Function.Version.ContentService (twilio_elixir v0.1.1)

Copy Markdown View Source

The code of a Function Version.

Operations: fetch

Summary

Functions

Retrieve a the content of a specific Function Version resource.

Functions

fetch(client, service_sid, function_sid, sid, opts \\ [])

Retrieve a the content of a specific Function Version resource.

Operation: FetchFunctionVersionContent | Tags: ServerlessV1FunctionVersionContent