Twilio.Serverless.V1.ServiceService (twilio_elixir v0.1.1)

Copy Markdown View Source

The top-level resource for a Serverless application, which serves as a container for the application environments.

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new Service resource.

Delete a Service resource.

Retrieve a specific Service resource.

Retrieve a list of all Services.

Stream: Retrieve a list of all Services. (lazy auto-pagination).

Update a specific Service resource.

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Serverless.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Service resource.

Operation: CreateService | Tags: ServerlessV1Service

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the Service resource. It can be a maximum of 255 characters. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UniqueName | string | A user-defined string that uniquely identifies the Service resource. It can be used as an alternative to the sid in the URL path to address the Service resource. This value must be 50 characters or less in length and be unique. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| IncludeCredentials | boolean | Whether to inject Account credentials into a function invocation context. The default value is true. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UiEditable | boolean | Whether the Service's properties and subresources can be edited via the UI. The default value is false. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a Service resource.

Operation: DeleteService | Tags: ServerlessV1Service

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Serverless.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a specific Service resource.

Operation: FetchService | Tags: ServerlessV1Service

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Services.

Operation: ListService | Tags: ServerlessV1Service

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Services. (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Serverless.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update a specific Service resource.

Operation: UpdateService | Tags: ServerlessV1Service

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

FriendlyNamestringA descriptive string that you create to describe the Service resource. It can be a maximum of 255 characters.
IncludeCredentialsbooleanWhether to inject Account credentials into a function invocation context.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UiEditable | boolean | Whether the Service resource's properties and subresources can be edited via the UI. The default value is false. |