Twilio.Studio.V1.Flow.Engagement.StepService (twilio_elixir v0.1.1)

Copy Markdown View Source

Steps within a Studio flow

Operations: list, fetch

Summary

Functions

Retrieve a list of all Steps for an Engagement.

Stream: Retrieve a list of all Steps for an Engagement. (lazy auto-pagination).

Functions

fetch(client, flow_sid, engagement_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Studio.V1.Flow.Engagement.Step.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a Step.

Operation: FetchStep | Tags: StudioV1Step

list(client, flow_sid, engagement_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Steps for an Engagement.

Operation: ListStep | Tags: StudioV1Step

stream(client, flow_sid, engagement_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: Retrieve a list of all Steps for an Engagement. (lazy auto-pagination).