Twilio.Studio.V2.FlowService (twilio_elixir v0.1.1)

Copy Markdown View Source

Studio flows

Operations: list, create, fetch, update, delete

Summary

Functions

Delete a specific Flow.

Retrieve a specific Flow.

Retrieve a list of all Flows.

Stream: Retrieve a list of all Flows. (lazy auto-pagination).

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Studio.V2.Flow.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a Flow.

Operation: CreateFlow | Tags: StudioV2Flow

Required Parameters

ParameterTypeDescription
DefinitionstringJSON representation of flow definition.
FriendlyNamestringThe string that you assigned to describe the Flow.
StatusstringValues: draft, published

Optional Parameters

ParameterTypeDescription
CommitMessagestringDescription of change made in the revision.

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Flow.

Operation: DeleteFlow | Tags: StudioV2Flow

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Studio.V2.Flow.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a specific Flow.

Operation: FetchFlow | Tags: StudioV2Flow

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Flows.

Operation: ListFlow | Tags: StudioV2Flow

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Flows. (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Studio.V2.Flow.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update a Flow.

Operation: UpdateFlow | Tags: StudioV2Flow

Required Parameters

ParameterTypeDescription
StatusstringValues: draft, published

Optional Parameters

ParameterTypeDescription
CommitMessagestringDescription of change made in the revision.
DefinitionstringJSON representation of flow definition.
FriendlyNamestringThe string that you assigned to describe the Flow.