Twilio.Supersim.V1.NetworkAccessProfile.NetworkAccessProfileNetworkService (twilio_elixir v0.1.1)

Copy Markdown View Source

Mobile operator networks which Network Access Profiles allow access to

Operations: list, create, fetch, delete

Summary

Functions

Add a Network resource to the Network Access Profile resource.

Remove a Network resource from the Network Access Profile resource's.

Fetch a Network Access Profile resource's Network resource.

Retrieve a list of Network Access Profile resource's Network resource.

Stream: Retrieve a list of Network Access Profile resource's Network resource. (lazy auto-pagination).

Functions

create(client, network_access_profile_sid, params \\ %{}, opts \\ [])

Add a Network resource to the Network Access Profile resource.

Operation: CreateNetworkAccessProfileNetwork | Tags: SupersimV1NetworkAccessProfileNetwork

Required Parameters

ParameterTypeDescription
NetworkstringThe SID of the Network resource to be added to the Network Access Profile resource.

delete(client, network_access_profile_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Remove a Network resource from the Network Access Profile resource's.

Operation: DeleteNetworkAccessProfileNetwork | Tags: SupersimV1NetworkAccessProfileNetwork

fetch(client, network_access_profile_sid, sid, opts \\ [])

Fetch a Network Access Profile resource's Network resource.

Operation: FetchNetworkAccessProfileNetwork | Tags: SupersimV1NetworkAccessProfileNetwork

list(client, network_access_profile_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of Network Access Profile resource's Network resource.

Operation: ListNetworkAccessProfileNetwork | Tags: SupersimV1NetworkAccessProfileNetwork

stream(client, network_access_profile_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of Network Access Profile resource's Network resource. (lazy auto-pagination).