Twilio.Supersim.V1.NetworkService (twilio_elixir v0.1.1)

Copy Markdown View Source

Mobile operator networks to which Super SIMs can connect

Operations: list, fetch

Summary

Functions

Fetch a Network resource.

Retrieve a list of Network resources.

Stream: Retrieve a list of Network resources. (lazy auto-pagination).

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Supersim.V1.Network.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a Network resource.

Operation: FetchNetwork | Tags: SupersimV1Network

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of Network resources.

Operation: ListNetwork | Tags: SupersimV1Network

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| IsoCountry | string | The ISO country code of the Network resources to read. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Mcc | string | The 'mobile country code' of a country. Network resources with this mcc in their identifiers will be read. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Mnc | string | The 'mobile network code' of a mobile operator network. Network resources with this mnc in their identifiers will be read. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of Network resources. (lazy auto-pagination).