Twilio.Supersim.V1.Sim.BillingPeriodService (twilio_elixir v0.1.1)

Copy Markdown View Source

Billing Period for an IoT Super SIM

Operations: list

Summary

Functions

Retrieve a list of Billing Periods for a Super SIM.

Stream: Retrieve a list of Billing Periods for a Super SIM. (lazy auto-pagination).

Functions

list(client, sim_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of Billing Periods for a Super SIM.

Operation: ListBillingPeriod | Tags: SupersimV1BillingPeriod

stream(client, sim_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of Billing Periods for a Super SIM. (lazy auto-pagination).