Twilio.Supersim.V1.SmsCommandService (twilio_elixir v0.1.1)

Copy Markdown View Source

Machine-to-machine SMS Commands sent to/from SIMs

Operations: list, create, fetch

Summary

Functions

Send SMS Command to a Sim.

Fetch SMS Command instance from your account.

Retrieve a list of SMS Commands from your account.

Stream: Retrieve a list of SMS Commands from your account. (lazy auto-pagination).

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Supersim.V1.SmsCommand.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Send SMS Command to a Sim.

Operation: CreateSmsCommand | Tags: SupersimV1SmsCommand

Required Parameters

ParameterTypeDescription
PayloadstringThe message body of the SMS Command.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Sim | string | The sid or unique_name of the SIM to send the SMS Command to. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

CallbackMethodstring (http-method)The HTTP method we should use to call callback_url. Can be: GET or POST and the default is POST. Values: GET, POST
CallbackUrlstring (uri)The URL we should call using the callback_method after we have sent the command.

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Supersim.V1.SmsCommand.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch SMS Command instance from your account.

Operation: FetchSmsCommand | Tags: SupersimV1SmsCommand

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of SMS Commands from your account.

Operation: ListSmsCommand | Tags: SupersimV1SmsCommand

Query Parameters

ParameterTypeDescription
SimstringThe SID or unique name of the Sim resource that SMS Command was sent to or from.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Status | string | The status of the SMS Command. Can be: queued, sent, delivered, received or failed. See the SMS Command Status Values for a description of each. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Direction | string | The direction of the SMS Command. Can be to_sim or from_sim. The value of to_sim is synonymous with the term mobile terminated, and from_sim is synonymous with the term mobile originated. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of SMS Commands from your account. (lazy auto-pagination).