Twilio.Sync.V1.Service.Document.PermissionService (twilio_elixir v0.1.1)

Copy Markdown View Source

Sync document permissions

Operations: list, fetch, update, delete

Summary

Functions

Delete a specific Sync Document Permission.

Fetch a specific Sync Document Permission.

Retrieve a list of all Permissions applying to a Sync Document.

Stream: Retrieve a list of all Permissions applying to a Sync Document. (lazy auto-pagination).

Update an identity's access to a specific Sync Document.

Functions

delete(client, service_sid, document_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Sync Document Permission.

Operation: DeleteDocumentPermission | Tags: SyncV1DocumentPermission

fetch(client, service_sid, document_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.Document.Permission.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Sync Document Permission.

Operation: FetchDocumentPermission | Tags: SyncV1DocumentPermission

list(client, service_sid, document_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Permissions applying to a Sync Document.

Operation: ListDocumentPermission | Tags: SyncV1DocumentPermission

stream(client, service_sid, document_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: Retrieve a list of all Permissions applying to a Sync Document. (lazy auto-pagination).

update(client, service_sid, document_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.Document.Permission.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update an identity's access to a specific Sync Document.

Operation: UpdateDocumentPermission | Tags: SyncV1DocumentPermission

Required Parameters

ParameterTypeDescription
ManagebooleanWhether the identity can delete the Sync Document. Default value is false.
ReadbooleanWhether the identity can read the Sync Document. Default value is false.
WritebooleanWhether the identity can update the Sync Document. Default value is false.