Sync Document objects
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateDocument | Tags: SyncV1Document
Operation: DeleteDocument | Tags: SyncV1Document
Operation: FetchDocument | Tags: SyncV1Document
Operation: ListDocument | Tags: SyncV1Document
Stream: (lazy auto-pagination).
Operation: UpdateDocument | Tags: SyncV1Document
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.Document.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateDocument | Tags: SyncV1Document
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Data | string | A JSON string that represents an arbitrary, schema-less object that the Sync Document stores. Can be up to 16 KiB in length. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Ttl | integer | How long, in seconds, before the Sync Document expires and is deleted (the Sync Document's time-to-live). |
UniqueName | string | An application-defined string that uniquely identifies the Sync Document |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteDocument | Tags: SyncV1Document
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.Document.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchDocument | Tags: SyncV1Document
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListDocument | Tags: SyncV1Document
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.Document.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateDocument | Tags: SyncV1Document
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Data | string | A JSON string that represents an arbitrary, schema-less object that the Sync Document stores. Can be up to 16 KiB in length. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Ttl | integer | How long, in seconds, before the Sync Document expires and is deleted (time-to-live). |