Twilio.Sync.V1.Service.List.ItemService (twilio_elixir v0.1.1)

Copy Markdown View Source

Items in a sync list

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateSyncListItem | Tags: SyncV1SyncListItem

Operation: DeleteSyncListItem | Tags: SyncV1SyncListItem

Operation: FetchSyncListItem | Tags: SyncV1SyncListItem

Operation: ListSyncListItem | Tags: SyncV1SyncListItem

Operation: UpdateSyncListItem | Tags: SyncV1SyncListItem

Functions

create(client, service_sid, list_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.List.Item.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateSyncListItem | Tags: SyncV1SyncListItem

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Data | string | A JSON string that represents an arbitrary, schema-less object that the List Item stores. Can be up to 16 KiB in length. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CollectionTtl | integer | How long, in seconds, before the List Item's parent Sync List expires (time-to-live) and is deleted. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ItemTtlintegerHow long, in seconds, before the List Item expires (time-to-live) and is deleted.
TtlintegerAn alias for item_ttl. If both parameters are provided, this value is ignored.

delete(client, service_sid, list_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteSyncListItem | Tags: SyncV1SyncListItem

fetch(client, service_sid, list_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.List.Item.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchSyncListItem | Tags: SyncV1SyncListItem

list(client, service_sid, list_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListSyncListItem | Tags: SyncV1SyncListItem

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

OrderstringHow to order the List Items returned by their index value. Can be: asc (ascending) or desc (descending) and the default is ascending.
FromstringThe index of the first Sync List Item resource to read. See also bounds.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Bounds | string | Whether to include the List Item referenced by the from parameter. Can be: inclusive to include the List Item referenced by the from parameter or exclusive to start with the next List Item. The default value is inclusive. |

stream(client, service_sid, list_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: (lazy auto-pagination).

update(client, service_sid, list_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.List.Item.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateSyncListItem | Tags: SyncV1SyncListItem

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CollectionTtl | integer | How long, in seconds, before the List Item's parent Sync List expires (time-to-live) and is deleted. This parameter can only be used when the List Item's data or ttl is updated in the same request. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Data | string | A JSON string that represents an arbitrary, schema-less object that the List Item stores. Can be up to 16 KiB in length. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ItemTtlintegerHow long, in seconds, before the List Item expires (time-to-live) and is deleted.
TtlintegerAn alias for item_ttl. If both parameters are provided, this value is ignored.