Twilio.Sync.V1.Service.List.PermissionService (twilio_elixir v0.1.1)

Copy Markdown View Source

Permissions for Sync list items

Operations: list, fetch, update, delete

Summary

Functions

Delete a specific Sync List Permission.

Fetch a specific Sync List Permission.

Retrieve a list of all Permissions applying to a Sync List.

Stream: Retrieve a list of all Permissions applying to a Sync List. (lazy auto-pagination).

Update an identity's access to a specific Sync List.

Functions

delete(client, service_sid, list_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Sync List Permission.

Operation: DeleteSyncListPermission | Tags: SyncV1SyncListPermission

fetch(client, service_sid, list_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.List.Permission.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Sync List Permission.

Operation: FetchSyncListPermission | Tags: SyncV1SyncListPermission

list(client, service_sid, list_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Permissions applying to a Sync List.

Operation: ListSyncListPermission | Tags: SyncV1SyncListPermission

stream(client, service_sid, list_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: Retrieve a list of all Permissions applying to a Sync List. (lazy auto-pagination).

update(client, service_sid, list_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.List.Permission.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update an identity's access to a specific Sync List.

Operation: UpdateSyncListPermission | Tags: SyncV1SyncListPermission

Required Parameters

ParameterTypeDescription
ManagebooleanWhether the identity can delete the Sync List. Default value is false.
ReadbooleanWhether the identity can read the Sync List and its Items. Default value is false.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Write | boolean | Whether the identity can create, update, and delete Items in the Sync List. Default value is false. |