Twilio.Sync.V1.Service.Map.ItemService (twilio_elixir v0.1.1)

Copy Markdown View Source

Keys in a sync map

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateSyncMapItem | Tags: SyncV1SyncMapItem

Operation: DeleteSyncMapItem | Tags: SyncV1SyncMapItem

Operation: FetchSyncMapItem | Tags: SyncV1SyncMapItem

Operation: ListSyncMapItem | Tags: SyncV1SyncMapItem

Operation: UpdateSyncMapItem | Tags: SyncV1SyncMapItem

Functions

create(client, service_sid, map_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.Map.Item.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateSyncMapItem | Tags: SyncV1SyncMapItem

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DatastringA JSON string that represents an arbitrary, schema-less object that the Map Item stores. Can be up to 16 KiB in length.
KeystringThe unique, user-defined key for the Map Item. Can be up to 320 characters long.

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CollectionTtl | integer | How long, in seconds, before the Map Item's parent Sync Map expires (time-to-live) and is deleted. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ItemTtlintegerHow long, in seconds, before the Map Item expires (time-to-live) and is deleted.
TtlintegerAn alias for item_ttl. If both parameters are provided, this value is ignored.

delete(client, service_sid, map_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteSyncMapItem | Tags: SyncV1SyncMapItem

fetch(client, service_sid, map_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.Map.Item.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchSyncMapItem | Tags: SyncV1SyncMapItem

list(client, service_sid, map_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListSyncMapItem | Tags: SyncV1SyncMapItem

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

OrderstringHow to order the Map Items returned by their key value. Can be: asc (ascending) or desc (descending) and the default is ascending. Map Items are ordered lexicographically by Item key.
FromstringThe key of the first Sync Map Item resource to read. See also bounds.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Bounds | string | Whether to include the Map Item referenced by the from parameter. Can be: inclusive to include the Map Item referenced by the from parameter or exclusive to start with the next Map Item. The default value is inclusive. |

stream(client, service_sid, map_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: (lazy auto-pagination).

update(client, service_sid, map_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.Map.Item.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateSyncMapItem | Tags: SyncV1SyncMapItem

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CollectionTtl | integer | How long, in seconds, before the Map Item's parent Sync Map expires (time-to-live) and is deleted. This parameter can only be used when the Map Item's data or ttl is updated in the same request. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Data | string | A JSON string that represents an arbitrary, schema-less object that the Map Item stores. Can be up to 16 KiB in length. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ItemTtlintegerHow long, in seconds, before the Map Item expires (time-to-live) and is deleted.
TtlintegerAn alias for item_ttl. If both parameters are provided, this value is ignored.