Service for Permission API operations.
Operations: list, fetch, update, delete
Summary
Functions
Delete a specific Sync Map Permission.
Fetch a specific Sync Map Permission.
Retrieve a list of all Permissions applying to a Sync Map.
Stream: Retrieve a list of all Permissions applying to a Sync Map. (lazy auto-pagination).
Update an identity's access to a specific Sync Map.
Functions
@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Sync Map Permission.
Operation: DeleteSyncMapPermission | Tags: SyncV1SyncMapPermission
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.Map.Permission.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Sync Map Permission.
Operation: FetchSyncMapPermission | Tags: SyncV1SyncMapPermission
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Permissions applying to a Sync Map.
Operation: ListSyncMapPermission | Tags: SyncV1SyncMapPermission
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Permissions applying to a Sync Map. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.Map.Permission.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an identity's access to a specific Sync Map.
Operation: UpdateSyncMapPermission | Tags: SyncV1SyncMapPermission
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Manage | boolean | Whether the identity can delete the Sync Map. Default value is false. |
Read | boolean | Whether the identity can read the Sync Map and its Items. Default value is false. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Write | boolean | Whether the identity can create, update, and delete Items in the Sync Map. Default value is false. |