Twilio.Sync.V1.Service.MapService (twilio_elixir v0.1.1)

Copy Markdown View Source

Sync map objects

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateSyncMap | Tags: SyncV1SyncMap

Operation: DeleteSyncMap | Tags: SyncV1SyncMap

Operation: FetchSyncMap | Tags: SyncV1SyncMap

Operation: ListSyncMap | Tags: SyncV1SyncMap

Operation: UpdateSyncMap | Tags: SyncV1SyncMap

Functions

create(client, service_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.Map.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateSyncMap | Tags: SyncV1SyncMap

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

CollectionTtlintegerHow long, in seconds, before the Sync Map expires (time-to-live) and is deleted.
TtlintegerAn alias for collection_ttl. If both parameters are provided, this value is ignored.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UniqueName | string | An application-defined string that uniquely identifies the resource. It can be used as an alternative to the sid in the URL path to address the resource. |

delete(client, service_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteSyncMap | Tags: SyncV1SyncMap

fetch(client, service_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.Map.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchSyncMap | Tags: SyncV1SyncMap

list(client, service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListSyncMap | Tags: SyncV1SyncMap

stream(client, service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, service_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.Map.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateSyncMap | Tags: SyncV1SyncMap

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

CollectionTtlintegerHow long, in seconds, before the Sync Map expires (time-to-live) and is deleted.
TtlintegerAn alias for collection_ttl. If both parameters are provided, this value is ignored.