Service for Stream API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new Stream.
Delete a specific Stream.
Fetch a specific Stream.
Retrieve a list of all Streams in a Service Instance.
Stream: Retrieve a list of all Streams in a Service Instance. (lazy auto-pagination).
Update a specific Stream.
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.Stream.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Stream.
Operation: CreateSyncStream | Tags: SyncV1SyncStream
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Ttl | integer | How long, in seconds, before the Stream expires and is deleted (time-to-live). |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. This value must be unique within its Service and it can be up to 320 characters long. The unique_name value can be used as an alternative to the sid in the URL path to address the resource. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Stream.
Operation: DeleteSyncStream | Tags: SyncV1SyncStream
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.Stream.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Stream.
Operation: FetchSyncStream | Tags: SyncV1SyncStream
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Streams in a Service Instance.
Operation: ListSyncStream | Tags: SyncV1SyncStream
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Streams in a Service Instance. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.Stream.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a specific Stream.
Operation: UpdateSyncStream | Tags: SyncV1SyncStream
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Ttl | integer | How long, in seconds, before the Stream expires and is deleted (time-to-live). |