Twilio.Sync.V1.ServiceService (twilio_elixir v0.1.1)

Copy Markdown View Source

Containers for sync objects

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateService | Tags: SyncV1Service

Operation: DeleteService | Tags: SyncV1Service

Operation: FetchService | Tags: SyncV1Service

Operation: ListService | Tags: SyncV1Service

Stream: (lazy auto-pagination).

Operation: UpdateService | Tags: SyncV1Service

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateService | Tags: SyncV1Service

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AclEnabledbooleanWhether token identities in the Service must be granted access to Sync objects by using the Permissions resource.
FriendlyNamestringA string that you assign to describe the resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ReachabilityDebouncingEnabled | boolean | Whether every endpoint_disconnected event should occur after a configurable delay. The default is false, where the endpoint_disconnected event occurs immediately after disconnection. When true, intervening reconnections can prevent the endpoint_disconnected event. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ReachabilityDebouncingWindow | integer | The reachability event delay in milliseconds if reachability_debouncing_enabled = true. Must be between 1,000 and 30,000 and defaults to 5,000. This is the number of milliseconds after the last running client disconnects, and a Sync identity is declared offline, before the webhook_url is called if all endpoints remain offline. A reconnection from the same identity by any endpoint during this interval prevents the call to webhook_url. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ReachabilityWebhooksEnabledbooleanWhether the service instance should call webhook_url when client endpoints connect to Sync. The default is false.
WebhookUrlstring (uri)The URL we should call when Sync objects are manipulated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| WebhooksFromRestEnabled | boolean | Whether the Service instance should call webhook_url when the REST API is used to update Sync objects. The default is false. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteService | Tags: SyncV1Service

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchService | Tags: SyncV1Service

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListService | Tags: SyncV1Service

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Sync.V1.Service.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateService | Tags: SyncV1Service

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AclEnabledbooleanWhether token identities in the Service must be granted access to Sync objects by using the Permissions resource.
FriendlyNamestringA string that you assign to describe the resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ReachabilityDebouncingEnabled | boolean | Whether every endpoint_disconnected event should occur after a configurable delay. The default is false, where the endpoint_disconnected event occurs immediately after disconnection. When true, intervening reconnections can prevent the endpoint_disconnected event. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ReachabilityDebouncingWindow | integer | The reachability event delay in milliseconds if reachability_debouncing_enabled = true. Must be between 1,000 and 30,000 and defaults to 5,000. This is the number of milliseconds after the last running client disconnects, and a Sync identity is declared offline, before the webhook is called if all endpoints remain offline. A reconnection from the same identity by any endpoint during this interval prevents the webhook from being called. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

ReachabilityWebhooksEnabledbooleanWhether the service instance should call webhook_url when client endpoints connect to Sync. The default is false.
WebhookUrlstring (uri)The URL we should call when Sync objects are manipulated.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| WebhooksFromRestEnabled | boolean | Whether the Service instance should call webhook_url when the REST API is used to update Sync objects. The default is false. |