Twilio.Taskrouter.V1.Workspace.EventService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Event API operations.

Operations: list, fetch

Summary

Functions

Operation: FetchEvent | Tags: TaskrouterV1Event

Operation: ListEvent | Tags: TaskrouterV1Event

Functions

fetch(client, workspace_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Taskrouter.V1.Workspace.Event.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchEvent | Tags: TaskrouterV1Event

list(client, workspace_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListEvent | Tags: TaskrouterV1Event

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

EndDatestring (date-time)Only include Events that occurred on or before this date, specified in GMT as an ISO 8601 date-time.
EventTypestringThe type of Events to read. Returns only Events of the type specified.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Minutes | integer | The period of events to read in minutes. Returns only Events that occurred since this many minutes in the past. The default is 15 minutes. Task Attributes for Events occuring more 43,200 minutes ago will be redacted. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ReservationSid | string | The SID of the Reservation with the Events to read. Returns only Events that pertain to the specified Reservation. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| StartDate | string (date-time) | Only include Events from on or after this date and time, specified in ISO 8601 format. Task Attributes for Events older than 30 days will be redacted. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| TaskQueueSid | string | The SID of the TaskQueue with the Events to read. Returns only the Events that pertain to the specified TaskQueue. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| TaskSid | string | The SID of the Task with the Events to read. Returns only the Events that pertain to the specified Task. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| WorkerSid | string | The SID of the Worker with the Events to read. Returns only the Events that pertain to the specified Worker. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| WorkflowSid | string | The SID of the Workflow with the Events to read. Returns only the Events that pertain to the specified Workflow. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

TaskChannelstringThe TaskChannel with the Events to read. Returns only the Events that pertain to the specified TaskChannel.
SidstringThe SID of the Event resource to read.

stream(client, workspace_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).