Twilio.Taskrouter.V1.Workspace.TaskQueue.TaskQueueCumulativeStatisticsService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for TaskQueueCumulativeStatistics API operations.

Operations: fetch

Summary

Functions

Operation: FetchTaskQueueCumulativeStatistics | Tags: TaskrouterV1TaskQueueCumulativeStatistics

Functions

fetch(client, workspace_sid, task_queue_sid, opts \\ [])

Operation: FetchTaskQueueCumulativeStatistics | Tags: TaskrouterV1TaskQueueCumulativeStatistics

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

EndDatestring (date-time)Only calculate statistics from this date and time and earlier, specified in GMT as an ISO 8601 date-time.
MinutesintegerOnly calculate statistics since this many minutes in the past. The default is 15 minutes.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| StartDate | string (date-time) | Only calculate statistics from this date and time and later, specified in ISO 8601 format. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| TaskChannel | string | Only calculate cumulative statistics on this TaskChannel. Can be the TaskChannel's SID or its unique_name, such as voice, sms, or default. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| SplitByWaitTime | string | A comma separated list of values that describes the thresholds, in seconds, to calculate statistics on. For each threshold specified, the number of Tasks canceled and reservations accepted above and below the specified thresholds in seconds are computed. TaskRouter will calculate statistics on up to 10,000 Tasks/Reservations for any given threshold. |