Twilio.Taskrouter.V1.Workspace.TaskQueue.TaskQueuesStatisticsService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for TaskQueuesStatistics API operations.

Operations: list

Summary

Functions

Operation: ListTaskQueuesStatistics | Tags: TaskrouterV1TaskQueuesStatistics

Functions

list(client, workspace_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListTaskQueuesStatistics | Tags: TaskrouterV1TaskQueuesStatistics

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

EndDatestring (date-time)Only calculate statistics from this date and time and earlier, specified in GMT as an ISO 8601 date-time.
FriendlyNamestringThe friendly_name of the TaskQueue statistics to read.
MinutesintegerOnly calculate statistics since this many minutes in the past. The default is 15 minutes.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| StartDate | string (date-time) | Only calculate statistics from this date and time and later, specified in ISO 8601 format. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| TaskChannel | string | Only calculate statistics on this TaskChannel. Can be the TaskChannel's SID or its unique_name, such as voice, sms, or default. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| SplitByWaitTime | string | A comma separated list of values that describes the thresholds, in seconds, to calculate statistics on. For each threshold specified, the number of Tasks canceled and reservations accepted above and below the specified thresholds in seconds are computed. |

stream(client, workspace_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).