Twilio.Taskrouter.V1.Workspace.TaskQueueService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for TaskQueue API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateTaskQueue | Tags: TaskrouterV1TaskQueue

Operation: DeleteTaskQueue | Tags: TaskrouterV1TaskQueue

Operation: FetchTaskQueue | Tags: TaskrouterV1TaskQueue

Operation: ListTaskQueue | Tags: TaskrouterV1TaskQueue

Operation: UpdateTaskQueue | Tags: TaskrouterV1TaskQueue

Functions

create(client, workspace_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Taskrouter.V1.Workspace.TaskQueue.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateTaskQueue | Tags: TaskrouterV1TaskQueue

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the TaskQueue. For example Support-Tier 1, Sales, or Escalation. |

Optional Parameters

ParameterTypeDescription
AssignmentActivitySidstringThe SID of the Activity to assign Workers when a task is assigned to them.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

MaxReservedWorkersintegerThe maximum number of Workers to reserve for the assignment of a Task in the queue. Can be an integer between 1 and 50, inclusive and defaults to 1.
ReservationActivitySidstringThe SID of the Activity to assign Workers when a task is reserved for them.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

TargetWorkersstringA string that describes the Worker selection criteria for any Tasks that enter the TaskQueue. For example, '"language" == "spanish"'. The default value is 1==1. If this value is empty, Tasks will wait in the TaskQueue until they are deleted or moved to another TaskQueue. For more information about Worker selection, see Describing Worker selection criteria.
TaskOrderstringValues: FIFO, LIFO

delete(client, workspace_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteTaskQueue | Tags: TaskrouterV1TaskQueue

fetch(client, workspace_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Taskrouter.V1.Workspace.TaskQueue.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchTaskQueue | Tags: TaskrouterV1TaskQueue

list(client, workspace_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListTaskQueue | Tags: TaskrouterV1TaskQueue

Query Parameters

ParameterTypeDescription
FriendlyNamestringThe friendly_name of the TaskQueue resources to read.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

EvaluateWorkerAttributesstringThe attributes of the Workers to read. Returns the TaskQueues with Workers that match the attributes specified in this parameter.
WorkerSidstringThe SID of the Worker with the TaskQueue resources to read.
OrderingstringSorting parameter for TaskQueues

stream(client, workspace_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, workspace_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Taskrouter.V1.Workspace.TaskQueue.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateTaskQueue | Tags: TaskrouterV1TaskQueue

Optional Parameters

ParameterTypeDescription
AssignmentActivitySidstringThe SID of the Activity to assign Workers when a task is assigned for them.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the TaskQueue. For example Support-Tier 1, Sales, or Escalation. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

MaxReservedWorkersintegerThe maximum number of Workers to create reservations for the assignment of a task while in the queue. Maximum of 50.
ReservationActivitySidstringThe SID of the Activity to assign Workers when a task is reserved for them.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

TargetWorkersstringA string describing the Worker selection criteria for any Tasks that enter the TaskQueue. For example '"language" == "spanish"' If no TargetWorkers parameter is provided, Tasks will wait in the queue until they are either deleted or moved to another queue. Additional examples on how to describing Worker selection criteria below.
TaskOrderstringValues: FIFO, LIFO