Twilio.Taskrouter.V1.Workspace.Worker.ChannelService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Channel API operations.

Operations: list, fetch, update

Summary

Functions

Operation: FetchWorkerChannel | Tags: TaskrouterV1WorkerChannel

Operation: ListWorkerChannel | Tags: TaskrouterV1WorkerChannel

Operation: UpdateWorkerChannel | Tags: TaskrouterV1WorkerChannel

Functions

fetch(client, workspace_sid, worker_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Taskrouter.V1.Workspace.Worker.Channel.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchWorkerChannel | Tags: TaskrouterV1WorkerChannel

list(client, workspace_sid, worker_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListWorkerChannel | Tags: TaskrouterV1WorkerChannel

stream(client, workspace_sid, worker_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: (lazy auto-pagination).

update(client, workspace_sid, worker_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Taskrouter.V1.Workspace.Worker.Channel.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateWorkerChannel | Tags: TaskrouterV1WorkerChannel

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Available | boolean | Whether the WorkerChannel is available. Set to false to prevent the Worker from receiving any new Tasks of this TaskChannel type. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Capacity | integer | The total number of Tasks that the Worker should handle for the TaskChannel type. TaskRouter creates reservations for Tasks of this TaskChannel type up to the specified capacity. If the capacity is 0, no new reservations will be created. |