Twilio.Taskrouter.V1.Workspace.Worker.WorkerStatisticsService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for WorkerStatistics API operations.

Operations: fetch

Summary

Functions

Operation: FetchWorkerInstanceStatistics | Tags: TaskrouterV1WorkerStatistics

Functions

fetch(client, workspace_sid, worker_sid, opts \\ [])

Operation: FetchWorkerInstanceStatistics | Tags: TaskrouterV1WorkerStatistics

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Minutes | integer | Only calculate statistics since this many minutes in the past. The default 15 minutes. This is helpful for displaying statistics for the last 15 minutes, 240 minutes (4 hours), and 480 minutes (8 hours) to see trends. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| StartDate | string (date-time) | Only calculate statistics from this date and time and later, specified in ISO 8601 format. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| EndDate | string (date-time) | Only include usage that occurred on or before this date, specified in GMT as an ISO 8601 date-time. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| TaskChannel | string | Only calculate statistics on this TaskChannel. Can be the TaskChannel's SID or its unique_name, such as voice, sms, or default. |