Twilio.Trunking.V1.Trunk.CredentialListService (twilio_elixir v0.1.1)

Copy Markdown View Source

List of credentials for accessing a trunk

Operations: list, create, fetch, delete

Summary

Functions

Operation: CreateCredentialList | Tags: TrunkingV1CredentialList

Operation: DeleteCredentialList | Tags: TrunkingV1CredentialList

Operation: FetchCredentialList | Tags: TrunkingV1CredentialList

Operation: ListCredentialList | Tags: TrunkingV1CredentialList

Functions

create(client, trunk_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Trunking.V1.Trunk.CredentialList.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateCredentialList | Tags: TrunkingV1CredentialList

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CredentialListSid | string | The SID of the Credential List that you want to associate with the trunk. Once associated, we will authenticate access to the trunk against this list. |

delete(client, trunk_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteCredentialList | Tags: TrunkingV1CredentialList

fetch(client, trunk_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Trunking.V1.Trunk.CredentialList.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchCredentialList | Tags: TrunkingV1CredentialList

list(client, trunk_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListCredentialList | Tags: TrunkingV1CredentialList

stream(client, trunk_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).