Twilio.Trunking.V1.TrunkService (twilio_elixir v0.1.1)

Copy Markdown View Source

Represents a SIP trunk

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateTrunk | Tags: TrunkingV1Trunk

Operation: DeleteTrunk | Tags: TrunkingV1Trunk

Operation: FetchTrunk | Tags: TrunkingV1Trunk

Operation: ListTrunk | Tags: TrunkingV1Trunk

Stream: (lazy auto-pagination).

Operation: UpdateTrunk | Tags: TrunkingV1Trunk

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Trunking.V1.Trunk.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateTrunk | Tags: TrunkingV1Trunk

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CnamLookupEnabled | boolean | Whether Caller ID Name (CNAM) lookup should be enabled for the trunk. If enabled, all inbound calls to the SIP Trunk from the United States and Canada automatically perform a CNAM Lookup and display Caller ID data on your phone. See CNAM Lookups for more information. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DisasterRecoveryMethod | string (http-method) | The HTTP method we should use to call the disaster_recovery_url. Can be: GET or POST. Values: GET, POST |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DisasterRecoveryUrl | string (uri) | The URL we should call using the disaster_recovery_method if an error occurs while sending SIP traffic towards the configured Origination URL. We retrieve TwiML from the URL and execute the instructions like any other normal TwiML call. See Disaster Recovery for more information. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DomainName | string | The unique address you reserve on Twilio to which you route your SIP traffic. Domain names can contain letters, digits, and - and must end with pstn.twilio.com. See Termination Settings for more information. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

SecurebooleanWhether Secure Trunking is enabled for the trunk. If enabled, all calls going through the trunk will be secure using SRTP for media and TLS for signaling. If disabled, then RTP will be used for media. See Secure Trunking for more information.
TransferCallerIdstringValues: from-transferee, from-transferor
TransferModestringValues: disable-all, enable-all, sip-only

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteTrunk | Tags: TrunkingV1Trunk

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Trunking.V1.Trunk.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchTrunk | Tags: TrunkingV1Trunk

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListTrunk | Tags: TrunkingV1Trunk

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Trunking.V1.Trunk.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateTrunk | Tags: TrunkingV1Trunk

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CnamLookupEnabled | boolean | Whether Caller ID Name (CNAM) lookup should be enabled for the trunk. If enabled, all inbound calls to the SIP Trunk from the United States and Canada automatically perform a CNAM Lookup and display Caller ID data on your phone. See CNAM Lookups for more information. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DisasterRecoveryMethod | string (http-method) | The HTTP method we should use to call the disaster_recovery_url. Can be: GET or POST. Values: GET, POST |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DisasterRecoveryUrl | string (uri) | The URL we should call using the disaster_recovery_method if an error occurs while sending SIP traffic towards the configured Origination URL. We retrieve TwiML from the URL and execute the instructions like any other normal TwiML call. See Disaster Recovery for more information. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DomainName | string | The unique address you reserve on Twilio to which you route your SIP traffic. Domain names can contain letters, digits, and - and must end with pstn.twilio.com. See Termination Settings for more information. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

SecurebooleanWhether Secure Trunking is enabled for the trunk. If enabled, all calls going through the trunk will be secure using SRTP for media and TLS for signaling. If disabled, then RTP will be used for media. See Secure Trunking for more information.
TransferCallerIdstringValues: from-transferee, from-transferor
TransferModestringValues: disable-all, enable-all, sip-only