Twilio.Trusthub.V1.ComplianceInquiry.Customer.ComplianceInquiriesService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for ComplianceInquiries API operations.

Operations: update

Summary

Functions

Resume a specific Compliance Inquiry that has expired, or re-open a rejected Compliance Inquiry for editing.

Functions

update(client, customer_id, params \\ %{}, opts \\ [])

Resume a specific Compliance Inquiry that has expired, or re-open a rejected Compliance Inquiry for editing.

Operation: UpdateComplianceInquiry | Tags: TrusthubV1ComplianceInquiries

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| PrimaryProfileSid | string | The unique SID identifier of the Primary Customer Profile that should be used as a parent. Only necessary when creating a secondary Customer Profile. |

Optional Parameters

ParameterTypeDescription
ThemeSetIdstringTheme id for styling the inquiry form.