Twilio.Trusthub.V1.ComplianceInquiry.Tollfree.ComplianceTollfreeInquiriesService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for ComplianceTollfreeInquiries API operations.

Operations: create

Summary

Functions

create(client, params \\ %{}, opts \\ [])

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Create a new Compliance Tollfree Verification Inquiry for the authenticated account. This is necessary to start a new embedded session.

Operation: CreateComplianceTollfreeInquiry | Tags: TrusthubV1ComplianceTollfreeInquiries

Required Parameters

ParameterTypeDescription
NotificationEmailstringThe email address to receive the notification about the verification result.
TollfreePhoneNumberstring (phone-number)The Tollfree phone number to be verified

Optional Parameters

ParameterTypeDescription
AdditionalInformationstringAdditional information to be provided for verification.
AgeGatedContentbooleanIndicates if the content is age gated.
BusinessCitystringThe city of the business or organization using the Tollfree number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BusinessContactEmail | string | The email address of the contact for the business or organization using the Tollfree number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BusinessContactFirstName | string | The first name of the contact for the business or organization using the Tollfree number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| BusinessContactLastName | string | The last name of the contact for the business or organization using the Tollfree number. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

BusinessContactPhonestring (phone-number)The phone number of the contact for the business or organization using the Tollfree number.
BusinessCountrystringThe country of the business or organization using the Tollfree number.
BusinessNamestringThe name of the business or organization using the Tollfree number.
BusinessPostalCodestringThe postal code of the business or organization using the Tollfree number.
BusinessRegistrationAuthoritystringThe Business Registration Authority of the business or organization.
BusinessRegistrationCountrystringThe Business Registration Country of the business or organization.
BusinessRegistrationNumberstringThe Business Registration Number of the business or organization.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

BusinessStateProvinceRegionstringThe state/province/region of the business or organization using the Tollfree number.
BusinessStreetAddressstringThe address of the business or organization using the Tollfree number.
BusinessStreetAddress2stringThe address of the business or organization using the Tollfree number.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

BusinessTypestringValues: PRIVATE_PROFIT, PUBLIC_PROFIT, NON_PROFIT, SOLE_PROPRIETOR, GOVERNMENT
BusinessWebsitestringThe website of the business or organization using the Tollfree number.
CustomerProfileSidstringThe Customer Profile Sid associated with the Account.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DoingBusinessAsstringTrade name, sub entity, or downstream business name of business being submitted for verification.
ExternalReferenceIdstringA legally recognized business registration number.
HelpMessageSamplestringA sample help message provided to users.
MessageVolumestringEstimate monthly volume of messages from the Tollfree Number.
OptInConfirmationMessagestringThe confirmation message sent to users when they opt in to receive messages.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

OptInImageUrlsarrayLink to an image that shows the opt-in workflow. Multiple images allowed and must be a publicly hosted URL.
OptInKeywordsarrayList of keywords that users can text in to opt in to receive messages.
OptInTypestringValues: VERBAL, WEB_FORM, PAPER_FORM, VIA_TEXT, MOBILE_QR_CODE
PrivacyPolicyUrlstringThe URL to the privacy policy for the business or organization.
ProductionMessageSamplestringAn example of message content, i.e. a sample message.
SkipMessagingUseCasebooleanSkip the messaging use case screen of the inquiry form.
TermsAndConditionsUrlstringThe URL to the terms and conditions for the business or organization.
ThemeSetIdstringTheme id for styling the inquiry form.
UseCaseCategoriesarrayThe category of the use case for the Tollfree Number. List as many are applicable..
UseCaseSummarystringUse this to further explain how messaging is used by the business or organization.
VettingIdstringUnique identifier for the created Vetting .
VettingProviderstringName of the vetting provider.