Twilio.Trusthub.V1.CustomerProfile.CustomerProfilesEntityAssignmentsService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for CustomerProfilesEntityAssignments API operations.

Operations: list, create, fetch, delete

Summary

Functions

Remove an Assignment Item Instance.

Fetch specific Assigned Item Instance.

Retrieve a list of all Assigned Items for an account.

Stream: Retrieve a list of all Assigned Items for an account. (lazy auto-pagination).

Functions

create(client, customer_profile_sid, params \\ %{}, opts \\ [])

Create a new Assigned Item.

Operation: CreateCustomerProfileEntityAssignment | Tags: TrusthubV1CustomerProfilesEntityAssignments

Required Parameters

ParameterTypeDescription
ObjectSidstringThe SID of an object bag that holds information of the different items.

delete(client, customer_profile_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Remove an Assignment Item Instance.

Operation: DeleteCustomerProfileEntityAssignment | Tags: TrusthubV1CustomerProfilesEntityAssignments

fetch(client, customer_profile_sid, sid, opts \\ [])

Fetch specific Assigned Item Instance.

Operation: FetchCustomerProfileEntityAssignment | Tags: TrusthubV1CustomerProfilesEntityAssignments

list(client, customer_profile_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Assigned Items for an account.

Operation: ListCustomerProfileEntityAssignment | Tags: TrusthubV1CustomerProfilesEntityAssignments

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| ObjectType | string | A string to filter the results by (EndUserType or SupportingDocumentType) machine-name. This is useful when you want to retrieve the entity-assignment of a specific end-user or supporting document. |

stream(client, customer_profile_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Assigned Items for an account. (lazy auto-pagination).