Twilio.Trusthub.V1.CustomerProfile.CustomerProfilesEvaluationsService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for CustomerProfilesEvaluations API operations.

Operations: list, create, fetch

Summary

Functions

Fetch specific Evaluation Instance.

Retrieve a list of Evaluations associated to the customer_profile resource.

Stream: Retrieve a list of Evaluations associated to the customer_profile resource. (lazy auto-pagination).

Functions

create(client, customer_profile_sid, params \\ %{}, opts \\ [])

Create a new Evaluation

Operation: CreateCustomerProfileEvaluation | Tags: TrusthubV1CustomerProfilesEvaluations

Required Parameters

ParameterTypeDescription
PolicySidstringThe unique string of a policy that is associated to the customer_profile resource.

fetch(client, customer_profile_sid, sid, opts \\ [])

Fetch specific Evaluation Instance.

Operation: FetchCustomerProfileEvaluation | Tags: TrusthubV1CustomerProfilesEvaluations

list(client, customer_profile_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of Evaluations associated to the customer_profile resource.

Operation: ListCustomerProfileEvaluation | Tags: TrusthubV1CustomerProfilesEvaluations

stream(client, customer_profile_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of Evaluations associated to the customer_profile resource. (lazy auto-pagination).