Twilio.Trusthub.V1.CustomerProfilesService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for CustomerProfiles API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new Customer-Profile.

Delete a specific Customer-Profile.

Fetch a specific Customer-Profile instance.

Retrieve a list of all Customer-Profiles for an account.

Stream: Retrieve a list of all Customer-Profiles for an account. (lazy auto-pagination).

Updates a Customer-Profile in an account.

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.CustomerProfiles.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Customer-Profile.

Operation: CreateCustomerProfile | Tags: TrusthubV1CustomerProfiles

Required Parameters

ParameterTypeDescription
EmailstringThe email address that will receive updates when the Customer-Profile resource changes status.
FriendlyNamestringThe string that you assigned to describe the resource.
PolicySidstringThe unique string of a policy that is associated to the Customer-Profile resource.

Optional Parameters

ParameterTypeDescription
StatusCallbackstring (uri)The URL we call to inform your application of status changes.

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Customer-Profile.

Operation: DeleteCustomerProfile | Tags: TrusthubV1CustomerProfiles

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.CustomerProfiles.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Customer-Profile instance.

Operation: FetchCustomerProfile | Tags: TrusthubV1CustomerProfiles

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Customer-Profiles for an account.

Operation: ListCustomerProfile | Tags: TrusthubV1CustomerProfiles

Query Parameters

ParameterTypeDescription
StatusstringThe verification status of the Customer-Profile resource.
FriendlyNamestringThe string that you assigned to describe the resource.
PolicySidstringThe unique string of a policy that is associated to the Customer-Profile resource.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Customer-Profiles for an account. (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.CustomerProfiles.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Updates a Customer-Profile in an account.

Operation: UpdateCustomerProfile | Tags: TrusthubV1CustomerProfiles

Optional Parameters

ParameterTypeDescription
EmailstringThe email address that will receive updates when the Customer-Profile resource changes status.
FriendlyNamestringThe string that you assigned to describe the resource.
StatusstringValues: draft, pending-review, in-review, twilio-rejected, twilio-approved
StatusCallbackstring (uri)The URL we call to inform your application of status changes.