Twilio.Trusthub.V1.EndUserService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for EndUser API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

Delete a specific End User.

Fetch specific End User Instance.

Retrieve a list of all End User for an account.

Stream: Retrieve a list of all End User for an account. (lazy auto-pagination).

Update an existing End User.

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.EndUser.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new End User.

Operation: CreateEndUser | Tags: TrusthubV1EndUser

Required Parameters

ParameterTypeDescription
FriendlyNamestringThe string that you assigned to describe the resource.
TypestringThe type of end user of the Bundle resource - can be individual or business.

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Attributes | string | The set of parameters that are the attributes of the End User resource which are derived End User Types. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific End User.

Operation: DeleteEndUser | Tags: TrusthubV1EndUser

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.EndUser.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch specific End User Instance.

Operation: FetchEndUser | Tags: TrusthubV1EndUser

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all End User for an account.

Operation: ListEndUser | Tags: TrusthubV1EndUser

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all End User for an account. (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.EndUser.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update an existing End User.

Operation: UpdateEndUser | Tags: TrusthubV1EndUser

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AttributesstringThe set of parameters that are the attributes of the End User resource which are derived End User Types.
FriendlyNamestringThe string that you assigned to describe the resource.