Twilio.Trusthub.V1.SupportingDocumentService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for SupportingDocument API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new Supporting Document.

Delete a specific Supporting Document.

Fetch specific Supporting Document Instance.

Retrieve a list of all Supporting Document for an account.

Stream: Retrieve a list of all Supporting Document for an account. (lazy auto-pagination).

Update an existing Supporting Document.

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.SupportingDocument.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Supporting Document.

Operation: CreateSupportingDocument | Tags: TrusthubV1SupportingDocument

Required Parameters

ParameterTypeDescription
FriendlyNamestringThe string that you assigned to describe the resource.
TypestringThe type of the Supporting Document.

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Attributes | string | The set of parameters that are the attributes of the Supporting Documents resource which are derived Supporting Document Types. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Supporting Document.

Operation: DeleteSupportingDocument | Tags: TrusthubV1SupportingDocument

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.SupportingDocument.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch specific Supporting Document Instance.

Operation: FetchSupportingDocument | Tags: TrusthubV1SupportingDocument

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Supporting Document for an account.

Operation: ListSupportingDocument | Tags: TrusthubV1SupportingDocument

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Supporting Document for an account. (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.SupportingDocument.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update an existing Supporting Document.

Operation: UpdateSupportingDocument | Tags: TrusthubV1SupportingDocument

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

AttributesstringThe set of parameters that are the attributes of the Supporting Document resource which are derived Supporting Document Types.
FriendlyNamestringThe string that you assigned to describe the resource.