Twilio.Trusthub.V1.TrustProduct.ChannelEndpointAssignmentService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for ChannelEndpointAssignment API operations.

Operations: list, create, fetch, delete

Summary

Functions

Remove an Assignment Item Instance.

Fetch specific Assigned Item Instance.

Retrieve a list of all Assigned Items for an account.

Stream: Retrieve a list of all Assigned Items for an account. (lazy auto-pagination).

Functions

create(client, trust_product_sid, params \\ %{}, opts \\ [])

Create a new Assigned Item.

Operation: CreateTrustProductChannelEndpointAssignment | Tags: TrusthubV1TrustProductsChannelEndpointAssignment

Required Parameters

ParameterTypeDescription
ChannelEndpointSidstringThe SID of an channel endpoint
ChannelEndpointTypestringThe type of channel endpoint. eg: phone-number

delete(client, trust_product_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Remove an Assignment Item Instance.

Operation: DeleteTrustProductChannelEndpointAssignment | Tags: TrusthubV1TrustProductsChannelEndpointAssignment

fetch(client, trust_product_sid, sid, opts \\ [])

Fetch specific Assigned Item Instance.

Operation: FetchTrustProductChannelEndpointAssignment | Tags: TrusthubV1TrustProductsChannelEndpointAssignment

list(client, trust_product_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Assigned Items for an account.

Operation: ListTrustProductChannelEndpointAssignment | Tags: TrusthubV1TrustProductsChannelEndpointAssignment

Query Parameters

ParameterTypeDescription
ChannelEndpointSidstringThe SID of an channel endpoint
ChannelEndpointSidsstringcomma separated list of channel endpoint sids

stream(client, trust_product_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Assigned Items for an account. (lazy auto-pagination).