Twilio.Trusthub.V1.TrustProduct.TrustProductsEvaluationsService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for TrustProductsEvaluations API operations.

Operations: list, create, fetch

Summary

Functions

Fetch specific Evaluation Instance.

Retrieve a list of Evaluations associated to the trust_product resource.

Stream: Retrieve a list of Evaluations associated to the trust_product resource. (lazy auto-pagination).

Functions

create(client, trust_product_sid, params \\ %{}, opts \\ [])

Create a new Evaluation

Operation: CreateTrustProductEvaluation | Tags: TrusthubV1TrustProductsEvaluations

Required Parameters

ParameterTypeDescription
PolicySidstringThe unique string of a policy that is associated to the customer_profile resource.

fetch(client, trust_product_sid, sid, opts \\ [])

Fetch specific Evaluation Instance.

Operation: FetchTrustProductEvaluation | Tags: TrusthubV1TrustProductsEvaluations

list(client, trust_product_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of Evaluations associated to the trust_product resource.

Operation: ListTrustProductEvaluation | Tags: TrusthubV1TrustProductsEvaluations

stream(client, trust_product_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of Evaluations associated to the trust_product resource. (lazy auto-pagination).