Twilio.Trusthub.V1.TrustProductsService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for TrustProducts API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new Trust Product.

Delete a specific Trust Product.

Fetch a specific Trust Product instance.

Retrieve a list of all Trust Products for an account.

Stream: Retrieve a list of all Trust Products for an account. (lazy auto-pagination).

Updates a Trust Product in an account.

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.TrustProducts.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Trust Product.

Operation: CreateTrustProduct | Tags: TrusthubV1TrustProducts

Required Parameters

ParameterTypeDescription
EmailstringThe email address that will receive updates when the Trust Product resource changes status.
FriendlyNamestringThe string that you assigned to describe the resource.
PolicySidstringThe unique string of a policy that is associated to the Trust Product resource.

Optional Parameters

ParameterTypeDescription
StatusCallbackstring (uri)The URL we call to inform your application of status changes.

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Trust Product.

Operation: DeleteTrustProduct | Tags: TrusthubV1TrustProducts

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.TrustProducts.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Trust Product instance.

Operation: FetchTrustProduct | Tags: TrusthubV1TrustProducts

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Trust Products for an account.

Operation: ListTrustProduct | Tags: TrusthubV1TrustProducts

Query Parameters

ParameterTypeDescription
StatusstringThe verification status of the Trust Product resource.
FriendlyNamestringThe string that you assigned to describe the resource.
PolicySidstringThe unique string of a policy that is associated to the Trust Product resource.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Trust Products for an account. (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Trusthub.V1.TrustProducts.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Updates a Trust Product in an account.

Operation: UpdateTrustProduct | Tags: TrusthubV1TrustProducts

Optional Parameters

ParameterTypeDescription
EmailstringThe email address that will receive updates when the Trust Product resource changes status.
FriendlyNamestringThe string that you assigned to describe the resource.
StatusstringValues: draft, pending-review, in-review, twilio-rejected, twilio-approved
StatusCallbackstring (uri)The URL we call to inform your application of status changes.