Twilio.Verify.V2.AttemptService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Attempt API operations.

Operations: list, fetch

Summary

Functions

Fetch a specific verification attempt.

List all the verification attempts for a given Account.

Stream: List all the verification attempts for a given Account. (lazy auto-pagination).

Functions

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Attempt.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific verification attempt.

Operation: FetchVerificationAttempt | Tags: VerifyV2VerificationAttempt

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

List all the verification attempts for a given Account.

Operation: ListVerificationAttempt | Tags: VerifyV2VerificationAttempt

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreatedAfter | string (date-time) | Datetime filter used to consider only Verification Attempts created after this datetime on the summary aggregation. Given as GMT in ISO 8601 formatted datetime string: yyyy-MM-dd'T'HH:mm:ss'Z. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DateCreatedBeforestring (date-time)Datetime filter used to consider only Verification Attempts created before this datetime on the summary aggregation. Given as GMT in ISO 8601 formatted datetime string: yyyy-MM-dd'T'HH:mm:ss'Z.
ChannelData.TostringDestination of a verification. It is phone number in E.164 format.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Countrystring (iso-country-code)Filter used to query Verification Attempts sent to the specified destination country.
ChannelstringFilter used to query Verification Attempts by communication channel.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| VerifyServiceSid | string | Filter used to query Verification Attempts by verify service. Only attempts of the provided SID will be returned. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| VerificationSid | string | Filter used to return all the Verification Attempts of a single verification. Only attempts of the provided verification SID will be returned. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Status | string | Filter used to query Verification Attempts by conversion status. Valid values are UNCONVERTED, for attempts that were not converted, and CONVERTED, for attempts that were confirmed. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: List all the verification attempts for a given Account. (lazy auto-pagination).