Twilio.Verify.V2.Service.AccessTokenService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for AccessToken API operations.

Operations: create, fetch

Summary

Functions

Create a new enrollment Access Token for the Entity

Fetch an Access Token for the Entity

Functions

create(client, service_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.AccessToken.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new enrollment Access Token for the Entity

Operation: CreateAccessToken | Tags: VerifyV2AccessToken

Required Parameters

ParameterTypeDescription
FactorTypestringValues: push

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | string | The unique external identifier for the Entity of the Service. This identifier should be immutable, not PII, and generated by your external system, such as your user's UUID, GUID, or SID. |

Optional Parameters

ParameterTypeDescription
FactorFriendlyNamestringThe friendly name of the factor that is going to be created with this access token

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Ttl | integer | How long, in seconds, the access token is valid. Can be an integer between 60 and 300. Default is 60. |

fetch(client, service_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.AccessToken.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch an Access Token for the Entity

Operation: FetchAccessToken | Tags: VerifyV2AccessToken