Twilio.Verify.V2.Service.Entity.Challenge.NotificationService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Notification API operations.

Operations: create

Summary

Functions

Create a new Notification for the corresponding Challenge

Functions

create(client, service_sid, identity, challenge_sid, params \\ %{}, opts \\ [])

Create a new Notification for the corresponding Challenge

Operation: CreateNotification | Tags: VerifyV2Notification

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Ttl | integer | How long, in seconds, the notification is valid. Can be an integer between 0 and 300. Default is 300. Delivery is attempted until the TTL elapses, even if the device is offline. 0 means that the notification delivery is attempted immediately, only once, and is not stored for future delivery. |