Twilio.Verify.V2.Service.EntityService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Entity API operations.

Operations: list, create, fetch, delete

Summary

Functions

Create a new Entity for the Service

Retrieve a list of all Entities for a Service.

Stream: Retrieve a list of all Entities for a Service. (lazy auto-pagination).

Functions

create(client, service_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.Entity.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Entity for the Service

Operation: CreateEntity | Tags: VerifyV2Entity

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Identity | string | The unique external identifier for the Entity of the Service. This identifier should be immutable, not PII, length between 8 and 64 characters, and generated by your external system, such as your user's UUID, GUID, or SID. It can only contain dash (-) separated alphanumeric characters. |

delete(client, service_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Entity.

Operation: DeleteEntity | Tags: VerifyV2Entity

fetch(client, service_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.Entity.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Entity.

Operation: FetchEntity | Tags: VerifyV2Entity

list(client, service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Entities for a Service.

Operation: ListEntity | Tags: VerifyV2Entity

stream(client, service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Entities for a Service. (lazy auto-pagination).