Twilio.Verify.V2.Service.Passkey.VerifyFactorService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for VerifyFactor API operations.

Operations: create

Summary

Functions

create(client, service_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Verify a Passkeys Factor

Operation: UpdatePasskeysFactor

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| response | object | The result of a WebAuthn credential registration via navigator.credentials.create(), as specified in AuthenticatorAttestationResponse. |

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

authenticatorAttachmentstringA string that indicates the mechanism by which the WebAuthn implementation is attached to the authenticator at the time the associated navigator.credentials.create() or navigator.credentials.get() call completes. Values: platform, cross-platform
idstringA base64url encoded representation of rawId.
rawIdstringThe globally unique identifier for this PublicKeyCredential.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| type | string | The valid credential types supported by the API. The values of this enumeration are used for versioning the AuthenticatorAssertion and AuthenticatorAttestation structures according to the type of the authenticator. Values: public-key |