Twilio.Verify.V2.Service.RateLimit.BucketService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Bucket API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

create(client, service_sid, rate_limit_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.Bucket.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Bucket for a Rate Limit

Operation: CreateBucket | Tags: VerifyV2Bucket

Required Parameters

ParameterTypeDescription
IntervalintegerNumber of seconds that the rate limit will be enforced over.
MaxintegerMaximum number of requests permitted in during the interval.

delete(client, service_sid, rate_limit_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Bucket.

Operation: DeleteBucket | Tags: VerifyV2Bucket

fetch(client, service_sid, rate_limit_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.Bucket.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Bucket.

Operation: FetchBucket | Tags: VerifyV2Bucket

list(client, service_sid, rate_limit_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Buckets for a Rate Limit.

Operation: ListBucket | Tags: VerifyV2Bucket

stream(client, service_sid, rate_limit_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: Retrieve a list of all Buckets for a Rate Limit. (lazy auto-pagination).

update(client, service_sid, rate_limit_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.Bucket.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update a specific Bucket.

Operation: UpdateBucket | Tags: VerifyV2Bucket

Optional Parameters

ParameterTypeDescription
IntervalintegerNumber of seconds that the rate limit will be enforced over.
MaxintegerMaximum number of requests permitted in during the interval.