Twilio.Verify.V2.Service.RateLimitService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for RateLimit API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new Rate Limit for a Service

Delete a specific Rate Limit.

Fetch a specific Rate Limit.

Retrieve a list of all Rate Limits for a service.

Stream: Retrieve a list of all Rate Limits for a service. (lazy auto-pagination).

Functions

create(client, service_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Rate Limit for a Service

Operation: CreateRateLimit | Tags: VerifyV2RateLimit

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UniqueName | string | Provides a unique and addressable name to be assigned to this Rate Limit, assigned by the developer, to be optionally used in addition to SID. This value should not contain PII. |

Optional Parameters

ParameterTypeDescription
DescriptionstringDescription of this Rate Limit

delete(client, service_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Rate Limit.

Operation: DeleteRateLimit | Tags: VerifyV2RateLimit

fetch(client, service_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Rate Limit.

Operation: FetchRateLimit | Tags: VerifyV2RateLimit

list(client, service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Rate Limits for a service.

Operation: ListRateLimit | Tags: VerifyV2RateLimit

stream(client, service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Rate Limits for a service. (lazy auto-pagination).

update(client, service_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update a specific Rate Limit.

Operation: UpdateRateLimit | Tags: VerifyV2RateLimit

Optional Parameters

ParameterTypeDescription
DescriptionstringDescription of this Rate Limit