Twilio.Verify.V2.Service.WebhookService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Webhook API operations.

Operations: list, create, fetch, update, delete

Summary

Functions

Create a new Webhook for the Service

Retrieve a list of all Webhooks for a Service.

Stream: Retrieve a list of all Webhooks for a Service. (lazy auto-pagination).

Operation: UpdateWebhook | Tags: VerifyV2Webhook

Functions

create(client, service_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.Webhook.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Create a new Webhook for the Service

Operation: CreateWebhook | Tags: VerifyV2Webhook

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| EventTypes | array | The array of events that this Webhook is subscribed to. Possible event types: *, factor.deleted, factor.created, factor.verified, challenge.approved, challenge.denied |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

FriendlyNamestringThe string that you assigned to describe the webhook. This value should not contain PII.
WebhookUrlstringThe URL associated with this Webhook.

Optional Parameters

ParameterTypeDescription
StatusstringValues: enabled, disabled
VersionstringValues: v1, v2

delete(client, service_sid, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a specific Webhook.

Operation: DeleteWebhook | Tags: VerifyV2Webhook

fetch(client, service_sid, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.Webhook.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Fetch a specific Webhook.

Operation: FetchWebhook | Tags: VerifyV2Webhook

list(client, service_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Retrieve a list of all Webhooks for a Service.

Operation: ListWebhook | Tags: VerifyV2Webhook

stream(client, service_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Retrieve a list of all Webhooks for a Service. (lazy auto-pagination).

update(client, service_sid, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Verify.V2.Service.Webhook.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateWebhook | Tags: VerifyV2Webhook

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| EventTypes | array | The array of events that this Webhook is subscribed to. Possible event types: *, factor.deleted, factor.created, factor.verified, challenge.approved, challenge.denied |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

FriendlyNamestringThe string that you assigned to describe the webhook. This value should not contain PII.
StatusstringValues: enabled, disabled
VersionstringValues: v1, v2
WebhookUrlstringThe URL associated with this Webhook.