Twilio.Verify.V2.TemplateService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Template API operations.

Operations: list

Summary

Functions

List all the available templates for a given Account.

Stream: List all the available templates for a given Account. (lazy auto-pagination).

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

List all the available templates for a given Account.

Operation: ListVerificationTemplate | Tags: VerifyV2Template

Query Parameters

ParameterTypeDescription
FriendlyNamestringString filter used to query templates with a given friendly name.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: List all the available templates for a given Account. (lazy auto-pagination).