Twilio.Video.V1.CompositionSetting.CompositionSettingsService (twilio_elixir v0.1.1)

Copy Markdown View Source

Recording composition settings

Operations: fetch, update

Summary

Functions

Operation: FetchCompositionSettings | Tags: VideoV1CompositionSettings

Operation: CreateCompositionSettings | Tags: VideoV1CompositionSettings

Functions

fetch(client, opts \\ [])

@spec fetch(
  Twilio.Client.t(),
  keyword()
) ::
  {:ok, Twilio.Resources.Video.V1.CompositionSetting.CompositionSettings.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchCompositionSettings | Tags: VideoV1CompositionSettings

update(client, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Video.V1.CompositionSetting.CompositionSettings.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateCompositionSettings | Tags: VideoV1CompositionSettings

Required Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource and show to the user in the console |

Optional Parameters

ParameterTypeDescription
AwsCredentialsSidstringThe SID of the stored Credential resource.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AwsS3Url | string (uri) | The URL of the AWS S3 bucket where the compositions should be stored. We only support DNS-compliant URLs like https://documentation-example-twilio-bucket/compositions, where compositions is the path in which you want the compositions to be stored. This URL accepts only URI-valid characters, as described in the RFC 3986. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AwsStorageEnabled | boolean | Whether all compositions should be written to the aws_s3_url. When false, all compositions are stored in our cloud. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

EncryptionEnabledbooleanWhether all compositions should be stored in an encrypted form. The default is false.
EncryptionKeySidstringThe SID of the Public Key resource to use for encryption.