Twilio.Video.V1.RecordingService (twilio_elixir v0.1.1)

Copy Markdown View Source

Single-track, single-media recordings

Operations: list, fetch, delete

Summary

Functions

Delete a Recording resource identified by a Recording SID.

Returns a single Recording resource identified by a Recording SID.

List of all Track recordings.

Stream: List of all Track recordings. (lazy auto-pagination).

Functions

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete a Recording resource identified by a Recording SID.

Operation: DeleteRecording | Tags: VideoV1Recording

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Video.V1.Recording.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Returns a single Recording resource identified by a Recording SID.

Operation: FetchRecording | Tags: VideoV1Recording

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

List of all Track recordings.

Operation: ListRecording | Tags: VideoV1Recording

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

StatusstringRead only the recordings that have this status. Can be: processing, completed, or deleted.
SourceSidstringRead only the recordings that have this source_sid.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| GroupingSid | array | Read only recordings with this grouping_sid, which may include a participant_sid and/or a room_sid. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreatedAfter | string (date-time) | Read only recordings that started on or after this ISO 8601 date-time with time zone. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DateCreatedBefore | string (date-time) | Read only recordings that started before this ISO 8601 date-time with time zone, given as YYYY-MM-DDThh:mm:ss+|-hh:mm or YYYY-MM-DDThh:mm:ssZ. | | MediaType | string | Read only recordings that have this media type. Can be either audio or video. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: List of all Track recordings. (lazy auto-pagination).