Twilio.Video.V1.Room.Participant.PublishedTrackService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for PublishedTrack API operations.

Operations: list, fetch

Summary

Functions

Returns a single Track resource represented by TrackName or SID.

Stream: Returns a list of tracks associated with a given Participant. Only currently Published Tracks are in the list resource. (lazy auto-pagination).

Functions

fetch(client, room_sid, participant_sid, sid, opts \\ [])

Returns a single Track resource represented by TrackName or SID.

Operation: FetchRoomParticipantPublishedTrack | Tags: VideoV1PublishedTrack

list(client, room_sid, participant_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Returns a list of tracks associated with a given Participant. Only currently Published Tracks are in the list resource.

Operation: ListRoomParticipantPublishedTrack | Tags: VideoV1PublishedTrack

stream(client, room_sid, participant_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: Returns a list of tracks associated with a given Participant. Only currently Published Tracks are in the list resource. (lazy auto-pagination).