Twilio.Video.V1.Room.Participant.SubscribeRulesService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for SubscribeRules API operations.

Operations: list, create

Summary

Functions

Update the Subscribe Rules for the Participant

Returns a list of Subscribe Rules for the Participant.

Stream: Returns a list of Subscribe Rules for the Participant. (lazy auto-pagination).

Functions

create(client, room_sid, participant_sid, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Video.V1.Room.Participant.SubscribeRules.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Update the Subscribe Rules for the Participant

Operation: UpdateRoomParticipantSubscribeRule | Tags: VideoV1SubscribeRules

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Rules | string | A JSON-encoded array of subscribe rules. See the Specifying Subscribe Rules section for further information. |

list(client, room_sid, participant_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Returns a list of Subscribe Rules for the Participant.

Operation: FetchRoomParticipantSubscribeRule | Tags: VideoV1SubscribeRules

stream(client, room_sid, participant_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: Returns a list of Subscribe Rules for the Participant. (lazy auto-pagination).