Twilio.Video.V1.Room.Participant.SubscribedTrackService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for SubscribedTrack API operations.

Operations: list, fetch

Summary

Functions

Returns a list of tracks that are subscribed for the participant.

Stream: Returns a list of tracks that are subscribed for the participant. (lazy auto-pagination).

Functions

fetch(client, room_sid, participant_sid, sid, opts \\ [])

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Returns a single Track resource represented by track_sid. Note: This is one resource with the Video API that requires a SID, be Track Name on the subscriber side is not guaranteed to be unique.

Operation: FetchRoomParticipantSubscribedTrack | Tags: VideoV1SubscribedTrack

list(client, room_sid, participant_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Returns a list of tracks that are subscribed for the participant.

Operation: ListRoomParticipantSubscribedTrack | Tags: VideoV1SubscribedTrack

stream(client, room_sid, participant_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) ::
  Enumerable.t()

Stream: Returns a list of tracks that are subscribed for the participant. (lazy auto-pagination).