Twilio.Video.V1.RoomService (twilio_elixir v0.1.1)

Copy Markdown View Source

Video rooms with one or more participants

Operations: list, create, fetch, update

Summary

Functions

Operation: CreateRoom | Tags: VideoV1Room

Operation: FetchRoom | Tags: VideoV1Room

Operation: ListRoom | Tags: VideoV1Room

Stream: (lazy auto-pagination).

Operation: UpdateRoom | Tags: VideoV1Room

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Video.V1.Room.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateRoom | Tags: VideoV1Room

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| AudioOnly | boolean | When set to true, indicates that the participants in the room will only publish audio. No video tracks will be allowed. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

EmptyRoomTimeoutintegerConfigures how long (in minutes) a room will remain active after last participant leaves. Valid values range from 1 to 60 minutes (no fractions).
EnableTurnbooleanDeprecated, now always considered to be true.
LargeRoombooleanWhen set to true, indicated that this is the large room.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MaxParticipantDuration | integer | The maximum number of seconds a Participant can be connected to the room. The maximum possible value is 86400 seconds (24 hours). The default is 14400 seconds (4 hours). |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MaxParticipants | integer | The maximum number of concurrent Participants allowed in the room. The maximum allowed value is 50. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

MediaRegionstringThe region for the Room's media server. Can be one of the available Media Regions.
RecordParticipantsOnConnectbooleanWhether to start recording when Participants connect.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| RecordingRules | string | A collection of Recording Rules that describe how to include or exclude matching tracks for recording |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| StatusCallback | string (uri) | The URL Twilio should call using the status_callback_method to send status information to your application on every room event. See Status Callbacks for more info. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| StatusCallbackMethod | string (http-method) | The HTTP method Twilio should use to call status_callback. Can be POST or GET. Values: GET, POST |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| TranscribeParticipantsOnConnect | boolean | Whether to start transcriptions when Participants connect. If TranscriptionsConfiguration is not provided, default settings will be used. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

TranscriptionsConfigurationobjectA collection of properties that describe transcription behaviour. If TranscribeParticipantsOnConnect is set to true and TranscriptionsConfiguration is not provided, default settings will be used.
TypestringValues: go, peer-to-peer, group, group-small

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UniqueName | string | An application-defined string that uniquely identifies the resource. It can be used as a room_sid in place of the resource's sid in the URL to address the resource, assuming it does not contain any reserved characters that would need to be URL encoded. This value is unique for in-progress rooms. SDK clients can use this name to connect to the room. REST API clients can use this name in place of the Room SID to interact with the room as long as the room is in-progress. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UnusedRoomTimeout | integer | Configures how long (in minutes) a room will remain active if no one joins. Valid values range from 1 to 60 minutes (no fractions). |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| VideoCodecs | array | An array of the video codecs that are supported when publishing a track in the room. Can be: VP8 and H264. |

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Video.V1.Room.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchRoom | Tags: VideoV1Room

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListRoom | Tags: VideoV1Room

Query Parameters

ParameterTypeDescription
StatusstringRead only the rooms with this status. Can be: in-progress (default) or completed
UniqueNamestringRead only rooms with the this unique_name.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DateCreatedAfterstring (date-time)Read only rooms that started on or after this date, given as YYYY-MM-DD.
DateCreatedBeforestring (date-time)Read only rooms that started before this date, given as YYYY-MM-DD.

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Video.V1.Room.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateRoom | Tags: VideoV1Room

Required Parameters

ParameterTypeDescription
StatusstringValues: in-progress, completed, failed