Twilio.Voice.V1.Archive.CallService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for Call API operations.

Operations: delete

Summary

Functions

Delete an archived call record from Bulk Export. Note: this does not also delete the record from the Voice API.

Functions

delete(client, date, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Delete an archived call record from Bulk Export. Note: this does not also delete the record from the Voice API.

Operation: DeleteArchivedCall | Tags: VoiceV1ArchivedCall