Twilio.Voice.V1.DialingPermission.Country.HighRiskSpecialPrefixeService (twilio_elixir v0.1.1)

Copy Markdown View Source

Service for HighRiskSpecialPrefixe API operations.

Operations: list

Summary

Functions

Stream: Fetch the high-risk special services prefixes from the country resource corresponding to the ISO country code (lazy auto-pagination).

Functions

list(client, iso_code, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

Fetch the high-risk special services prefixes from the country resource corresponding to the ISO country code

Operation: ListDialingPermissionsHrsPrefixes | Tags: VoiceV1HighriskSpecialPrefix

stream(client, iso_code, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: Fetch the high-risk special services prefixes from the country resource corresponding to the ISO country code (lazy auto-pagination).