Twilio.Voice.V1.IpRecordService (twilio_elixir v0.1.1)

Copy Markdown View Source

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

IP Records hold information about the IP addresses and ranges (CIDR blocks) that your traffic will be associated with.

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateIpRecord | Tags: VoiceV1IpRecord

Operation: DeleteIpRecord | Tags: VoiceV1IpRecord

Operation: FetchIpRecord | Tags: VoiceV1IpRecord

Operation: ListIpRecord | Tags: VoiceV1IpRecord

Stream: (lazy auto-pagination).

Operation: UpdateIpRecord | Tags: VoiceV1IpRecord

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Voice.V1.IpRecord.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateIpRecord | Tags: VoiceV1IpRecord

Required Parameters

ParameterTypeDescription
IpAddressstringAn IP address in dotted decimal notation, IPv4 only.

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| CidrPrefixLength | integer | An integer representing the length of the CIDR prefix to use with this IP address. By default the entire IP address is used, which for IPv4 is value 32. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It is not unique and can be up to 255 characters long. |

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteIpRecord | Tags: VoiceV1IpRecord

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Voice.V1.IpRecord.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchIpRecord | Tags: VoiceV1IpRecord

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListIpRecord | Tags: VoiceV1IpRecord

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Voice.V1.IpRecord.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateIpRecord | Tags: VoiceV1IpRecord

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It is not unique and can be up to 255 characters long. |