Twilio.Wireless.V1.RatePlanService (twilio_elixir v0.1.1)

Copy Markdown View Source

Capabilities and restrictions for SIMs

Operations: list, create, fetch, update, delete

Summary

Functions

Operation: CreateRatePlan | Tags: WirelessV1RatePlan

Operation: DeleteRatePlan | Tags: WirelessV1RatePlan

Operation: FetchRatePlan | Tags: WirelessV1RatePlan

Operation: ListRatePlan | Tags: WirelessV1RatePlan

Stream: (lazy auto-pagination).

Operation: UpdateRatePlan | Tags: WirelessV1RatePlan

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Wireless.V1.RatePlan.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: CreateRatePlan | Tags: WirelessV1RatePlan

Optional Parameters

ParameterTypeDescription
DataEnabledbooleanWhether SIMs can use GPRS/3G/4G/LTE data connectivity.

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

DataLimitintegerThe total data usage (download and upload combined) in Megabytes that the Network allows during one month on the home network (T-Mobile USA). The metering period begins the day of activation and ends on the same day in the following month. Can be up to 2TB and the default value is 1000.
DataLimitStrategystringValues: block, throttle

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| DataMetering | string | The model used to meter data usage. Can be: payg and quota-1, quota-10, and quota-50. Learn more about the available data metering models. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It does not have to be unique. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| InternationalRoaming | array | The list of services that SIMs capable of using GPRS/3G/4G/LTE data connectivity can use outside of the United States. Can contain: data and messaging. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| InternationalRoamingDataLimit | integer | The total data usage (download and upload combined) in Megabytes that the Network allows during one month when roaming outside the United States. Can be up to 2TB. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| MessagingEnabled | boolean | Whether SIMs can make, send, and receive SMS using Commands. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| NationalRoamingDataLimit | integer | The total data usage (download and upload combined) in Megabytes that the Network allows during one month on non-home networks in the United States. The metering period begins the day of activation and ends on the same day in the following month. Can be up to 2TB. See national roaming for more info. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| NationalRoamingEnabled | boolean | Whether SIMs can roam on networks other than the home network (T-Mobile USA) in the United States. See national roaming. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

UniqueNamestringAn application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource.
VoiceEnabledbooleanDeprecated.

delete(client, sid, opts \\ [])

@spec delete(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}

Operation: DeleteRatePlan | Tags: WirelessV1RatePlan

fetch(client, sid, opts \\ [])

@spec fetch(Twilio.Client.t(), String.t(), keyword()) ::
  {:ok, Twilio.Resources.Wireless.V1.RatePlan.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: FetchRatePlan | Tags: WirelessV1RatePlan

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListRatePlan | Tags: WirelessV1RatePlan

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).

update(client, sid, params \\ %{}, opts \\ [])

@spec update(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Resources.Wireless.V1.RatePlan.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: UpdateRatePlan | Tags: WirelessV1RatePlan

Optional Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| FriendlyName | string | A descriptive string that you create to describe the resource. It does not have to be unique. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| UniqueName | string | An application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource. |