Twilio.Wireless.V1.Sim.UsageRecordService (twilio_elixir v0.1.1)

Copy Markdown View Source

Usage information for SIMs

Operations: list

Summary

Functions

Operation: ListUsageRecord | Tags: WirelessV1UsageRecord

Stream: (lazy auto-pagination).

Functions

list(client, sim_sid, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), String.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListUsageRecord | Tags: WirelessV1UsageRecord

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| End | string (date-time) | Only include usage that occurred on or before this date, specified in ISO 8601. The default is the current time. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Start | string (date-time) | Only include usage that has occurred on or after this date, specified in ISO 8601. The default is one month before the end parameter value. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Granularity | string | How to summarize the usage by time. Can be: daily, hourly, or all. The default is all. A value of all returns one Usage Record that describes the usage for the entire period. |

stream(client, sim_sid, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).