Twilio.Wireless.V1.UsageRecordService (twilio_elixir v0.1.1)

Copy Markdown View Source

Aggregated Usage information for all SIMs on an Account

Operations: list

Summary

Functions

Operation: ListAccountUsageRecord | Tags: WirelessV1UsageRecord

Stream: (lazy auto-pagination).

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(Twilio.Client.t(), map(), keyword()) ::
  {:ok, Twilio.Page.t()}
  | {:ok, map(), map()}
  | :ok
  | {:error, Twilio.Error.t()}

Operation: ListAccountUsageRecord | Tags: WirelessV1UsageRecord

Query Parameters

ParameterTypeDescription

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| End | string (date-time) | Only include usage that has occurred on or before this date. Format is ISO 8601. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Start | string (date-time) | Only include usage that has occurred on or after this date. Format is ISO 8601. |

credo:disable-for-next-line Credo.Check.Readability.MaxLineLength

| Granularity | string | How to summarize the usage by time. Can be: daily, hourly, or all. A value of all returns one Usage Record that describes the usage for the entire period. |

stream(client, params \\ %{}, opts \\ [])

@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()

Stream: (lazy auto-pagination).