Auth Token promotion
Operations: update
Summary
Functions
@spec update(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Accounts.V1.AuthToken.Promote.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Promote the secondary Auth Token to primary. After promoting the new token, all requests to Twilio using your old primary Auth Token will result in an error.
Operation: UpdateAuthTokenPromotion | Tags: AccountsV1AuthTokenPromotion