Service for BulkContacts API operations.
Operations: create
Summary
Functions
Operation: CreateBulkContacts | Tags: AccountsV1BulkContacts
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Accounts.V1.Contact.BulkContacts.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateBulkContacts | Tags: AccountsV1BulkContacts
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Items | array | A list of objects where each object represents a contact's details. Each object includes the following fields: contact_id, which must be a string representing phone number in E.164 format; correlation_id, a unique 32-character UUID that maps the response to the original request; country_iso_code, a string representing the country using the ISO format (e.g., US for the United States); and zip_code, a string representing the postal code. |