credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
An Address instance resource represents your or your customer's physical location within a country. Around the world, some local authorities require the name and address of the user to be on file with Twilio to purchase and own a phone number.
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateAddress | Tags: Api20100401Address
Operation: DeleteAddress | Tags: Api20100401Address
Operation: FetchAddress | Tags: Api20100401Address
Operation: ListAddress | Tags: Api20100401Address
Stream: (lazy auto-pagination).
Operation: UpdateAddress | Tags: Api20100401Address
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Address.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateAddress | Tags: Api20100401Address
Required Parameters
| Parameter | Type | Description |
|---|---|---|
City | string | The city of the new address. |
CustomerName | string | The name to associate with the new address. |
IsoCountry | string (iso-country-code) | The ISO country code of the new address. |
PostalCode | string | The postal code of the new address. |
Region | string | The state or region of the new address. |
Street | string | The number and street address of the new address. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
AutoCorrectAddress | boolean | Whether we should automatically correct the address. Can be: true or false and the default is true. If empty or true, we will correct the address you provide if necessary. If false, we won't alter the address you provide. |
EmergencyEnabled | boolean | Whether to enable emergency calling on the new address. Can be: true or false. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
FriendlyName | string | A descriptive string that you create to describe the new address. It can be up to 64 characters long for Regulatory Compliance addresses and 32 characters long for Emergency addresses. |
StreetSecondary | string | The additional number and street address of the address. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteAddress | Tags: Api20100401Address
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Address.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchAddress | Tags: Api20100401Address
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListAddress | Tags: Api20100401Address
Query Parameters
| Parameter | Type | Description |
|---|---|---|
CustomerName | string | The customer_name of the Address resources to read. |
FriendlyName | string | The string that identifies the Address resources to read. |
EmergencyEnabled | boolean | Whether the address can be associated to a number for emergency calling. |
IsoCountry | string (iso-country-code) | The ISO country code of the Address resources to read. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Address.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateAddress | Tags: Api20100401Address
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
AutoCorrectAddress | boolean | Whether we should automatically correct the address. Can be: true or false and the default is true. If empty or true, we will correct the address you provide if necessary. If false, we won't alter the address you provide. |
City | string | The city of the address. |
CustomerName | string | The name to associate with the address. |
EmergencyEnabled | boolean | Whether to enable emergency calling on the address. Can be: true or false. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
FriendlyName | string | A descriptive string that you create to describe the new address. It can be up to 64 characters long for Regulatory Compliance addresses and 32 characters long for Emergency addresses. |
PostalCode | string | The postal code of the address. |
Region | string | The state or region of the address. |
Street | string | The number and street address of the address. |
StreetSecondary | string | The additional number and street address of the address. |