API and webhook requests and responses. Contains parameters and TwiML for application control.
Operations: list
Summary
Functions
Retrieve a list of all events for a call.
Stream: Retrieve a list of all events for a call. (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all events for a call.
Operation: ListCallEvent | Tags: Api20100401Event
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all events for a call. (lazy auto-pagination).