Service for Transcription API operations.
Operations: create, update
Summary
Functions
Create a Transcription
Stop a Transcription using either the SID of the Transcription resource or the name used when creating the resource
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Call.Transcription.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a Transcription
Operation: CreateRealtimeTranscription | Tags: Api20100401CallTranscription
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
EnableAutomaticPunctuation | boolean | The provider will add punctuation to recognition result |
EnableProviderData | boolean | Whether the callback includes raw provider data. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Hints | string | A Phrase contains words and phrase "hints" so that the speech recognition engine is more likely to recognize them. |
InboundTrackLabel | string | Friendly name given to the Inbound Track |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IntelligenceService | string | The SID or unique name of the Intelligence Service for persisting transcripts and running post-call Language Operators |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| LanguageCode | string | Language code used by the transcription engine, specified in BCP-47 format |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Name | string | The user-specified name of this Transcription, if one was given when the Transcription was created. This may be used to stop the Transcription. |
OutboundTrackLabel | string | Friendly name given to the Outbound Track |
PartialResults | boolean | Indicates if partial results are going to be sent to the customer |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
ProfanityFilter | boolean | indicates if the server will attempt to filter out profanities, replacing all but the initial character in each filtered word with asterisks |
SpeechModel | string | Recognition model used by the transcription engine, among those supported by the provider |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
StatusCallbackMethod | string (http-method) | The http method for the status_callback (one of GET, POST). Values: GET, POST |
StatusCallbackUrl | string (uri) | Absolute URL of the status callback. |
Track | string | Values: inbound_track, outbound_track, both_tracks |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| TranscriptionEngine | string | Definition of the transcription engine to be used, among those supported by Twilio |
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Call.Transcription.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Stop a Transcription using either the SID of the Transcription resource or the name used when creating the resource
Operation: UpdateRealtimeTranscription | Tags: Api20100401CallTranscription
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Status | string | Values: stopped |