Allows your server-side application to send messages to the Voice SDK end user during an active Call.
Operations: create
Summary
Functions
Create a new User Defined Message for the given Call SID.
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Call.UserDefinedMessage.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new User Defined Message for the given Call SID.
Operation: CreateUserDefinedMessage | Tags: Api20100401UserDefinedMessage
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Content | string | The User Defined Message in the form of URL-encoded JSON string. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IdempotencyKey | string | A unique string value to identify API call. This should be a unique string value per API call and can be a randomly generated. |