Recordings of conferences
Operations: list, fetch, update, delete
Summary
Functions
Delete a recording from your account
Fetch an instance of a recording for a call
Retrieve a list of recordings belonging to the call used to make the request
Stream: Retrieve a list of recordings belonging to the call used to make the request (lazy auto-pagination).
Functions
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a recording from your account
Operation: DeleteConferenceRecording | Tags: Api20100401ConferenceRecording
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Conference.Recording.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch an instance of a recording for a call
Operation: FetchConferenceRecording | Tags: Api20100401ConferenceRecording
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of recordings belonging to the call used to make the request
Operation: ListConferenceRecording | Tags: Api20100401ConferenceRecording
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateCreated | string (date) | The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateCreated< | string (date) | The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateCreated> | string (date) | The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of recordings belonging to the call used to make the request (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Conference.Recording.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Changes the status of the recording to paused, stopped, or in-progress. Note: To use Twilio.CURRENT, pass it as recording sid.
Operation: UpdateConferenceRecording | Tags: Api20100401ConferenceRecording
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Status | string | Values: in-progress, paused, stopped, processing, completed, absent |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| PauseBehavior | string | Whether to record during a pause. Can be: skip or silence and the default is silence. skip does not record during the pause period, while silence will replace the actual audio of the call with silence during the pause period. This parameter only applies when setting status is set to paused. |