Twilio Connect apps
Operations: list, fetch, update, delete
Summary
Functions
Delete an instance of a connect-app
Fetch an instance of a connect-app
Retrieve a list of connect-apps belonging to the account used to make the request
Stream: Retrieve a list of connect-apps belonging to the account used to make the request (lazy auto-pagination).
Update a connect-app with the specified parameters
Functions
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete an instance of a connect-app
Operation: DeleteConnectApp | Tags: Api20100401ConnectApp
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.ConnectApp.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch an instance of a connect-app
Operation: FetchConnectApp | Tags: Api20100401ConnectApp
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of connect-apps belonging to the account used to make the request
Operation: ListConnectApp | Tags: Api20100401ConnectApp
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of connect-apps belonging to the account used to make the request (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.ConnectApp.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a connect-app with the specified parameters
Operation: UpdateConnectApp | Tags: Api20100401ConnectApp
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
AuthorizeRedirectUrl | string (uri) | The URL to redirect the user to after we authenticate the user and obtain authorization to access the Connect App. |
CompanyName | string | The company name to set for the Connect App. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DeauthorizeCallbackMethod | string (http-method) | The HTTP method to use when calling deauthorize_callback_url. Values: GET, POST |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
DeauthorizeCallbackUrl | string (uri) | The URL to call using the deauthorize_callback_method to de-authorize the Connect App. |
Description | string | A description of the Connect App. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |
HomepageUrl | string (uri) | A public URL where users can obtain more information about this Connect App. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Permissions | array | A comma-separated list of the permissions you will request from the users of this ConnectApp. Can include: get-all and post-all. |