credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
The MessageFeedback subresource of a Message resource. MessageFeedback contains the reported outcome of whether the Message recipient performed a tracked user action.
Operations: create
Summary
Functions
Create Message Feedback to confirm a tracked user action was performed by the recipient of the associated Message
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Message.Feedback.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create Message Feedback to confirm a tracked user action was performed by the recipient of the associated Message
Operation: CreateMessageFeedback | Tags: Api20100401Feedback
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Outcome | string | Values: confirmed, unconfirmed |