credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
The Media subresource of a Message resource represents a piece of media, such as an image, that is associated with the Message.
Operations: list, fetch, delete
Summary
Functions
Delete the Media resource.
Fetch a single Media resource associated with a specific Message resource
Read a list of Media resources associated with a specific Message resource
Stream: Read a list of Media resources associated with a specific Message resource (lazy auto-pagination).
Functions
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete the Media resource.
Operation: DeleteMedia | Tags: Api20100401MediaInstance
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Message.Media.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a single Media resource associated with a specific Message resource
Operation: FetchMedia | Tags: Api20100401MediaInstance
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Read a list of Media resources associated with a specific Message resource
Operation: ListMedia | Tags: Api20100401Media
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateCreated | string (date-time) | Only include Media resources that were created on this date. Specify a date as YYYY-MM-DD in GMT, for example: 2009-07-06, to read Media that were created on this date. You can also specify an inequality, such as StartTime<=YYYY-MM-DD, to read Media that were created on or before midnight of this date, and StartTime>=YYYY-MM-DD to read Media that were created on or after midnight of this date. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateCreated< | string (date-time) | Only include Media resources that were created on this date. Specify a date as YYYY-MM-DD in GMT, for example: 2009-07-06, to read Media that were created on this date. You can also specify an inequality, such as StartTime<=YYYY-MM-DD, to read Media that were created on or before midnight of this date, and StartTime>=YYYY-MM-DD to read Media that were created on or after midnight of this date. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateCreated> | string (date-time) | Only include Media resources that were created on this date. Specify a date as YYYY-MM-DD in GMT, for example: 2009-07-06, to read Media that were created on this date. You can also specify an inequality, such as StartTime<=YYYY-MM-DD, to read Media that were created on or before midnight of this date, and StartTime>=YYYY-MM-DD to read Media that were created on or after midnight of this date. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Read a list of Media resources associated with a specific Message resource (lazy auto-pagination).