credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
An OutgoingCallerId resource represents a single verified number that may be used as a caller ID when making outgoing calls via the REST API and within the TwiML <Dial> verb.
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateValidationRequest | Tags: Api20100401ValidationRequest
Delete the caller-id specified from the account
Fetch an outgoing-caller-id belonging to the account used to make the request
Retrieve a list of outgoing-caller-ids belonging to the account used to make the request
Stream: Retrieve a list of outgoing-caller-ids belonging to the account used to make the request (lazy auto-pagination).
Updates the caller-id
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.OutgoingCallerId.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateValidationRequest | Tags: Api20100401ValidationRequest
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| PhoneNumber | string (phone-number) | The phone number to verify in E.164 format, which consists of a + followed by the country code and subscriber number. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
CallDelay | integer | The number of seconds to delay before initiating the verification call. Can be an integer between 0 and 60, inclusive. The default is 0. |
Extension | string | The digits to dial after connecting the verification call. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the new caller ID resource. It can be up to 64 characters long. The default value is a formatted version of the phone number. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| StatusCallback | string (uri) | The URL we should call using the status_callback_method to send status information about the verification process to your application. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| StatusCallbackMethod | string (http-method) | The HTTP method we should use to call status_callback. Can be: GET or POST, and the default is POST. Values: GET, POST |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete the caller-id specified from the account
Operation: DeleteOutgoingCallerId | Tags: Api20100401OutgoingCallerId
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.OutgoingCallerId.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch an outgoing-caller-id belonging to the account used to make the request
Operation: FetchOutgoingCallerId | Tags: Api20100401OutgoingCallerId
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of outgoing-caller-ids belonging to the account used to make the request
Operation: ListOutgoingCallerId | Tags: Api20100401OutgoingCallerId
Query Parameters
| Parameter | Type | Description |
|---|---|---|
PhoneNumber | string (phone-number) | The phone number of the OutgoingCallerId resources to read. |
FriendlyName | string | The string that identifies the OutgoingCallerId resources to read. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of outgoing-caller-ids belonging to the account used to make the request (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.OutgoingCallerId.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Updates the caller-id
Operation: UpdateOutgoingCallerId | Tags: Api20100401OutgoingCallerId
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |