Queues of calls
Operations: list, create, fetch, update, delete
Summary
Functions
Create a queue
Remove an empty queue
Fetch an instance of a queue identified by the QueueSid
Retrieve a list of queues belonging to the account used to make the request
Stream: Retrieve a list of queues belonging to the account used to make the request (lazy auto-pagination).
Update the queue with the new parameters
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Queue.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a queue
Operation: CreateQueue | Tags: Api20100401Queue
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you created to describe this resource. It can be up to 64 characters long. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| MaxSize | integer | The maximum number of calls allowed to be in the queue. The default is 1000. The maximum is 5000. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Remove an empty queue
Operation: DeleteQueue | Tags: Api20100401Queue
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Queue.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch an instance of a queue identified by the QueueSid
Operation: FetchQueue | Tags: Api20100401Queue
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of queues belonging to the account used to make the request
Operation: ListQueue | Tags: Api20100401Queue
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of queues belonging to the account used to make the request (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Queue.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update the queue with the new parameters
Operation: UpdateQueue | Tags: Api20100401Queue
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you created to describe this resource. It can be up to 64 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| MaxSize | integer | The maximum number of calls allowed to be in the queue. The default is 1000. The maximum is 5000. |