The results of an Add-on API call
Operations: list, fetch, delete
Summary
Functions
Delete a result and purge all associated Payloads
Fetch an instance of an AddOnResult
Retrieve a list of results belonging to the recording
Stream: Retrieve a list of results belonging to the recording (lazy auto-pagination).
Functions
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a result and purge all associated Payloads
Operation: DeleteRecordingAddOnResult | Tags: Api20100401AddOnResult
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Recording.AddOnResult.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch an instance of an AddOnResult
Operation: FetchRecordingAddOnResult | Tags: Api20100401AddOnResult
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of results belonging to the recording
Operation: ListRecordingAddOnResult | Tags: Api20100401AddOnResult
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of results belonging to the recording (lazy auto-pagination).