Twilio.Api.V2010.SIP.CredentialList.CredentialService
(twilio_elixir v0.1.1)
Username and password information for SIP Domains
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new credential resource.
Delete a credential resource.
Fetch a single credential.
Retrieve a list of credentials.
Stream: Retrieve a list of credentials. (lazy auto-pagination).
Update a credential resource.
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.SIP.CredentialList.Credential.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new credential resource.
Operation: CreateSipCredential | Tags: Api20100401Credential
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Password | string | The password that the username will use when authenticating SIP requests. The password must be a minimum of 12 characters, contain at least 1 digit, and have mixed case. (eg IWasAtSignal2018) |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Username | string | The username that will be passed when authenticating SIP requests. The username should be sent in response to Twilio's challenge of the initial INVITE. It can be up to 32 characters long. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a credential resource.
Operation: DeleteSipCredential | Tags: Api20100401Credential
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.SIP.CredentialList.Credential.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a single credential.
Operation: FetchSipCredential | Tags: Api20100401Credential
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of credentials.
Operation: ListSipCredential | Tags: Api20100401Credential
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of credentials. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.SIP.CredentialList.Credential.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a credential resource.
Operation: UpdateSipCredential | Tags: Api20100401Credential
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Password | string | The password that the username will use when authenticating SIP requests. The password must be a minimum of 12 characters, contain at least 1 digit, and have mixed case. (eg IWasAtSignal2018) |