Twilio.Api.V2010.SIP.Domain.Auth.Call.AuthCallsCredentialListMappingService
(twilio_elixir v0.1.1)
Credential lists for SIP calls
Operations: list, create, fetch, delete
Summary
Functions
Create a new credential list mapping resource
Delete a credential list mapping from the requested domain
Fetch a specific instance of a credential list mapping
Retrieve a list of credential list mappings belonging to the domain used in the request
Stream: Retrieve a list of credential list mappings belonging to the domain used in the request (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.SIP.Domain.Auth.Call.AuthCallsCredentialListMapping.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new credential list mapping resource
Operation: CreateSipAuthCallsCredentialListMapping | Tags: Api20100401AuthCallsCredentialListMapping
Required Parameters
| Parameter | Type | Description |
|---|---|---|
CredentialListSid | string | The SID of the CredentialList resource to map to the SIP domain. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a credential list mapping from the requested domain
Operation: DeleteSipAuthCallsCredentialListMapping | Tags: Api20100401AuthCallsCredentialListMapping
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.SIP.Domain.Auth.Call.AuthCallsCredentialListMapping.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific instance of a credential list mapping
Operation: FetchSipAuthCallsCredentialListMapping | Tags: Api20100401AuthCallsCredentialListMapping
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of credential list mappings belonging to the domain used in the request
Operation: ListSipAuthCallsCredentialListMapping | Tags: Api20100401AuthCallsCredentialListMapping
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of credential list mappings belonging to the domain used in the request (lazy auto-pagination).