Twilio.Api.V2010.SIP.IpAccessControlList.IpAddressService
(twilio_elixir v0.1.1)
IP addresses that have access to a SIP Domain
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new IpAddress resource.
Delete an IpAddress resource.
Read one IpAddress resource.
Read multiple IpAddress resources.
Stream: Read multiple IpAddress resources. (lazy auto-pagination).
Update an IpAddress resource.
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.SIP.IpAccessControlList.IpAddress.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new IpAddress resource.
Operation: CreateSipIpAddress | Tags: Api20100401SipIpAddress
Required Parameters
| Parameter | Type | Description |
|---|---|---|
FriendlyName | string | A human readable descriptive text for this resource, up to 255 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IpAddress | string | An IP address in dotted decimal notation from which you want to accept traffic. Any SIP requests from this IP address will be allowed by Twilio. IPv4 only supported today. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| CidrPrefixLength | integer | An integer representing the length of the CIDR prefix to use with this IP address when accepting traffic. By default the entire IP address is used. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete an IpAddress resource.
Operation: DeleteSipIpAddress | Tags: Api20100401SipIpAddress
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.SIP.IpAccessControlList.IpAddress.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Read one IpAddress resource.
Operation: FetchSipIpAddress | Tags: Api20100401SipIpAddress
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Read multiple IpAddress resources.
Operation: ListSipIpAddress | Tags: Api20100401SipIpAddress
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Read multiple IpAddress resources. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.SIP.IpAccessControlList.IpAddress.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an IpAddress resource.
Operation: UpdateSipIpAddress | Tags: Api20100401SipIpAddress
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
CidrPrefixLength | integer | An integer representing the length of the CIDR prefix to use with this IP address when accepting traffic. By default the entire IP address is used. |
FriendlyName | string | A human readable descriptive text for this resource, up to 255 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IpAddress | string | An IP address in dotted decimal notation from which you want to accept traffic. Any SIP requests from this IP address will be allowed by Twilio. IPv4 only supported today. |