Text transcriptions of call recordings
Operations: list, fetch, delete
Summary
Functions
Delete a transcription from the account used to make the request
Fetch an instance of a Transcription
Retrieve a list of transcriptions belonging to the account used to make the request
Stream: Retrieve a list of transcriptions belonging to the account used to make the request (lazy auto-pagination).
Functions
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a transcription from the account used to make the request
Operation: DeleteTranscription | Tags: Api20100401Transcription
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Api.V2010.Transcription.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch an instance of a Transcription
Operation: FetchTranscription | Tags: Api20100401Transcription
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of transcriptions belonging to the account used to make the request
Operation: ListTranscription | Tags: Api20100401Transcription
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of transcriptions belonging to the account used to make the request (lazy auto-pagination).