Usage records summarized by day
Operations: list
Summary
Functions
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListUsageRecordDaily | Tags: Api20100401Daily
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Category | string | The usage category of the UsageRecord resources to read. Only UsageRecord resources in the specified category are retrieved. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| StartDate | string (date) | Only include usage that has occurred on or after this date. Specify the date in GMT and format as YYYY-MM-DD. You can also specify offsets from the current date, such as: -30days, which will set the start date to be 30 days before the current date. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| EndDate | string (date) | Only include usage that occurred on or before this date. Specify the date in GMT and format as YYYY-MM-DD. You can also specify offsets from the current date, such as: +30days, which will set the end date to 30 days from the current date. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IncludeSubaccounts | boolean | Whether to include usage from the master account and all its subaccounts. Can be: true (the default) to include usage from the master account and all subaccounts or false to retrieve usage from only the specified account. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).