Service for Job API operations.
Operations: list, create
Summary
Functions
Operation: CreateExportCustomJob | Tags: BulkexportsV1ExportCustomJob
Operation: ListExportCustomJob | Tags: BulkexportsV1ExportCustomJob
Stream: (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Bulkexports.V1.Export.Job.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateExportCustomJob | Tags: BulkexportsV1ExportCustomJob
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
EndDay | string | The end day for the custom export specified as a string in the format of yyyy-mm-dd. End day is inclusive and must be 2 days earlier than the current UTC day. |
FriendlyName | string | The friendly name specified when creating the job |
StartDay | string | The start day for the custom export specified as a string in the format of yyyy-mm-dd |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Email | string | The optional email to send the completion notification to. You can set both webhook, and email, or one or the other. If you set neither, the job will run but you will have to query to determine your job's status. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| WebhookMethod | string | This is the method used to call the webhook on completion of the job. If this is supplied, WebhookUrl must also be supplied. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| WebhookUrl | string | The optional webhook url called on completion of the job. If this is supplied, WebhookMethod must also be supplied. If you set neither webhook nor email, you will have to check your job's status manually. |
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListExportCustomJob | Tags: BulkexportsV1ExportCustomJob
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).