Pending invitations to users to become channel members
Operations: list, create, fetch, delete
Summary
Functions
Operation: CreateInvite | Tags: ChatV1Invite
Operation: DeleteInvite | Tags: ChatV1Invite
Operation: FetchInvite | Tags: ChatV1Invite
Operation: ListInvite | Tags: ChatV1Invite
Stream: (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V1.Service.Channel.Invite.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateInvite | Tags: ChatV1Invite
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Identity | string | The identity value that uniquely identifies the new resource's User within the Service. See access tokens for more info. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| RoleSid | string | The SID of the Role assigned to the new member. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteInvite | Tags: ChatV1Invite
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Chat.V1.Service.Channel.Invite.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchInvite | Tags: ChatV1Invite
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListInvite | Tags: ChatV1Invite
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Identity | array | The User's identity value of the resources to read. See access tokens for more details. |
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).