Channels represent chat rooms
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateChannel | Tags: ChatV1Channel
Operation: DeleteChannel | Tags: ChatV1Channel
Operation: FetchChannel | Tags: ChatV1Channel
Operation: ListChannel | Tags: ChatV1Channel
Stream: (lazy auto-pagination).
Operation: UpdateChannel | Tags: ChatV1Channel
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V1.Service.Channel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateChannel | Tags: ChatV1Channel
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Attributes | string | A valid JSON string that contains application-specific data. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
FriendlyName | string | A descriptive string that you create to describe the new resource. It can be up to 64 characters long. |
Type | string | Values: public, private |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource's sid in the URL. This value must be 64 characters or less in length and be unique within the Service. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteChannel | Tags: ChatV1Channel
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Chat.V1.Service.Channel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchChannel | Tags: ChatV1Channel
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListChannel | Tags: ChatV1Channel
Query Parameters
| Parameter | Type | Description |
|---|---|---|
Type | array | The visibility of the Channels to read. Can be: public or private and defaults to public. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V1.Service.Channel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateChannel | Tags: ChatV1Channel
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Attributes | string | A valid JSON string that contains application-specific data. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource's sid in the URL. This value must be 64 characters or less in length and be unique within the Service. |