Roles determining user or member permissions
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateRole | Tags: ChatV1Role
Operation: DeleteRole | Tags: ChatV1Role
Operation: FetchRole | Tags: ChatV1Role
Operation: ListRole | Tags: ChatV1Role
Stream: (lazy auto-pagination).
Operation: UpdateRole | Tags: ChatV1Role
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V1.Service.Role.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateRole | Tags: ChatV1Role
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the new resource. It can be up to 64 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Permission | array | A permission that you grant to the new role. Only one permission can be granted per parameter. To assign more than one permission, repeat this parameter for each permission value. The values for this parameter depend on the role's type and are described in the documentation. |
Type | string | Values: channel, deployment |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteRole | Tags: ChatV1Role
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Chat.V1.Service.Role.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchRole | Tags: ChatV1Role
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListRole | Tags: ChatV1Role
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V1.Service.Role.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateRole | Tags: ChatV1Role
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Permission | array | A permission that you grant to the role. Only one permission can be granted per parameter. To assign more than one permission, repeat this parameter for each permission value. The values for this parameter depend on the role's type and are described in the documentation. |