Webhooks for specific channels
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateChannelWebhook | Tags: ChatV2Webhook
Operation: DeleteChannelWebhook | Tags: ChatV2Webhook
Operation: FetchChannelWebhook | Tags: ChatV2Webhook
Operation: ListChannelWebhook | Tags: ChatV2Webhook
Stream: (lazy auto-pagination).
Operation: UpdateChannelWebhook | Tags: ChatV2Webhook
Functions
@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V2.Service.Channel.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateChannelWebhook | Tags: ChatV2Webhook
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Type | string | Values: webhook, trigger, studio |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Configuration.Filters | array | The events that cause us to call the Channel Webhook. Used when type is webhook. This parameter takes only one event. To specify more than one event, repeat this parameter for each event. For the list of possible events, see Webhook Event Triggers. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Configuration.FlowSid | string | The SID of the Studio Flow to call when an event in configuration.filters occurs. Used only when type is studio. |
Configuration.Method | string | Values: GET, POST |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Configuration.RetryCount | integer | The number of times to retry the webhook if the first attempt fails. Can be an integer between 0 and 3, inclusive, and the default is 0. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Configuration.Triggers | array | A string that will cause us to call the webhook when it is present in a message body. This parameter takes only one trigger string. To specify more than one, repeat this parameter for each trigger string up to a total of 5 trigger strings. Used only when type = trigger. |
Configuration.Url | string | The URL of the webhook to call using the configuration.method. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteChannelWebhook | Tags: ChatV2Webhook
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Chat.V2.Service.Channel.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchChannelWebhook | Tags: ChatV2Webhook
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListChannelWebhook | Tags: ChatV2Webhook
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V2.Service.Channel.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateChannelWebhook | Tags: ChatV2Webhook
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Configuration.Filters | array | The events that cause us to call the Channel Webhook. Used when type is webhook. This parameter takes only one event. To specify more than one event, repeat this parameter for each event. For the list of possible events, see Webhook Event Triggers. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Configuration.FlowSid | string | The SID of the Studio Flow to call when an event in configuration.filters occurs. Used only when type = studio. |
Configuration.Method | string | Values: GET, POST |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Configuration.RetryCount | integer | The number of times to retry the webhook if the first attempt fails. Can be an integer between 0 and 3, inclusive, and the default is 0. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Configuration.Triggers | array | A string that will cause us to call the webhook when it is present in a message body. This parameter takes only one trigger string. To specify more than one, repeat this parameter for each trigger string up to a total of 5 trigger strings. Used only when type = trigger. |
Configuration.Url | string | The URL of the webhook to call using the configuration.method. |