Channels represent chat rooms
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateChannel | Tags: ChatV2Channel
Operation: DeleteChannel | Tags: ChatV2Channel
Operation: FetchChannel | Tags: ChatV2Channel
Operation: ListChannel | Tags: ChatV2Channel
Stream: (lazy auto-pagination).
Operation: UpdateChannel | Tags: ChatV2Channel
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V2.Service.Channel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateChannel | Tags: ChatV2Channel
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Attributes | string | A valid JSON string that contains application-specific data. |
CreatedBy | string | The identity of the User that created the channel. Default is: system. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateCreated | string (date-time) | The date, specified in ISO 8601 format, to assign to the resource as the date it was created. The default value is the current time set by the Chat service. Note that this should only be used in cases where a Channel is being recreated from a backup/separate source. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateUpdated | string (date-time) | The date, specified in ISO 8601 format, to assign to the resource as the date it was last updated. The default value is null. Note that this parameter should only be used in cases where a Channel is being recreated from a backup/separate source and where a Message was previously updated. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
FriendlyName | string | A descriptive string that you create to describe the new resource. It can be up to 64 characters long. |
Type | string | Values: public, private |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the Channel resource's sid in the URL. This value must be 64 characters or less in length and be unique within the Service. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteChannel | Tags: ChatV2Channel
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Chat.V2.Service.Channel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchChannel | Tags: ChatV2Channel
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListChannel | Tags: ChatV2Channel
Query Parameters
| Parameter | Type | Description |
|---|---|---|
Type | array | The visibility of the Channels to read. Can be: public or private and defaults to public. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V2.Service.Channel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateChannel | Tags: ChatV2Channel
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Attributes | string | A valid JSON string that contains application-specific data. |
CreatedBy | string | The identity of the User that created the channel. Default is: system. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateCreated | string (date-time) | The date, specified in ISO 8601 format, to assign to the resource as the date it was created. The default value is the current time set by the Chat service. Note that this should only be used in cases where a Channel is being recreated from a backup/separate source. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateUpdated | string (date-time) | The date, specified in ISO 8601 format, to assign to the resource as the date it was last updated. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 256 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource's sid in the URL. This value must be 256 characters or less in length and unique within the Service. |