List of channels for a given user
Operations: list, fetch, update, delete
Summary
Functions
Removes User from selected Channel.
Operation: FetchUserChannel | Tags: ChatV2UserChannel
List all Channels for a given User.
Stream: List all Channels for a given User. (lazy auto-pagination).
Operation: UpdateUserChannel | Tags: ChatV2UserChannel
Functions
@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Removes User from selected Channel.
Operation: DeleteUserChannel | Tags: ChatV2UserChannel
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Chat.V2.Service.User.Channel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchUserChannel | Tags: ChatV2UserChannel
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
List all Channels for a given User.
Operation: ListUserChannel | Tags: ChatV2UserChannel
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: List all Channels for a given User. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V2.Service.User.Channel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateUserChannel | Tags: ChatV2UserChannel
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| LastConsumedMessageIndex | integer | The index of the last Message in the Channel that the Member has read. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
LastConsumptionTimestamp | string (date-time) | The ISO 8601 timestamp of the last Message read event for the Member within the Channel. |
NotificationLevel | string | Values: default, muted |