A Channel resource represents a chat/conversation channel with an ordered list of messages and a participant roster.
Operations: update
Summary
Functions
Update a specific Channel.
Functions
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Chat.V3.Service.Channel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a specific Channel.
Operation: UpdateChannel | Tags: ChatV3Channel
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
MessagingServiceSid | string | The unique ID of the Messaging Service this channel belongs to. |
Type | string | Values: public, private |