A Content resource represents rich messaging content and its respective approval request status.
Operations: list
Summary
Functions
Retrieve a list of Contents with approval statuses belonging to the account used to make the request
Stream: Retrieve a list of Contents with approval statuses belonging to the account used to make the request (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Contents with approval statuses belonging to the account used to make the request
Operation: ListContentAndApprovals | Tags: Contentv1ContentAndApprovals
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Contents with approval statuses belonging to the account used to make the request (lazy auto-pagination).