A Legacy Content resource represents legacy rich messaging content.
Operations: list
Summary
Functions
Retrieve a list of Legacy Contents belonging to the account used to make the request
Stream: Retrieve a list of Legacy Contents belonging to the account used to make the request (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Legacy Contents belonging to the account used to make the request
Operation: ListLegacyContent | Tags: Contentv1LegacyContent
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Legacy Contents belonging to the account used to make the request (lazy auto-pagination).