A Content resource represents rich messaging content and its respective approval request status.
Operations: list
Summary
Functions
Retrieve a list of Contents with approval statuses belonging to the account used to make the request
Stream: Retrieve a list of Contents with approval statuses belonging to the account used to make the request (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Contents with approval statuses belonging to the account used to make the request
Operation: ListContentAndApprovals | Tags: ContentV2ContentAndApprovals
Query Parameters
| Parameter | Type | Description |
|---|---|---|
SortByDate | string | Whether to sort by ascending or descending date updated |
SortByContentName | string | Whether to sort by ascending or descending content name |
DateCreatedAfter | string (date-time) | Filter by >=[date-time] |
DateCreatedBefore | string (date-time) | Filter by <=[date-time] |
ContentName | string | Filter by Regex Pattern in content name |
Content | string | Filter by Regex Pattern in template content |
Language | array | Filter by array of valid language(s) |
ContentType | array | Filter by array of contentType(s) |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ChannelEligibility | array | Filter by array of ChannelEligibility(s), where ChannelEligibility=<channel>:<status> |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Contents with approval statuses belonging to the account used to make the request (lazy auto-pagination).