Twilio.Conversations.V1.Configuration.AddressService
(twilio_elixir v0.1.1)
Address Configuration resource manages the configurations related to a unique address within Conversations
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new address configuration
Remove an existing address configuration
Fetch an address configuration
Retrieve a list of address configurations for an account
Stream: Retrieve a list of address configurations for an account (lazy auto-pagination).
Update an existing address configuration
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Configuration.Address.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new address configuration
Operation: CreateConfigurationAddress | Tags: ConversationsV1AddressConfiguration
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Address | string | The unique address to be configured. The address can be a whatsapp address or phone number |
Type | string | Values: sms, whatsapp, messenger, gbm, email, rcs, apple, chat |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| AddressCountry | string | An ISO 3166-1 alpha-2n country code which the address belongs to. This is currently only applicable to short code addresses. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
AutoCreation.ConversationServiceSid | string | Conversation Service for the auto-created conversation. If not set, the conversation is created in the default service. |
AutoCreation.Enabled | boolean | Enable/Disable auto-creating conversations for messages to this address |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
AutoCreation.StudioFlowSid | string | For type studio, the studio flow SID where the webhook should be sent to. |
AutoCreation.StudioRetryCount | integer | For type studio, number of times to retry the webhook request |
AutoCreation.Type | string | Values: webhook, studio, default |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
AutoCreation.WebhookFilters | array | The list of events, firing webhook event for this Conversation. Values can be any of the following: onMessageAdded, onMessageUpdated, onMessageRemoved, onConversationUpdated, onConversationStateUpdated, onConversationRemoved, onParticipantAdded, onParticipantUpdated, onParticipantRemoved, onDeliveryUpdated |
AutoCreation.WebhookMethod | string | Values: get, post |
AutoCreation.WebhookUrl | string | For type webhook, the url for the webhook request. |
FriendlyName | string | The human-readable name of this configuration, limited to 256 characters. Optional. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Remove an existing address configuration
Operation: DeleteConfigurationAddress | Tags: ConversationsV1AddressConfiguration
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Configuration.Address.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch an address configuration
Operation: FetchConfigurationAddress | Tags: ConversationsV1AddressConfiguration
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of address configurations for an account
Operation: ListConfigurationAddress | Tags: ConversationsV1AddressConfiguration
Query Parameters
| Parameter | Type | Description |
|---|---|---|
Type | string | Filter the address configurations by its type. This value can be one of: whatsapp, sms. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of address configurations for an account (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Configuration.Address.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an existing address configuration
Operation: UpdateConfigurationAddress | Tags: ConversationsV1AddressConfiguration
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
AutoCreation.ConversationServiceSid | string | Conversation Service for the auto-created conversation. If not set, the conversation is created in the default service. |
AutoCreation.Enabled | boolean | Enable/Disable auto-creating conversations for messages to this address |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
AutoCreation.StudioFlowSid | string | For type studio, the studio flow SID where the webhook should be sent to. |
AutoCreation.StudioRetryCount | integer | For type studio, number of times to retry the webhook request |
AutoCreation.Type | string | Values: webhook, studio, default |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
AutoCreation.WebhookFilters | array | The list of events, firing webhook event for this Conversation. Values can be any of the following: onMessageAdded, onMessageUpdated, onMessageRemoved, onConversationUpdated, onConversationStateUpdated, onConversationRemoved, onParticipantAdded, onParticipantUpdated, onParticipantRemoved, onDeliveryUpdated |
AutoCreation.WebhookMethod | string | Values: get, post |
AutoCreation.WebhookUrl | string | For type webhook, the url for the webhook request. |
FriendlyName | string | The human-readable name of this configuration, limited to 256 characters. Optional. |