Twilio.Conversations.V1.Configuration.WebhookService
(twilio_elixir v0.1.1)
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
A Webhook resource manages a service-level set of callback URLs and their configuration for receiving all conversation events.
Operations: fetch, update
Summary
Functions
Operation: FetchConfigurationWebhook | Tags: ConversationsV1Webhook
Operation: UpdateConfigurationWebhook | Tags: ConversationsV1Webhook
Functions
@spec fetch( Twilio.Client.t(), keyword() ) :: {:ok, Twilio.Resources.Conversations.V1.Configuration.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchConfigurationWebhook | Tags: ConversationsV1Webhook
@spec update(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Configuration.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateConfigurationWebhook | Tags: ConversationsV1Webhook
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Filters | array | The list of webhook event triggers that are enabled for this Service: onMessageAdded, onMessageUpdated, onMessageRemoved, onMessageAdd, onMessageUpdate, onMessageRemove, onConversationUpdated, onConversationRemoved, onConversationAdd, onConversationAdded, onConversationRemove, onConversationUpdate, onConversationStateUpdated, onParticipantAdded, onParticipantUpdated, onParticipantRemoved, onParticipantAdd, onParticipantRemove, onParticipantUpdate, onDeliveryUpdated, onUserAdded, onUserUpdate, onUserUpdated |
Method | string | The HTTP method to be used when sending a webhook request. |
PostWebhookUrl | string | The absolute url the post-event webhook request should be sent to. |
PreWebhookUrl | string | The absolute url the pre-event webhook request should be sent to. |
Target | string | Values: webhook, flex |