The Configuration resource manages a set of account-level settings applicable to the Conversations API.
Operations: fetch, update
Summary
Functions
Fetch the global configuration of conversations on your account
Update the global configuration of conversations on your account
Functions
@spec fetch( Twilio.Client.t(), keyword() ) :: {:ok, Twilio.Resources.Conversations.V1.Configuration.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch the global configuration of conversations on your account
Operation: FetchConfiguration | Tags: ConversationsV1Configuration
@spec update(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Configuration.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update the global configuration of conversations on your account
Operation: UpdateConfiguration | Tags: ConversationsV1Configuration
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DefaultChatServiceSid | string | The SID of the default Conversation Service to use when creating a conversation. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DefaultClosedTimer | string | Default ISO8601 duration when conversation will be switched to closed state. Minimum value for this timer is 10 minutes. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DefaultInactiveTimer | string | Default ISO8601 duration when conversation will be switched to inactive state. Minimum value for this timer is 1 minute. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DefaultMessagingServiceSid | string | The SID of the default Messaging Service to use when creating a conversation. |