Twilio.Conversations.V1.Service.Configuration.WebhookService
(twilio_elixir v0.1.1)
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
A service webhook configuration resource manages a service-level set of callback URLs and their configuration for receiving all the corresponding service events.
Operations: fetch, update
Summary
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Service.Configuration.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific service webhook configuration.
Operation: FetchServiceWebhookConfiguration | Tags: ConversationsV1Webhook
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Service.Configuration.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a specific Webhook.
Operation: UpdateServiceWebhookConfiguration | Tags: ConversationsV1Webhook
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Filters | array | The list of events that your configured webhook targets will receive. Events not configured here will not fire. Possible values are onParticipantAdd, onParticipantAdded, onDeliveryUpdated, onConversationUpdated, onConversationRemove, onParticipantRemove, onConversationUpdate, onMessageAdd, onMessageRemoved, onParticipantUpdated, onConversationAdded, onMessageAdded, onConversationAdd, onConversationRemoved, onParticipantUpdate, onMessageRemove, onMessageUpdated, onParticipantRemoved, onMessageUpdate or onConversationStateUpdated. |
Method | string | The HTTP method to be used when sending a webhook request. One of GET or POST. |
PostWebhookUrl | string (uri) | The absolute url the post-event webhook request should be sent to. |
PreWebhookUrl | string (uri) | The absolute url the pre-event webhook request should be sent to. |