A Service User resource represents a conversation user belonging to a specific conversation service.
Operations: list, create, fetch, update, delete
Summary
Functions
Add a new conversation user to your service
Remove a conversation user from your service
Fetch a conversation user from your service
Retrieve a list of all conversation users in your service
Stream: Retrieve a list of all conversation users in your service (lazy auto-pagination).
Update an existing conversation user in your service
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Service.User.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Add a new conversation user to your service
Operation: CreateServiceUser | Tags: ConversationsV1User
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Identity | string | The application-defined string that uniquely identifies the resource's User within the Conversation Service. This value is often a username or an email address, and is case-sensitive. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Attributes | string | The JSON Object string that stores application-specific data. If attributes have not been set, {} is returned. |
FriendlyName | string | The string that you assigned to describe the resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| RoleSid | string | The SID of a service-level Role to assign to the user. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Remove a conversation user from your service
Operation: DeleteServiceUser | Tags: ConversationsV1User
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Service.User.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a conversation user from your service
Operation: FetchServiceUser | Tags: ConversationsV1User
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all conversation users in your service
Operation: ListServiceUser | Tags: ConversationsV1User
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all conversation users in your service (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Conversations.V1.Service.User.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an existing conversation user in your service
Operation: UpdateServiceUser | Tags: ConversationsV1User
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Attributes | string | The JSON Object string that stores application-specific data. If attributes have not been set, {} is returned. |
FriendlyName | string | The string that you assigned to describe the resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| RoleSid | string | The SID of a service-level Role to assign to the user. |