Version of the Schema
Operations: list, fetch
Summary
Functions
Fetch a specific schema and version.
Retrieve a paginated list of versions of the schema.
Stream: Retrieve a paginated list of versions of the schema. (lazy auto-pagination).
Functions
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Events.V1.Schema.SchemaVersion.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific schema and version.
Operation: FetchSchemaVersion | Tags: EventsV1SchemaVersion
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a paginated list of versions of the schema.
Operation: ListSchemaVersion | Tags: EventsV1SchemaVersion
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a paginated list of versions of the schema. (lazy auto-pagination).