Service for InsightsUserRoles API operations.
Operations: fetch
Summary
Functions
This is used by Flex UI and Quality Management to fetch the Flex Insights roles for the user
Functions
@spec fetch( Twilio.Client.t(), keyword() ) :: {:ok, Twilio.Resources.Flex.V1.Insight.InsightsUserRoles.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
This is used by Flex UI and Quality Management to fetch the Flex Insights roles for the user
Operation: FetchInsightsUserRoles | Tags: FlexV1InsightsUserRoles