Twilio.Flex.V1.Insight.QualityManagement.Assessment.CommentService
(twilio_elixir v0.1.1)
Service for Comment API operations.
Operations: list, create
Summary
Functions
To create a comment assessment for a conversation
To create a comment assessment for a conversation
Stream: To create a comment assessment for a conversation (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.Insight.QualityManagement.Assessment.Comment.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To create a comment assessment for a conversation
Operation: CreateInsightsAssessmentsComment | Tags: FlexV1InsightsAssessmentsComment
Required Parameters
| Parameter | Type | Description |
|---|---|---|
AgentId | string | The id of the agent. |
CategoryId | string | The ID of the category |
CategoryName | string | The name of the category |
Comment | string | The Assessment comment. |
Offset | number | The offset |
SegmentId | string | The id of the segment. |
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To create a comment assessment for a conversation
Operation: ListInsightsAssessmentsComment | Tags: FlexV1InsightsAssessmentsComment
Query Parameters
| Parameter | Type | Description |
|---|---|---|
SegmentId | string | The id of the segment. |
AgentId | string | The id of the agent. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: To create a comment assessment for a conversation (lazy auto-pagination).