Twilio.Flex.V1.Insight.QualityManagement.QuestionService
(twilio_elixir v0.1.1)
Service for Question API operations.
Operations: list, create, update, delete
Summary
Functions
To create a question for a Category
Operation: DeleteInsightsQuestionnairesQuestion | Tags: FlexV1InsightsQuestionnairesQuestion
To get all the question for the given categories
Stream: To get all the question for the given categories (lazy auto-pagination).
To update the question
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.Insight.QualityManagement.Question.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To create a question for a Category
Operation: CreateInsightsQuestionnairesQuestion | Tags: FlexV1InsightsQuestionnairesQuestion
Required Parameters
| Parameter | Type | Description |
|---|---|---|
AllowNa | boolean | The flag to enable for disable NA for answer. |
AnswerSetId | string | The answer_set for the question. |
CategorySid | string | The SID of the category |
Question | string | The question. |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Description | string | The description for the question. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteInsightsQuestionnairesQuestion | Tags: FlexV1InsightsQuestionnairesQuestion
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To get all the question for the given categories
Operation: ListInsightsQuestionnairesQuestion | Tags: FlexV1InsightsQuestionnairesQuestion
Query Parameters
| Parameter | Type | Description |
|---|---|---|
CategorySid | array | The list of category SIDs |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: To get all the question for the given categories (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.Insight.QualityManagement.Question.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To update the question
Operation: UpdateInsightsQuestionnairesQuestion | Tags: FlexV1InsightsQuestionnairesQuestion
Required Parameters
| Parameter | Type | Description |
|---|---|---|
AllowNa | boolean | The flag to enable for disable NA for answer. |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
AnswerSetId | string | The answer_set for the question. |
CategorySid | string | The SID of the category |
Description | string | The description for the question. |
Question | string | The question. |