Twilio.Flex.V1.Insight.QualityManagement.Setting.InsightsSettingsAnswerSetsService
(twilio_elixir v0.1.1)
Service for InsightsSettingsAnswerSets API operations.
Operations: list
Summary
Functions
To get the Answer Set Settings for an Account
Stream: To get the Answer Set Settings for an Account (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
To get the Answer Set Settings for an Account
Operation: FetchInsightsSettingsAnswersets | Tags: FlexV1InsightsSettingsAnswerSets
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: To get the Answer Set Settings for an Account (lazy auto-pagination).