Twilio.Flex.V1.Interaction.Channel.InteractionChannelParticipantService
(twilio_elixir v0.1.1)
Service for InteractionChannelParticipant API operations.
Operations: list, create, update
Summary
Functions
Add a Participant to a Channel.
List all Participants for a Channel.
Stream: List all Participants for a Channel. (lazy auto-pagination).
Update an existing Channel Participant.
Functions
@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.Interaction.Channel.InteractionChannelParticipant.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Add a Participant to a Channel.
Operation: CreateInteractionChannelParticipant | Tags: FlexV1InteractionChannelParticipant
Required Parameters
| Parameter | Type | Description |
|---|---|---|
MediaProperties | string | JSON representing the Media Properties for the new Participant. |
Type | string | Values: supervisor, customer, external, agent, unknown |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
RoutingProperties | string | Object representing the Routing Properties for the new Participant. |
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
List all Participants for a Channel.
Operation: ListInteractionChannelParticipant | Tags: FlexV1InteractionChannelParticipant
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: List all Participants for a Channel. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.Interaction.Channel.InteractionChannelParticipant.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an existing Channel Participant.
Operation: UpdateInteractionChannelParticipant | Tags: FlexV1InteractionChannelParticipant
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Status | string | Values: closed, wrapup |