Service for Plugin API operations.
Operations: list, create, fetch, update
Summary
Functions
Operation: CreatePlugin | Tags: FlexV1Plugin
Operation: FetchPlugin | Tags: FlexV1Plugin
Operation: ListPlugin | Tags: FlexV1Plugin
Stream: (lazy auto-pagination).
Operation: UpdatePlugin | Tags: FlexV1Plugin
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.PluginService.Plugin.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreatePlugin | Tags: FlexV1Plugin
Required Parameters
| Parameter | Type | Description |
|---|---|---|
UniqueName | string | The Flex Plugin's unique name. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Description | string | A descriptive string that you create to describe the plugin resource. It can be up to 500 characters long |
FriendlyName | string | The Flex Plugin's friendly name. |
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.PluginService.Plugin.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchPlugin | Tags: FlexV1Plugin
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListPlugin | Tags: FlexV1Plugin
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Flex.V1.PluginService.Plugin.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdatePlugin | Tags: FlexV1Plugin
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Description | string | A descriptive string that you update to describe the plugin resource. It can be up to 500 characters long |
FriendlyName | string | The Flex Plugin's friendly name. |