Service for Authorize API operations.
Operations: list
Summary
Functions
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
List Authorize resources.
Operation: FetchAuthorize | Tags: OauthV1Authorize
Query Parameters
| Parameter | Type | Description |
|---|---|---|
response_type | string | Response Type |
client_id | string | The Client Identifier |
redirect_uri | string | The url to which response will be redirected to |
scope | string | The scope of the access request |
state | string | An opaque value which can be used to maintain state between the request and callback |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream all resources with lazy auto-pagination.