Service for Conference API operations.
Operations: list, fetch
Summary
Functions
Get a specific Conference Summary.
Get a list of Conference Summaries.
Stream: Get a list of Conference Summaries. (lazy auto-pagination).
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Insights.V1.Conference.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Get a specific Conference Summary.
Operation: FetchConference | Tags: InsightsV1Conference
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Get a list of Conference Summaries.
Operation: ListConference | Tags: InsightsV1Conference
Query Parameters
| Parameter | Type | Description |
|---|---|---|
ConferenceSid | string | The SID of the conference. |
FriendlyName | string | Custom label for the conference resource, up to 64 characters. |
Status | string | Conference status. |
CreatedAfter | string | Conferences created after the provided timestamp specified in ISO 8601 format |
CreatedBefore | string | Conferences created before the provided timestamp specified in ISO 8601 format. |
MixerRegion | string | Twilio region where the conference media was mixed. |
Tags | string | Tags applied by Twilio for common potential configuration, quality, or performance issues. |
Subaccount | string | Account SID for the subaccount whose resources you wish to retrieve. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
DetectedIssues | string | Potential configuration, behavior, or performance issues detected during the conference. |
EndReason | string | Conference end reason; e.g. last participant left, modified by API, etc. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Get a list of Conference Summaries. (lazy auto-pagination).