Service for CallSummaries API operations.
Operations: list
Summary
Functions
Get a list of Call Summaries.
Stream: Get a list of Call Summaries. (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Get a list of Call Summaries.
Operation: ListCallSummaries | Tags: InsightsV1CallSummaries
Query Parameters
| Parameter | Type | Description |
|---|---|---|
From | string | A calling party. Could be an E.164 number, a SIP URI, or a Twilio Client registered name. |
To | string | A called party. Could be an E.164 number, a SIP URI, or a Twilio Client registered name. |
FromCarrier | string | An origination carrier. |
ToCarrier | string | A destination carrier. |
FromCountryCode | string | A source country code based on phone number in From. |
ToCountryCode | string | A destination country code. Based on phone number in To. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| VerifiedCaller | boolean | A boolean flag indicating whether or not the caller was verified using SHAKEN/STIR.One of 'true' or 'false'. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| HasTag | boolean | A boolean flag indicating the presence of one or more Voice Insights Call Tags. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| StartTime | string | A Start time of the calls. xm (x minutes), xh (x hours), xd (x days), 1w, 30m, 3d, 4w or datetime-ISO. Defaults to 4h. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
EndTime | string | An End Time of the calls. xm (x minutes), xh (x hours), xd (x days), 1w, 30m, 3d, 4w or datetime-ISO. Defaults to 0m. |
CallType | string | A Call Type of the calls. One of carrier, sip, trunking or client. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| CallState | string | A Call State of the calls. One of ringing, completed, busy, fail, noanswer, canceled, answered, undialed. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Direction | string | A Direction of the calls. One of outbound_api, outbound_dial, inbound, trunking_originating, trunking_terminating. |
ProcessingState | string | A Processing State of the Call Summaries. One of completed, partial or all. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
SortBy | string | A Sort By criterion for the returned list of Call Summaries. One of start_time or end_time. |
Subaccount | string | A unique SID identifier of a Subaccount. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| AbnormalSession | boolean | A boolean flag indicating an abnormal session where the last SIP response was not 200 OK. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
AnsweredBy | string | An Answered By value for the calls based on Answering Machine Detection (AMD). One of unknown, machine_start, machine_end_beep, machine_end_silence, machine_end_other, human or fax. |
AnsweredByAnnotation | string | Either machine or human. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ConnectivityIssueAnnotation | string | A Connectivity Issue with the calls. One of no_connectivity_issue, invalid_number, caller_id, dropped_call, or number_reachability. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
QualityIssueAnnotation | string | A subjective Quality Issue with the calls. One of no_quality_issue, low_volume, choppy_robotic, echo, dtmf, latency, owa, static_noise. |
SpamAnnotation | boolean | A boolean flag indicating spam calls. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| CallScoreAnnotation | string | A Call Score of the calls. Use a range of 1-5 to indicate the call experience score, with the following mapping as a reference for the rated call [5: Excellent, 4: Good, 3 : Fair, 2 : Poor, 1: Bad]. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| BrandedEnabled | boolean | A boolean flag indicating whether or not the calls were branded using Twilio Branded Calls. One of 'true' or 'false' |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
VoiceIntegrityEnabled | boolean | A boolean flag indicating whether or not the phone number had voice integrity enabled.One of 'true' or 'false' |
BrandedBundleSid | string | A unique SID identifier of the Branded Call. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
BrandedLogo | boolean | Indicates whether the branded logo was displayed during the in_brand branded call. Possible values are true (logo was present) or false (logo was not present). |
BrandedType | string | Indicates whether the Branded Call is in_band vs out_of_band. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| BrandedUseCase | string | Specifies the user-defined purpose for the call, as provided during the setup of in_band branded calling. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
BrandedCallReason | string | Specifies the user-defined reason for the call, which will be displayed to the end user on their mobile device during an in_band branded call. |
VoiceIntegrityBundleSid | string | A unique SID identifier of the Voice Integrity Profile. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| VoiceIntegrityUseCase | string | A Voice Integrity Use Case . Is of type enum. One of 'abandonedcart', 'appointment_reminders', 'appointment_scheduling', 'asset_management', 'automated_support', 'call_tracking', 'click_to_call', 'contact_tracing', 'contactless_delivery', 'customer_support', 'dating/social', 'delivery_notifications', 'distance_learning', 'emergency_notifications', 'employee_notifications', 'exam_proctoring', 'field_notifications', 'first_responder', 'fraud_alerts', 'group_messaging', 'identify&verification', 'intelligent_routing', 'lead_alerts', 'lead_distribution', 'lead_generation', 'lead_management', 'lead_nurturing', 'marketing_events', 'mass_alerts', 'meetings/collaboration', 'order_notifications', 'outbound_dialer', 'pharmacy', 'phone_system', 'purchase_confirmation', 'remote_appointments', 'rewards_program', 'self-service', 'service_alerts', 'shift_management', 'survey/research', 'telehealth', 'telemarketing', 'therapy(individual+group)'. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| BusinessProfileIdentity | string | A Business Identity of the calls. Is of type enum. One of 'direct_customer', 'isv_reseller_or_partner'. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
BusinessProfileIndustry | string | A Business Industry of the calls. Is of type enum. One of 'automotive', 'agriculture', 'banking', 'consumer', 'construction', 'education', 'engineering', 'energy', 'oil_and_gas', 'fast_moving_consumer_goods', 'financial', 'fintech', 'food_and_beverage', 'government', 'healthcare', 'hospitality', 'insurance', 'legal', 'manufacturing', 'media', 'online', 'professional_services', 'raw_materials', 'real_estate', 'religion', 'retail', 'jewelry', 'technology', 'telecommunications', 'transportation', 'travel', 'electronics', 'not_for_profit' |
BusinessProfileBundleSid | string | A unique SID identifier of the Business Profile. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| BusinessProfileType | string | A Business Profile Type of the calls. Is of type enum. One of 'primary', 'secondary'. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Get a list of Call Summaries. (lazy auto-pagination).