Service for Metric API operations.
Operations: list
Summary
Functions
Get a list of Call Metrics for a Call.
Stream: Get a list of Call Metrics for a Call. (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Get a list of Call Metrics for a Call.
Operation: ListMetric | Tags: InsightsV1Metric
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Edge | string | The Edge of this Metric. One of unknown_edge, carrier_edge, sip_edge, sdk_edge or client_edge. |
Direction | string | The Direction of this Metric. One of unknown, inbound, outbound or both. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Get a list of Call Metrics for a Call. (lazy auto-pagination).