Service for Custom API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new Custom Operator for the given Account
Delete a specific Custom Operator.
Fetch a specific Custom Operator.
Retrieves a list of all Custom Operators for an Account.
Stream: Retrieves a list of all Custom Operators for an Account. (lazy auto-pagination).
Update a specific Custom Operator.
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Intelligence.V2.Operator.Custom.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Custom Operator for the given Account
Operation: CreateCustomOperator | Tags: IntelligenceV2CustomOperator
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Config | string | Operator configuration, following the schema defined by the Operator Type. |
FriendlyName | string | A human readable description of the new Operator, up to 64 characters. |
OperatorType | string | Operator Type for this Operator. References an existing Operator Type resource. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Custom Operator.
Operation: DeleteCustomOperator | Tags: IntelligenceV2CustomOperator
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Intelligence.V2.Operator.Custom.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Custom Operator.
Operation: FetchCustomOperator | Tags: IntelligenceV2CustomOperator
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieves a list of all Custom Operators for an Account.
Operation: ListCustomOperator | Tags: IntelligenceV2CustomOperator
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Availability | string | Returns Custom Operators with the provided availability type. Possible values: internal, beta, public, retired. |
LanguageCode | string | Returns Custom Operators that support the provided language code. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieves a list of all Custom Operators for an Account. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Intelligence.V2.Operator.Custom.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a specific Custom Operator.
Operation: UpdateCustomOperator | Tags: IntelligenceV2CustomOperator
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Config | string | Operator configuration, following the schema defined by the Operator Type. |
FriendlyName | string | A human-readable name of this resource, up to 64 characters. |