Service for Operator API operations.
Operations: list, fetch
Summary
Functions
Fetch a specific Operator. Works for both Custom and Pre-built Operators.
Retrieves a list of all Operators for an Account, both Custom and Pre-built.
Stream: Retrieves a list of all Operators for an Account, both Custom and Pre-built. (lazy auto-pagination).
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Intelligence.V2.Operator.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Operator. Works for both Custom and Pre-built Operators.
Operation: FetchOperator | Tags: IntelligenceV2Operator
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieves a list of all Operators for an Account, both Custom and Pre-built.
Operation: ListOperator | Tags: IntelligenceV2Operator
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Availability | string | Returns Operators with the provided availability type. Possible values: internal, beta, public, retired. |
LanguageCode | string | Returns Operators that support the provided language code. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieves a list of all Operators for an Account, both Custom and Pre-built. (lazy auto-pagination).