Service for Sentence API operations.
Operations: list, fetch
Summary
Functions
Fetch Public Key Encrypted Sentences by TranscriptSid
Get all Transcript Sentences by TranscriptSid
Stream: Get all Transcript Sentences by TranscriptSid (lazy auto-pagination).
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Intelligence.V2.Transcript.Sentence.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch Public Key Encrypted Sentences by TranscriptSid
Operation: FetchEncryptedSentences | Tags: IntelligenceV2EncryptedSentences
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Redacted | boolean | Grant access to PII Redacted/Unredacted Sentences. If redaction is enabled, the default is true to access redacted sentences. |
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Get all Transcript Sentences by TranscriptSid
Operation: ListSentence | Tags: IntelligenceV2Sentence
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Redacted | boolean | Grant access to PII Redacted/Unredacted Sentences. If redaction is enabled, the default is true to access redacted sentences. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| WordTimestamps | boolean | Returns word level timestamps information, if word_timestamps is enabled. The default is false. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Get all Transcript Sentences by TranscriptSid (lazy auto-pagination).