Service for Transcript API operations.
Operations: list, create, fetch, delete
Summary
Functions
Create a new Transcript for the service
Delete a specific Transcript.
Fetch a specific Transcript.
Retrieve a list of Transcripts for a given service.
Stream: Retrieve a list of Transcripts for a given service. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Intelligence.V2.Transcript.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Transcript for the service
Operation: CreateTranscript | Tags: IntelligenceV2Transcript
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Channel | string | JSON object describing Media Channel including Source and Participants |
ServiceSid | string | The unique SID identifier of the Service. |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
CustomerKey | string | Used to store client provided metadata. Maximum of 64 double-byte UTF8 characters. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| MediaStartTime | string (date-time) | The date that this Transcript's media was started, given in ISO 8601 format. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Transcript.
Operation: DeleteTranscript | Tags: IntelligenceV2Transcript
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Intelligence.V2.Transcript.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Transcript.
Operation: FetchTranscript | Tags: IntelligenceV2Transcript
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Transcripts for a given service.
Operation: ListTranscript | Tags: IntelligenceV2Transcript
Query Parameters
| Parameter | Type | Description |
|---|---|---|
ServiceSid | string | The unique SID identifier of the Service. |
BeforeStartTime | string | Filter by before StartTime. |
AfterStartTime | string | Filter by after StartTime. |
BeforeDateCreated | string | Filter by before DateCreated. |
AfterDateCreated | string | Filter by after DateCreated. |
Status | string | Filter by status. |
LanguageCode | string | Filter by Language Code. |
SourceSid | string | Filter by SourceSid. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Transcripts for a given service. (lazy auto-pagination).