credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
A Deactivation resource to retrieve a list of United States phone numbers that have been deactivated by mobile carriers on a specific date.
Operations: fetch
Summary
Functions
Fetch a list of all United States numbers that have been deactivated on a specific date.
Functions
@spec fetch( Twilio.Client.t(), keyword() ) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a list of all United States numbers that have been deactivated on a specific date.
Operation: FetchDeactivation | Tags: MessagingV1Deactivations
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Date | string (date) | The request will return a list of all United States Phone Numbers that were deactivated on the day specified by this parameter. This date should be specified in YYYY-MM-DD format. |