Twilio.Messaging.V1.LinkShortening.Domain.ConfigService
(twilio_elixir v0.1.1)
Service for Config API operations.
Operations: fetch, update
Summary
Functions
Operation: FetchDomainConfig | Tags: MessagingV1DomainConfig
Operation: UpdateDomainConfig | Tags: MessagingV1DomainConfig
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Messaging.V1.LinkShortening.Domain.Config.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchDomainConfig | Tags: MessagingV1DomainConfig
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Messaging.V1.LinkShortening.Domain.Config.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateDomainConfig | Tags: MessagingV1DomainConfig
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| CallbackUrl | string (uri) | URL to receive click events to your webhook whenever the recipients click on the shortened links |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ContinueOnFailure | boolean | Boolean field to set customer delivery preference when there is a failure in linkShortening service |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DisableHttps | boolean | Customer's choice to send links with/without "https://" attached to shortened url. If true, messages will not be sent with https:// at the beginning of the url. If false, messages will be sent with https:// at the beginning of the url. False is the default behavior if it is not specified. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FallbackUrl | string (uri) | Any requests we receive to this domain that do not match an existing shortened message will be redirected to the fallback url. These will likely be either expired messages, random misdirected traffic, or intentional scraping. |