Twilio.Messaging.V1.Service.Compliance.Usa2p.UsecaseService
(twilio_elixir v0.1.1)
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Messaging Service Use Case resource. Fetch possible use cases for service. The Use Cases API returns an empty list if there is an issue with the customer's A2P brand registration. This Brand cannot register any campaign use cases. Customers are requested to contact support with their A2P brand information.
Operations: list
Summary
Functions
Operation: FetchUsAppToPersonUsecase | Tags: MessagingV1UsAppToPersonUsecase
Stream: (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchUsAppToPersonUsecase | Tags: MessagingV1UsAppToPersonUsecase
Query Parameters
| Parameter | Type | Description |
|---|---|---|
BrandRegistrationSid | string | The unique string to identify the A2P brand. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).