Twilio.Messaging.V1.Service.DestinationAlphaSenderService
(twilio_elixir v0.1.1)
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
A Messaging Service resource to add, fetch or remove Destination and Default Alpha Sender IDs from a Messaging Service. Destination Alpha Sender can send to a particular ISO country code. Default Alpha Senders can send to all countries.
Operations: list, create, fetch, delete
Summary
Functions
Operation: CreateDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender
Operation: DeleteDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender
Operation: FetchDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender
Operation: ListDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender
Stream: (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Messaging.V1.Service.DestinationAlphaSender.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| AlphaSender | string | The Alphanumeric Sender ID string. Can be up to 11 characters long. Valid characters are A-Z, a-z, 0-9, space, hyphen -, plus +, underscore _ and ampersand &. This value cannot contain only numbers. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IsoCountryCode | string | The Optional Two Character ISO Country Code the Alphanumeric Sender ID will be used for. If the IsoCountryCode is not provided, a default Alpha Sender will be created that can be used across all countries. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Messaging.V1.Service.DestinationAlphaSender.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListDestinationAlphaSender | Tags: MessagingV1DestinationAlphaSender
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IsoCountryCode | string | Optional filter to return only alphanumeric sender IDs associated with the specified two-character ISO country code. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).