Twilio.Numbers.V2.RegulatoryCompliance.Bundle.CloneService
(twilio_elixir v0.1.1)
Service for Clone API operations.
Operations: update
Summary
Functions
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.Bundle.Clone.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Creates a new clone of the Bundle in target Account. It will internally create clones of all the bundle items (identities and documents) of the original bundle
Operation: CreateBundleClone | Tags: NumbersV2BundleClone
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| TargetAccountSid | string | The SID of the Account where the bundle needs to be cloned. |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
FriendlyName | string | The string that you assigned to describe the cloned bundle. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| MoveToDraft | boolean | If set to true, the cloned bundle will be in the DRAFT state, else it will be twilio-approved |