Twilio.Numbers.V2.RegulatoryCompliance.Bundle.CopyService
(twilio_elixir v0.1.1)
Service for Copy API operations.
Operations: list, create
Summary
Functions
Retrieve a list of all Bundles Copies for a Bundle.
Stream: Retrieve a list of all Bundles Copies for a Bundle. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.Bundle.Copy.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Creates a new copy of a Bundle. It will internally create copies of all the bundle items (identities and documents) of the original bundle
Operation: CreateBundleCopy | Tags: NumbersV2BundleCopy
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
FriendlyName | string | The string that you assigned to describe the copied bundle. |
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Bundles Copies for a Bundle.
Operation: ListBundleCopy | Tags: NumbersV2BundleCopy
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Bundles Copies for a Bundle. (lazy auto-pagination).