Twilio.Numbers.V2.RegulatoryCompliance.Bundle.ReplaceItemsService
(twilio_elixir v0.1.1)
Service for ReplaceItems API operations.
Operations: create
Summary
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.Bundle.ReplaceItems.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Replaces all bundle items in the target bundle (specified in the path) with all the bundle items of the source bundle (specified by the from_bundle_sid body param)
Operation: CreateReplaceItems | Tags: NumbersV2ReplaceItems
Required Parameters
| Parameter | Type | Description |
|---|---|---|
FromBundleSid | string | The source bundle sid to copy the item assignments from. |