Twilio.Numbers.V2.RegulatoryCompliance.RegulationService
(twilio_elixir v0.1.1)
Service for Regulation API operations.
Operations: list, fetch
Summary
Functions
Fetch specific Regulation Instance.
Retrieve a list of all Regulations.
Stream: Retrieve a list of all Regulations. (lazy auto-pagination).
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Numbers.V2.RegulatoryCompliance.Regulation.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch specific Regulation Instance.
Operation: FetchRegulation | Tags: NumbersV2Regulation
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IncludeConstraints | boolean | A boolean parameter indicating whether to include constraints or not for supporting end user, documents and their fields |
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Regulations.
Operation: ListRegulation | Tags: NumbersV2Regulation
Query Parameters
| Parameter | Type | Description |
|---|---|---|
EndUserType | string | The type of End User the regulation requires - can be individual or business. |
IsoCountry | string | The ISO country code of the phone number's country. |
NumberType | string | The type of phone number that the regulatory requiremnt is restricting. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IncludeConstraints | boolean | A boolean parameter indicating whether to include constraints or not for supporting end user, documents and their fields |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Regulations. (lazy auto-pagination).