Service for Authorize API operations.
Operations: list
Summary
Functions
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieves authorize uri
Operation: FetchAuthorize | Tags: OauthV1Authorize
Query Parameters
| Parameter | Type | Description |
|---|---|---|
ResponseType | string | Response Type |
ClientId | string | The Client Identifier |
RedirectUri | string | The url to which response will be redirected to |
Scope | string | The scope of the access request |
State | string | An opaque value which can be used to maintain state between the request and callback |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieves authorize uri (lazy auto-pagination).