Twilio.Preview.Marketplace.InstalledAddOn.InstalledAddOnExtensionService
(twilio_elixir v0.1.1)
Service for InstalledAddOnExtension API operations.
Operations: list, fetch, update
Summary
Functions
Fetch an instance of an Extension for the Installed Add-on.
Retrieve a list of Extensions for the Installed Add-on.
Stream: Retrieve a list of Extensions for the Installed Add-on. (lazy auto-pagination).
Update an Extension for an Add-on installation.
Functions
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Preview.Marketplace.InstalledAddOn.InstalledAddOnExtension.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch an instance of an Extension for the Installed Add-on.
Operation: FetchMarketplaceInstalledAddOnExtension | Tags: PreviewMarketplaceInstalledAddOnExtension
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Extensions for the Installed Add-on.
Operation: ListMarketplaceInstalledAddOnExtension | Tags: PreviewMarketplaceInstalledAddOnExtension
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Extensions for the Installed Add-on. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Preview.Marketplace.InstalledAddOn.InstalledAddOnExtension.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an Extension for an Add-on installation.
Operation: UpdateMarketplaceInstalledAddOnExtension | Tags: PreviewMarketplaceInstalledAddOnExtension
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Enabled | boolean | Whether the Extension should be invoked. |