Service for PhoneNumber API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Add a Phone Number to a Service's Proxy Number Pool.
Delete a specific Phone Number from a Service.
Fetch a specific Phone Number.
Stream: Retrieve a list of all Phone Numbers in the Proxy Number Pool for a Service. A maximum of 100 records will be returned per page. (lazy auto-pagination).
Update a specific Proxy Number.
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Proxy.V1.Service.PhoneNumber.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Add a Phone Number to a Service's Proxy Number Pool.
Operation: CreatePhoneNumber | Tags: ProxyV1PhoneNumber
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IsReserved | boolean | Whether the new phone number should be reserved and not be assigned to a participant using proxy pool logic. See Reserved Phone Numbers for more information. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| PhoneNumber | string (phone-number) | The phone number in E.164 format. E.164 phone numbers consist of a + followed by the country code and subscriber number without punctuation characters. For example, +14155551234. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Sid | string | The SID of a Twilio IncomingPhoneNumber resource that represents the Twilio Number you would like to assign to your Proxy Service. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Phone Number from a Service.
Operation: DeletePhoneNumber | Tags: ProxyV1PhoneNumber
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Proxy.V1.Service.PhoneNumber.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Phone Number.
Operation: FetchPhoneNumber | Tags: ProxyV1PhoneNumber
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Retrieve a list of all Phone Numbers in the Proxy Number Pool for a Service. A maximum of 100 records will be returned per page.
Operation: ListPhoneNumber | Tags: ProxyV1PhoneNumber
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Phone Numbers in the Proxy Number Pool for a Service. A maximum of 100 records will be returned per page. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Proxy.V1.Service.PhoneNumber.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a specific Proxy Number.
Operation: UpdatePhoneNumber | Tags: ProxyV1PhoneNumber
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IsReserved | boolean | Whether the phone number should be reserved and not be assigned to a participant using proxy pool logic. See Reserved Phone Numbers for more information. |