Twilio.Proxy.V1.Service.Session.Participant.MessageInteractionService
(twilio_elixir v0.1.1)
Service for MessageInteraction API operations.
Operations: list, create, fetch
Summary
Functions
Operation: FetchMessageInteraction | Tags: ProxyV1MessageInteraction
Operation: ListMessageInteraction | Tags: ProxyV1MessageInteraction
Stream: (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Proxy.V1.Service.Session.Participant.MessageInteraction.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Create a new message Interaction to send directly from your system to one Participant. The inbound properties for the Interaction will always be empty.
Operation: CreateMessageInteraction | Tags: ProxyV1MessageInteraction
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Body | string | The message to send to the participant |
MediaUrl | array | Reserved. Not currently supported. |
@spec fetch( Twilio.Client.t(), String.t(), String.t(), String.t(), String.t(), keyword() ) :: {:ok, Twilio.Resources.Proxy.V1.Service.Session.Participant.MessageInteraction.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchMessageInteraction | Tags: ProxyV1MessageInteraction
@spec list(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListMessageInteraction | Tags: ProxyV1MessageInteraction
@spec stream(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).