Service for Participant API operations.
Operations: list, create, fetch, delete
Summary
Functions
Add a new Participant to the Session
Fetch a specific Participant.
Retrieve a list of all Participants in a Session.
Stream: Retrieve a list of all Participants in a Session. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Proxy.V1.Service.Session.Participant.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Add a new Participant to the Session
Operation: CreateParticipant | Tags: ProxyV1Participant
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Identifier | string | The phone number of the Participant. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | The string that you assigned to describe the participant. This value must be 255 characters or fewer. This value should not have PII. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
ProxyIdentifier | string | The proxy phone number to use for the Participant. If not specified, Proxy will select a number from the pool. |
ProxyIdentifierSid | string | The SID of the Proxy Identifier to assign to the Participant. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Delete a specific Participant. This is a soft-delete. The participant remains associated with the session and cannot be re-added. Participants are only permanently deleted when the Session is deleted.
Operation: DeleteParticipant | Tags: ProxyV1Participant
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Proxy.V1.Service.Session.Participant.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Participant.
Operation: FetchParticipant | Tags: ProxyV1Participant
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Participants in a Session.
Operation: ListParticipant | Tags: ProxyV1Participant
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Participants in a Session. (lazy auto-pagination).