Service for Service API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new Service for Twilio Proxy
Delete a specific Service.
Fetch a specific Service.
Retrieve a list of all Services for Twilio Proxy. A maximum of 100 records will be returned per page.
Stream: Retrieve a list of all Services for Twilio Proxy. A maximum of 100 records will be returned per page. (lazy auto-pagination).
Update a specific Service.
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Proxy.V1.Service.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Service for Twilio Proxy
Operation: CreateService | Tags: ProxyV1Service
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. This value must be 191 characters or fewer in length and be unique. This value should not have PII. |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
CallbackUrl | string (uri) | The URL we should call when the interaction status changes. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ChatInstanceSid | string | The SID of the Chat Service Instance managed by Proxy Service. The Chat Service enables Proxy to forward SMS and channel messages to this chat instance. This is a one-to-one relationship. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
DefaultTtl | integer | The default ttl value to set for Sessions created in the Service. The TTL (time to live) is measured in seconds after the Session's last create or last Interaction. The default value of 0 indicates an unlimited Session length. You can override a Session's default TTL value by setting its ttl value. |
GeoMatchLevel | string | Values: area-code, overlay, radius, country |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
InterceptCallbackUrl | string (uri) | The URL we call on each interaction. If we receive a 403 status, we block the interaction; otherwise the interaction continues. |
NumberSelectionBehavior | string | Values: avoid-sticky, prefer-sticky |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| OutOfSessionCallbackUrl | string (uri) | The URL we should call when an inbound call or SMS action occurs on a closed or non-existent Session. If your server (or a Twilio function) responds with valid TwiML, we will process it. This means it is possible, for example, to play a message for a call, send an automated text message response, or redirect a call to another Phone Number. See Out-of-Session Callback Response Guide for more information. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Service.
Operation: DeleteService | Tags: ProxyV1Service
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Proxy.V1.Service.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Service.
Operation: FetchService | Tags: ProxyV1Service
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Services for Twilio Proxy. A maximum of 100 records will be returned per page.
Operation: ListService | Tags: ProxyV1Service
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Services for Twilio Proxy. A maximum of 100 records will be returned per page. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Proxy.V1.Service.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a specific Service.
Operation: UpdateService | Tags: ProxyV1Service
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
CallbackUrl | string (uri) | The URL we should call when the interaction status changes. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ChatInstanceSid | string | The SID of the Chat Service Instance managed by Proxy Service. The Chat Service enables Proxy to forward SMS and channel messages to this chat instance. This is a one-to-one relationship. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
DefaultTtl | integer | The default ttl value to set for Sessions created in the Service. The TTL (time to live) is measured in seconds after the Session's last create or last Interaction. The default value of 0 indicates an unlimited Session length. You can override a Session's default TTL value by setting its ttl value. |
GeoMatchLevel | string | Values: area-code, overlay, radius, country |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
InterceptCallbackUrl | string (uri) | The URL we call on each interaction. If we receive a 403 status, we block the interaction; otherwise the interaction continues. |
NumberSelectionBehavior | string | Values: avoid-sticky, prefer-sticky |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| OutOfSessionCallbackUrl | string (uri) | The URL we should call when an inbound call or SMS action occurs on a closed or non-existent Session. If your server (or a Twilio function) responds with valid TwiML, we will process it. This means it is possible, for example, to play a message for a call, send an automated text message response, or redirect a call to another Phone Number. See Out-of-Session Callback Response Guide for more information. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. This value must be 191 characters or fewer in length and be unique. This value should not have PII. |