Auth Token promotion
Properties
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that the secondary Auth Token was created for. |
auth_token | The promoted Auth Token that must be used to authenticate future API requests.. PII: sensitive |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in UTC when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
url | The URI for this resource, relative to https://accounts.twilio.com. Format: uri |