User provided public keys
SID prefix: CR
Parent: /Credentials
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Credential that the PublicKey resource belongs to. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
friendly_name | The string that you assigned to describe the resource.. PII: standard |
sid | The unique string that that we created to identify the PublicKey resource. |
url | The URI for this resource, relative to https://accounts.twilio.com. Format: uri |