Twilio accounts (aka Project) or subaccounts
SID prefix: AC
Sub-resources
addresses—/2010-04-01/Accounts/{account_sid}/Addresses.jsonapplications—/2010-04-01/Accounts/{account_sid}/Applications.jsonauthorized_connect_apps—/2010-04-01/Accounts/{account_sid}/AuthorizedConnectApps.jsonavailable_phone_numbers—/2010-04-01/Accounts/{account_sid}/AvailablePhoneNumbers.jsonbalance—/2010-04-01/Accounts/{account_sid}/Balance.jsoncalls—/2010-04-01/Accounts/{account_sid}/Calls.jsonconferences—/2010-04-01/Accounts/{account_sid}/Conferences.jsonconnect_apps—/2010-04-01/Accounts/{account_sid}/ConnectApps.jsonincoming_phone_numbers—/2010-04-01/Accounts/{account_sid}/IncomingPhoneNumbers.jsonkeys—/2010-04-01/Accounts/{account_sid}/Keys.jsonmessages—/2010-04-01/Accounts/{account_sid}/Messages.jsonnew_keys—/2010-04-01/Accounts/{account_sid}/Keys.jsonnew_signing_keys—/2010-04-01/Accounts/{account_sid}/SigningKeys.jsonnotifications—/2010-04-01/Accounts/{account_sid}/Notifications.jsonoutgoing_caller_ids—/2010-04-01/Accounts/{account_sid}/OutgoingCallerIds.jsonqueues—/2010-04-01/Accounts/{account_sid}/Queues.jsonrecordings—/2010-04-01/Accounts/{account_sid}/Recordings.jsonshort_codes—/2010-04-01/Accounts/{account_sid}/SMS/ShortCodes.jsonsigning_keys—/2010-04-01/Accounts/{account_sid}/SigningKeys.jsonsip—/2010-04-01/Accounts/{account_sid}/SIP.jsonsms—/2010-04-01/Accounts/{account_sid}/SMS.jsontokens—/2010-04-01/Accounts/{account_sid}/Tokens.jsontranscriptions—/2010-04-01/Accounts/{account_sid}/Transcriptions.jsonusage—/2010-04-01/Accounts/{account_sid}/Usage.jsonvalidation_requests—/2010-04-01/Accounts/{account_sid}/OutgoingCallerIds.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
auth_token | The authorization token for this account. This token should be kept a secret, so no sharing.. PII: sensitive |
date_created | The date that this account was created, in GMT in RFC 2822 format. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date that this account was last updated, in GMT in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| friendly_name | A human readable description of this account, up to 64 characters long. By default the FriendlyName is your email address.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
owner_account_sid | The unique 34 character id that represents the parent of this account. The OwnerAccountSid of a parent account is it's own sid. |
sid | A 34 character string that uniquely identifies this resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
status | The status of this account. Usually active, but can be suspended or closed.. Values: active, suspended, closed |
subresource_uris | A Map of various subresources available for the given Account Instance. Format: uri-map |
type | The type of this account. Either Trial or Full if it's been upgraded. Values: Trial, Full |
uri | The URI for this resource, relative to https://api.twilio.com |
Summary
Types
@type t() :: %Twilio.Resources.Api.V2010.Account{ auth_token: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, friendly_name: String.t() | nil, owner_account_sid: String.t() | nil, sid: String.t() | nil, status: String.t(), subresource_uris: map() | nil, type: String.t(), uri: String.t() | nil }