Twilio.Resources.Api.V2010.AvailablePhoneNumber.MachineToMachine
(twilio_elixir v0.1.1)
Available machine-to-machine phone numbers
Parent: /Accounts/{AccountSid}/AvailablePhoneNumbers/{CountryCode}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
address_requirements | The type of Address resource the phone number requires. Can be: none, any, local, or foreign. none means no address is required. any means an address is required, but it can be anywhere in the world. local means an address in the phone number's country is required. foreign means an address outside of the phone number's country is required. |
beta | Whether the phone number is new to the Twilio platform. Can be: true or false. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
capabilities | The set of Boolean properties that indicate whether a phone number can receive calls or messages. Capabilities are: Voice, SMS, and MMS and each capability can be: true or false.. Format: phone-number-capabilities |
friendly_name | A formatted version of the phone number.. Format: phone-number |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| iso_country | The ISO country code of this phone number.. Format: iso-country-code |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| lata | The LATA of this phone number. Available for only phone numbers from the US and Canada. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
latitude | The latitude of this phone number's location. Available for only phone numbers from the US and Canada. |
locality | The locality or city of this phone number's location. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| longitude | The longitude of this phone number's location. Available for only phone numbers from the US and Canada. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| phone_number | The phone number in E.164 format, which consists of a + followed by the country code and subscriber number.. Format: phone-number |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| postal_code | The postal or ZIP code of this phone number's location. Available for only phone numbers from the US and Canada. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| rate_center | The rate center of this phone number. Available for only phone numbers from the US and Canada. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| region | The two-letter state or province abbreviation of this phone number's location. Available for only phone numbers from the US and Canada. |
Summary
Types
@type t() :: %Twilio.Resources.Api.V2010.AvailablePhoneNumber.MachineToMachine{ address_requirements: String.t() | nil, beta: boolean() | nil, capabilities: map() | nil, friendly_name: String.t() | nil, iso_country: String.t() | nil, lata: String.t() | nil, latitude: float() | nil, locality: String.t() | nil, longitude: float() | nil, phone_number: String.t() | nil, postal_code: String.t() | nil, rate_center: String.t() | nil, region: String.t() | nil }