Twilio.Resources.Api.V2010.AvailablePhoneNumberCountry
(twilio_elixir v0.1.1)
Country codes with available phone numbers
Parent: /Accounts/{Sid}.json
Sub-resources
local—/2010-04-01/Accounts/{account_sid}/AvailablePhoneNumbers/{country_code}/Local.json
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
machine_to_machine—/2010-04-01/Accounts/{account_sid}/AvailablePhoneNumbers/{country_code}/MachineToMachine.jsonmobile—/2010-04-01/Accounts/{account_sid}/AvailablePhoneNumbers/{country_code}/Mobile.jsonnational—/2010-04-01/Accounts/{account_sid}/AvailablePhoneNumbers/{country_code}/National.jsonshared_cost—/2010-04-01/Accounts/{account_sid}/AvailablePhoneNumbers/{country_code}/SharedCost.jsontoll_free—/2010-04-01/Accounts/{account_sid}/AvailablePhoneNumbers/{country_code}/TollFree.jsonvoip—/2010-04-01/Accounts/{account_sid}/AvailablePhoneNumbers/{country_code}/Voip.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
beta | Whether all phone numbers available in the country are new to the Twilio platform. true if they are and false if all numbers are not in the Twilio Phone Number Beta program. |
country | The name of the country. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| country_code | The ISO-3166-1 country code of the country.. Format: iso-country-code |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
subresource_uris | A list of related AvailablePhoneNumber resources identified by their URIs relative to https://api.twilio.com.. Format: uri-map |
uri | The URI of the Country resource, relative to https://api.twilio.com.. Format: uri |