API and webhook requests and responses. Contains parameters and TwiML for application control.
Parent: /Accounts/{AccountSid}/Calls/{Sid}.json
Properties
| Field | Description |
|---|---|
request | Contains a dictionary representing the request of the call.. PII: sensitive |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| response | Contains a dictionary representing the call response, including a list of the call events.. PII: sensitive |