Start and stop forked media streaming using the SIPREC protocol.
SID prefix: SR
Parent: /Accounts/{AccountSid}/Calls/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created this Siprec resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| call_sid | The SID of the Call the Siprec resource is associated with. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT that this resource was last updated, specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
name | The user-specified name of this Siprec, if one was given when the Siprec was created. This may be used to stop the Siprec. |
sid | The SID of the Siprec resource. |
status | The status - one of stopped, in-progress. Values: in-progress, stopped |
uri | The URI of the resource, relative to https://api.twilio.com. |