Transcription resource.
SID prefix: GT
Parent: /Accounts/{AccountSid}/Calls/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created this Transcription resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| call_sid | The SID of the Call the Transcription resource is associated with. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT that this resource was last updated, specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
name | The user-specified name of this Transcription, if one was given when the Transcription was created. This may be used to stop the Transcription. |
sid | The SID of the Transcription resource. |
status | The status - one of stopped, in-flight. Values: in-progress, stopped |