Allows your server-side application to send messages to the Voice SDK end user during an active Call.
SID prefix: KX
Parent: /Accounts/{AccountSid}/Calls/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created User Defined Message. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| call_sid | The SID of the Call the User Defined Message is associated with. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_created | The date that this User Defined Message was created, given in RFC 2822 format.. Format: date-time-rfc-2822 |
sid | The SID that uniquely identifies this User Defined Message. |