Conference participants
Parent: /Accounts/{AccountSid}/Conferences/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Participant resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| call_sid | The SID of the Call the Participant resource is associated with. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| call_sid_to_coach | The SID of the participant who is being coached. The participant being coached is the only participant who can hear the participant who is coaching. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
coaching | Whether the participant is coaching another call. Can be: true or false. If not present, defaults to false unless call_sid_to_coach is defined. If true, call_sid_to_coach must be defined. |
conference_sid | The SID of the conference the participant is in. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
end_conference_on_exit | Whether the conference ends when the participant leaves. Can be: true or false and the default is false. If true, the conference ends and all other participants drop out when the participant leaves. |
hold | Whether the participant is on hold. Can be true or false. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
label | The user-specified label of this participant, if one was given when the participant was created. This may be used to fetch, update or delete the participant. |
muted | Whether the participant is muted. Can be true or false. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| queue_time | The wait time in milliseconds before participant's call is placed. Only available in the response to a create participant request. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| start_conference_on_enter | Whether the conference starts when the participant joins the conference, if it has not already started. Can be: true or false and the default is true. If false and the conference has not started, the participant is muted and hears background music until another participant starts the conference. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
status | The status of the participant's call in a session. Can be: queued, connecting, ringing, connected, complete, or failed.. Values: queued, connecting, ringing, connected, complete, failed |
uri | The URI of the resource, relative to https://api.twilio.com. |
Summary
Types
@type t() :: %Twilio.Resources.Api.V2010.Conference.Participant{ account_sid: String.t() | nil, call_sid: String.t() | nil, call_sid_to_coach: String.t() | nil, coaching: boolean() | nil, conference_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, end_conference_on_exit: boolean() | nil, hold: boolean() | nil, label: String.t() | nil, muted: boolean() | nil, queue_time: String.t() | nil, start_conference_on_enter: boolean() | nil, status: String.t(), uri: String.t() | nil }