Recordings of conferences
SID prefix: RE
Parent: /Accounts/{AccountSid}/Conferences/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Conference Recording resource. |
api_version | The API version used to create the recording. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| call_sid | The SID of the Call the Conference Recording resource is associated with. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
channels | The number of channels in the final recording file. Can be: 1, or 2. Separating a two leg call into two separate channels of the recording file is supported in Dial and Outbound Rest API record options. |
conference_sid | The Conference SID that identifies the conference associated with the recording. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT that the resource was last updated, specified in RFC 2822 format.. Format: date-time-rfc-2822 |
duration | The length of the recording in seconds. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| encryption_details | How to decrypt the recording if it was encrypted using Call Recording Encryption feature. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
error_code | The error code that describes why the recording is absent. The error code is described in our Error Dictionary. This value is null if the recording status is not absent. |
price | The one-time cost of creating the recording in the price_unit currency. |
price_unit | The currency used in the price property. Example: USD.. Format: currency |
sid | The unique string that that we created to identify the Conference Recording resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| source | How the recording was created. Can be: DialVerb, Conference, OutboundAPI, Trunking, RecordVerb, StartCallRecordingAPI, StartConferenceRecordingAPI.. Values: DialVerb, Conference, OutboundAPI, Trunking, RecordVerb, StartCallRecordingAPI, StartConferenceRecordingAPI |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| start_time | The start time of the recording in GMT and in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
status | The status of the recording. Can be: processing, completed and absent. For more detailed statuses on in-progress recordings, check out how to Update a Recording Resource.. Values: in-progress, paused, stopped, processing, completed, absent |
uri | The URI of the resource, relative to https://api.twilio.com. |
Summary
Types
@type t() :: %Twilio.Resources.Api.V2010.Conference.Recording{ account_sid: String.t() | nil, api_version: String.t() | nil, call_sid: String.t() | nil, channels: integer(), conference_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, duration: String.t() | nil, encryption_details: String.t() | nil, error_code: integer() | nil, price: String.t() | nil, price_unit: String.t() | nil, sid: String.t() | nil, source: String.t(), start_time: String.t() | nil, status: String.t(), uri: String.t() | nil }