credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
The MessageFeedback subresource of a Message resource. MessageFeedback contains the reported outcome of whether the Message recipient performed a tracked user action.
Parent: /Accounts/{AccountSid}/Messages/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account associated with this MessageFeedback resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when this MessageFeedback resource was created, specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when this MessageFeedback resource was last updated, specified in RFC 2822 format.. Format: date-time-rfc-2822 |
message_sid | The SID of the Message resource associated with this MessageFeedback resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
outcome | Reported outcome indicating whether there is confirmation that the Message recipient performed a tracked user action. Can be: unconfirmed or confirmed. For more details see How to Optimize Message Deliverability with Message Feedback.. Values: confirmed, unconfirmed |
uri | The URI of the resource, relative to https://api.twilio.com. |