credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
The Media subresource of a Message resource represents a piece of media, such as an image, that is associated with the Message.
SID prefix: ME
Parent: /Accounts/{AccountSid}/Messages/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account associated with this Media resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| content_type | The default MIME type of the media, for example image/jpeg, image/png, or image/gif. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when this Media resource was created, specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when this Media resource was last updated, specified in RFC 2822 format.. Format: date-time-rfc-2822 |
parent_sid | The SID of the Message resource that is associated with this Media resource. |
sid | The unique string that identifies this Media resource. |
uri | The URI of this Media resource, relative to https://api.twilio.com. |