[DEPRECATED] Log entries
SID prefix: NO
Parent: /Accounts/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Notification resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| api_version | The API version used to generate the notification. Can be empty for events that don't have a specific API version, such as incoming phone calls. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| call_sid | The SID of the Call the Notification resource is associated with. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
error_code | A unique error code for the error condition that is described in our Error Dictionary. |
log | An integer log level that corresponds to the type of notification: 0 is ERROR, 1 is WARNING. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
message_date | The date the notification was actually generated in RFC 2822 format. Message buffering can cause this value to differ from date_created.. Format: date-time-rfc-2822 |
message_text | The text of the notification. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| more_info | The URL for more information about the error condition. This value is a page in our Error Dictionary.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| request_method | The HTTP method used to generate the notification. If the notification was generated during a phone call, this is the HTTP Method used to request the resource on your server. If the notification was generated by your use of our REST API, this is the HTTP method used to call the resource on our servers.. Values: GET, POST. Format: http-method |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| request_url | The URL of the resource that generated the notification. If the notification was generated during a phone call, this is the URL of the resource on your server that caused the notification. If the notification was generated by your use of our REST API, this is the URL of the resource you called.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
request_variables | The HTTP GET or POST variables we sent to your server. However, if the notification was generated by our REST API, this contains the HTTP POST or PUT variables you sent to our API. |
response_body | The HTTP body returned by your server. |
response_headers | The HTTP headers returned by your server. |
sid | The unique string that that we created to identify the Notification resource. |
uri | The URI of the resource, relative to https://api.twilio.com. |
Summary
Types
@type t() :: %Twilio.Resources.Api.V2010.Notification{ account_sid: String.t() | nil, api_version: String.t() | nil, call_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, error_code: String.t() | nil, log: String.t() | nil, message_date: String.t() | nil, message_text: String.t() | nil, more_info: String.t() | nil, request_method: String.t() | nil, request_url: String.t() | nil, request_variables: String.t() | nil, response_body: String.t() | nil, response_headers: String.t() | nil, sid: String.t() | nil, uri: String.t() | nil }