credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
An OutgoingCallerId resource represents a single verified number that may be used as a caller ID when making outgoing calls via the REST API and within the TwiML <Dial> verb.
SID prefix: PN
Parent: /Accounts/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the OutgoingCallerId resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time-rfc-2822 |
friendly_name | The string that you assigned to describe the resource.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
phone_number | The phone number in E.164 format, which consists of a + followed by the country code and subscriber number.. Format: phone-number. PII: standard |
sid | The unique string that that we created to identify the OutgoingCallerId resource. |
uri | The URI of the resource, relative to https://api.twilio.com. |