Queues of calls
SID prefix: QU
Parent: /Accounts/{Sid}.json
Sub-resources
members—/2010-04-01/Accounts/{account_sid}/Queues/{queue_sid}/Members.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created this Queue resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
average_wait_time | The average wait time in seconds of the members in this queue. This is calculated at the time of the request. |
current_size | The number of calls currently in the queue. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT that this resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT that this resource was last updated, specified in RFC 2822 format.. Format: date-time-rfc-2822 |
friendly_name | A string that you assigned to describe this resource. |
max_size | The maximum number of calls that can be in the queue. The default is 1000 and the maximum is 5000. |
sid | The unique string that that we created to identify this Queue resource. |
uri | The URI of this resource, relative to https://api.twilio.com. |