Calls in a call queue
Parent: /Accounts/{AccountSid}/Queues/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
call_sid | The SID of the Call the Member resource is associated with. |
date_enqueued | The date that the member was enqueued, given in RFC 2822 format.. Format: date-time-rfc-2822 |
position | This member's current position in the queue. |
queue_sid | The SID of the Queue the member is in. |
uri | The URI of the resource, relative to https://api.twilio.com. |
wait_time | The number of seconds the member has been in the queue. |