Lists of SIP credentials
SID prefix: CL
Parent: /Accounts/{AccountSid}/SIP.json
Sub-resources
credentials—/2010-04-01/Accounts/{account_sid}/SIP/CredentialLists/{credential_list_sid}/Credentials.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The unique id of the Account that owns this resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date that this resource was created, given as GMT in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date that this resource was last updated, given as GMT in RFC 2822 format.. Format: date-time-rfc-2822 |
friendly_name | A human readable descriptive text that describes the CredentialList, up to 64 characters long. |
sid | A 34 character string that uniquely identifies this resource. |
subresource_uris | A list of credentials associated with this credential list.. Format: uri-map |
uri | The URI for this resource, relative to https://api.twilio.com. |