Twilio.Resources.Api.V2010.SIP.Domain.Auth.Call.AuthCallsCredentialListMapping
(twilio_elixir v0.1.1)
Credential lists for SIP calls
SID prefix: CL
Parent: /Accounts/{AccountSid}/SIP/Domains/{DomainSid}/Auth/Calls.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the CredentialListMapping resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time-rfc-2822 |
friendly_name | The string that you assigned to describe the resource.. PII: standard |
sid | The unique string that that we created to identify the CredentialListMapping resource. |