Access control lists of IP address resources
SID prefix: AL
Parent: /Accounts/{AccountSid}/SIP.json
Sub-resources
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
ip_addresses—/2010-04-01/Accounts/{account_sid}/SIP/IpAccessControlLists/{ip_access_control_list_sid}/IpAddresses.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The unique id of the Account that owns this resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date that this resource was created, given as GMT in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date that this resource was last updated, given as GMT in RFC 2822 format.. Format: date-time-rfc-2822 |
friendly_name | A human readable descriptive text, up to 255 characters long. |
sid | A 34 character string that uniquely identifies this resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
subresource_uris | A list of the IpAddress resources associated with this IP access control list resource.. Format: uri-map |
uri | The URI for this resource, relative to https://api.twilio.com |