Messaging short codes
SID prefix: SC
Parent: /Accounts/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created this ShortCode resource. |
api_version | The API version used to start a new TwiML session when an SMS message is sent to this short code. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT that this resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT that this resource was last updated, specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
friendly_name | A string that you assigned to describe this resource. By default, the FriendlyName is the short code. |
short_code | The short code. e.g., 894546. |
sid | The unique string that that we created to identify this ShortCode resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| sms_fallback_method | The HTTP method we use to call the sms_fallback_url. Can be: GET or POST.. Values: GET, POST. Format: http-method |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| sms_fallback_url | The URL that we call if an error occurs while retrieving or executing the TwiML from sms_url.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
sms_method | The HTTP method we use to call the sms_url. Can be: GET or POST.. Values: GET, POST. Format: http-method |
sms_url | The URL we call when receiving an incoming SMS message to this short code.. Format: uri |
uri | The URI of this resource, relative to https://api.twilio.com. |
Summary
Types
@type t() :: %Twilio.Resources.Api.V2010.SMS.ShortCode{ account_sid: String.t() | nil, api_version: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, friendly_name: String.t() | nil, short_code: String.t() | nil, sid: String.t() | nil, sms_fallback_method: String.t() | nil, sms_fallback_url: String.t() | nil, sms_method: String.t() | nil, sms_url: String.t() | nil, uri: String.t() | nil }