Credentials for ICE servers
Parent: /Accounts/{Sid}.json
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Token resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time-rfc-2822 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time-rfc-2822 |
ice_servers | An array representing the ephemeral credentials and the STUN and TURN server URIs. |
password | The temporary password that the username will use when authenticating with Twilio. |
ttl | The duration in seconds for which the username and password are valid. |
username | The temporary username that uniquely identifies a Token. |