Feedback resource.
Parent: /Assistants/{id}
Properties
| Field | Description |
|---|---|
account_sid | The SID of the Account that created the Feedback. |
assistant_id | The Assistant ID. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the Feedback was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the Feedback was last updated specified in ISO 8601 format.. Format: date-time |
id | The Feedback ID. |
message_id | The Message ID. |
score | The Score to provide as Feedback (0-1). Format: float |
session_id | The Session ID. |
text | The text to be given as feedback. |
user_sid | The SID of the User created the Feedback. |