Knowledge resource.
Parent: /Assistants/{id}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Knowledge resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the Knowledge was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the Knowledge was last updated specified in ISO 8601 format.. Format: date-time |
description | The type of knowledge source. |
embedding_model | The embedding model to be used for the knowledge source. |
id | The description of knowledge. |
knowledge_source_details | The details of the knowledge source based on the type. |
name | The name of the knowledge source. |
status | The status of processing the knowledge source ('QUEUED', 'PROCESSING', 'COMPLETED', 'FAILED') |
type | The type of knowledge source ('Web', 'Database', 'Text', 'File') |
url | The url of the knowledge resource. |
Summary
Types
@type t() :: %Twilio.Resources.Assistants.V1.Assistant.Knowledge{ account_sid: String.t(), date_created: String.t(), date_updated: String.t(), description: String.t(), embedding_model: String.t(), id: String.t(), knowledge_source_details: map(), name: String.t(), status: String.t(), type: String.t(), url: String.t() }