Message resource.
Parent: /Assistants/{id}
Properties
| Field | Description |
|---|---|
aborted | This property will denote whether the request was aborted or not. |
account_sid | The SID of the Account that sent the Message. |
body | If successful, the body of the generated response |
error | The error message if generation was not successful |
flagged | If successful, this property will denote whether the response was flagged or not. |
session_id | The unique name for the session. |
status | success or failure based on whether the request successfully generated a response. |