Tool resource.
Parent: /Assistants/{id}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Tool resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the Tool was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the Tool was last updated specified in ISO 8601 format.. Format: date-time |
description | The description of the tool. |
enabled | True if the tool is enabled. |
id | The tool ID. |
meta | The metadata related to method, url, input_schema to used with the Tool. |
name | The name of the tool. |
requires_auth | The authentication requirement for the tool. |
type | The type of the tool. ('WEBHOOK') |
url | The url of the tool resource. |