Message resource.
Parent: /Sessions/{id}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Message resource. |
assistant_id | The Assistant ID. |
content | The content of the message. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the Message was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the Message was last updated specified in ISO 8601 format.. Format: date-time |
id | The message ID. |
identity | The identity of the user. |
meta | The metadata of the message. |
role | The role of the user associated with the message. |
session_id | The Session ID. |