Pending invitations to users to become channel members
SID prefix: IN
Parent: /Services/{ServiceSid}/Channels/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Invite resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
channel_sid | The SID of the Channel the resource belongs to. |
created_by | The identity of the User that created the invite. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
identity | The application-defined string that uniquely identifies the resource's User within the Service. See access tokens for more info.. PII: standard |
role_sid | The SID of the Role assigned to the resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
service_sid | The SID of the Service the resource is associated with. |
sid | The unique string that we created to identify the Invite resource. |
url | The absolute URL of the Invite resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Chat.V1.Service.Channel.Invite{ account_sid: String.t() | nil, channel_sid: String.t() | nil, created_by: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, identity: String.t() | nil, role_sid: String.t() | nil, service_sid: String.t() | nil, sid: String.t() | nil, url: String.t() | nil }