Users joined to specific channels
SID prefix: MB
Parent: /Services/{ServiceSid}/Channels/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Member resource. |
channel_sid | The unique ID of the Channel for the member. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| identity | The application-defined string that uniquely identifies the resource's User within the Service. See access tokens for more info.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| last_consumed_message_index | The index of the last Message in the Channel that the Member has read. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
last_consumption_timestamp | The ISO 8601 timestamp string that represents the date-time of the last Message read event for the Member within the Channel.. Format: date-time |
role_sid | The SID of the Role assigned to the member. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
service_sid | The SID of the Service the resource is associated with. |
sid | The unique string that we created to identify the Member resource. |
url | The absolute URL of the Member resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Chat.V1.Service.Channel.Member{ account_sid: String.t() | nil, channel_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, identity: String.t() | nil, last_consumed_message_index: integer() | nil, last_consumption_timestamp: String.t() | nil, role_sid: String.t() | nil, service_sid: String.t() | nil, sid: String.t() | nil, url: String.t() | nil }