Webhooks for specific channels
SID prefix: WH
Parent: /Services/{ServiceSid}/Channels/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Channel Webhook resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| channel_sid | The SID of the Channel the Channel Webhook resource belongs to. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| configuration | The JSON string that describes how the channel webhook is configured. The configuration object contains the url, method, filters, and retry_count values that are configured by the create and update actions. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
service_sid | The SID of the Service the Channel Webhook resource is associated with. |
sid | The unique string that we created to identify the Channel Webhook resource. |
type | The type of webhook. Can be: webhook, studio, or trigger. |
url | The absolute URL of the Channel Webhook resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Chat.V2.Service.Channel.Webhook{ account_sid: String.t() | nil, channel_sid: String.t() | nil, configuration: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, service_sid: String.t() | nil, sid: String.t() | nil, type: String.t() | nil, url: String.t() | nil }