Twilio.Resources.Content.V1.Content.ApprovalRequest
(twilio_elixir v0.1.1)
An Approval Fetch resource represents the approval status of a Content resource.
SID prefix: HX
Parent: /Content/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created Content resource. |
sid | The unique string that that we created to identify the Content resource. |
url | The URL of the resource, relative to https://content.twilio.com.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| whatsapp | Contains the whatsapp approval information for the Content resource, with fields such as approval status, rejection reason, and category, amongst others. |