A Legacy Content resource represents legacy rich messaging content.
SID prefix: HX
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created Content resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time |
friendly_name | A string name used to describe the Content resource. Not visible to the end recipient. |
language | Two-letter (ISO 639-1) language code (e.g., en) identifying the language the Content resource is in. |
legacy_body | The string body field of the legacy content template associated with this Content resource |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
legacy_template_name | The string name of the legacy content template associated with this Content resource, unique across all template names for its account. Only lowercase letters, numbers and underscores are allowed |
sid | The unique string that that we created to identify the Content resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
types | The Content types (e.g. twilio/text) for this Content resource. |
url | The URL of the resource, relative to https://content.twilio.com.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| variables | Defines the default placeholder values for variables included in the Content resource. e.g. {"1": "Customer_Name"}. |
Summary
Types
@type t() :: %Twilio.Resources.Content.V1.LegacyContent{ account_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, friendly_name: String.t() | nil, language: String.t() | nil, legacy_body: String.t() | nil, legacy_template_name: String.t() | nil, sid: String.t() | nil, types: map() | nil, url: String.t() | nil, variables: map() | nil }