The Configuration resource manages a set of account-level settings applicable to the Conversations API.
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account responsible for this configuration. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| default_chat_service_sid | The SID of the default Conversation Service used when creating a conversation. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| default_closed_timer | Default ISO8601 duration when conversation will be switched to closed state. Minimum value for this timer is 10 minutes. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| default_inactive_timer | Default ISO8601 duration when conversation will be switched to inactive state. Minimum value for this timer is 1 minute. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| default_messaging_service_sid | The SID of the default Messaging Service used when creating a conversation. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
links | Contains absolute API resource URLs to access the webhook and default service configurations.. Format: uri-map |
url | An absolute API resource URL for this global configuration.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Conversations.V1.Configuration{ account_sid: String.t() | nil, default_chat_service_sid: String.t() | nil, default_closed_timer: String.t() | nil, default_inactive_timer: String.t() | nil, default_messaging_service_sid: String.t() | nil, links: map() | nil, url: String.t() | nil }