A Role resource represents a set of permissions granted to a user within a service or a conversation.
SID prefix: RL
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Role resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| chat_service_sid | The SID of the Conversation Service the Role resource is associated with. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
friendly_name | The string that you assigned to describe the resource.. PII: standard |
permissions | An array of the permissions the role has been granted. |
sid | The unique string that we created to identify the Role resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
type | The type of role. Can be: conversation for Conversation roles or service for Conversation Service roles.. Values: conversation, service |
url | An absolute API resource URL for this user role.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Conversations.V1.Role{ account_sid: String.t() | nil, chat_service_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, friendly_name: String.t() | nil, permissions: list() | nil, sid: String.t() | nil, type: String.t(), url: String.t() | nil }