A Service resource is a top-level conversation resource container that serves as a data silo.
SID prefix: IS
Sub-resources
bindings — /v1/Services/{chat_service_sid}/Bindingsconfiguration — /v1/Services/{chat_service_sid}/Configurationconversation_with_participants — /v1/Services/{chat_service_sid}/ConversationWithParticipantsconversations — /v1/Services/{chat_service_sid}/Conversationsparticipant_conversations — /v1/Services/{chat_service_sid}/ParticipantConversationsroles — /v1/Services/{chat_service_sid}/Rolesusers — /v1/Services/{chat_service_sid}/Users
Properties
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The unique ID of the Account responsible for this service. |
date_created | The date that this resource was created.. Format: date-time |
date_updated | The date that this resource was last updated.. Format: date-time |
friendly_name | The human-readable name of this service, limited to 256 characters. Optional.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
links | Contains absolute API resource URLs to access conversations, users, roles, bindings and configuration of this service.. Format: uri-map |
sid | A 34 character string that uniquely identifies this resource. |
url | An absolute API resource URL for this service.. Format: uri |