Twilio.Resources.Conversations.V1.Service.Configuration
(twilio_elixir v0.1.1)
A Service Configuration resource manages service-level settings applicable to the Conversation API.
Parent: /Services/{Sid}
Properties
| Field | Description |
|---|---|
chat_service_sid | The unique string that we created to identify the Service configuration resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| default_chat_service_role_sid | The service-level role assigned to users when they are added to the service. See Conversation Role for more info about roles. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| default_conversation_creator_role_sid | The conversation-level role assigned to a conversation creator when they join a new conversation. See Conversation Role for more info about roles. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| default_conversation_role_sid | The conversation-level role assigned to users when they are added to a conversation. See Conversation Role for more info about roles. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| links | Contains an absolute API resource URL to access the push notifications configuration of this service.. Format: uri-map |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
reachability_enabled | Whether the Reachability Indicator is enabled for this Conversations Service. The default is false. |
url | An absolute API resource URL for this service configuration.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Conversations.V1.Service.Configuration{ chat_service_sid: String.t() | nil, default_chat_service_role_sid: String.t() | nil, default_conversation_creator_role_sid: String.t() | nil, default_conversation_role_sid: String.t() | nil, links: map() | nil, reachability_enabled: boolean() | nil, url: String.t() | nil }