A Service Notification resource manages a set of settings to determine push notification behavior at service level.
Parent: /Services/{ChatServiceSid}/Configuration
Properties
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The unique ID of the Account responsible for this configuration. |
added_to_conversation | The Push Notification configuration for being added to a Conversation. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
chat_service_sid | The SID of the Conversation Service the Configuration applies to. |
log_enabled | Weather the notification logging is enabled. |
new_message | The Push Notification configuration for New Messages. |
removed_from_conversation | The Push Notification configuration for being removed from a Conversation. |
url | An absolute API resource URL for this configuration.. Format: uri |