Twilio.Resources.Conversations.V1.Service.Configuration.Webhook
(twilio_elixir v0.1.1)
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
A service webhook configuration resource manages a service-level set of callback URLs and their configuration for receiving all the corresponding service events.
Parent: /Services/{ChatServiceSid}/Configuration
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The unique ID of the Account responsible for this service. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| chat_service_sid | The unique ID of the Conversation Service this conversation belongs to. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| filters | The list of events that your configured webhook targets will receive. Events not configured here will not fire. Possible values are onParticipantAdd, onParticipantAdded, onDeliveryUpdated, onConversationUpdated, onConversationRemove, onParticipantRemove, onConversationUpdate, onMessageAdd, onMessageRemoved, onParticipantUpdated, onConversationAdded, onMessageAdded, onConversationAdd, onConversationRemoved, onParticipantUpdate, onMessageRemove, onMessageUpdated, onParticipantRemoved, onMessageUpdate or onConversationStateUpdated. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
method | The HTTP method to be used when sending a webhook request. One of GET or POST.. Values: GET, POST |
post_webhook_url | The absolute url the post-event webhook request should be sent to.. Format: uri |
pre_webhook_url | The absolute url the pre-event webhook request should be sent to.. Format: uri |
url | An absolute API resource URL for this webhook.. Format: uri |