Twilio.Resources.Conversations.V1.Service.Conversation.Webhook
(twilio_elixir v0.1.1)
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
A Conversation-scoped Webhook resource manages a set of callback URLs and their configuration for receiving events specific to one conversation.
SID prefix: WH
Parent: /Services/{ChatServiceSid}/Conversations/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The unique ID of the Account responsible for this conversation. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
chat_service_sid | The SID of the Conversation Service the Participant resource is associated with. |
configuration | The configuration of this webhook. Is defined based on target. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
conversation_sid | The unique ID of the Conversation for this webhook. |
date_created | The date that this resource was created.. Format: date-time |
date_updated | The date that this resource was last updated.. Format: date-time |
sid | A 34 character string that uniquely identifies this resource. |
target | The target of this webhook: webhook, studio, trigger |
url | An absolute API resource URL for this webhook.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Conversations.V1.Service.Conversation.Webhook{ account_sid: String.t() | nil, chat_service_sid: String.t() | nil, configuration: String.t() | nil, conversation_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, sid: String.t() | nil, target: String.t() | nil, url: String.t() | nil }