A User resource represents a conversation user belonging to a default conversation service.
SID prefix: US
Sub-resources
user_conversations—/v1/Users/{user_sid}/Conversations
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the User resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| attributes | The JSON Object string that stores application-specific data. If attributes have not been set, {} is returned.. PII: sensitive |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| chat_service_sid | The SID of the Conversation Service the User resource is associated with. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
friendly_name | The string that you assigned to describe the resource.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| identity | The application-defined string that uniquely identifies the resource's User within the Conversation Service. This value is often a username or an email address, and is case-sensitive.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| is_notifiable | Whether the User has a potentially valid Push Notification registration (APN or GCM) for this Conversations Service. If at least one registration exists, true; otherwise false. This value is only returned by Fetch actions that return a single resource and null is always returned by a Read action. This value is null if the Service's reachability_enabled is false, and if the User has never had a notification registration, even if the Service's reachability_enabled is true. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
is_online | Whether the User is actively connected to this Conversations Service and online. This value is only returned by Fetch actions that return a single resource and null is always returned by a Read action. This value is null if the Service's reachability_enabled is false, if the User has never been online for this Conversations Service, even if the Service's reachability_enabled is true. |
links | Format: uri-map |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
role_sid | The SID of a service-level Role assigned to the user. |
sid | The unique string that we created to identify the User resource. |
url | An absolute API resource URL for this user.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Conversations.V1.User{ account_sid: String.t() | nil, attributes: String.t() | nil, chat_service_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, friendly_name: String.t() | nil, identity: String.t() | nil, is_notifiable: boolean() | nil, is_online: boolean() | nil, links: map() | nil, role_sid: String.t() | nil, sid: String.t() | nil, url: String.t() | nil }