Version of the Schema
Parent: /Schemas/{Id}
Properties
| Field | Description |
|---|---|
date_created | The date the schema version was created, given in ISO 8601 format.. Format: date-time |
id | The unique identifier of the schema. Each schema can have multiple versions, that share the same id. |
raw | Format: uri |
schema_version | The version of this schema. |
url | The URL of this resource.. Format: uri |