Subscription to send Event Types to a Sink
SID prefix: DF
Sub-resources
subscribed_events—/v1/Subscriptions/{subscription_sid}/SubscribedEvents
Properties
| Field | Description |
|---|---|
account_sid | The unique SID identifier of the Account. |
date_created | The date that this Subscription was created, given in ISO 8601 format.. Format: date-time |
date_updated | The date that this Subscription was updated, given in ISO 8601 format.. Format: date-time |
description | A human readable description for the Subscription |
links | Contains a dictionary of URL links to nested resources of this Subscription.. Format: uri-map |
sid | A 34 character string that uniquely identifies this Subscription. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
sink_sid | The SID of the sink that events selected by this subscription should be sent to. Sink must be active for the subscription to be created. |
url | The URL of this resource.. Format: uri |