Twilio.Resources.Flex.V1.Insight.QualityManagement.Assessment.Comment
(twilio_elixir v0.1.1)
Comment resource.
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Flex Insights resource and owns this resource. |
agent_id | The id of the agent. |
assessment_sid | The SID of the assessment. |
comment | The comment added for assessment. |
offset | The offset |
report | The flag indicating if this assessment is part of report |
segment_id | The id of the segment. |
timestamp | The timestamp when the record is inserted |
url | Format: uri |
user_email | The email id of the user. |
user_name | The name of the user. |
weight | The weightage given to this comment |
Summary
Types
@type t() :: %Twilio.Resources.Flex.V1.Insight.QualityManagement.Assessment.Comment{ account_sid: String.t() | nil, agent_id: String.t() | nil, assessment_sid: String.t() | nil, comment: String.t() | nil, offset: String.t() | nil, report: boolean() | nil, segment_id: String.t() | nil, timestamp: String.t() | nil, url: String.t() | nil, user_email: String.t() | nil, user_name: String.t() | nil, weight: String.t() | nil }