Twilio.Resources.Flex.V1.Insight.QualityManagement.InsightsQuestionnaires
(twilio_elixir v0.1.1)
InsightsQuestionnaires resource.
Properties
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Flex Insights resource and owns this resource. |
active | The flag to enable or disable questionnaire |
description | The description of this questionnaire |
name | The name of this category. |
questionnaire_sid | The sid of this questionnaire |
questions | The list of questions with category for a questionnaire |
url | Format: uri |