Twilio.Resources.Flex.V1.Insight.QualityManagement.Question
(twilio_elixir v0.1.1)
Question resource.
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Flex Insights resource and owns this resource. |
allow_na | The flag to enable for disable NA for answer. |
answer_set | Set of answers for the question |
answer_set_id | The answer_set for the question. |
category | The Category for the question. |
description | The description for the question. |
question | The question. |
question_sid | The SID of the question |
url | Format: uri |
usage | Integer value that tells a particular question is used by how many questionnaires |
Summary
Types
@type t() :: %Twilio.Resources.Flex.V1.Insight.QualityManagement.Question{ account_sid: String.t() | nil, allow_na: boolean() | nil, answer_set: String.t() | nil, answer_set_id: String.t() | nil, category: String.t() | nil, description: String.t() | nil, question: String.t() | nil, question_sid: String.t() | nil, url: String.t() | nil, usage: integer() }