Interaction resource.
SID prefix: KD
Sub-resources
channels—/v1/Interactions/{interaction_sid}/Channels
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
channel | A JSON object that defines the Interaction’s communication channel and includes details about the channel. See the Outbound SMS and inbound (API-initiated) Channel object examples. |
links | Format: uri-map |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
routing | A JSON Object representing the routing rules for the Interaction Channel. See Outbound SMS Example for an example Routing object. The Interactions resource uses TaskRouter for all routing functionality. All attributes in the Routing object on your Interaction request body are added “as is” to the task. For a list of known attributes consumed by the Flex UI and/or Flex Insights, see Known Task Attributes. |
sid | The unique string created by Twilio to identify an Interaction resource, prefixed with KD. |
url | Format: uri |