Twilio.Resources.Flex.V1.Interaction.Channel.InteractionChannelInvite
(twilio_elixir v0.1.1)
InteractionChannelInvite resource.
SID prefix: KG
Parent: /Interactions/{InteractionSid}/Channels/{Sid}
Properties
| Field | Description |
|---|---|
channel_sid | The Channel SID for this Invite. |
interaction_sid | The Interaction SID for this Channel. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
routing | A JSON object representing the routing rules for the Interaction Channel. See Outbound SMS Example for an example Routing object. The Interactions resource uses TaskRouter for all routing functionality. All attributes in the Routing object on your Interaction request body are added “as is” to the task. For a list of known attributes consumed by the Flex UI and/or Flex Insights, see Known Task Attributes. |
sid | The unique string created by Twilio to identify an Interaction Channel Invite resource. |
url | Format: uri |