Twilio.Resources.Flex.V1.Interaction.InteractionChannel
(twilio_elixir v0.1.1)
InteractionChannel resource.
SID prefix: UO
Parent: /Interactions/{Sid}
Sub-resources
invites—/v1/Interactions/{interaction_sid}/Channels/{channel_sid}/Invitesparticipants—/v1/Interactions/{interaction_sid}/Channels/{channel_sid}/Participantstransfers—/v1/Interactions/{interaction_sid}/Channels/{channel_sid}/Transfers
Properties
| Field | Description |
|---|---|
error_code | The Twilio error code for a failed channel. |
error_message | The error message for a failed channel. |
interaction_sid | The unique string created by Twilio to identify an Interaction resource, prefixed with KD. |
links | Format: uri-map |
sid | The unique string created by Twilio to identify an Interaction Channel resource, prefixed with UO. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| status | The status of this channel.. Values: setup, active, failed, closed, inactive, pause, transfer |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
type | The Interaction Channel's type. Can be: sms, email, chat, whatsapp, web, messenger, or gbm. Note: These can be different from the task channel type specified in the Routing attributes. Task channel type corresponds to channel capacity while this channel type is the actual media type. Values: voice, sms, email, web, whatsapp, chat, messenger, gbm |
url | Format: uri |