PluginVersions resource.
SID prefix: FV
Parent: /PluginService/Plugins/{Sid}
Properties
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Flex Plugin Version resource and owns this resource. |
archived | Whether the Flex Plugin Version is archived. The default value is false. |
changelog | A changelog that describes the changes this Flex Plugin Version brings.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_created | The date and time in GMT when the Flex Plugin Version was created specified in ISO 8601 format.. Format: date-time |
plugin_sid | The SID of the Flex Plugin resource this Flex Plugin Version belongs to. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
plugin_url | The URL of where the Flex Plugin Version JavaScript bundle is hosted on.. Format: uri. PII: standard |
private | Whether the Flex Plugin Version is validated. The default value is false. |
sid | The unique string that we created to identify the Flex Plugin Version resource. |
url | The absolute URL of the Flex Plugin Version resource.. Format: uri |
version | The unique version of this Flex Plugin Version. |