Release resource.
SID prefix: FK
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Plugin Release resource and owns this resource. |
configuration_sid | The SID of the Plugin Configuration resource to release. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_created | The date and time in GMT when the Flex Plugin Release was created specified in ISO 8601 format.. Format: date-time |
sid | The unique string that we created to identify the Plugin Release resource. |
url | The absolute URL of the Plugin Release resource.. Format: uri |