WebChannel resource.
SID prefix: CH
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the WebChannel resource and owns this Workflow. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
flex_flow_sid | The SID of the Flex Flow. |
sid | The unique string that we created to identify the WebChannel resource. |
url | The absolute URL of the WebChannel resource.. Format: uri |