Participant resource.
Parent: /Video/Rooms/{RoomSid}
Properties
| Field | Description |
|---|
account_sid | Account SID associated with the room. |
codecs | Codecs detected from the participant. Can be VP8, H264, or VP9. |
duration_sec | Amount of time in seconds the participant was in the room.. Format: int64 |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| edge_location | Name of the edge location the participant connected to. See the list of public edge locations for the possible values.. Values: ashburn, dublin, frankfurt, singapore, sydney, sao_paulo, roaming, umatilla, tokyo |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
end_reason | Reason the participant left the room. See the list of possible values here. |
error_code | Errors encountered by the participant. |
error_code_url | Twilio error code dictionary link. |
join_time | When the participant joined the room.. Format: date-time |
leave_time | When the participant left the room.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
media_region | Twilio media region the participant connected to. See the list of possible media servers here.. Values: us1, us2, au1, br1, ie1, jp1, sg1, in1, de1, gll |
participant_identity | The application-defined string that uniquely identifies the participant within a Room. |
participant_sid | Unique identifier for the participant. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| properties | Object containing information about the participant's data from the room. See below for more information. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
publisher_info | Object containing information about the SDK name and version. See below for more information. |
room_sid | Unique identifier for the room. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
status | Status of the room. Can be in_progress or completed.. Values: in_progress, connected, completed, disconnected |
url | URL of the participant resource.. Format: uri |