AvailableAddOn resource.
SID prefix: XB
Sub-resources
extensions—/v1/AvailableAddOns/{available_add_on_sid}/Extensions
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
configuration_schema | The JSON object with the configuration that must be provided when installing a given Add-on. |
description | A short description of the Add-on's functionality. |
friendly_name | The string that you assigned to describe the resource. |
links | The URLs of related resources.. Format: uri-map |
pricing_type | How customers are charged for using this Add-on. |
sid | The unique string that we created to identify the AvailableAddOn resource. |
url | The absolute URL of the resource.. Format: uri |