Twilio.Resources.Messaging.V1.A2p.BrandRegistration.SmsOtp
(twilio_elixir v0.1.1)
A Messaging Service resource to retry OTP verification for Sole Proprietor Brand Registrations.
Parent: /a2p/BrandRegistrations/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Brand Registration resource. |
brand_registration_sid | The unique string to identify Brand Registration of Sole Proprietor Brand |