A Messaging Service resource to add and get Brand Vettings.
Parent: /a2p/BrandRegistrations/{Sid}
Properties
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the vetting record. |
brand_sid | The unique string to identify Brand Registration. |
brand_vetting_sid | The Twilio SID of the third-party vetting record. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
url | The absolute URL of the Brand Vetting resource.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
vetting_class | The type of vetting that has been conducted. One of “STANDARD” (Aegis) or “POLITICAL” (Campaign Verify). |
vetting_id | The unique identifier of the vetting from the third-party provider. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
vetting_provider | The third-party provider that has conducted the vetting. One of “CampaignVerify” (Campaign Verify tokens) or “AEGIS” (Secondary Vetting).. Values: campaign-verify, aegis |
vetting_status | The status of the import vetting attempt. One of “PENDING,” “SUCCESS,” or “FAILED”. |