Twilio.Resources.Messaging.V1.Service.PreregisteredUsa2p
(twilio_elixir v0.1.1)
Resource to associate preregistered campaign with Messaging Service.
SID prefix: QE
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that the Campaign belongs to. |
campaign_id | ID of the preregistered campaign. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
messaging_service_sid | The SID of the Messaging Service that the resource is associated with. |
sid | The unique string that identifies a US A2P Compliance resource QE2c6890da8086d771620e9b13fadeba0b. |