Debugger alerts
SID prefix: NO
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Alert resource. |
alert_text | The text of the alert. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| api_version | The API version used when the alert was generated. Can be empty for events that don't have a specific API version. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_generated | The date and time in GMT when the alert was generated specified in ISO 8601 format. Due to buffering, this can be different than date_created.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
error_code | The error code for the condition that generated the alert. See the Error Dictionary for possible causes and solutions to the error. |
log_level | The log level. Can be: error, warning, notice, or debug. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| more_info | The URL of the page in our Error Dictionary with more information about the error condition. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| request_headers | The request headers of the request that generated the alert. This value is only returned when a single Alert resource is fetched. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| request_method | The method used by the request that generated the alert. If the alert was generated by a request we made to your server, this is the method we used. If the alert was generated by a request from your application to our API, this is the method your application used.. Values: GET, POST. Format: http-method |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| request_url | The URL of the request that generated the alert. If the alert was generated by a request we made to your server, this is the URL on your server that generated the alert. If the alert was generated by a request from your application to our API, this is the URL of the resource requested. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| request_variables | The variables passed in the request that generated the alert. This value is only returned when a single Alert resource is fetched. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| resource_sid | The SID of the resource for which the alert was generated. For instance, if your server failed to respond to an HTTP request during the flow of a particular call, this value would be the SID of the server. This value is empty if the alert was not generated for a particular resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| response_body | The response body of the request that generated the alert. This value is only returned when a single Alert resource is fetched. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
response_headers | The response headers of the request that generated the alert. This value is only returned when a single Alert resource is fetched. |
service_sid | The SID of the service or resource that generated the alert. Can be null. |
sid | The unique string that we created to identify the Alert resource. |
url | The absolute URL of the Alert resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Monitor.V1.Alert{ account_sid: String.t() | nil, alert_text: String.t() | nil, api_version: String.t() | nil, date_created: String.t() | nil, date_generated: String.t() | nil, date_updated: String.t() | nil, error_code: String.t() | nil, log_level: String.t() | nil, more_info: String.t() | nil, request_headers: String.t() | nil, request_method: String.t() | nil, request_url: String.t() | nil, request_variables: String.t() | nil, resource_sid: String.t() | nil, response_body: String.t() | nil, response_headers: String.t() | nil, service_sid: String.t() | nil, sid: String.t() | nil, url: String.t() | nil }