Credential resource.
SID prefix: CR
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Credential resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
friendly_name | The string that you assigned to describe the resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
sandbox | [APN only] Whether to send the credential to sandbox APNs. Can be true to send to sandbox APNs or false to send to production. |
sid | The unique string that we created to identify the Credential resource. |
type | The Credential type. Can be: gcm, fcm, or apn.. Values: gcm, apn, fcm |
url | The absolute URL of the Credential resource.. Format: uri |