Twilio.Resources.Numbers.V1.HostedNumber.Eligibility.Bulk
(twilio_elixir v0.1.1)
Bulk resource.
Properties
| Field | Description |
|---|---|
date_completed | Format: date-time |
date_created | Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
friendly_name | This is the string that you assigned as a friendly name for describing the eligibility check request. |
request_id | The SID of the bulk eligibility check that you want to know about. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
results | The result set that contains the eligibility check response for each requested number, each result has at least the following attributes: phone_number: The requested phone number ,hosting_account_sid: The account sid where the phone number will be hosted, country: Phone number’s country, eligibility_status: Indicates the eligibility status of the PN (Eligible/Ineligible), eligibility_sub_status: Indicates the sub status of the eligibility , ineligibility_reason: Reason for number's ineligibility (if applicable), next_step: Suggested next step in the hosting process based on the eligibility status. |
status | This is the status of the bulk eligibility check request. (Example: COMPLETE, IN_PROGRESS) |
url | This is the url of the request that you're trying to reach out to locate the resource.. Format: uri |