Twilio.Resources.Numbers.V1.Porting.Configuration.Webhook
(twilio_elixir v0.1.1)
Webhook resource.
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
notifications_of | A list to filter what notification events to receive for this account and its sub accounts. If it is an empty list, then it means that there are no filters for the notifications events to send in each webhook and all events will get sent. |
port_in_target_date_created | Creation date for the port in webhook configuration. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
port_in_target_url | The complete webhook url that will be called when a notification event for port in request or port in phone number happens. Format: uri |
port_out_target_date_created | Creation date for the port out webhook configuration. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
port_out_target_url | The complete webhook url that will be called when a notification event for a port out phone number happens.. Format: uri |
url | The URL of the webhook configuration request. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Numbers.V1.Porting.Configuration.Webhook{ notifications_of: list() | nil, port_in_target_date_created: String.t() | nil, port_in_target_url: String.t() | nil, port_out_target_date_created: String.t() | nil, port_out_target_url: String.t() | nil, url: String.t() | nil }