Clone resource.
Properties
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Bundle resource. |
bundle_sid | The unique string that we created to identify the Bundle resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
email | The email address that will receive updates when the Bundle resource changes status. |
friendly_name | The string that you assigned to describe the resource. |
regulation_sid | The unique string of a regulation that is associated to the Bundle resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
status | The verification status of the Bundle resource.. Values: draft, pending-review, in-review, twilio-rejected, twilio-approved, provisionally-approved |
status_callback | The URL we call to inform your application of status changes.. Format: uri |
url | The URL of this resource.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| valid_until | The date and time in GMT in ISO 8601 format when the resource will be valid until.. Format: date-time |