Twilio.Resources.Numbers.V2.RegulatoryCompliance.Bundle.Evaluation
(twilio_elixir v0.1.1)
Evaluation resource.
SID prefix: EL
Parent: /RegulatoryCompliance/Bundles/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Bundle resource. |
bundle_sid | The unique string that we created to identify the Bundle resource. |
date_created | Format: date-time |
regulation_sid | The unique string of a regulation that is associated to the Bundle resource. |
results | The results of the Evaluation which includes the valid and invalid attributes. |
sid | The unique string that identifies the Evaluation resource. |
status | The compliance status of the Evaluation resource.. Values: compliant, noncompliant |
url | Format: uri |