Twilio.Resources.Numbers.V2.RegulatoryCompliance.SupportingDocumentType
(twilio_elixir v0.1.1)
SupportingDocumentType resource.
SID prefix: OY
Parent: /RegulatoryCompliance
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
fields | The required information for creating a Supporting Document. The required fields will change as regulatory needs change and will differ for businesses and individuals. |
friendly_name | A human-readable description of the Supporting Document Type resource. |
machine_name | The machine-readable description of the Supporting Document Type resource. |
sid | The unique string that identifies the Supporting Document Type resource. |
url | The absolute URL of the Supporting Document Type resource.. Format: uri |