Token resource.
Properties
| Field | Description |
|---|---|
access_token | Token which carries the necessary information to access a Twilio resource directly. |
expires_in | Format: int64 |
id_token | Token which carries the information necessary of user profile. |
refresh_token | Token which carries the information necessary to get a new access token. |
token_type | Token type |