Twilio.Resources.Preview.Marketplace.AvailableAddOn.AvailableAddOnExtension
(twilio_elixir v0.1.1)
AvailableAddOnExtension resource.
SID prefix: XF
Parent: /AvailableAddOns/{Sid}
Properties
| Field | Description |
|---|---|
available_add_on_sid | The SID of the AvailableAddOn resource to which this extension applies. |
friendly_name | The string that you assigned to describe the resource. |
product_name | The name of the Product this Extension is used within. |
sid | The unique string that we created to identify the AvailableAddOnExtension resource. |
unique_name | An application-defined string that uniquely identifies the resource. |
url | The absolute URL of the resource.. Format: uri |