InstalledAddOn resource.
SID prefix: XE
Sub-resources
extensions — /marketplace/InstalledAddOns/{installed_add_on_sid}/Extensionsusage — /marketplace/InstalledAddOns/{installed_add_on_sid}/Usage
Properties
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the InstalledAddOn resource. |
configuration | The JSON object that represents the current configuration of installed Add-on. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
description | A short description of the Add-on's functionality. |
friendly_name | The string that you assigned to describe the resource. |
links | The URLs of related resources.. Format: uri-map |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
sid | The unique string that we created to identify the InstalledAddOn resource. This Sid can also be found in the Console on that specific Add-ons page as the 'Available Add-on Sid'. |
unique_name | An application-defined string that uniquely identifies the resource. |
url | The absolute URL of the resource.. Format: uri |