Messaging pricing by country
Parent: /Messaging
Properties
| Field | Description |
|---|---|
country | The name of the country. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
inbound_sms_prices | The list of InboundPrice records that describe the price to receive an inbound SMS to the different Twilio phone number types supported in this country |
iso_country | The ISO country code.. Format: iso-country-code |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| outbound_sms_prices | The list of OutboundSMSPrice records that represent the price to send a message for each MCC/MNC applicable in this country. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
price_unit | The currency in which prices are measured, specified in ISO 4127 format (e.g. usd, eur, jpy).. Format: currency |
url | The absolute URL of the resource.. Format: uri |