Voice pricing by country
Parent: /Voice
Properties
| Field | Description |
|---|---|
country | The name of the country. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
inbound_call_prices | The list of InboundCallPrice records. |
iso_country | The ISO country code.. Format: iso-country-code |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| outbound_prefix_prices | The list of OutboundPrefixPrice records, which include a list of the prefixes, the friendly_name, base_price, and the current_price for those prefixes. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
price_unit | The currency in which prices are measured, specified in ISO 4127 format (e.g. usd, eur, jpy).. Format: currency |
url | The absolute URL of the resource.. Format: uri |