Voice pricing for a specific phone number
Parent: /Voice
Properties
| Field | Description |
|---|---|
country | The name of the country. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
inbound_call_price | The InboundCallPrice record. If null, the Phone Number is not a Twilio number owned by this account.. Format: inbound-call-price |
iso_country | The ISO country code.. Format: iso-country-code |
number | The phone number.. Format: phone-number |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| outbound_call_price | The OutboundCallPrice record, which includes a list of origination_prefixes and the base_price and current_price for those prefixes.. Format: outbound-call-price |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
price_unit | The currency in which prices are measured, specified in ISO 4127 format (e.g. usd, eur, jpy).. Format: currency |
url | The absolute URL of the resource.. Format: uri |