Twilio.Resources.Proxy.V1.Service.Session.Interaction
(twilio_elixir v0.1.1)
Interaction resource.
SID prefix: KI
Parent: /Services/{ServiceSid}/Sessions/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Interaction resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| data | A JSON string that includes the message body of message interactions (e.g. {"body": "hello"}) or the call duration (when available) of a call (e.g. {"duration": "5"}).. PII: sensitive |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The ISO 8601 date and time in GMT when the Interaction was created.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The ISO 8601 date and time in GMT when the resource was last updated.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| inbound_participant_sid | The SID of the inbound Participant resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| inbound_resource_sid | The SID of the inbound resource; either the Call or Message. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| inbound_resource_status | The inbound resource status of the Interaction. Will always be delivered for messages and in-progress for calls.. Values: accepted, answered, busy, canceled, completed, deleted, delivered, delivery-unknown, failed, in-progress, initiated, no-answer, queued, received, receiving, ringing, scheduled, sending, sent, undelivered, unknown |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
inbound_resource_type | The inbound resource type. Can be Call or Message. |
inbound_resource_url | The URL of the Twilio inbound resource. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| outbound_participant_sid | The SID of the outbound Participant). |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| outbound_resource_sid | The SID of the outbound resource; either the Call or Message. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| outbound_resource_status | The inbound resource status of the Interaction. Will always be delivered for messages and in-progress for calls.. Values: accepted, answered, busy, canceled, completed, deleted, delivered, delivery-unknown, failed, in-progress, initiated, no-answer, queued, received, receiving, ringing, scheduled, sending, sent, undelivered, unknown |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
outbound_resource_type | The outbound resource type. Can be: Call or Message. |
outbound_resource_url | The URL of the Twilio outbound resource.. Format: uri |
service_sid | The SID of the parent Service resource. |
session_sid | The SID of the parent Session resource. |
sid | The unique string that we created to identify the Interaction resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
type | The Type of the Interaction. Can be: message, voice or unknown.. Values: message, voice, unknown |
url | The absolute URL of the Interaction resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Proxy.V1.Service.Session.Interaction{ account_sid: String.t() | nil, data: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, inbound_participant_sid: String.t() | nil, inbound_resource_sid: String.t() | nil, inbound_resource_status: String.t(), inbound_resource_type: String.t() | nil, inbound_resource_url: String.t() | nil, outbound_participant_sid: String.t() | nil, outbound_resource_sid: String.t() | nil, outbound_resource_status: String.t(), outbound_resource_type: String.t() | nil, outbound_resource_url: String.t() | nil, service_sid: String.t() | nil, session_sid: String.t() | nil, sid: String.t() | nil, type: String.t(), url: String.t() | nil }