Twilio.Resources.Proxy.V1.Service.Session.Participant
(twilio_elixir v0.1.1)
Participant resource.
SID prefix: KP
Parent: /Services/{ServiceSid}/Sessions/{Sid}
Sub-resources
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
message_interactions—/v1/Services/{service_sid}/Sessions/{session_sid}/Participants/{participant_sid}/MessageInteractions
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Participant resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The ISO 8601 date and time in GMT when the resource was created.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_deleted | The ISO 8601 date when the Participant was removed from the session.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The ISO 8601 date and time in GMT when the resource was last updated.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| friendly_name | The string that you assigned to describe the participant. This value must be 255 characters or fewer. Supports UTF-8 characters. This value should not have PII. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
identifier | The phone number or channel identifier of the Participant. This value must be 191 characters or fewer. Supports UTF-8 characters.. PII: standard |
links | The URLs to resources related the participant.. Format: uri-map |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
proxy_identifier | The phone number or short code (masked number) of the participant's partner. The participant will call or message the partner participant at this number. |
proxy_identifier_sid | The SID of the Proxy Identifier assigned to the Participant. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
service_sid | The SID of the resource's parent Service resource. |
session_sid | The SID of the parent Session resource. |
sid | The unique string that we created to identify the Participant resource. |
url | The absolute URL of the Participant resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Proxy.V1.Service.Session.Participant{ account_sid: String.t() | nil, date_created: String.t() | nil, date_deleted: String.t() | nil, date_updated: String.t() | nil, friendly_name: String.t() | nil, identifier: String.t() | nil, links: map() | nil, proxy_identifier: String.t() | nil, proxy_identifier_sid: String.t() | nil, service_sid: String.t() | nil, session_sid: String.t() | nil, sid: String.t() | nil, url: String.t() | nil }