PhoneNumber resource.
SID prefix: QQ
Properties
| Field | Description |
|---|---|
account_sid | The unique SID identifier of the Account. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date that this phone number was assigned an Inbound Processing Region, given in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date that the Inbound Processing Region was updated for this phone number, given in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
friendly_name | A human readable description of the Inbound Processing Region assignments for this phone number, up to 64 characters. |
phone_number | The phone number in E.164 format |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
sid | A 34 character string that uniquely identifies the Inbound Processing Region assignments for this phone number. |
url | The absolute URL of the resource.. Format: uri |
voice_region | The Inbound Processing Region used for this phone number for voice. |