Twilio.Resources.Serverless.V1.Service.Build.Status
(twilio_elixir v0.1.1)
The status of a Build resource.
SID prefix: ZB
Parent: /Services/{ServiceSid}/Builds/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Build resource. |
service_sid | The SID of the Service that the Build resource is associated with. |
sid | The unique string that we created to identify the Build resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
status | The status of the Build. Can be: building, completed, or failed.. Values: building, completed, failed |
url | The absolute URL of the Build Status resource.. Format: uri |