Twilio.Resources.Serverless.V1.Service.Environment.Deployment
(twilio_elixir v0.1.1)
An association of a Build with an Environment so that the Build is published in the Environment.
SID prefix: ZD
Parent: /Services/{ServiceSid}/Environments/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Deployment resource. |
build_sid | The SID of the Build for the deployment. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the Deployment resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the Deployment resource was last updated specified in ISO 8601 format.. Format: date-time |
environment_sid | The SID of the Environment for the Deployment. |
service_sid | The SID of the Service that the Deployment resource is associated with. |
sid | The unique string that we created to identify the Deployment resource. |
url | The absolute URL of the Deployment resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Serverless.V1.Service.Environment.Deployment{ account_sid: String.t() | nil, build_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, environment_sid: String.t() | nil, service_sid: String.t() | nil, sid: String.t() | nil, url: String.t() | nil }