Twilio.Resources.Serverless.V1.Service.Environment.Log
(twilio_elixir v0.1.1)
A record of an event that occurred related to a function invocation.
SID prefix: NO
Parent: /Services/{ServiceSid}/Environments/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Log resource. |
build_sid | The SID of the build that corresponds to the log. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_created | The date and time in GMT when the Log resource was created specified in ISO 8601 format.. Format: date-time |
deployment_sid | The SID of the deployment that corresponds to the log. |
environment_sid | The SID of the environment in which the log occurred. |
function_sid | The SID of the function whose invocation produced the log. |
level | The log level. |
message | The log message. |
request_sid | The SID of the request associated with the log. |
service_sid | The SID of the Service that the Log resource is associated with. |
sid | The unique string that we created to identify the Log resource. |
url | The absolute URL of the Log resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Serverless.V1.Service.Environment.Log{ account_sid: String.t() | nil, build_sid: String.t() | nil, date_created: String.t() | nil, deployment_sid: String.t() | nil, environment_sid: String.t() | nil, function_sid: String.t() | nil, level: String.t() | nil, message: String.t() | nil, request_sid: String.t() | nil, service_sid: String.t() | nil, sid: String.t() | nil, url: String.t() | nil }