Twilio.Resources.Serverless.V1.Service.Function.Version.Content
(twilio_elixir v0.1.1)
The code of a Function Version.
SID prefix: ZN
Parent: /Services/{ServiceSid}/Functions/{FunctionSid}/Versions/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Function Version resource. |
content | The content of the Function Version resource. |
function_sid | The SID of the Function that is the parent of the Function Version. |
service_sid | The SID of the Service that the Function Version resource is associated with. |
sid | The unique string that we created to identify the Function Version resource. |
url | Format: uri |