Studio flows
SID prefix: FW
Sub-resources
engagements—/v1/Flows/{flow_sid}/Engagementsexecutions—/v1/Flows/{flow_sid}/Executions
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Flow resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
friendly_name | The string that you assigned to describe the Flow. |
links | The URLs of the Flow's nested resources.. Format: uri-map |
sid | The unique string that we created to identify the Flow resource. |
status | The status of the Flow. Can be: draft or published.. Values: draft, published |
url | The absolute URL of the resource.. Format: uri |
version | The latest version number of the Flow's definition. |