Studio flows
SID prefix: FW
Sub-resources
executions—/v2/Flows/{flow_sid}/Executionsrevisions—/v2/Flows/{sid}/Revisionstest_users—/v2/Flows/{sid}/TestUsers
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Flow resource. |
commit_message | Description of change made in the revision. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
definition | JSON representation of flow definition. |
errors | List of error in the flow definition. |
friendly_name | The string that you assigned to describe the Flow. |
links | The URLs of the Flow's nested resources.. Format: uri-map |
revision | The latest revision number of the Flow's definition. |
sid | The unique string that we created to identify the Flow resource. |
status | The status of the Flow. Can be: draft or published.. Values: draft, published |
url | The absolute URL of the resource.. Format: uri |
valid | Boolean if the flow definition is valid. |
warnings | List of warnings in the flow definition. |
webhook_url | Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Studio.V2.Flow{ account_sid: String.t() | nil, commit_message: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, definition: String.t() | nil, errors: list() | nil, friendly_name: String.t() | nil, links: map() | nil, revision: integer(), sid: String.t() | nil, status: String.t(), url: String.t() | nil, valid: boolean() | nil, warnings: list() | nil, webhook_url: String.t() | nil }