JSON context for executions
Parent: /Flows/{FlowSid}/Executions/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the ExecutionContext resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
context | The current state of the Flow's Execution. As a flow executes, we save its state in this context. We save data that your widgets can access as variables in configuration fields or in text areas as variable substitution.. PII: standard |
execution_sid | The SID of the context's Execution resource. |
flow_sid | The SID of the Flow. |
url | The absolute URL of the resource.. Format: uri |