NetworkAccessProfile resource.
SID prefix: HA
Sub-resources
networks—/v1/NetworkAccessProfiles/{network_access_profile_sid}/Networks
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that the Network Access Profile belongs to. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
links | Format: uri-map |
sid | The unique string that identifies the Network Access Profile resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
unique_name | An application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource. |
url | The absolute URL of the Network Access Profile resource.. Format: uri |