Twilio.Resources.Supersim.V1.NetworkAccessProfile.NetworkAccessProfileNetwork
(twilio_elixir v0.1.1)
Mobile operator networks which Network Access Profiles allow access to
SID prefix: HW
Parent: /NetworkAccessProfiles/{Sid}
Properties
| Field | Description |
|---|---|
friendly_name | A human readable identifier of the Network this resource refers to. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
identifiers | Array of objects identifying the MCC-MNCs that are included in the Network resource. |
iso_country | The ISO country code of the Network resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
network_access_profile_sid | The unique string that identifies the Network resource's Network Access Profile resource. |
sid | The unique string that identifies the Network resource. |
url | The absolute URL of the Network resource.. Format: uri |