Individual IoT Super SIMs
SID prefix: HS
Sub-resources
billing_periods—/v1/Sims/{sim_sid}/BillingPeriodssim_ip_addresses—/v1/Sims/{sim_sid}/IpAddresses
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that the Super SIM belongs to. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
fleet_sid | The unique ID of the Fleet configured for this SIM. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
iccid | The ICCID associated with the SIM.. PII: standard |
links | Format: uri-map |
sid | The unique string that identifies the Sim resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| status | The status of the Super SIM. Can be new, ready, active, inactive, or scheduled. See the Super SIM Status Values for a description of each.. Values: new, ready, active, inactive, scheduled |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
unique_name | An application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource. |
url | The absolute URL of the Sim Resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Supersim.V1.Sim{ account_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, fleet_sid: String.t() | nil, iccid: String.t() | nil, links: map() | nil, sid: String.t() | nil, status: String.t(), unique_name: String.t() | nil, url: String.t() | nil }