Billing Period for an IoT Super SIM
SID prefix: HB
Parent: /Sims/{Sid}
Properties
| Field | Description |
|---|---|
account_sid | The SID of the Account the Super SIM belongs to. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
end_time | The end time of the Billing Period specified in ISO 8601 format.. Format: date-time |
period_type | The type of Billing Period. Can be ready or active.. Values: ready, active |
sid | The SID of the Billing Period. |
sim_sid | The SID of the Super SIM the Billing Period belongs to. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| start_time | The start time of the Billing Period specified in ISO 8601 format.. Format: date-time |