Sync Document objects
SID prefix: ET
Parent: /Services/{Sid}
Sub-resources
permissions—/v1/Services/{service_sid}/Documents/{document_sid}/Permissions
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Document resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| created_by | The identity of the Sync Document's creator. If the Sync Document is created from the client SDK, the value matches the Access Token's identity field. If the Sync Document was created from the REST API, the value is system.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| data | An arbitrary, schema-less object that the Sync Document stores. Can be up to 16 KiB in length.. PII: sensitive |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_expires | The date and time in GMT when the Sync Document expires and will be deleted, specified in ISO 8601 format. If the Sync Document does not expire, this value is null. The Document resource might not be deleted immediately after it expires.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
links | The URLs of resources related to the Sync Document.. Format: uri-map |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| revision | The current revision of the Sync Document, represented as a string. The revision property is used with conditional updates to ensure data consistency. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
service_sid | The SID of the Sync Service the resource is associated with. |
sid | The unique string that we created to identify the Document resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
unique_name | An application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource and can be up to 320 characters long.. PII: standard |
url | The absolute URL of the Document resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Sync.V1.Service.Document{ account_sid: String.t() | nil, created_by: String.t() | nil, data: String.t() | nil, date_created: String.t() | nil, date_expires: String.t() | nil, date_updated: String.t() | nil, links: map() | nil, revision: String.t() | nil, service_sid: String.t() | nil, sid: String.t() | nil, unique_name: String.t() | nil, url: String.t() | nil }