Sync document permissions
Parent: /Services/{ServiceSid}/Documents/{Sid}
Properties
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Document Permission resource. |
document_sid | The SID of the Sync Document to which the Document Permission applies. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
identity | The application-defined string that uniquely identifies the resource's User within the Service to an FPA token.. PII: standard |
manage | Whether the identity can delete the Sync Document. |
read | Whether the identity can read the Sync Document. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
service_sid | The SID of the Sync Service the resource is associated with. |
url | The absolute URL of the Sync Document Permission resource.. Format: uri |
write | Whether the identity can update the Sync Document. |