Permission resource.
Parent: /Services/{ServiceSid}/Maps/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Sync Map Permission resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
identity | The application-defined string that uniquely identifies the resource's User within the Service to an FPA token.. PII: standard |
manage | Whether the identity can delete the Sync Map. |
map_sid | The SID of the Sync Map to which the Permission applies. |
read | Whether the identity can read the Sync Map and its Items. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
service_sid | The SID of the Sync Service the resource is associated with. |
url | The absolute URL of the Sync Map Permission resource.. Format: uri |
write | Whether the identity can create, update, and delete Items in the Sync Map. |