Activity resource.
SID prefix: WA
Parent: /Workspaces/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Activity resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| available | Whether the Worker is eligible to receive a Task when it occupies the Activity. A value of true, 1, or yes indicates the Activity is available. All other values indicate that it is not. The value cannot be changed after the Activity is created. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
friendly_name | The string that you assigned to describe the Activity resource. |
links | Format: uri-map |
sid | The unique string that we created to identify the Activity resource. |
url | The absolute URL of the Activity resource.. Format: uri |
workspace_sid | The SID of the Workspace that contains the Activity. |
Summary
Types
@type t() :: %Twilio.Resources.Taskrouter.V1.Workspace.Activity{ account_sid: String.t() | nil, available: boolean() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, friendly_name: String.t() | nil, links: map() | nil, sid: String.t() | nil, url: String.t() | nil, workspace_sid: String.t() | nil }