Twilio.Resources.Taskrouter.V1.Workspace.Worker.WorkerStatistics
(twilio_elixir v0.1.1)
WorkerStatistics resource.
Parent: /Workspaces/{WorkspaceSid}/Workers/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Worker resource. |
cumulative | An object that contains the cumulative statistics for the Worker. |
url | The absolute URL of the WorkerChannel statistics resource.. Format: uri |
worker_sid | The SID of the Worker that contains the WorkerChannel. |
workspace_sid | The SID of the Workspace that contains the WorkerChannel. |