Workflow resource.
SID prefix: WW
Parent: /Workspaces/{Sid}
Sub-resources
cumulative_statistics—/v1/Workspaces/{workspace_sid}/Workflows/{workflow_sid}/CumulativeStatisticsreal_time_statistics—/v1/Workspaces/{workspace_sid}/Workflows/{workflow_sid}/RealTimeStatisticsstatistics—/v1/Workspaces/{workspace_sid}/Workflows/{workflow_sid}/Statistics
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Workflow resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| assignment_callback_url | The URL that we call when a task managed by the Workflow is assigned to a Worker. See Assignment Callback URL for more information.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| configuration | A JSON string that contains the Workflow's configuration. See Configuring Workflows for more information. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
document_content_type | The MIME type of the document. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| fallback_assignment_callback_url | The URL that we call when a call to the assignment_callback_url fails.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
friendly_name | The string that you assigned to describe the Workflow resource. For example, Customer Support or 2014 Election Campaign.. PII: standard |
links | The URLs of related resources.. Format: uri-map |
sid | The unique string that we created to identify the Workflow resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
task_reservation_timeout | How long TaskRouter will wait for a confirmation response from your application after it assigns a Task to a Worker. Can be up to 86,400 (24 hours) and the default is 120. |
url | The absolute URL of the Workflow resource.. Format: uri |
workspace_sid | The SID of the Workspace that contains the Workflow. |
Summary
Types
@type t() :: %Twilio.Resources.Taskrouter.V1.Workspace.Workflow{ account_sid: String.t() | nil, assignment_callback_url: String.t() | nil, configuration: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, document_content_type: String.t() | nil, fallback_assignment_callback_url: String.t() | nil, friendly_name: String.t() | nil, links: map() | nil, sid: String.t() | nil, task_reservation_timeout: integer(), url: String.t() | nil, workspace_sid: String.t() | nil }