Twilio.Resources.Taskrouter.V1.Workspace.Workflow.WorkflowRealTimeStatistics
(twilio_elixir v0.1.1)
WorkflowRealTimeStatistics resource.
Parent: /Workspaces/{WorkspaceSid}/Workflows/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Workflow resource. |
longest_task_waiting_age | The age of the longest waiting Task. |
longest_task_waiting_sid | The SID of the longest waiting Task. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| tasks_by_priority | The number of Tasks by priority. For example: {"0": "10", "99": "5"} shows 10 Tasks at priority 0 and 5 at priority 99. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
tasks_by_status | The number of Tasks by their current status. For example: {"pending": "1", "reserved": "3", "assigned": "2", "completed": "5"}. |
total_tasks | The total number of Tasks. |
url | The absolute URL of the Workflow statistics resource.. Format: uri |
workflow_sid | Returns the list of Tasks that are being controlled by the Workflow with the specified SID value. |
workspace_sid | The SID of the Workspace that contains the Workflow. |
Summary
Types
@type t() :: %Twilio.Resources.Taskrouter.V1.Workspace.Workflow.WorkflowRealTimeStatistics{ account_sid: String.t() | nil, longest_task_waiting_age: integer(), longest_task_waiting_sid: String.t() | nil, tasks_by_priority: String.t() | nil, tasks_by_status: String.t() | nil, total_tasks: integer(), url: String.t() | nil, workflow_sid: String.t() | nil, workspace_sid: String.t() | nil }