Twilio.Resources.Taskrouter.V1.Workspace.Workflow.WorkflowStatistics
(twilio_elixir v0.1.1)
WorkflowStatistics resource.
Parent: /Workspaces/{WorkspaceSid}/Workflows/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Workflow resource. |
cumulative | An object that contains the cumulative statistics for the Workflow. |
realtime | An object that contains the real-time statistics for the Workflow. |
url | The absolute URL of the Workflow statistics resource.. Format: uri |
workflow_sid | Returns the list of Tasks that are being controlled by the Workflow with the specified SID value. |
workspace_sid | The SID of the Workspace that contains the Workflow. |