WorkspaceCumulativeStatistics resource.
Parent: /Workspaces/{Sid}
Properties
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Workspace resource. |
avg_task_acceptance_time | The average time in seconds between Task creation and acceptance. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
end_time | The end of the interval during which these statistics were calculated, in ISO 8601 format.. Format: date-time |
reservations_accepted | The total number of Reservations accepted by Workers. |
reservations_canceled | The total number of Reservations that were canceled. |
reservations_created | The total number of Reservations that were created for Workers. |
reservations_rejected | The total number of Reservations that were rejected. |
reservations_rescinded | The total number of Reservations that were rescinded. |
reservations_timed_out | The total number of Reservations that were timed out. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| split_by_wait_time | A list of objects that describe the number of Tasks canceled and reservations accepted above and below the thresholds specified in seconds. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
start_time | The beginning of the interval during which these statistics were calculated, in ISO 8601 format.. Format: date-time |
tasks_canceled | The total number of Tasks that were canceled. |
tasks_completed | The total number of Tasks that were completed. |
tasks_created | The total number of Tasks created. |
tasks_deleted | The total number of Tasks that were deleted. |
tasks_moved | The total number of Tasks that were moved from one queue to another. |
tasks_timed_out_in_workflow | The total number of Tasks that were timed out of their Workflows (and deleted). |
url | The absolute URL of the Workspace statistics resource.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| wait_duration_until_accepted | The wait duration statistics (avg, min, max, total) for Tasks that were accepted. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
wait_duration_until_canceled | The wait duration statistics (avg, min, max, total) for Tasks that were canceled. |
workspace_sid | The SID of the Workspace. |