Twilio.Resources.Taskrouter.V1.Workspace.WorkspaceStatistics
(twilio_elixir v0.1.1)
WorkspaceStatistics resource.
Parent: /Workspaces/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Workspace resource. |
cumulative | An object that contains the cumulative statistics for the Workspace. |
realtime | An object that contains the real-time statistics for the Workspace. |
url | The absolute URL of the Workspace statistics resource.. Format: uri |
workspace_sid | The SID of the Workspace. |