List of credentials for accessing a trunk
SID prefix: CL
Parent: /Trunks/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the CredentialList resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
friendly_name | The string that you assigned to describe the resource. |
sid | The unique string that we created to identify the CredentialList resource. |
trunk_sid | The SID of the Trunk the credential list in associated with. |
url | The absolute URL of the resource.. Format: uri |