Twilio.Resources.Trusthub.V1.ComplianceInquiry.Customer.ComplianceInquiries
(twilio_elixir v0.1.1)
ComplianceInquiries resource.
Properties
| Field | Description |
|---|---|
customer_id | The CustomerID matching the Customer Profile that should be resumed or resubmitted for editing. |
inquiry_id | The unique ID used to start an embedded compliance registration session. |
inquiry_session_token | The session token used to start an embedded compliance registration session. |
url | The URL of this resource.. Format: uri |