Twilio.Resources.Trusthub.V1.ComplianceInquiry.Tollfree.ComplianceTollfreeInquiries
(twilio_elixir v0.1.1)
ComplianceTollfreeInquiries resource.
Properties
| Field | Description |
|---|---|
inquiry_id | The unique ID used to start an embedded compliance registration session. |
inquiry_session_token | The session token used to start an embedded compliance registration session. |
registration_id | The TolfreeId matching the Tollfree Profile that should be resumed or resubmitted for editing. |
url | The URL of this resource.. Format: uri |