Twilio.Resources.Trusthub.V1.CustomerProfile.ChannelEndpointAssignment
(twilio_elixir v0.1.1)
ChannelEndpointAssignment resource.
SID prefix: RA
Parent: /CustomerProfiles/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Item Assignment resource. |
channel_endpoint_sid | The SID of an channel endpoint |
channel_endpoint_type | The type of channel endpoint. eg: phone-number |
customer_profile_sid | The unique string that we created to identify the CustomerProfile resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
sid | The unique string that we created to identify the Item Assignment resource. |
url | The absolute URL of the Identity resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Trusthub.V1.CustomerProfile.ChannelEndpointAssignment{ account_sid: String.t() | nil, channel_endpoint_sid: String.t() | nil, channel_endpoint_type: String.t() | nil, customer_profile_sid: String.t() | nil, date_created: String.t() | nil, sid: String.t() | nil, url: String.t() | nil }