Twilio.Resources.Trusthub.V1.CustomerProfile.CustomerProfilesEvaluations
(twilio_elixir v0.1.1)
CustomerProfilesEvaluations resource.
SID prefix: EL
Parent: /CustomerProfiles/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the customer_profile resource. |
customer_profile_sid | The unique string that we created to identify the customer_profile resource. |
date_created | Format: date-time |
policy_sid | The unique string of a policy that is associated to the customer_profile resource. |
results | The results of the Evaluation which includes the valid and invalid attributes. |
sid | The unique string that identifies the Evaluation resource. |
status | The compliance status of the Evaluation resource.. Values: compliant, noncompliant |
url | Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Trusthub.V1.CustomerProfile.CustomerProfilesEvaluations{ account_sid: String.t() | nil, customer_profile_sid: String.t() | nil, date_created: String.t() | nil, policy_sid: String.t() | nil, results: list() | nil, sid: String.t() | nil, status: String.t(), url: String.t() | nil }