EndUser resource.
SID prefix: IT
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the End User resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| attributes | The set of parameters that are the attributes of the End Users resource which are listed in the End User Types.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in ISO 8601 format.. Format: date-time |
friendly_name | The string that you assigned to describe the resource. |
sid | The unique string created by Twilio to identify the End User resource. |
type | The type of end user of the Bundle resource - can be individual or business. |
url | The absolute URL of the End User resource.. Format: uri |