Policies resource.
SID prefix: RN
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
friendly_name | A human-readable description that is assigned to describe the Policy resource. Examples can include Primary Customer profile policy |
requirements | The SID of an object that holds the policy information |
sid | The unique string that identifies the Policy resource. |
url | The absolute URL of the Policy resource.. Format: uri |