Twilio.Resources.Trusthub.V1.TrustProduct.TrustProductsEvaluations
(twilio_elixir v0.1.1)
TrustProductsEvaluations resource.
SID prefix: EL
Parent: /TrustProducts/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the trust_product resource. |
date_created | Format: date-time |
policy_sid | The unique string of a policy that is associated to the trust_product resource. |
results | The results of the Evaluation which includes the valid and invalid attributes. |
sid | The unique string that identifies the Evaluation resource. |
status | The compliance status of the Evaluation resource.. Values: compliant, noncompliant |
trust_product_sid | The unique string that we created to identify the trust_product resource. |
url | Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Trusthub.V1.TrustProduct.TrustProductsEvaluations{ account_sid: String.t() | nil, date_created: String.t() | nil, policy_sid: String.t() | nil, results: list() | nil, sid: String.t() | nil, status: String.t(), trust_product_sid: String.t() | nil, url: String.t() | nil }