Form resource.
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
form_meta | Additional information for the available forms for this type. E.g. The separator string used for binding in a Factor push. |
form_type | The Type of this Form. Currently only form-push is supported.. Values: form-push |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
forms | Object that contains the available forms for this type. This available forms are given in the standard JSON Schema format |
url | The URL to access the forms for this type.. Format: uri |