Service resource.
SID prefix: VA
Sub-resources
access_tokens—/v2/Services/{service_sid}/AccessTokensentities—/v2/Services/{service_sid}/Entitiesmessaging_configurations—/v2/Services/{service_sid}/MessagingConfigurationsrate_limits—/v2/Services/{service_sid}/RateLimitsverification_checks—/v2/Services/{service_sid}/VerificationCheckverifications—/v2/Services/{service_sid}/Verificationswebhooks—/v2/Services/{service_sid}/Webhooks
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
account_sid | The SID of the Account that created the Service resource. |
code_length | The length of the verification code to generate. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| custom_code_enabled | Whether to allow sending verifications with a custom code instead of a randomly generated one. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| do_not_share_warning_enabled | Whether to add a security warning at the end of an SMS verification body. Disabled by default and applies only to SMS. Example SMS body: Your AppName verification code is: 1234. Don’t share this code with anyone; our employees will never ask for the code |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| dtmf_input_required | Whether to ask the user to press a number before delivering the verify code in a phone call. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
friendly_name | The name that appears in the body of your verification messages. It can be up to 30 characters long and can include letters, numbers, spaces, dashes, underscores. Phone numbers, special characters or links are NOT allowed. It cannot contain more than 4 (consecutive or non-consecutive) digits. This value should not contain PII. |
links | The URLs of related resources.. Format: uri-map |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
lookup_enabled | Whether to perform a lookup with each verification started and return info about the phone number. |
psd2_enabled | Whether to pass PSD2 transaction parameters when starting a verification. |
push | Configurations for the Push factors (channel) created under this Service. |
sid | The unique string that we created to identify the Service resource. |
skip_sms_to_landlines | Whether to skip sending SMS verifications to landlines. Requires lookup_enabled. |
totp | Configurations for the TOTP factors (channel) created under this Service. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
tts_name | The name of an alternative text-to-speech service to use in phone calls. Applies only to TTS languages. |
url | The absolute URL of the resource.. Format: uri |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| verify_event_subscription_enabled | Whether to allow verifications from the service to reach the stream-events sinks if configured |
Summary
Types
@type t() :: %Twilio.Resources.Verify.V2.Service{ account_sid: String.t() | nil, code_length: integer(), custom_code_enabled: boolean() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, default_template_sid: String.t() | nil, do_not_share_warning_enabled: boolean() | nil, dtmf_input_required: boolean() | nil, friendly_name: String.t() | nil, links: map() | nil, lookup_enabled: boolean() | nil, passkeys: String.t() | nil, psd2_enabled: boolean() | nil, push: String.t() | nil, sid: String.t() | nil, skip_sms_to_landlines: boolean() | nil, totp: String.t() | nil, tts_name: String.t() | nil, url: String.t() | nil, verify_event_subscription_enabled: boolean() | nil, whatsapp: String.t() | nil }