AccessToken resource.
SID prefix: YK
Parent: /Services/{Sid}
Properties
| Field | Description |
|---|---|
account_sid | The unique SID identifier of the Account. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_created | The date that this access token was created, given in ISO 8601 format.. Format: date-time |
entity_identity | The unique external identifier for the Entity of the Service. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
factor_friendly_name | A human readable description of this factor, up to 64 characters. For a push factor, this can be the device's name.. PII: standard |
factor_type | The Type of the Factor. Currently only push is supported.. Values: push |
service_sid | The unique SID identifier of the Verify Service. |
sid | A 34 character string that uniquely identifies this Access Token. |
token | The access token generated for enrollment, this is an encrypted json web token. |
ttl | How long, in seconds, the access token is valid. Max: 5 minutes |
url | The URL of this resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Verify.V2.Service.AccessToken{ account_sid: String.t() | nil, date_created: String.t() | nil, entity_identity: String.t() | nil, factor_friendly_name: String.t() | nil, factor_type: String.t(), service_sid: String.t() | nil, sid: String.t() | nil, token: String.t() | nil, ttl: integer(), url: String.t() | nil }