Entity resource.
SID prefix: YE
Parent: /Services/{Sid}
Sub-resources
challenges—/v2/Services/{service_sid}/Entities/{identity}/Challengesfactors—/v2/Services/{service_sid}/Entities/{identity}/Factorsnew_factors—/v2/Services/{service_sid}/Entities/{identity}/Factors
Properties
| Field | Description |
|---|---|
account_sid | The unique SID identifier of the Account. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date that this Entity was created, given in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date that this Entity was updated, given in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
identity | The unique external identifier for the Entity of the Service. This identifier should be immutable, not PII, length between 8 and 64 characters, and generated by your external system, such as your user's UUID, GUID, or SID. It can only contain dash (-) separated alphanumeric characters.. PII: standard |
links | Contains a dictionary of URL links to nested resources of this Entity.. Format: uri-map |
service_sid | The unique SID identifier of the Service. |
sid | A 34 character string that uniquely identifies this Entity. |
url | The URL of this resource.. Format: uri |