Twilio.Resources.Verify.V2.Service.Entity.Challenge
(twilio_elixir v0.1.1)
Challenge resource.
SID prefix: YC
Parent: /Services/{ServiceSid}/Entities/{Identity}
Sub-resources
notifications—/v2/Services/{service_sid}/Entities/{identity}/Challenges/{challenge_sid}/Notifications
Properties
| Field | Description |
|---|---|
account_sid | The unique SID identifier of the Account. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date that this Challenge was created, given in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_responded | The date that this Challenge was responded, given in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date that this Challenge was updated, given in ISO 8601 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
details | Details provided to give context about the Challenge. Intended to be shown to the end user.. PII: standard |
entity_sid | The unique SID identifier of the Entity. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
expiration_date | The date-time when this Challenge expires, given in ISO 8601 format. The default value is five (5) minutes after Challenge creation. The max value is sixty (60) minutes after creation.. Format: date-time |
factor_sid | The unique SID identifier of the Factor. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| factor_type | The Factor Type of this Challenge. Currently push and totp are supported.. Values: push, totp, passkeys |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| hidden_details | Details provided to give context about the Challenge. Intended to be hidden from the end user. It must be a stringified JSON with only strings values eg. {"ip": "172.168.1.234"}. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
identity | Customer unique identity for the Entity owner of the Challenge. This identifier should be immutable, not PII, length between 8 and 64 characters, and generated by your external system, such as your user's UUID, GUID, or SID. It can only contain dash (-) separated alphanumeric characters.. PII: standard |
links | Contains a dictionary of URL links to nested resources of this Challenge.. Format: uri-map |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| metadata | Custom metadata associated with the challenge. This is added by the Device/SDK directly to allow for the inclusion of device information. It must be a stringified JSON with only strings values eg. {"os": "Android"}. Can be up to 1024 characters in length.. PII: standard |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
responded_reason | Reason for the Challenge to be in certain status. One of none, not_needed or not_requested.. Values: none, not_needed, not_requested |
service_sid | The unique SID identifier of the Service. |
sid | A 34 character string that uniquely identifies this Challenge. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
status | The Status of this Challenge. One of pending, expired, approved or denied.. Values: pending, expired, approved, denied |
url | The URL of this resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Verify.V2.Service.Entity.Challenge{ account_sid: String.t() | nil, date_created: String.t() | nil, date_responded: String.t() | nil, date_updated: String.t() | nil, details: String.t() | nil, entity_sid: String.t() | nil, expiration_date: String.t() | nil, factor_sid: String.t() | nil, factor_type: String.t(), hidden_details: String.t() | nil, identity: String.t() | nil, links: map() | nil, metadata: String.t() | nil, responded_reason: String.t(), service_sid: String.t() | nil, sid: String.t() | nil, status: String.t(), url: String.t() | nil }