Twilio.Resources.Verify.V2.Service.MessagingConfiguration
(twilio_elixir v0.1.1)
MessagingConfiguration resource.
Parent: /Services/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Service resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| country | The ISO-3166-1 country code of the country this configuration will be applied to. If this is a global configuration, Country will take the value all. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| messaging_service_sid | The SID of the Messaging Service to be used to send SMS to the country of this configuration. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
service_sid | The SID of the Service that the resource is associated with. |
url | The URL of this resource.. Format: uri |