RateLimit resource.
SID prefix: RK
Parent: /Services/{Sid}
Sub-resources
buckets—/v2/Services/{service_sid}/RateLimits/{rate_limit_sid}/Buckets
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Rate Limit resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
description | Description of this Rate Limit |
links | The URLs of related resources.. Format: uri-map |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
service_sid | The SID of the Service the resource is associated with. |
sid | A 34 character string that uniquely identifies this Rate Limit. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
unique_name | Provides a unique and addressable name to be assigned to this Rate Limit, assigned by the developer, to be optionally used in addition to SID. This value should not contain PII. |
url | The URL of this resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Verify.V2.Service.RateLimit{ account_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, description: String.t() | nil, links: map() | nil, service_sid: String.t() | nil, sid: String.t() | nil, unique_name: String.t() | nil, url: String.t() | nil }