Twilio.Resources.Verify.V2.Service.RateLimit.Bucket
(twilio_elixir v0.1.1)
Bucket resource.
SID prefix: BL
Parent: /Services/{ServiceSid}/RateLimits/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Rate Limit resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
interval | Number of seconds that the rate limit will be enforced over. |
max | Maximum number of requests permitted in during the interval. |
rate_limit_sid | The Twilio-provided string that uniquely identifies the Rate Limit resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
service_sid | The SID of the Service the resource is associated with. |
sid | A 34 character string that uniquely identifies this Bucket. |
url | The URL of this resource.. Format: uri |
Summary
Types
@type t() :: %Twilio.Resources.Verify.V2.Service.RateLimit.Bucket{ account_sid: String.t() | nil, date_created: String.t() | nil, date_updated: String.t() | nil, interval: integer(), max: integer(), rate_limit_sid: String.t() | nil, service_sid: String.t() | nil, sid: String.t() | nil, url: String.t() | nil }