Connection Policy for sending traffic to your communications infrastructure.
SID prefix: NY
Sub-resources
targets—/v1/ConnectionPolicies/{connection_policy_sid}/Targets
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the Connection Policy resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT when the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT when the resource was last updated specified in RFC 2822 format.. Format: date-time |
friendly_name | The string that you assigned to describe the resource. |
links | The URLs of related resources.. Format: uri-map |
sid | The unique string that we created to identify the Connection Policy resource. |
url | The absolute URL of the resource.. Format: uri |