credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
With Source IP Mappings, Twilio can recognize your SIP requests based on where they are sent from. The Request-URI no longer has to have the FQDN (Fully Qualified Domain Name) of your SIP Domain.
SID prefix: IB
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| date_created | The date and time in GMT that the resource was created specified in RFC 2822 format.. Format: date-time |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
date_updated | The date and time in GMT that the resource was last updated specified in RFC 2822 format.. Format: date-time |
ip_record_sid | The Twilio-provided string that uniquely identifies the IP Record resource to map from. |
sid | The unique string that we created to identify the IP Record resource. |
sip_domain_sid | The SID of the SIP Domain that the IP Record is mapped to. |
url | The absolute URL of the resource.. Format: uri |