Usage information for SIMs
Parent: /Sims/{Sid}
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the UsageRecord resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| commands | An object that describes the SIM's usage of Commands during the specified period. See Commands Usage Object. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| data | An object that describes the SIM's data usage during the specified period. See Data Usage Object. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| period | The time period for which the usage is reported. Contains start and end datetime values given as GMT in ISO 8601 format. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| sim_sid | The SID of the Sim resource that this Usage Record is for. |