Aggregated Usage information for all SIMs on an Account
Properties
| Field | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| account_sid | The SID of the Account that created the AccountUsageRecord resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| commands | An object that describes the aggregated Commands usage for all SIMs during the specified period. See Commands Usage Object. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| data | An object that describes the aggregated Data usage for all SIMs over the period. See Data Usage Object. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| period | The time period for which usage is reported. Contains start and end properties that describe the period using GMT date-time values specified in ISO 8601 format. |