Service for PhoneNumber API operations.
Operations: fetch, update
Summary
Functions
Fetch the Inbound Processing Region assigned to a phone number.
Assign an Inbound Processing Region to a phone number.
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Routes.V2.PhoneNumber.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch the Inbound Processing Region assigned to a phone number.
Operation: FetchPhoneNumber | Tags: RoutesV2PhoneNumber
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Routes.V2.PhoneNumber.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Assign an Inbound Processing Region to a phone number.
Operation: UpdatePhoneNumber | Tags: RoutesV2PhoneNumber
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
FriendlyName | string | A human readable description of this resource, up to 64 characters. |
VoiceRegion | string | The Inbound Processing Region used for this phone number for voice |