A wrapper that represents a static file and groups the different Versions of the static file.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new Asset resource.
Delete an Asset resource.
Retrieve a specific Asset resource.
Retrieve a list of all Assets.
Stream: Retrieve a list of all Assets. (lazy auto-pagination).
Update a specific Asset resource.
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Asset.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Asset resource.
Operation: CreateAsset | Tags: ServerlessV1Asset
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the Asset resource. It can be a maximum of 255 characters. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete an Asset resource.
Operation: DeleteAsset | Tags: ServerlessV1Asset
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Asset.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a specific Asset resource.
Operation: FetchAsset | Tags: ServerlessV1Asset
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Assets.
Operation: ListAsset | Tags: ServerlessV1Asset
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Assets. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Asset.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a specific Asset resource.
Operation: UpdateAsset | Tags: ServerlessV1Asset
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the Asset resource. It can be a maximum of 255 characters. |