A collection of Function Versions, Asset Versions, Dependencies, and a Runtime that form a deployable unit.
Operations: list, create, fetch, delete
Summary
Functions
Create a new Build resource. At least one function version or asset version is required.
Delete a Build resource.
Retrieve a specific Build resource.
Retrieve a list of all Builds.
Stream: Retrieve a list of all Builds. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Build.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Build resource. At least one function version or asset version is required.
Operation: CreateBuild | Tags: ServerlessV1Build
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
AssetVersions | array | The list of Asset Version resource SIDs to include in the Build. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Dependencies | string | A list of objects that describe the Dependencies included in the Build. Each object contains the name and version of the dependency. |
FunctionVersions | array | The list of the Function Version resource SIDs to include in the Build. |
Runtime | string | The Runtime version that will be used to run the Build resource when it is deployed. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a Build resource.
Operation: DeleteBuild | Tags: ServerlessV1Build
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Build.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a specific Build resource.
Operation: FetchBuild | Tags: ServerlessV1Build
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Builds.
Operation: ListBuild | Tags: ServerlessV1Build
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Builds. (lazy auto-pagination).