Twilio.Serverless.V1.Service.Environment.DeploymentService
(twilio_elixir v0.1.1)
An association of a Build with an Environment so that the Build is published in the Environment.
Operations: list, create, fetch
Summary
Functions
Create a new Deployment.
Retrieve a specific Deployment.
Retrieve a list of all Deployments.
Stream: Retrieve a list of all Deployments. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Environment.Deployment.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Deployment.
Operation: CreateDeployment | Tags: ServerlessV1Deployment
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
BuildSid | string | The SID of the Build for the Deployment. |
IsPlugin | boolean | Whether the Deployment is a plugin. |
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Environment.Deployment.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a specific Deployment.
Operation: FetchDeployment | Tags: ServerlessV1Deployment
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Deployments.
Operation: ListDeployment | Tags: ServerlessV1Deployment
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Deployments. (lazy auto-pagination).