Twilio.Serverless.V1.Service.Environment.VariableService
(twilio_elixir v0.1.1)
A key and value pair that is specific to an Environment.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new Variable.
Delete a specific Variable.
Retrieve a specific Variable.
Retrieve a list of all Variables.
Stream: Retrieve a list of all Variables. (lazy auto-pagination).
Update a specific Variable.
Functions
@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Environment.Variable.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Variable.
Operation: CreateVariable | Tags: ServerlessV1Variable
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Key | string | A string by which the Variable resource can be referenced. It can be a maximum of 128 characters. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Value | string | A string that contains the actual value of the Variable. It can be a maximum of 450 bytes in size. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Variable.
Operation: DeleteVariable | Tags: ServerlessV1Variable
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Environment.Variable.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a specific Variable.
Operation: FetchVariable | Tags: ServerlessV1Variable
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Variables.
Operation: ListVariable | Tags: ServerlessV1Variable
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Variables. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Environment.Variable.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a specific Variable.
Operation: UpdateVariable | Tags: ServerlessV1Variable
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Key | string | A string by which the Variable resource can be referenced. It can be a maximum of 128 characters. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Value | string | A string that contains the actual value of the Variable. It can be a maximum of 450 bytes in size. |