Represents a deployed build of a given set of Functions and/or Assets at a specific URL.
Operations: list, create, fetch, delete
Summary
Functions
Create a new environment.
Delete a specific environment.
Retrieve a specific environment.
Retrieve a list of all environments.
Stream: Retrieve a list of all environments. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Environment.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new environment.
Operation: CreateEnvironment | Tags: ServerlessV1Environment
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | A user-defined string that uniquely identifies the Environment resource. It can be a maximum of 100 characters. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DomainSuffix | string | A URL-friendly name that represents the environment and forms part of the domain name. It can be a maximum of 16 characters. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific environment.
Operation: DeleteEnvironment | Tags: ServerlessV1Environment
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Environment.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a specific environment.
Operation: FetchEnvironment | Tags: ServerlessV1Environment
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all environments.
Operation: ListEnvironment | Tags: ServerlessV1Environment
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all environments. (lazy auto-pagination).