credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
A wrapper that represents a Serverless JavaScript function and groups the different and groups the different Versions of this code.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new Function resource.
Delete a Function resource.
Retrieve a specific Function resource.
Retrieve a list of all Functions.
Stream: Retrieve a list of all Functions. (lazy auto-pagination).
Update a specific Function resource.
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Function.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Function resource.
Operation: CreateFunction | Tags: ServerlessV1Function
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the Function resource. It can be a maximum of 255 characters. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a Function resource.
Operation: DeleteFunction | Tags: ServerlessV1Function
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Function.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a specific Function resource.
Operation: FetchFunction | Tags: ServerlessV1Function
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Functions.
Operation: ListFunction | Tags: ServerlessV1Function
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Functions. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Serverless.V1.Service.Function.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a specific Function resource.
Operation: UpdateFunction | Tags: ServerlessV1Function
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the Function resource. It can be a maximum of 255 characters. |