[DEPRECATED] Excecutions of Studio flows
Operations: list, create, fetch, delete
Summary
Functions
Triggers a new Engagement for the Flow
Delete this Engagement and all Steps relating to it.
Retrieve an Engagement
Retrieve a list of all Engagements for the Flow.
Stream: Retrieve a list of all Engagements for the Flow. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Studio.V1.Flow.Engagement.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Triggers a new Engagement for the Flow
Operation: CreateEngagement | Tags: StudioV1Engagement
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| From | string (phone-number) | The Twilio phone number to send messages or initiate calls from during the Flow Engagement. Available as variable {{flow.channel.address}} |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| To | string (phone-number) | The Contact phone number to start a Studio Flow Engagement, available as variable {{contact.channel.address}}. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Parameters | string | A JSON string we will add to your flow's context and that you can access as variables inside your flow. For example, if you pass in Parameters={'name':'Zeke'} then inside a widget you can reference the variable {{flow.data.name}} which will return the string 'Zeke'. Note: the JSON value must explicitly be passed as a string, not as a hash object. Depending on your particular HTTP library, you may need to add quotes or URL encode your JSON string. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete this Engagement and all Steps relating to it.
Operation: DeleteEngagement | Tags: StudioV1Engagement
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Studio.V1.Flow.Engagement.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve an Engagement
Operation: FetchEngagement | Tags: StudioV1Engagement
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Engagements for the Flow.
Operation: ListEngagement | Tags: StudioV1Engagement
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Engagements for the Flow. (lazy auto-pagination).