Studio flows
Operations: list, create, fetch, update, delete
Summary
Functions
Create a Flow.
Delete a specific Flow.
Retrieve a specific Flow.
Retrieve a list of all Flows.
Stream: Retrieve a list of all Flows. (lazy auto-pagination).
Update a Flow.
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Studio.V2.Flow.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a Flow.
Operation: CreateFlow | Tags: StudioV2Flow
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Definition | string | JSON representation of flow definition. |
FriendlyName | string | The string that you assigned to describe the Flow. |
Status | string | Values: draft, published |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
CommitMessage | string | Description of change made in the revision. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Flow.
Operation: DeleteFlow | Tags: StudioV2Flow
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Studio.V2.Flow.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a specific Flow.
Operation: FetchFlow | Tags: StudioV2Flow
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Flows.
Operation: ListFlow | Tags: StudioV2Flow
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Flows. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Studio.V2.Flow.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a Flow.
Operation: UpdateFlow | Tags: StudioV2Flow
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Status | string | Values: draft, published |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
CommitMessage | string | Description of change made in the revision. |
Definition | string | JSON representation of flow definition. |
FriendlyName | string | The string that you assigned to describe the Flow. |