Twilio.Supersim.V1.NetworkAccessProfile.NetworkAccessProfileNetworkService
(twilio_elixir v0.1.1)
Mobile operator networks which Network Access Profiles allow access to
Operations: list, create, fetch, delete
Summary
Functions
Add a Network resource to the Network Access Profile resource.
Remove a Network resource from the Network Access Profile resource's.
Fetch a Network Access Profile resource's Network resource.
Retrieve a list of Network Access Profile resource's Network resource.
Stream: Retrieve a list of Network Access Profile resource's Network resource. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Supersim.V1.NetworkAccessProfile.NetworkAccessProfileNetwork.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Add a Network resource to the Network Access Profile resource.
Operation: CreateNetworkAccessProfileNetwork | Tags: SupersimV1NetworkAccessProfileNetwork
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Network | string | The SID of the Network resource to be added to the Network Access Profile resource. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Remove a Network resource from the Network Access Profile resource's.
Operation: DeleteNetworkAccessProfileNetwork | Tags: SupersimV1NetworkAccessProfileNetwork
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Supersim.V1.NetworkAccessProfile.NetworkAccessProfileNetwork.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a Network Access Profile resource's Network resource.
Operation: FetchNetworkAccessProfileNetwork | Tags: SupersimV1NetworkAccessProfileNetwork
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Network Access Profile resource's Network resource.
Operation: ListNetworkAccessProfileNetwork | Tags: SupersimV1NetworkAccessProfileNetwork
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Network Access Profile resource's Network resource. (lazy auto-pagination).