Service for NetworkAccessProfile API operations.
Operations: list, create, fetch, update
Summary
Functions
Create a new Network Access Profile
Fetch a Network Access Profile instance from your account.
Retrieve a list of Network Access Profiles from your account.
Stream: Retrieve a list of Network Access Profiles from your account. (lazy auto-pagination).
Updates the given properties of a Network Access Profile in your account.
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Supersim.V1.NetworkAccessProfile.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Network Access Profile
Operation: CreateNetworkAccessProfile | Tags: SupersimV1NetworkAccessProfile
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Networks | array | List of Network SIDs that this Network Access Profile will allow connections to. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource. |
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Supersim.V1.NetworkAccessProfile.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a Network Access Profile instance from your account.
Operation: FetchNetworkAccessProfile | Tags: SupersimV1NetworkAccessProfile
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Network Access Profiles from your account.
Operation: ListNetworkAccessProfile | Tags: SupersimV1NetworkAccessProfile
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Network Access Profiles from your account. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Supersim.V1.NetworkAccessProfile.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Updates the given properties of a Network Access Profile in your account.
Operation: UpdateNetworkAccessProfile | Tags: SupersimV1NetworkAccessProfile
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
UniqueName | string | The new unique name of the Network Access Profile. |