Mobile operator networks to which Super SIMs can connect
Operations: list, fetch
Summary
Functions
Fetch a Network resource.
Retrieve a list of Network resources.
Stream: Retrieve a list of Network resources. (lazy auto-pagination).
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Supersim.V1.Network.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a Network resource.
Operation: FetchNetwork | Tags: SupersimV1Network
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Network resources.
Operation: ListNetwork | Tags: SupersimV1Network
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| IsoCountry | string | The ISO country code of the Network resources to read. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Mcc | string | The 'mobile country code' of a country. Network resources with this mcc in their identifiers will be read. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Mnc | string | The 'mobile network code' of a mobile operator network. Network resources with this mnc in their identifiers will be read. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Network resources. (lazy auto-pagination).