Individual IoT Super SIMs
Operations: list, create, fetch, update
Summary
Functions
Register a Super SIM to your Account
Fetch a Super SIM instance from your account.
Retrieve a list of Super SIMs from your account.
Stream: Retrieve a list of Super SIMs from your account. (lazy auto-pagination).
Updates the given properties of a Super SIM instance from your account.
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Supersim.V1.Sim.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Register a Super SIM to your Account
Operation: CreateSim | Tags: SupersimV1Sim
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Iccid | string | The ICCID of the Super SIM to be added to your Account. |
RegistrationCode | string | The 10-digit code required to claim the Super SIM for your Account. |
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Supersim.V1.Sim.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a Super SIM instance from your account.
Operation: FetchSim | Tags: SupersimV1Sim
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Super SIMs from your account.
Operation: ListSim | Tags: SupersimV1Sim
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Status | string | The status of the Sim resources to read. Can be new, ready, active, inactive, or scheduled. |
Fleet | string | The SID or unique name of the Fleet to which a list of Sims are assigned. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Iccid | string | The ICCID associated with a Super SIM to filter the list by. Passing this parameter will always return a list containing zero or one SIMs. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Super SIMs from your account. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Supersim.V1.Sim.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Updates the given properties of a Super SIM instance from your account.
Operation: UpdateSim | Tags: SupersimV1Sim
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| AccountSid | string | The SID of the Account to which the Sim resource should belong. The Account SID can only be that of the requesting Account or that of a Subaccount of the requesting Account. Only valid when the Sim resource's status is new. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| CallbackMethod | string (http-method) | The HTTP method we should use to call callback_url. Can be: GET or POST and the default is POST. Values: GET, POST |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
CallbackUrl | string (uri) | The URL we should call using the callback_method after an asynchronous update has finished. |
Fleet | string | The SID or unique name of the Fleet to which the SIM resource should be assigned. |
Status | string | Values: ready, active, inactive |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource. |