Machine-to-machine SMS Commands sent to/from SIMs
Operations: list, create, fetch
Summary
Functions
Send SMS Command to a Sim.
Fetch SMS Command instance from your account.
Retrieve a list of SMS Commands from your account.
Stream: Retrieve a list of SMS Commands from your account. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Supersim.V1.SmsCommand.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Send SMS Command to a Sim.
Operation: CreateSmsCommand | Tags: SupersimV1SmsCommand
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Payload | string | The message body of the SMS Command. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Sim | string | The sid or unique_name of the SIM to send the SMS Command to. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
CallbackMethod | string (http-method) | The HTTP method we should use to call callback_url. Can be: GET or POST and the default is POST. Values: GET, POST |
CallbackUrl | string (uri) | The URL we should call using the callback_method after we have sent the command. |
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Supersim.V1.SmsCommand.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch SMS Command instance from your account.
Operation: FetchSmsCommand | Tags: SupersimV1SmsCommand
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of SMS Commands from your account.
Operation: ListSmsCommand | Tags: SupersimV1SmsCommand
Query Parameters
| Parameter | Type | Description |
|---|---|---|
Sim | string | The SID or unique name of the Sim resource that SMS Command was sent to or from. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Status | string | The status of the SMS Command. Can be: queued, sent, delivered, received or failed. See the SMS Command Status Values for a description of each. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Direction | string | The direction of the SMS Command. Can be to_sim or from_sim. The value of to_sim is synonymous with the term mobile terminated, and from_sim is synonymous with the term mobile originated. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of SMS Commands from your account. (lazy auto-pagination).