Permissions for Sync list items
Operations: list, fetch, update, delete
Summary
Functions
Delete a specific Sync List Permission.
Fetch a specific Sync List Permission.
Retrieve a list of all Permissions applying to a Sync List.
Stream: Retrieve a list of all Permissions applying to a Sync List. (lazy auto-pagination).
Update an identity's access to a specific Sync List.
Functions
@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Sync List Permission.
Operation: DeleteSyncListPermission | Tags: SyncV1SyncListPermission
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.List.Permission.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Sync List Permission.
Operation: FetchSyncListPermission | Tags: SyncV1SyncListPermission
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Permissions applying to a Sync List.
Operation: ListSyncListPermission | Tags: SyncV1SyncListPermission
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Permissions applying to a Sync List. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.List.Permission.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update an identity's access to a specific Sync List.
Operation: UpdateSyncListPermission | Tags: SyncV1SyncListPermission
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Manage | boolean | Whether the identity can delete the Sync List. Default value is false. |
Read | boolean | Whether the identity can read the Sync List and its Items. Default value is false. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Write | boolean | Whether the identity can create, update, and delete Items in the Sync List. Default value is false. |