Sync list objects
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateSyncList | Tags: SyncV1SyncList
Operation: DeleteSyncList | Tags: SyncV1SyncList
Operation: FetchSyncList | Tags: SyncV1SyncList
Operation: ListSyncList | Tags: SyncV1SyncList
Stream: (lazy auto-pagination).
Operation: UpdateSyncList | Tags: SyncV1SyncList
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.List.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateSyncList | Tags: SyncV1SyncList
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
CollectionTtl | integer | How long, in seconds, before the Sync List expires (time-to-live) and is deleted. |
Ttl | integer | Alias for collection_ttl. If both are provided, this value is ignored. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. This value must be unique within its Service and it can be up to 320 characters long. The unique_name value can be used as an alternative to the sid in the URL path to address the resource. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteSyncList | Tags: SyncV1SyncList
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.List.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchSyncList | Tags: SyncV1SyncList
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListSyncList | Tags: SyncV1SyncList
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.List.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateSyncList | Tags: SyncV1SyncList
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
CollectionTtl | integer | How long, in seconds, before the Sync List expires (time-to-live) and is deleted. |
Ttl | integer | An alias for collection_ttl. If both are provided, this value is ignored. |