Sync map objects
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateSyncMap | Tags: SyncV1SyncMap
Operation: DeleteSyncMap | Tags: SyncV1SyncMap
Operation: FetchSyncMap | Tags: SyncV1SyncMap
Operation: ListSyncMap | Tags: SyncV1SyncMap
Stream: (lazy auto-pagination).
Operation: UpdateSyncMap | Tags: SyncV1SyncMap
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.Map.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateSyncMap | Tags: SyncV1SyncMap
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
CollectionTtl | integer | How long, in seconds, before the Sync Map expires (time-to-live) and is deleted. |
Ttl | integer | An alias for collection_ttl. If both parameters are provided, this value is ignored. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the resource. It can be used as an alternative to the sid in the URL path to address the resource. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteSyncMap | Tags: SyncV1SyncMap
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.Map.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchSyncMap | Tags: SyncV1SyncMap
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListSyncMap | Tags: SyncV1SyncMap
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Sync.V1.Service.Map.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateSyncMap | Tags: SyncV1SyncMap
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
CollectionTtl | integer | How long, in seconds, before the Sync Map expires (time-to-live) and is deleted. |
Ttl | integer | An alias for collection_ttl. If both parameters are provided, this value is ignored. |