Service for Activity API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateActivity | Tags: TaskrouterV1Activity
Operation: DeleteActivity | Tags: TaskrouterV1Activity
Operation: FetchActivity | Tags: TaskrouterV1Activity
Operation: ListActivity | Tags: TaskrouterV1Activity
Stream: (lazy auto-pagination).
Operation: UpdateActivity | Tags: TaskrouterV1Activity
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Taskrouter.V1.Workspace.Activity.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateActivity | Tags: TaskrouterV1Activity
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the Activity resource. It can be up to 64 characters long. These names are used to calculate and expose statistics about Workers, and provide visibility into the state of each Worker. Examples of friendly names include: on-call, break, and email. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Available | boolean | Whether the Worker should be eligible to receive a Task when it occupies the Activity. A value of true, 1, or yes specifies the Activity is available. All other values specify that it is not. The value cannot be changed after the Activity is created. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteActivity | Tags: TaskrouterV1Activity
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Taskrouter.V1.Workspace.Activity.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchActivity | Tags: TaskrouterV1Activity
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListActivity | Tags: TaskrouterV1Activity
Query Parameters
| Parameter | Type | Description |
|---|---|---|
FriendlyName | string | The friendly_name of the Activity resources to read. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Available | string | Whether return only Activity resources that are available or unavailable. A value of true returns only available activities. Values of '1' or yes also indicate true. All other values represent false and return activities that are unavailable. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Taskrouter.V1.Workspace.Activity.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateActivity | Tags: TaskrouterV1Activity
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the Activity resource. It can be up to 64 characters long. These names are used to calculate and expose statistics about Workers, and provide visibility into the state of each Worker. Examples of friendly names include: on-call, break, and email. |