Types of tasks
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateTaskChannel | Tags: TaskrouterV1TaskChannel
Operation: DeleteTaskChannel | Tags: TaskrouterV1TaskChannel
Operation: FetchTaskChannel | Tags: TaskrouterV1TaskChannel
Operation: ListTaskChannel | Tags: TaskrouterV1TaskChannel
Stream: (lazy auto-pagination).
Operation: UpdateTaskChannel | Tags: TaskrouterV1TaskChannel
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Taskrouter.V1.Workspace.TaskChannel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateTaskChannel | Tags: TaskrouterV1TaskChannel
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the Task Channel. It can be up to 64 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | An application-defined string that uniquely identifies the Task Channel, such as voice or sms. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ChannelOptimizedRouting | boolean | Whether the Task Channel should prioritize Workers that have been idle. If true, Workers that have been idle the longest are prioritized. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteTaskChannel | Tags: TaskrouterV1TaskChannel
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Taskrouter.V1.Workspace.TaskChannel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchTaskChannel | Tags: TaskrouterV1TaskChannel
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListTaskChannel | Tags: TaskrouterV1TaskChannel
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Taskrouter.V1.Workspace.TaskChannel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateTaskChannel | Tags: TaskrouterV1TaskChannel
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ChannelOptimizedRouting | boolean | Whether the TaskChannel should prioritize Workers that have been idle. If true, Workers that have been idle the longest are prioritized. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the Task Channel. It can be up to 64 characters long. |