Twilio.Taskrouter.V1.Workspace.TaskQueue.TaskQueueStatisticsService
(twilio_elixir v0.1.1)
Service for TaskQueueStatistics API operations.
Operations: fetch
Summary
Functions
Operation: FetchTaskQueueStatistics | Tags: TaskrouterV1TaskQueueStatistics
Functions
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Taskrouter.V1.Workspace.TaskQueue.TaskQueueStatistics.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchTaskQueueStatistics | Tags: TaskrouterV1TaskQueueStatistics
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
EndDate | string (date-time) | Only calculate statistics from this date and time and earlier, specified in GMT as an ISO 8601 date-time. |
Minutes | integer | Only calculate statistics since this many minutes in the past. The default is 15 minutes. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| StartDate | string (date-time) | Only calculate statistics from this date and time and later, specified in ISO 8601 format. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| TaskChannel | string | Only calculate real-time and cumulative statistics for the specified TaskChannel. Can be the TaskChannel's SID or its unique_name, such as voice, sms, or default. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| SplitByWaitTime | string | A comma separated list of values that describes the thresholds, in seconds, to calculate statistics on. For each threshold specified, the number of Tasks canceled and reservations accepted above and below the specified thresholds in seconds are computed. |