Twilio.Taskrouter.V1.Workspace.Worker.ChannelService
(twilio_elixir v0.1.1)
Service for Channel API operations.
Operations: list, fetch, update
Summary
Functions
Operation: FetchWorkerChannel | Tags: TaskrouterV1WorkerChannel
Operation: ListWorkerChannel | Tags: TaskrouterV1WorkerChannel
Stream: (lazy auto-pagination).
Operation: UpdateWorkerChannel | Tags: TaskrouterV1WorkerChannel
Functions
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Taskrouter.V1.Workspace.Worker.Channel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchWorkerChannel | Tags: TaskrouterV1WorkerChannel
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListWorkerChannel | Tags: TaskrouterV1WorkerChannel
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Taskrouter.V1.Workspace.Worker.Channel.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateWorkerChannel | Tags: TaskrouterV1WorkerChannel
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Available | boolean | Whether the WorkerChannel is available. Set to false to prevent the Worker from receiving any new Tasks of this TaskChannel type. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Capacity | integer | The total number of Tasks that the Worker should handle for the TaskChannel type. TaskRouter creates reservations for Tasks of this TaskChannel type up to the specified capacity. If the capacity is 0, no new reservations will be created. |