List of credentials for accessing a trunk
Operations: list, create, fetch, delete
Summary
Functions
Operation: CreateCredentialList | Tags: TrunkingV1CredentialList
Operation: DeleteCredentialList | Tags: TrunkingV1CredentialList
Operation: FetchCredentialList | Tags: TrunkingV1CredentialList
Operation: ListCredentialList | Tags: TrunkingV1CredentialList
Stream: (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Trunking.V1.Trunk.CredentialList.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateCredentialList | Tags: TrunkingV1CredentialList
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| CredentialListSid | string | The SID of the Credential List that you want to associate with the trunk. Once associated, we will authenticate access to the trunk against this list. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteCredentialList | Tags: TrunkingV1CredentialList
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Trunking.V1.Trunk.CredentialList.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchCredentialList | Tags: TrunkingV1CredentialList
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListCredentialList | Tags: TrunkingV1CredentialList
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).