Network element entry points into your communications infrastructure
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateOriginationUrl | Tags: TrunkingV1OriginationUrl
Operation: DeleteOriginationUrl | Tags: TrunkingV1OriginationUrl
Operation: FetchOriginationUrl | Tags: TrunkingV1OriginationUrl
Operation: ListOriginationUrl | Tags: TrunkingV1OriginationUrl
Stream: (lazy auto-pagination).
Operation: UpdateOriginationUrl | Tags: TrunkingV1OriginationUrl
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Trunking.V1.Trunk.OriginationUrl.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateOriginationUrl | Tags: TrunkingV1OriginationUrl
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Enabled | boolean | Whether the URL is enabled. The default is true. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Priority | integer | The relative importance of the URI. Can be an integer from 0 to 65535, inclusive, and the default is 10. The lowest number represents the most important URI. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| SipUrl | string (uri) | The SIP address you want Twilio to route your Origination calls to. This must be a sip: schema. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Weight | integer | The value that determines the relative share of the load the URI should receive compared to other URIs with the same priority. Can be an integer from 1 to 65535, inclusive, and the default is 10. URLs with higher values receive more load than those with lower ones with the same priority. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteOriginationUrl | Tags: TrunkingV1OriginationUrl
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Trunking.V1.Trunk.OriginationUrl.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchOriginationUrl | Tags: TrunkingV1OriginationUrl
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListOriginationUrl | Tags: TrunkingV1OriginationUrl
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Trunking.V1.Trunk.OriginationUrl.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateOriginationUrl | Tags: TrunkingV1OriginationUrl
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Enabled | boolean | Whether the URL is enabled. The default is true. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It can be up to 64 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Priority | integer | The relative importance of the URI. Can be an integer from 0 to 65535, inclusive, and the default is 10. The lowest number represents the most important URI. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| SipUrl | string (uri) | The SIP address you want Twilio to route your Origination calls to. This must be a sip: schema. sips is NOT supported. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Weight | integer | The value that determines the relative share of the load the URI should receive compared to other URIs with the same priority. Can be an integer from 1 to 65535, inclusive, and the default is 10. URLs with higher values receive more load than those with lower ones with the same priority. |