Twilio.Trusthub.V1.CustomerProfile.ChannelEndpointAssignmentService
(twilio_elixir v0.1.1)
Service for ChannelEndpointAssignment API operations.
Operations: list, create, fetch, delete
Summary
Functions
Create a new Assigned Item.
Remove an Assignment Item Instance.
Fetch specific Assigned Item Instance.
Retrieve a list of all Assigned Items for an account.
Stream: Retrieve a list of all Assigned Items for an account. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Trusthub.V1.CustomerProfile.ChannelEndpointAssignment.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Assigned Item.
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Operation: CreateCustomerProfileChannelEndpointAssignment | Tags: TrusthubV1CustomerProfilesChannelEndpointAssignment
Required Parameters
| Parameter | Type | Description |
|---|---|---|
ChannelEndpointSid | string | The SID of an channel endpoint |
ChannelEndpointType | string | The type of channel endpoint. eg: phone-number |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Remove an Assignment Item Instance.
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Operation: DeleteCustomerProfileChannelEndpointAssignment | Tags: TrusthubV1CustomerProfilesChannelEndpointAssignment
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Trusthub.V1.CustomerProfile.ChannelEndpointAssignment.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch specific Assigned Item Instance.
Operation: FetchCustomerProfileChannelEndpointAssignment | Tags: TrusthubV1CustomerProfilesChannelEndpointAssignment
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Assigned Items for an account.
Operation: ListCustomerProfileChannelEndpointAssignment | Tags: TrusthubV1CustomerProfilesChannelEndpointAssignment
Query Parameters
| Parameter | Type | Description |
|---|---|---|
ChannelEndpointSid | string | The SID of an channel endpoint |
ChannelEndpointSids | string | comma separated list of channel endpoint sids |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Assigned Items for an account. (lazy auto-pagination).