Twilio.Trusthub.V1.CustomerProfile.CustomerProfilesEntityAssignmentsService
(twilio_elixir v0.1.1)
Service for CustomerProfilesEntityAssignments API operations.
Operations: list, create, fetch, delete
Summary
Functions
Create a new Assigned Item.
Remove an Assignment Item Instance.
Fetch specific Assigned Item Instance.
Retrieve a list of all Assigned Items for an account.
Stream: Retrieve a list of all Assigned Items for an account. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Trusthub.V1.CustomerProfile.CustomerProfilesEntityAssignments.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Assigned Item.
Operation: CreateCustomerProfileEntityAssignment | Tags: TrusthubV1CustomerProfilesEntityAssignments
Required Parameters
| Parameter | Type | Description |
|---|---|---|
ObjectSid | string | The SID of an object bag that holds information of the different items. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Remove an Assignment Item Instance.
Operation: DeleteCustomerProfileEntityAssignment | Tags: TrusthubV1CustomerProfilesEntityAssignments
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Trusthub.V1.CustomerProfile.CustomerProfilesEntityAssignments.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch specific Assigned Item Instance.
Operation: FetchCustomerProfileEntityAssignment | Tags: TrusthubV1CustomerProfilesEntityAssignments
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Assigned Items for an account.
Operation: ListCustomerProfileEntityAssignment | Tags: TrusthubV1CustomerProfilesEntityAssignments
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| ObjectType | string | A string to filter the results by (EndUserType or SupportingDocumentType) machine-name. This is useful when you want to retrieve the entity-assignment of a specific end-user or supporting document. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Assigned Items for an account. (lazy auto-pagination).