Twilio.Trusthub.V1.CustomerProfile.CustomerProfilesEvaluationsService
(twilio_elixir v0.1.1)
Service for CustomerProfilesEvaluations API operations.
Operations: list, create, fetch
Summary
Functions
Create a new Evaluation
Fetch specific Evaluation Instance.
Retrieve a list of Evaluations associated to the customer_profile resource.
Stream: Retrieve a list of Evaluations associated to the customer_profile resource. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Trusthub.V1.CustomerProfile.CustomerProfilesEvaluations.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Evaluation
Operation: CreateCustomerProfileEvaluation | Tags: TrusthubV1CustomerProfilesEvaluations
Required Parameters
| Parameter | Type | Description |
|---|---|---|
PolicySid | string | The unique string of a policy that is associated to the customer_profile resource. |
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Trusthub.V1.CustomerProfile.CustomerProfilesEvaluations.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch specific Evaluation Instance.
Operation: FetchCustomerProfileEvaluation | Tags: TrusthubV1CustomerProfilesEvaluations
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Evaluations associated to the customer_profile resource.
Operation: ListCustomerProfileEvaluation | Tags: TrusthubV1CustomerProfilesEvaluations
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Evaluations associated to the customer_profile resource. (lazy auto-pagination).