Service for CustomerProfiles API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new Customer-Profile.
Delete a specific Customer-Profile.
Fetch a specific Customer-Profile instance.
Retrieve a list of all Customer-Profiles for an account.
Stream: Retrieve a list of all Customer-Profiles for an account. (lazy auto-pagination).
Updates a Customer-Profile in an account.
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Trusthub.V1.CustomerProfiles.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Customer-Profile.
Operation: CreateCustomerProfile | Tags: TrusthubV1CustomerProfiles
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Email | string | The email address that will receive updates when the Customer-Profile resource changes status. |
FriendlyName | string | The string that you assigned to describe the resource. |
PolicySid | string | The unique string of a policy that is associated to the Customer-Profile resource. |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
StatusCallback | string (uri) | The URL we call to inform your application of status changes. |
@spec delete(Twilio.Client.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Customer-Profile.
Operation: DeleteCustomerProfile | Tags: TrusthubV1CustomerProfiles
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Trusthub.V1.CustomerProfiles.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Customer-Profile instance.
Operation: FetchCustomerProfile | Tags: TrusthubV1CustomerProfiles
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Customer-Profiles for an account.
Operation: ListCustomerProfile | Tags: TrusthubV1CustomerProfiles
Query Parameters
| Parameter | Type | Description |
|---|---|---|
Status | string | The verification status of the Customer-Profile resource. |
FriendlyName | string | The string that you assigned to describe the resource. |
PolicySid | string | The unique string of a policy that is associated to the Customer-Profile resource. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Customer-Profiles for an account. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Trusthub.V1.CustomerProfiles.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Updates a Customer-Profile in an account.
Operation: UpdateCustomerProfile | Tags: TrusthubV1CustomerProfiles
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Email | string | The email address that will receive updates when the Customer-Profile resource changes status. |
FriendlyName | string | The string that you assigned to describe the resource. |
Status | string | Values: draft, pending-review, in-review, twilio-rejected, twilio-approved |
StatusCallback | string (uri) | The URL we call to inform your application of status changes. |