Twilio.Trusthub.V1.TrustProduct.TrustProductsEvaluationsService
(twilio_elixir v0.1.1)
Service for TrustProductsEvaluations API operations.
Operations: list, create, fetch
Summary
Functions
Create a new Evaluation
Fetch specific Evaluation Instance.
Retrieve a list of Evaluations associated to the trust_product resource.
Stream: Retrieve a list of Evaluations associated to the trust_product resource. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Trusthub.V1.TrustProduct.TrustProductsEvaluations.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Evaluation
Operation: CreateTrustProductEvaluation | Tags: TrusthubV1TrustProductsEvaluations
Required Parameters
| Parameter | Type | Description |
|---|---|---|
PolicySid | string | The unique string of a policy that is associated to the customer_profile resource. |
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Trusthub.V1.TrustProduct.TrustProductsEvaluations.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch specific Evaluation Instance.
Operation: FetchTrustProductEvaluation | Tags: TrusthubV1TrustProductsEvaluations
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of Evaluations associated to the trust_product resource.
Operation: ListTrustProductEvaluation | Tags: TrusthubV1TrustProductsEvaluations
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of Evaluations associated to the trust_product resource. (lazy auto-pagination).