Twilio.Verify.V2.Service.Entity.Challenge.NotificationService
(twilio_elixir v0.1.1)
Service for Notification API operations.
Operations: create
Summary
Functions
Create a new Notification for the corresponding Challenge
Functions
@spec create(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.Entity.Challenge.Notification.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Notification for the corresponding Challenge
Operation: CreateNotification | Tags: VerifyV2Notification
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Ttl | integer | How long, in seconds, the notification is valid. Can be an integer between 0 and 300. Default is 300. Delivery is attempted until the TTL elapses, even if the device is offline. 0 means that the notification delivery is attempted immediately, only once, and is not stored for future delivery. |