Service for Entity API operations.
Operations: list, create, fetch, delete
Summary
Functions
Create a new Entity for the Service
Delete a specific Entity.
Fetch a specific Entity.
Retrieve a list of all Entities for a Service.
Stream: Retrieve a list of all Entities for a Service. (lazy auto-pagination).
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.Entity.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Entity for the Service
Operation: CreateEntity | Tags: VerifyV2Entity
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Identity | string | The unique external identifier for the Entity of the Service. This identifier should be immutable, not PII, length between 8 and 64 characters, and generated by your external system, such as your user's UUID, GUID, or SID. It can only contain dash (-) separated alphanumeric characters. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Entity.
Operation: DeleteEntity | Tags: VerifyV2Entity
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.Entity.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Entity.
Operation: FetchEntity | Tags: VerifyV2Entity
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Entities for a Service.
Operation: ListEntity | Tags: VerifyV2Entity
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Entities for a Service. (lazy auto-pagination).