Twilio.Verify.V2.Service.Passkey.VerifyFactorService
(twilio_elixir v0.1.1)
Service for VerifyFactor API operations.
Operations: create
Summary
Functions
Verify a Passkeys Factor
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Verify a Passkeys Factor
Operation: UpdatePasskeysFactor
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| response | object | The result of a WebAuthn credential registration via navigator.credentials.create(), as specified in AuthenticatorAttestationResponse. |
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
authenticatorAttachment | string | A string that indicates the mechanism by which the WebAuthn implementation is attached to the authenticator at the time the associated navigator.credentials.create() or navigator.credentials.get() call completes. Values: platform, cross-platform |
id | string | A base64url encoded representation of rawId. |
rawId | string | The globally unique identifier for this PublicKeyCredential. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| type | string | The valid credential types supported by the API. The values of this enumeration are used for versioning the AuthenticatorAssertion and AuthenticatorAttestation structures according to the type of the authenticator. Values: public-key |