Service for Bucket API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new Bucket for a Rate Limit
Delete a specific Bucket.
Fetch a specific Bucket.
Retrieve a list of all Buckets for a Rate Limit.
Stream: Retrieve a list of all Buckets for a Rate Limit. (lazy auto-pagination).
Update a specific Bucket.
Functions
@spec create(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.Bucket.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Bucket for a Rate Limit
Operation: CreateBucket | Tags: VerifyV2Bucket
Required Parameters
| Parameter | Type | Description |
|---|---|---|
Interval | integer | Number of seconds that the rate limit will be enforced over. |
Max | integer | Maximum number of requests permitted in during the interval. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Bucket.
Operation: DeleteBucket | Tags: VerifyV2Bucket
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.Bucket.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Bucket.
Operation: FetchBucket | Tags: VerifyV2Bucket
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Buckets for a Rate Limit.
Operation: ListBucket | Tags: VerifyV2Bucket
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Buckets for a Rate Limit. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.Bucket.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a specific Bucket.
Operation: UpdateBucket | Tags: VerifyV2Bucket
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Interval | integer | Number of seconds that the rate limit will be enforced over. |
Max | integer | Maximum number of requests permitted in during the interval. |