Service for RateLimit API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new Rate Limit for a Service
Delete a specific Rate Limit.
Fetch a specific Rate Limit.
Retrieve a list of all Rate Limits for a service.
Stream: Retrieve a list of all Rate Limits for a service. (lazy auto-pagination).
Update a specific Rate Limit.
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Rate Limit for a Service
Operation: CreateRateLimit | Tags: VerifyV2RateLimit
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UniqueName | string | Provides a unique and addressable name to be assigned to this Rate Limit, assigned by the developer, to be optionally used in addition to SID. This value should not contain PII. |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Description | string | Description of this Rate Limit |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Rate Limit.
Operation: DeleteRateLimit | Tags: VerifyV2RateLimit
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Rate Limit.
Operation: FetchRateLimit | Tags: VerifyV2RateLimit
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Rate Limits for a service.
Operation: ListRateLimit | Tags: VerifyV2RateLimit
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Rate Limits for a service. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.RateLimit.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Update a specific Rate Limit.
Operation: UpdateRateLimit | Tags: VerifyV2RateLimit
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Description | string | Description of this Rate Limit |