Service for VerificationCheck API operations.
Operations: create
Summary
Functions
challenge a specific Verification Check.
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.VerificationCheck.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
challenge a specific Verification Check.
Operation: CreateVerificationCheck | Tags: VerifyV2VerificationCheck
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Amount | string | The amount of the associated PSD2 compliant transaction. Requires the PSD2 Service flag enabled. |
Code | string | The 4-10 character string being verified. |
Payee | string | The payee of the associated PSD2 compliant transaction. Requires the PSD2 Service flag enabled. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| SnaClientToken | string | A sna client token received in sna url invocation response needs to be passed in Verification Check request and should match to get successful response. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| To | string | The phone number or email to verify. Either this parameter or the verification_sid must be specified. Phone numbers must be in E.164 format. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| VerificationSid | string | A SID that uniquely identifies the Verification Check. Either this parameter or the to phone number/email must be specified. |