Service for Webhook API operations.
Operations: list, create, fetch, update, delete
Summary
Functions
Create a new Webhook for the Service
Delete a specific Webhook.
Fetch a specific Webhook.
Retrieve a list of all Webhooks for a Service.
Stream: Retrieve a list of all Webhooks for a Service. (lazy auto-pagination).
Operation: UpdateWebhook | Tags: VerifyV2Webhook
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Create a new Webhook for the Service
Operation: CreateWebhook | Tags: VerifyV2Webhook
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| EventTypes | array | The array of events that this Webhook is subscribed to. Possible event types: *, factor.deleted, factor.created, factor.verified, challenge.approved, challenge.denied |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
FriendlyName | string | The string that you assigned to describe the webhook. This value should not contain PII. |
WebhookUrl | string | The URL associated with this Webhook. |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Status | string | Values: enabled, disabled |
Version | string | Values: v1, v2 |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete a specific Webhook.
Operation: DeleteWebhook | Tags: VerifyV2Webhook
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Fetch a specific Webhook.
Operation: FetchWebhook | Tags: VerifyV2Webhook
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve a list of all Webhooks for a Service.
Operation: ListWebhook | Tags: VerifyV2Webhook
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve a list of all Webhooks for a Service. (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Verify.V2.Service.Webhook.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateWebhook | Tags: VerifyV2Webhook
Optional Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| EventTypes | array | The array of events that this Webhook is subscribed to. Possible event types: *, factor.deleted, factor.created, factor.verified, challenge.approved, challenge.denied |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
FriendlyName | string | The string that you assigned to describe the webhook. This value should not contain PII. |
Status | string | Values: enabled, disabled |
Version | string | Values: v1, v2 |
WebhookUrl | string | The URL associated with this Webhook. |