Service for Template API operations.
Operations: list
Summary
Functions
List all the available templates for a given Account.
Stream: List all the available templates for a given Account. (lazy auto-pagination).
Functions
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
List all the available templates for a given Account.
Operation: ListVerificationTemplate | Tags: VerifyV2Template
Query Parameters
| Parameter | Type | Description |
|---|---|---|
FriendlyName | string | String filter used to query templates with a given friendly name. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: List all the available templates for a given Account. (lazy auto-pagination).