Twilio.Video.V1.RecordingSetting.RecordingSettingsService
(twilio_elixir v0.1.1)
Recording settings
Operations: fetch, update
Summary
Functions
Operation: FetchRecordingSettings | Tags: VideoV1RecordingSettings
Operation: CreateRecordingSettings | Tags: VideoV1RecordingSettings
Functions
@spec fetch( Twilio.Client.t(), keyword() ) :: {:ok, Twilio.Resources.Video.V1.RecordingSetting.RecordingSettings.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchRecordingSettings | Tags: VideoV1RecordingSettings
@spec update(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Video.V1.RecordingSetting.RecordingSettings.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateRecordingSettings | Tags: VideoV1RecordingSettings
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource and be shown to users in the console |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
AwsCredentialsSid | string | The SID of the stored Credential resource. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| AwsS3Url | string (uri) | The URL of the AWS S3 bucket where the recordings should be stored. We only support DNS-compliant URLs like https://documentation-example-twilio-bucket/recordings, where recordings is the path in which you want the recordings to be stored. This URL accepts only URI-valid characters, as described in the RFC 3986. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| AwsStorageEnabled | boolean | Whether all recordings should be written to the aws_s3_url. When false, all recordings are stored in our cloud. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
EncryptionEnabled | boolean | Whether all recordings should be stored in an encrypted form. The default is false. |
EncryptionKeySid | string | The SID of the Public Key resource to use for encryption. |