Twilio.Video.V1.Room.Participant.PublishedTrackService
(twilio_elixir v0.1.1)
Service for PublishedTrack API operations.
Operations: list, fetch
Summary
Functions
Returns a single Track resource represented by TrackName or SID.
Stream: Returns a list of tracks associated with a given Participant. Only currently Published Tracks are in the list resource. (lazy auto-pagination).
Functions
@spec fetch(Twilio.Client.t(), String.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Video.V1.Room.Participant.PublishedTrack.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Returns a single Track resource represented by TrackName or SID.
Operation: FetchRoomParticipantPublishedTrack | Tags: VideoV1PublishedTrack
@spec list(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Returns a list of tracks associated with a given Participant. Only currently Published Tracks are in the list resource.
Operation: ListRoomParticipantPublishedTrack | Tags: VideoV1PublishedTrack
@spec stream(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: Returns a list of tracks associated with a given Participant. Only currently Published Tracks are in the list resource. (lazy auto-pagination).