Participants in video rooms
Operations: list, fetch, update
Summary
Functions
Operation: FetchRoomParticipant | Tags: VideoV1Participant
Operation: ListRoomParticipant | Tags: VideoV1Participant
Stream: (lazy auto-pagination).
Operation: UpdateRoomParticipant | Tags: VideoV1Participant
Functions
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Video.V1.Room.Participant.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchRoomParticipant | Tags: VideoV1Participant
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListRoomParticipant | Tags: VideoV1Participant
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Status | string | Read only the participants with this status. Can be: connected or disconnected. For in-progress Rooms the default Status is connected, for completed Rooms only disconnected Participants are returned. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Identity | string | Read only the Participants with this User identity value. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateCreatedAfter | string (date-time) | Read only Participants that started after this date in ISO 8601 format. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| DateCreatedBefore | string (date-time) | Read only Participants that started before this date in ISO 8601 format. |
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Video.V1.Room.Participant.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateRoomParticipant | Tags: VideoV1Participant
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Status | string | Values: connected, disconnected, reconnecting |