Service for Call API operations.
Operations: delete
Summary
Functions
Delete an archived call record from Bulk Export. Note: this does not also delete the record from the Voice API.
Functions
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Delete an archived call record from Bulk Export. Note: this does not also delete the record from the Voice API.
Operation: DeleteArchivedCall | Tags: VoiceV1ArchivedCall