Twilio.Voice.V1.ConnectionPolicy.ConnectionPolicyTargetService
(twilio_elixir v0.1.1)
Network element entry points into your communications infrastructure
Operations: list, create, fetch, update, delete
Summary
Functions
Operation: CreateConnectionPolicyTarget | Tags: VoiceV1ConnectionPolicyTarget
Operation: DeleteConnectionPolicyTarget | Tags: VoiceV1ConnectionPolicyTarget
Operation: FetchConnectionPolicyTarget | Tags: VoiceV1ConnectionPolicyTarget
Operation: ListConnectionPolicyTarget | Tags: VoiceV1ConnectionPolicyTarget
Stream: (lazy auto-pagination).
Operation: UpdateConnectionPolicyTarget | Tags: VoiceV1ConnectionPolicyTarget
Functions
@spec create(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Voice.V1.ConnectionPolicy.ConnectionPolicyTarget.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: CreateConnectionPolicyTarget | Tags: VoiceV1ConnectionPolicyTarget
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Target | string (uri) | The SIP address you want Twilio to route your calls to. This must be a sip: schema. sips is NOT supported. |
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Enabled | boolean | Whether the Target is enabled. The default is true. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It is not unique and can be up to 255 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Priority | integer | The relative importance of the target. Can be an integer from 0 to 65535, inclusive, and the default is 10. The lowest number represents the most important target. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Weight | integer | The value that determines the relative share of the load the Target should receive compared to other Targets with the same priority. Can be an integer from 1 to 65535, inclusive, and the default is 10. Targets with higher values receive more load than those with lower ones with the same priority. |
@spec delete(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, map()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: DeleteConnectionPolicyTarget | Tags: VoiceV1ConnectionPolicyTarget
@spec fetch(Twilio.Client.t(), String.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Voice.V1.ConnectionPolicy.ConnectionPolicyTarget.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: FetchConnectionPolicyTarget | Tags: VoiceV1ConnectionPolicyTarget
@spec list(Twilio.Client.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: ListConnectionPolicyTarget | Tags: VoiceV1ConnectionPolicyTarget
@spec stream(Twilio.Client.t(), String.t(), map(), keyword()) :: Enumerable.t()
Stream: (lazy auto-pagination).
@spec update(Twilio.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, Twilio.Resources.Voice.V1.ConnectionPolicy.ConnectionPolicyTarget.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Operation: UpdateConnectionPolicyTarget | Tags: VoiceV1ConnectionPolicyTarget
Optional Parameters
| Parameter | Type | Description |
|---|---|---|
Enabled | boolean | Whether the Target is enabled. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| FriendlyName | string | A descriptive string that you create to describe the resource. It is not unique and can be up to 255 characters long. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Priority | integer | The relative importance of the target. Can be an integer from 0 to 65535, inclusive. The lowest number represents the most important target. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Target | string (uri) | The SIP address you want Twilio to route your calls to. This must be a sip: schema. sips is NOT supported. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| Weight | integer | The value that determines the relative share of the load the Target should receive compared to other Targets with the same priority. Can be an integer from 1 to 65535, inclusive. Targets with higher values receive more load than those with lower ones with the same priority. |