Twilio.Voice.V1.DialingPermission.BulkCountryUpdateService
(twilio_elixir v0.1.1)
Service for BulkCountryUpdate API operations.
Operations: create
Summary
Functions
@spec create(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Resources.Voice.V1.DialingPermission.BulkCountryUpdate.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
Create a bulk update request to change voice dialing country permissions of one or more countries identified by the corresponding ISO country code
Operation: CreateDialingPermissionsCountryBulkUpdate | Tags: VoiceV1BulkCountryUpdate
Required Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| UpdateRequest | string | URL encoded JSON array of update objects. example : [ { "iso_code": "GB", "low_risk_numbers_enabled": "true", "high_risk_special_numbers_enabled":"true", "high_risk_tollfraud_numbers_enabled": "false" } ] |