Service for Country API operations.
Operations: list, fetch
Summary
Functions
Retrieve voice dialing country permissions identified by the given ISO country code
Retrieve all voice dialing country permissions for this account
Stream: Retrieve all voice dialing country permissions for this account (lazy auto-pagination).
Functions
@spec fetch(Twilio.Client.t(), String.t(), keyword()) :: {:ok, Twilio.Resources.Voice.V1.DialingPermission.Country.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve voice dialing country permissions identified by the given ISO country code
Operation: FetchDialingPermissionsCountry | Tags: VoiceV1Country
@spec list(Twilio.Client.t(), map(), keyword()) :: {:ok, Twilio.Page.t()} | {:ok, map(), map()} | :ok | {:error, Twilio.Error.t()}
Retrieve all voice dialing country permissions for this account
Operation: ListDialingPermissionsCountry | Tags: VoiceV1Country
Query Parameters
| Parameter | Type | Description |
|---|
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
IsoCode | string (iso-country-code) | Filter to retrieve the country permissions by specifying the ISO country code |
Continent | string | Filter to retrieve the country permissions by specifying the continent |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| CountryCode | string | Filter the results by specified country codes |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| LowRiskNumbersEnabled | boolean | Filter to retrieve the country permissions with dialing to low-risk numbers enabled. Can be: true or false. |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| HighRiskSpecialNumbersEnabled | boolean | Filter to retrieve the country permissions with dialing to high-risk special service numbers enabled. Can be: true or false |
credo:disable-for-next-line Credo.Check.Readability.MaxLineLength
| HighRiskTollfraudNumbersEnabled | boolean | Filter to retrieve the country permissions with dialing to high-risk toll fraud numbers enabled. Can be: true or false. |
@spec stream(Twilio.Client.t(), map(), keyword()) :: Enumerable.t()
Stream: Retrieve all voice dialing country permissions for this account (lazy auto-pagination).